(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    493883,      18898]*)
(*NotebookOutlinePosition[    520482,      19771]*)
(*  CellTagsIndexPosition[    520438,      19767]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\[IndentingNewLine]\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  " Cylinders through five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]]
}], "Title",
  TextAlignment->Center],

Cell[TextData[StyleBox["Daniel Lichtblau\nMay 2004",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]], "Author",
  TextAlignment->Center],

Cell["\<\
Wolfram Research, Inc.
100 Trade Centre Dr.
Champaign, IL 61820
danl@wolfram.com\
\>", "Address"],

Cell[TextData[{
  StyleBox["Abstract.",
    FontWeight->"Bold"],
  " We address the following question: Given five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ", determine a right circular cylinder containing those points. We obtain \
algebraic equations for the axial line and radius parameters and show that \
these give six solutions in the generic case. An even number (0, 2, 4, or 6) \
will be real valued and hence correspond to actual cylinders in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ". Of these possibilities we will see that none is nongeneric; there are  \
sets with nonempty interiors in the configuration space that give rise to \
each case. We will also investigate several computational and theoretical \
issues related to this problem. In particular we will show how \
Gr\[ODoubleDot]bner bases and equation solving techniques may be used to \
advantage in pursuit of this and related problems.\n",
  "\n",
  "2000 Mathematics Subject Classification: 14N10, 14Q10, 51N20, 52A15, \
65C05, 65H10, 68U20.",
  "\n\n",
  "Key words and phrases: Computational geometry, enumerative geometry, Gr\
\[ODoubleDot]bner bases, nonlinear systems of equations."
}], "Abstract"],

Cell[CellGroupData[{

Cell["1. Outline of the problem", "Section"],

Cell[TextData[{
  "Given five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ", we are to determine all right circular cylinders containing those \
points. We will do this by using the input data to set up and solve equations \
for the axial line and radius parameters. We will see that generically one \
obtains six solutions to these equations. Not surprisingly, an even number of \
the six must be real valued, as the complex valued ones appear in conjugate \
pairs. Moreover there are open regions in the real configuration space that \
give each of these possibilities and hence none are generically disallowed. \
In the sequel we frequently use the term \"real cylinders\" to denote real \
valued solutions to the cylinder equations that arise from a given \
configuration of five points. Sometimes we refer to arbitrary solutions as \
\"cylinders\" even if they have complex values. The meaning should be clear \
from context. As worded the problem appears to dwell in the realm of \
enumerative geometry, but note that it may be recast in a computational \
geometry setting: Given five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ", find the smallest ",
  Cell[BoxData[
      \(r\)],
    FontSlant->"Italic"],
  " and orientation parameters such that the cylinder of radius ",
  Cell[BoxData[
      RowBox[{"2", " ", 
        StyleBox["r",
          FontSlant->"Italic"]}]]],
  " with those parameters encloses tangentially the balls of radius ",
  Cell[BoxData[
      \(r\)],
    FontSlant->"Italic"],
  " centered at the points. Several related topics we discuss will also have \
computational geometry intepretations."
}], "Text"],

Cell[TextData[{
  "We will discuss both approximate and exact computational methods for \
finding the (real or complex) cylinders. We show how certain specific \
configurations give rise to open sets in our domain for which we obtain the \
extreme cases, that is, either zero or six real cylinders. Here are a few of \
the related questions we will consider.\n(1) Given the points and \
corresponding cylinder parameters, how might we display them graphically?\n\
(2) Given the cylinder parameters, how may we obtain its implicit equation as \
a hypersurface in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  "?\n(3) Reversing this, how can one obtain parameters from the implicit \
form?\n(4) Given six or more points, how do we find the coordinates of a \
(generically unique) cylinder in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " that \"best\" fits those points?\n(5) Given five points chosen with \
random uniform distribution in a cube, what is the expected probability that \
one lies inside the convex hull of the other four (this is related to the \
\"no real cylinder\" case)."
}], "Text"],

Cell[TextData[{
  "Some of the material below was posted in response to a Usenet news group \
query on this topic [24]. Related techniques and results were similarly \
presented by Dave Rusin [29]. That one obtains six cylinders was previously \
demonstrated in [5], though by rather different means. Independent of this \
work, similar theory is developed in [13]. A related problem, finding \
cylinders of a given radius through four given points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ", is discussed in [15] and [26]. A nice survey of computational \
commutative algebra methods that are applicable to nonlinear problems in \
computational geometry can be found in [7]. Another good general treatment of \
theoretical and practical aspects of using Gr\[ODoubleDot]bner bases in \
computational geometry is chapter 7 of [18]. Computations in the sequel were \
performed with the version of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " [33] under development at the time of this writing (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (TM) is a registered trademark of Wolfram Research, Incorporated). Most \
were done on a 1.4 GHz Athelon machine under Linux."
}], "Text"],

Cell["\<\
The remainder of this paper is structured as follows. In section 2 \
we present several computational sides to the problem. These include finding \
and counting cylinder solutions. In section 3 we handle various associated \
computational geometry problems, and basics of point/cylinder visualization. \
Considerable attention is given to the ways in which these specialized \
methods intersect computational mathematics in general. Section 4 delves into \
the frequencies of real cylinders containing suitably random point sets. \
These investigations are again largely computational, though we relate some \
to a recent result in integral geometry. In section 5 we state and prove \
several theorems regarding the enumerative geometry of the problem. Following \
that are summary and acknowledgements.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Computing cylinders through five points", "Section"],

Cell[CellGroupData[{

Cell["Finding cylinder parameters from a set of 5 points", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell["\<\
We will assume unless otherwise stated that our points are generic. \
In particular, no three are collinear, no four are coplanar, cylinder axes do \
not lie in coordinate planes, and so forth. These assumptions allow us to \
avoid avoid computational complexity that would arise from parametrizing \
axial directions using a sphere (this gives rise to two problems: we have one \
extra variable, and so to eliminate it we would add an equation that \
normalizes the direction. Moreover we would double the size of our solution \
set because any direction is equivalent to its negative). Given these \
stipulations we proceed as follows. \
\>", "Text"],

Cell[TextData[{
  "With our assumptions in place, given a cylinder axis line ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  " in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " we may parametrize it as ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            StyleBox["y",
              FontSlant->"Italic"], "=", 
            RowBox[{
              RowBox[{
                StyleBox["a",
                  FontSlant->"Italic"], " ", 
                StyleBox["x",
                  FontSlant->"Italic"]}], "+", 
              StyleBox["b",
                FontSlant->"Italic"]}]}], ",", 
          RowBox[{
            StyleBox["z",
              FontSlant->"Italic"], "=", 
            RowBox[{
              StyleBox[\(c\ x\),
                FontSlant->"Italic"], "+", 
              StyleBox["d",
                FontSlant->"Italic"]}]}]}], "}"}]]],
  ". Given ",
  Cell[BoxData[
      RowBox[{
        StyleBox["r",
          FontSlant->"Italic"], ">", "0"}]]],
  " there is a unique circular cylinder ",
  Cell[BoxData[
      StyleBox["C",
        FontSlant->"Italic"]]],
  " of radius ",
  Cell[BoxData[
      \(r\)],
    FontSlant->"Italic"],
  " with center axis ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  ". Supposing we have five points on that cylinder the following questions \
now arise. How do we find ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      StyleBox["r",
        FontSlant->"Italic"]]],
  "? How do we use them to parametrize ",
  Cell[BoxData[
      StyleBox["C",
        FontSlant->"Italic"]]],
  " e.g. for purposes of plotting it? Why do we even expect this will \
determine finitely many cylinders?"
}], "Text"],

Cell[TextData[{
  "This last is answered as follows. Given a point on ",
  Cell[BoxData[
      StyleBox["C",
        FontSlant->"Italic"]]],
  " we will project orthogonally onto ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  " in order to get an equation involving the parameters we wish to find. We \
have five parameters to determine in the ",
  "setup",
  " used above, and each point will give us an algebraic equation of the form \
",
  Cell[BoxData[
      RowBox[{\(\[LeftDoubleBracketingBar]perp\[RightDoubleBracketingBar]\^2\)\
, "=", 
        SuperscriptBox[
          StyleBox["r",
            FontSlant->"Italic"], "2"]}]]],
  ". For generic choice of points the equations should be algebraically \
independent, hence the dimension of the solution set would be zero. In more \
detail, if we take five points with indeterminate coordinates (that is, \
coordinates expressed as variables) then we obtain a system of five equations \
of the form ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(f\_j\),
            FontSlant->"Italic"], "[", 
          RowBox[{
            StyleBox["a",
              FontSlant->"Italic"], ",", 
            StyleBox["b",
              FontSlant->"Italic"], ",", 
            StyleBox["c",
              FontSlant->"Italic"], ",", 
            StyleBox["d",
              FontSlant->"Italic"], ",", 
            StyleBox["r",
              FontSlant->"Italic"]}], "]"}], "=", "0"}]]],
  " for which we want to solve for the cylinder parameters in terms of the \
coordinates. To show there are finitely many solutions it suffices by the \
implicit function theorem to show that the Jacobian of the map ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox[\(f\_1\),
            FontSlant->"Italic"], ",", 
          StyleBox[\(f\_2\),
            FontSlant->"Italic"], ",", 
          StyleBox[\(f\_3\),
            FontSlant->"Italic"], ",", 
          StyleBox[\(f\_4\),
            FontSlant->"Italic"], ",", 
          StyleBox[\(f\_5\),
            FontSlant->"Italic"]}], "}"}]]],
  " has full rank for these generic coordinates. One can do this explicitly \
by finding the symbolic Jacobian, plugging in random values for the \
coordinates, and checking that the resulting matrix has full rank. We will \
instead show a computation in the last section that demonstrates there are \
generically at most nine solutions. Simple reasoning will further reduce this \
to eight. Following that is a more elaborate  proof that the actual number is \
six."
}], "Text"],

Cell[TextData[{
  "Let us demonstrate how to solve for the cylinder parameters with a \
specific example. We will take as our parameter values ",
  Cell[BoxData[
      RowBox[{
        StyleBox["a",
          FontSlant->"Italic"], "=", "3"}]]],
  ", ",
  Cell[BoxData[
      RowBox[{
        StyleBox["b",
          FontSlant->"Italic"], "=", "2"}]]],
  ", ",
  Cell[BoxData[
      RowBox[{
        StyleBox["c",
          FontSlant->"Italic"], "=", "4"}]]],
  ", ",
  Cell[BoxData[
      RowBox[{
        StyleBox["d",
          FontSlant->"Italic"], "=", \(-1\)}]]],
  ",and ",
  Cell[BoxData[
      RowBox[{
        StyleBox["r",
          FontSlant->"Italic"], "=", \(\@21\)}]]],
  "."
}], "Text"],

Cell[TextData[{
  "The locus of points on ",
  Cell[BoxData[
      StyleBox["C",
        FontSlant->"Italic"]]],
  " is obtained as sums of a vector on ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  " plus a vector of length ",
  Cell[BoxData[
      \(r\)],
    FontSlant->"Italic"],
  " perpendicular to ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  ". All vectors perpendicular to ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  " are spanned by any independent pair. We can obtain an orthonormal pair ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          OverscriptBox[
            StyleBox[\(w\_1\),
              FontSlant->"Italic"], "\[RightArrow]"], ",", 
          OverscriptBox[
            StyleBox[\(w\_2\),
              FontSlant->"Italic"], "\[RightArrow]"]}], "}"}]]],
  " in the standard way by finding the null space to the matrix whose one row \
is the vector along the axial direction, that is, ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["vec",
            FontSlant->"Italic"], "\[RightArrow]"], "=", 
        RowBox[{"{", 
          RowBox[{"1", ",", 
            StyleBox["a",
              FontSlant->"Italic"], ",", 
            StyleBox["c",
              FontSlant->"Italic"]}], "}"}]}]]],
  ", and then using Gram\[Hyphen]Schmidt to orthogonalize that pair."
}], "Text"],

Cell[TextData[{
  "We will then select five \"random\" points on ",
  Cell[BoxData[
      StyleBox["C",
        FontSlant->"Italic"]]],
  ". We do this by selecting five values for an axial vector scale factor ",
  Cell[BoxData[
      \(x\)],
    FontSlant->"Italic"],
  " and five values for an angle ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " such that ",
  Cell[BoxData[
      \(0 \[LessEqual] \[Theta] \[LessEqual] 2\ \[Pi]\)]],
  ". Our points will be of the form ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["v",
            FontSlant->"Italic"], "\[RightArrow]"], "+", 
        OverscriptBox[
          StyleBox["w",
            FontSlant->"Italic"], "\[RightArrow]"]}]]],
  " where "
}], "Text"],

Cell[BoxData[
    RowBox[{\(v\& \[RightArrow] \), "=", 
      RowBox[{
        RowBox[{"x", " ", 
          OverscriptBox[
            StyleBox["vec",
              FontSlant->"Italic"], "\[RightArrow]"]}], "+", 
        OverscriptBox[
          StyleBox["offset",
            FontSlant->"Italic"], "\[RightArrow]"]}]}]], "DisplayFormula"],

Cell[BoxData[
    \(\(w\& \[RightArrow] \) = 
      r\ Cos[\[Theta]]\ \(\(w\_1\)\& \[RightArrow] \) + 
        r\ Sin[\[Theta]]\ \(\(\(w\_2\)\& \[RightArrow] \)\(.\)\)\)], \
"DisplayFormula"],

Cell["\<\
We will then show how to recover a set of cylinder parameters from \
these five points.\
\>", "Text"],

Cell[BoxData[{
    \(Off[General::spell1]\), "\[IndentingNewLine]", 
    \(Off[ParametricPlot3D::ppcom]\), "\[IndentingNewLine]", 
    \(Needs["\<LinearAlgebra`Orthogonalization`\>"]; \), \
"\[IndentingNewLine]", 
    \( (*Needs["\<Graphics`Colors`\>"]; *) \)}], "Input",
  CellLabel->"In[5]:=",
  CellOpen->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \({a, b, c, d, r} = {3, 2, 4, \(-1\), 
        Sqrt[21]}; \), "\[IndentingNewLine]", 
    \(vec = {1, a, c}; offset = {0, b, d}; \), "\[IndentingNewLine]", 
    \(pair = NullSpace[{vec}]; \), "\[IndentingNewLine]", 
    \({w1, w2} = GramSchmidt[pair]\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({{\(-\(4\/\@17\)\), 0, 
        1\/\@17}, {\(-\(3\/\@442\)\), \@\(17\/26\), \(-6\)\ \
\@\(2\/221\)}}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[BoxData[{
    \(SeedRandom[111111]; \), "\n", 
    \(xvals = Table[Random[Real, {\(-10\), 10}], {5}]; \), "\n", 
    \(thetas = Table[Random[Real, {0, 2\ \[Pi]}], {5}]; \), "\n", 
    \(points = 
      Table[xvals\[LeftDoubleBracket]j\[RightDoubleBracket]\ vec + offset + 
          r\ Cos[thetas\[LeftDoubleBracket]j\[RightDoubleBracket]]\ w1 + 
          r\ Sin[thetas\[LeftDoubleBracket]j\[RightDoubleBracket]]\ w2, {j, 
          5}]; \)}], "Input",
  CellLabel->"In[17]:="],

Cell[TextData[{
  "Given a point on ",
  Cell[BoxData[
      StyleBox["C",
        FontSlant->"Italic"]]],
  " we want to project orthogonally onto ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  ", to get an equation involving the parameters we wish to find. This cannot \
be done immediately because ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  " is not a subspace so we first translate our point by subtracting ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["offset",
          FontSlant->"Italic"], "\[RightArrow]"]]],
  ". We then project onto the line spanned by ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["vec",
          FontSlant->"Italic"], "\[RightArrow]"]]],
  ". Subtracting this projection from the translated vector gives us our ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["perp",
          FontSlant->"Italic"], "\[RightArrow]"]]],
  "."
}], "Text"],

Cell[BoxData[
    \(perp[vec1_, vec_, offset_] := 
      vec1 - offset - Projection[vec1 - offset, vec]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(perps = 
      Table[perp[points[\([\)\(j\)\(]\)], vec, offset], {j, 5}]; \)], "Input",\

  CellLabel->"In[22]:="],

Cell[TextData[{
  "One can readily check this by taking the five points and seeing that all \
perps have length\[Hyphen]squared equal to ",
  Cell[BoxData[
      \(21\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[# . # &, perps]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({21.000000000000007`, 21.000000000000007`, 21.`, 21.000000000000004`, 
      20.999999999999996`}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "When we use this point set to find ",
  Cell[BoxData[
      \(r\)],
    FontSlant->"Italic"],
  " and the parameters describing ",
  Cell[BoxData[
      \(L\)],
    FontSlant->"Italic"],
  " we will of course clear those that we set above so they become symbolic \
indeterminates. Using these points we will obtain the needed algebraic \
expressions for which we extract roots."
}], "Text"],

Cell[BoxData[{
    \(Clear[vec, offset, a, b, c, d, r]\), "\[IndentingNewLine]", 
    \(vec = {1, a, c}; offset = {0, b, d}; \), "\[IndentingNewLine]", 
    \(perps = 
      Map[perp[#, vec, offset] &, points]; \), "\[IndentingNewLine]", 
    \(exprs = Map[Numerator[Together[# . # - r^2]] &, perps]; \)}], "Input",
  CellLabel->"In[24]:="],

Cell["\<\
We can use numerical methods to find some roots. This is apparently \
very sensitive to initial conditions and often simply fails.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rt1 = 
      FindRoot[Evaluate[Thread[exprs \[Equal] 0]], {a, 3.4}, {b, 2.8}, {c, 
          3.7}, {d, \(-1.6\)}, {r, 3.3}, 
        MaxIterations \[Rule] 500]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({a \[Rule] 2.9999999999999982`, b \[Rule] 2.0000000000000497`, 
      c \[Rule] 4.`, d \[Rule] \(-0.9999999999999116`\), 
      r \[Rule] 4.582575694955832`}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rt2 = 
      FindRoot[Evaluate[Thread[exprs \[Equal] 0]], {a, 2.7}, {b, 1.8}, {c, 
          3.2}, {d, \(- .7\)}, {r, 3}, MaxIterations \[Rule] 500]\)], "Input",\

  CellLabel->"In[23]:="],

Cell[BoxData[
    \({a \[Rule] 1.9055462597449175`, b \[Rule] 7.088932735763867`, 
      c \[Rule] 2.481186134700685`, d \[Rule] 7.022338473142289`, 
      r \[Rule] \(-4.442099315061336`\)}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell["\<\
Here is another well known method to find numeric roots. We will \
sum the squares of the polynomials for which we just found zeroes and then \
minimize this sum. This too is sensitive to initial guesses.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(esquares = Apply[Plus, Map[#^2 &, exprs]]; \), "\[IndentingNewLine]", 
    \({m3, rt3} = 
      FindMinimum[
        Evaluate[esquares], {a, 2.4}, {b, 1.8}, {c, 3.2}, {d, \(- .8\)}, {r, 
          3}, MaxIterations \[Rule] 500, 
        Method \[Rule] LevenbergMarquardt]\)}], "Input"],

Cell[BoxData[
    \(FindMinimum::"fmlim" \(\(:\)\(\ \)\) 
      "The minimum could not be bracketed in \!\(500\) iterations."\)], \
"Message"],

Cell[BoxData[
    \({2.52308946451904`*^6, {a \[Rule] 0.17460682483199516`, 
        b \[Rule] \(-0.25752708016506126`\), c \[Rule] 0.21727752640039658`, 
        d \[Rule] \(-4.560640944382838`\), 
        r \[Rule] 6.935066850481429`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({m4, rt4} = 
      FindMinimum[
        Evaluate[esquares], {a, 2.4}, {b, 1.8}, {c, 2.2}, {d, \(-1.8\)}, {r, 
          3}, MaxIterations \[Rule] 500, 
        Method \[Rule] LevenbergMarquardt]\)], "Input"],

Cell[BoxData[
    \({3.616847228388113`*^-22, {a \[Rule] 1.905546259744919`, 
        b \[Rule] 7.088932735763862`, c \[Rule] 2.481186134700687`, 
        d \[Rule] 7.022338473142274`, 
        r \[Rule] 4.442099315061334`}}\)], "Output"]
}, Open  ]],

Cell["\<\
Clearly the above methods are not terribly robust. Next we will \
show how to find cylinder parameters using a global solver for nonlinear \
algebraic systems of equations.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solving simultaneously for all roots of the cylinder parameter \
equations\
\>", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell[TextData[{
  "An obvious drawback to the methods seen thus far is the need for good \
initial guesses. We may instead take advantage of the fact that the equations \
are all polynomial, and use a global solver suitable for such systems. We \
demonstrate below the utility of this approach. For simplicity we will only \
use integer coordinates. Specifically, we will take five points whose \
coordinates are all integers in the range ",
  Cell[BoxData[
      \({\(-10\), 10}\)]],
  ", and show how to find our parameter values. To simplify matters we will \
solve for the square of the radius this time. This will avoid solutions with \
negative values for ",
  Cell[BoxData[
      \(r\)],
    FontSlant->"Italic"],
  " as well as cut in half the number of complex valued solutions."
}], "Text"],

Cell[BoxData[{
    \(SeedRandom[1111]; \), "\n", 
    \(intpoints\  = \ 
      Table[Random[Integer, \ {\(-10\), 10}], \ {5}, \ {3}]; \), "\n", 
    \(perps\  = \ 
      Table[perp[intpoints[\([\)\(j\)\(]\)], \ vec, \ offset], \ {j, 
          5}]; \), "\n", 
    \(exprs\  = \ 
      Map[Numerator[Together[# . # - rsqr]] &, \ perps]; \)}], "Input",
  CellLabel->"In[33]:="],

Cell[TextData[{
  "Suprising though it may seem, it turns out to be computationally painless \
to get all solutions to this system, rather than just a particular solution. \
We do this with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(NSolve\)],
    FontWeight->"Bold"],
  " function, which uses a hybrid symbolic-numeric technique to efficiently \
find all roots. Explanations of this technology may be found in [9] [10] \
[25]."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[solns\  = \ NSolve[exprs, \ {a, b, c, d, rsqr}]]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \({0.26999999999999996`\ Second, {{a \[Rule] \(-1.0325259075825723`\) + 
              0.7603932771750517`\ \[ImaginaryI], 
          b \[Rule] \(\(6.113486801864835`\)\(\[InvisibleSpace]\)\) - 
              3.37419483081285`\ \[ImaginaryI], 
          c \[Rule] \(-0.3229311576392079`\) - 
              1.3776831086306327`\ \[ImaginaryI], 
          d \[Rule] \(-0.2954273706579208`\) + 
              6.870899763930675`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(344.24996789135207`\)\(\[InvisibleSpace]\)\) + 
              23.85542813864446`\ \[ImaginaryI]}, {a \[Rule] \
\(-1.0325259075825723`\) - 0.7603932771750517`\ \[ImaginaryI], 
          b \[Rule] \(\(6.113486801864835`\)\(\[InvisibleSpace]\)\) + 
              3.37419483081285`\ \[ImaginaryI], 
          c \[Rule] \(-0.3229311576392079`\) + 
              1.3776831086306327`\ \[ImaginaryI], 
          d \[Rule] \(-0.2954273706579208`\) - 
              6.870899763930675`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(344.24996789135207`\)\(\[InvisibleSpace]\)\) - 
              23.85542813864446`\ \[ImaginaryI]}, {a \[Rule] 
            30.93619063054792`, b \[Rule] 93.17198490700757`, 
          c \[Rule] 37.11856454050949`, d \[Rule] 92.70335932458393`, 
          rsqr \[Rule] 198.25814525146873`}, {a \[Rule] 0.1516349817800302`, 
          b \[Rule] \(-1.2574764323345713`\), c \[Rule] 1.5889682335326285`, 
          d \[Rule] \(-6.4504620534964685`\), 
          rsqr \[Rule] 
            83.05541588958086`}, {a \[Rule] \(\(0.613253377898699`\)\(\
\[InvisibleSpace]\)\) - 0.35933457831813814`\ \[ImaginaryI], 
          b \[Rule] \(-4.49777058703572`\) - 
              3.771322076075301`\ \[ImaginaryI], 
          c \[Rule] \(\(0.10293369139682847`\)\(\[InvisibleSpace]\)\) + 
              0.15985221448146145`\ \[ImaginaryI], 
          d \[Rule] \(-1.569794137120324`\) + 
              2.232748606080981`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(57.5606178134414`\)\(\[InvisibleSpace]\)\) + 
              13.753354443608522`\ \[ImaginaryI]}, {a \[Rule] \
\(\(0.613253377898699`\)\(\[InvisibleSpace]\)\) + 
              0.35933457831813814`\ \[ImaginaryI], 
          b \[Rule] \(-4.49777058703572`\) + 
              3.771322076075301`\ \[ImaginaryI], 
          c \[Rule] \(\(0.10293369139682847`\)\(\[InvisibleSpace]\)\) - 
              0.15985221448146145`\ \[ImaginaryI], 
          d \[Rule] \(-1.569794137120324`\) - 
              2.232748606080981`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(57.5606178134414`\)\(\[InvisibleSpace]\)\) - 
              13.753354443608522`\ \[ImaginaryI]}}}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
Actually we can get exact solutions in the same way, albeit at \
greater computational cost. This illustrates a sort of cascading \"hybrid\" \
algorithm: one starts with asymbolic-numeric method to handle numeric \
problems, then modifies it to give exact rather than approximate \
results.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      exactsolns\  = \ 
        NSolve[exprs, \ {a, b, c, d, rsqr}, 
          WorkingPrecision \[Rule] Infinity]; ]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({1.71`\ Second, Null}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["\<\
The solution set in exact form is a bit larger than merits \
printing:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeafCount[exactsolns]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(12139\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["\<\
We can improve considerably on the computational efficiency of \
finding cylinder parameters from five points. For one, a different \
formulation of the problem, to be utilized later, finds directions for which \
all points project onto the same circle in a plane perpendicular to the \
direction. Using this we can reduce the computational time by a substantial \
factor vs. the method shown above. \
\>", "Text"],

Cell[TextData[{
  "In addition to changing the formulation of the problem to one that is \
computationally easier, one might also change the solver method. We discuss \
one very efficient alternative. This is the sparse homotopy method described \
in [30]. Here one constructs a readily solved system using information from \
the Newton polytope. One then forms a homotopy to move from each solution of \
the first system to a solution of the new system. If we call the systems ",
  Cell[BoxData[
      \(F \((x)\)\)]],
  " and ",
  Cell[BoxData[
      \(G \((x)\)\)]],
  " respectively, where ",
  Cell[BoxData[
      RowBox[{"x", Cell[""]}]]],
  "denotes a vector of variables, then one adds a new variable, ",
  Cell[BoxData[
      \(t\)]],
  ", and sets up the homotopy between solutions in each set as a relation ",
  Cell[BoxData[
      \(\((1 - t)\) F \((x)\) + t\ G \((x)\) = 0\)]],
  ". At time ",
  Cell[BoxData[
      \(t = 0\)]],
  " we have a solution to the first system, and a time ",
  Cell[BoxData[
      \(t = 1\)]],
  " we have a solution to the new system. Techniques for moving along the \
homtopy path generally involve some sort of predictor\[Hyphen]corrector \
method to increment ",
  Cell[BoxData[
      \(t\)]],
  " by a small amount and then alter the coordinates of ",
  Cell[BoxData[
      \(x\)]],
  " to maintain the relation above; a general introduction to this method is \
presented in [23]. For our cylinder problem there is a nice refinement that \
goes by the name of the \"cheater's homotopy\" wherein we start with known \
solutions for one set of points and hence can skip the first step of the \
general approach. In order to find cylinder parameters for each subsequent \
set of points we simply use a homotopy appropriate for the new set of \
equations."
}], "Text"],

Cell["\<\
An occasional disadvantage to the general sparse homotopy technique \
is that in some cases one has fewer actual solutions than are given by the \
starting system. When this occurs, in the process of following the homotopies \
some must wander off to infinity. This can pose difficulties for the software \
in terms of deciding when a path is diverging rather than merely wandering \
afar prior to converging. As we will explain later, the sparse homotopy \
method will predict that there are eight solutions for cylinder parameters, \
two more than are actually present. Hence the cheater's homotopy is all the \
more appealing for this class of problems. It should be noted, however, that \
the general sparse method is far better at approximating the correct number \
of solutions than any predecessor approach based on homotopies, and moreover \
it tends to handle systems with far more solutions than can be successfully \
tackled by methods such as [9] that require computation of matrix \
eigensystems. See [31] for further details.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The size of the solution set", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell[TextData[{
  "In examples that use ",
  Cell[BoxData[
      \(NSolve\)],
    FontWeight->"Bold"],
  " we get six possibly complex valued solutions. To find out what is \
happening we will continue with the example above. We now form a \
(lexicographic) Gr\[ODoubleDot]bner basis for ",
  Cell[BoxData[
      \(exprs\)],
    FontSlant->"Italic"],
  ". This is a standard tactic for computational equation manipulation [1] \
[3] [6] [11] [17]. The idea is that it effectively triangulates the \
polynomial system in a manner that will become clear below. As we do not care \
about the ordering among the variables, we use the built in heuristic sorting \
algorithm (which was designed for the purpose of speed enhancement)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Timing[gb\  = \ GroebnerBasis[exprs, \ Sort \[Rule] True]; ]\), "\n", 
    \(gb[\([\)\(1\)\(]\)]\)}], "Input"],

Cell[BoxData[
    \({0.8799999999999955`\ Second, Null}\)], "Output"],

Cell[BoxData[
    \(\(-36556110913245\) + 220390657872336\ c - 1091903566289090\ c\^2 + 
      412701818100667\ c\^3 - 375539205226535\ c\^4 + 327695756151531\ c\^5 - 
      8563282997415\ c\^6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The coefficients are large so we will only show that first polynomial. It \
is also instructive to see the structure of the full set of polynomials. The \
code fragment below serves for this purpose. We see that the first polynomial \
is of degree ",
  Cell[BoxData[
      \(6\)]],
  " in the variable ",
  Cell[BoxData[
      \(c\)],
    FontSlant->"Italic"],
  " (as we already knew), and the rest are quintic in ",
  Cell[BoxData[
      \(c\)],
    FontSlant->"Italic"],
  " and linear in each of the respective other variables. So now we see what \
was meant by triangularizing the system. To solve it one could find the six \
roots in ",
  Cell[BoxData[
      \(c\)],
    FontSlant->"Italic"],
  " and back substitute each into the remaining equations in order to get six \
corresponding solutions in each of the remaining variables."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(list1 = 
      Map[Apply[List, #] &, gb] /. _Integer*x_ \[Rule] 
          x; \), "\[IndentingNewLine]", 
    \(list2 = Map[Cases[#, a_ /; \(! IntegerQ[a]\)] &, list1]\)}], "Input"],

Cell[BoxData[
    \({{c, c\^2, c\^3, c\^4, c\^5, c\^6}, {a, c, c\^2, c\^3, c\^4, c\^5}, {c, 
        c\^2, c\^3, c\^4, c\^5, d}, {b, c, c\^2, c\^3, c\^4, c\^5}, {c, c\^2, 
        c\^3, c\^4, c\^5, rsqr}}\)], "Output"]
}, Open  ]],

Cell["\<\
This tells us to expect six solutions in general. While a theorem \
and proof will be deferred until later, two reasons to believe this are \
offered below.\
\>", "Text"],

Cell["\<\
Reason 1: In the theory of lexicographic Gr\[ODoubleDot]bner bases \
there is a fact known as the Shape Lemma [2], which may be stated as follows. \
As is well known, a generic zero dimensional polynomial ideal over an \
infinite field is radical and in general position with respect to the last \
variable in any ordering of the variables. In other words, the variety has no \
multiplicity and moreover its finitely many points do not share any \
coordinates. The lemma states that under these circumstances any \
lexicographic Gr\[ODoubleDot]bner basis will have exactly one polynomial with \
leading term a pure product in each variable, all but the one in the smallest \
variable will be linear, and that one in the smallest variable will have \
degree equal to the size of the solution set. One interpretation of the Shape \
Lemma is almost a matter of philosophy: one proves the above fact given a \
radical ideal in general position, and then asserts that generic ideals \
satisfy these hypotheses. In addition to the Shape Lemma there is the \
following result: lexicographic Gr\[ODoubleDot]bner bases of ideals defined \
over rational function fields remain Gr\[ODoubleDot]bner bases after generic \
specialization of coefficients [16] [21]. In other words, there is a Zariski\
\[Hyphen]open set in the parameter space for which specializations do not \
alter the skeleton of the basis. We use these facts as follows: if our \
selection of coefficients was generic, we may conclude that the generic Gr\
\[ODoubleDot]bner basis has the same shape as that of the basis we just \
obtained. Moreover we may believe that our selection was generic because (i) \
it had the correct shape of a generic basis, and (ii) we chose the data at \
random from a fairly large set.\
\>", "Text"],

Cell["\<\
Reason 2: The simulation indicated below tested over 4000 randomly \
chosen configurations. Every one gave exactly six solutions, and this too \
strongly suggests that six is the generic value.\
\>", "Text"],

Cell["\<\
We will also use the results of these tests to say a bit about \
percentages of examples for which one obtains given numbers of real \
solutions.\
\>", "Text"],

Cell[TextData[{
  "One might ask why we do not simply compute a lexicographic basis for our \
system using generic coefficients. The answer is that it does not finish in \
finite time. Indeed, even making one coordinate a parameter leads to \
tremendous computational effort (nearly an hour on a ",
  StyleBox["Pentium 2",
    FontSlant->"Italic"],
  "  ",
  "333",
  StyleBox["Mh processor",
    FontVariations->{"CompatibilityType"->0}],
  ") and very large coefficients for the basis; polynomials in that parameter \
are of high degree with large integer coefficients."
}], "Text"],

Cell[TextData[{
  "Another thing to note is that Gr\[ODoubleDot]bner bases computations never \
leave their base field. In other words, if we begin with real data then the \
polynomials in the basis will have real coefficients. As we now know the form \
of the generic Gr\[ODoubleDot]bner basis for our systems, an immediate \
conclusion is that we will get complex solutions in pairs, and thus we might \
have zero, two, four, or six (real) cylinders in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ". In the case of the example above we have two."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Computational geometry of the solution cylinders", "Section"],

Cell[CellGroupData[{

Cell["\<\
Finding the implicit equation of a cylinder from its parametric \
form\
\>", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell[TextData[{
  "Given the parameters of a cylinder, it is natural to ask how one might \
obtain the implicit form. The first method we show, best described as \
\"applied brute force\", is from modern elimination theory. Some references \
for this technique are [1] [11] [18] [22]. We begin with equations for ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox["x",
            FontSlant->"Italic"], ",", 
          StyleBox["y",
            FontSlant->"Italic"], ",", 
          StyleBox["z",
            FontSlant->"Italic"]}], "}"}]]],
  " in terms of the five parameters and the sine and cosine of an \
(unrestricted) angular parameter. In more detail, we have a parametrization \
for the cylinder in terms of a scalar multiplier ",
  Cell[BoxData[
      \(t\)],
    FontSlant->"Italic"],
  " for the direction vector ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["vec",
          FontSlant->"Italic"], "\[RightArrow]"]]],
  " and an angle ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " to determine a unit vector in the plane orthogonal to ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["vec",
          FontSlant->"Italic"], "\[RightArrow]"]]],
  ". To make this parametrization algebraic we can use the usual pair of \
trigonometric functions, abbreviated below as (algebraic variables) ",
  Cell[BoxData[
      \(sin\)],
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      StyleBox["cos",
        FontSlant->"Italic"]]],
  ". This gives one parameter more but of course we also now have the \
polynomial ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox["cos",
            FontSlant->"Italic"], "2"], "+", 
        SuperscriptBox[
          StyleBox["sin",
            FontSlant->"Italic"], "2"], "-", "1"}]]],
  ". We use a standard Gr\[ODoubleDot]bner basis method for elimination of \
variables, which involves a term ordering that is typically efficient for \
partially triangularizing the polynomials. In particular it weights terms \
that involve any of the elimination variables higher than all other terms. We \
form a Gr\[ODoubleDot]bner basis with respect to such an ordering and remove \
all polynomials that contain any of the elimination variables ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox["t",
            FontSlant->"Italic"], ",", 
          StyleBox["sin",
            FontSlant->"Italic"], ",", 
          StyleBox["cos",
            FontSlant->"Italic"]}], "}"}]]],
  ". What remains, a single polynomial, is the implicit relation in the \
variables ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox["x",
            FontSlant->"Italic"], ",", 
          StyleBox["y",
            FontSlant->"Italic"], ",", 
          StyleBox["z",
            FontSlant->"Italic"]}], "}"}]]],
  ". The code snippet below uses some simplifications such as clearing of \
denominators."
}], "Text"],

Cell[BoxData[{
    \(Clear[a, b, c, d, t, r]; \), "\n", 
    \(vec = {1, a, c}; offset = {0, b, d}; \), "\n", 
    \(pair = NullSpace[{vec}]; \), "\n", 
    \({w1, w2} = GramSchmidt[pair]; \), "\n", 
    \(polys = 
      Append[t\ vec + offset + r\ cos\ w1 + r\ sin\ w2 - {x, y, z}, 
        sin\^2 + cos\^2 - 1]; \)}], "Input",
  CellLabel->"In[62]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ee = Numerator[MapAll[Together, polys]]; \), "\n", 
    \(ff = Numerator[Together[PowerExpand[ee]]]; \), "\n", 
    \(Timing[
      imp = First[
          GroebnerBasis[ff, {x, y, z}, {t, sin, cos}, Sort \[Rule] True, 
            MonomialOrder \[Rule] EliminationOrder, 
            CoefficientDomain \[Rule] RationalFunctions]]]\)}], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \({1.6300000000000003`\ Second, 
      b\^2 + b\^2\ c\^2 - 2\ a\ b\ c\ d + d\^2 + a\^2\ d\^2 - r\^2 - 
        a\^2\ r\^2 - 
        c\^2\ r\^2 + \((2\ a\ b + 2\ c\ d)\)\ x + \((a\^2 + 
              c\^2)\)\ x\^2 + \((\(-2\)\ b - 2\ b\ c\^2 + 2\ a\ c\ d)\)\ y - 
        2\ a\ x\ y + \((1 + c\^2)\)\ y\^2 + \((2\ a\ b\ c - 2\ d - 
              2\ a\^2\ d)\)\ z - 2\ c\ x\ z - 
        2\ a\ c\ y\ z + \((1 + a\^2)\)\ z\^2}\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell[TextData[{
  "Note that, as one might expect, the implicit polynomial is a function of \
",
  Cell[BoxData[
      SuperscriptBox[
        StyleBox["r",
          FontSlant->"Italic"], "2"]]],
  "."
}], "Text"],

Cell["\<\
We now check this implicit polynomial with the example we used \
above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(i3 = 
      imp /. {a \[Rule] 3, b \[Rule] 2, c \[Rule] 4, d \[Rule] \(-1\), 
          r \[Rule] Sqrt[21]}\), "\[IndentingNewLine]", 
    \(i3 /. Map[Thread[{x, y, z} -> #] &, points] // Chop\)}], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(\(-420\) + 4\ x + 25\ x\^2 - 92\ y - 6\ x\ y + 17\ y\^2 + 68\ z - 
      8\ x\ z - 24\ y\ z + 10\ z\^2\)], "Output",
  CellLabel->"Out[105]="],

Cell[BoxData[
    \({0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[106]="]
}, Open  ]],

Cell["\<\
Here is a more clever way to find the implicit form. Just use the \
formulation we gave to find the distance from a point to the axial line. This \
gives an equation satisfied by every point on the cylinder. Hence it will be \
the hypersurface expression we seek.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pp = perp[{x, y, z}, vec, offset]; \), "\n", 
    \(imp2 = Numerator[Together[pp . pp - r\^2]]; \), "\n", 
    \(Together[imp - imp2]\)}], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell["\<\
As is so often the case, we see that brute force can be useful but \
it is no match for finesse. Why is the first approach of interest? Simply \
because it is a standard technique in computational algebraic geometry, and \
works when geometric intuition may not be so readily available.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Finding cylinder parameters from the implicit form", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell[TextData[{
  "Now we look into the reverse problem of finding parameters from the \
implicit form. Algebraic parametrization of algebraic objects is in general \
difficult, when it can be done at all. That said, parametrization of quadric \
surfaces in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " can be done and in fact is not terribly hard; general methods for this \
are presented in [18, chapter 5]. For the case of cylinders we will show a \
very simple approach. Note that we are using a trigonometric parameter to \
describe circle coordinates and thus it is not algebraic (though it suits our \
purposes quite well). If so desired, one can convert to the usual algebraic \
parametrization after a rotation of coordinates. We leave the details to the \
interested reader. We will illustrate our method for cylinders using the \
example above. As we know the general implicit form, it suffices merely to \
equate coefficients with those of the specific implicit form and solve for \
the parameters. Some of the coefficients are linear in the cylinder \
parameters so this is computationally quite easy."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(generalImplicitForm = 
      imp /. \[InvisibleSpace]r\^2 \[Rule] rsqr; \), "\n", 
    \(thiscase = 
      generalImplicitForm /. \[InvisibleSpace]{a \[Rule] 3, b \[Rule] 2, 
          c \[Rule] 4, d \[Rule] \(-1\), rsqr \[Rule] 21}; \), "\n", 
    \(SolveAlways[
      thiscase \[Equal] generalImplicitForm, {x, y, z}]\)}], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({{rsqr \[Rule] 21, b \[Rule] 2, d \[Rule] \(-1\), a \[Rule] 3, 
        c \[Rule] 4}}\)], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell[TextData[{
  "Were the coefficient equations not so readily solvable we could instead do \
as follows. Starting with that cylinder in implicit form we generate at least \
five points that lie on it. To this end we might simply take values for ",
  Cell[BoxData[
      \(x\)]],
  " and ",
  Cell[BoxData[
      RowBox[{"y", Cell[""]}]]],
  "coordinates, and solve for ",
  Cell[BoxData[
      \(z\)]],
  ". We then form equations for the parameters from the first five points and \
solve them. This gives candidate parameter values. Last we find the implicit \
equation corresponding to each set of parameters: the correct parameters will \
be the ones that recover the original implicit form (up to scalar multiple)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(points = 
      Partition[
        Flatten[{x, y, z} /. \[InvisibleSpace]Table[
              Solve[{thiscase \[Equal] 0, x \[Equal] j, y \[Equal] 0}, {x, y, 
                  z}], {j, 0, 2}]], 3]; \), "\n", 
    \(perps = 
      Table[perp[points\[LeftDoubleBracket]k\[RightDoubleBracket], vec, 
          offset], {k, 5}]; \), "\n", 
    \(exprs = \((Numerator[Together[#1 . #1 - rsqr]] &)\) /@ 
        perps; \), "\n", 
    \(Select[candidates, 
      NumericQ[Together[\(generalImplicitForm \
/. \[InvisibleSpace]#1\)\/thiscase]] &]\)}], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \({{rsqr \[Rule] 21, b \[Rule] 2, d \[Rule] \(-1\), c \[Rule] 4, 
        a \[Rule] 3}}\)], "Output",
  CellLabel->"Out[81]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving for overdetermined cylinders", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell[TextData[{
  "A natural question to ask, regarding computations related to this problem, \
is what we might do to find a cylinder (approximately) containing more than \
five given points? The typical case is where the points all lie approximately \
on a cylinder and we wish to find the best fitting one (perhaps to assess \
tolerance). We will use ",
  Cell[BoxData[
      \(FindMinimum\)],
    FontWeight->"Bold"],
  " for this task. We can set up an expression to minimize as follows. First \
form the list ",
  Cell[BoxData[
      \(perps\)],
    FontSlant->"Italic"],
  " of orthogonal complements to projections of our points onto the axial \
line. Then take a sum of squares of differences between projected lengths and \
radius. To illustrate we reconstruct our original example, but this time we \
will use more points chosen at random, and we will add random noise to these. \
We know approximately the correct values for the parameters, and at this \
value our sum of squares will be near zero. An important issue is how to find \
good starting values. We do this by taking five points, solving for cylinder \
parameters, and then using other points to decide which of the six \
possibilities we should utilize."
}], "Text"],

Cell[BoxData[{
    \({a, b, c, d, rspr} = {3, 2, 4, \(-1\), 21}; numpts = 8; \), "\n", 
    \(vec = {1, a, c}; offset = {0, b, d}; \), "\n", 
    \(pair = NullSpace[{vec}]; \), "\n", 
    \({w1, w2} = GramSchmidt[pair]; \), "\n", 
    \(xvals = Table[Random[Real, {\(-10\), 10}], {numpts}]; \), "\n", 
    \(thetas = Table[Random[Real, {0, 2\ \[Pi]}], {numpts}]; \), "\n", 
    \(randomNoise3D[max_] := max\ Table[Random[], {3}]\), "\n", 
    \(points = 
      Table[xvals\[LeftDoubleBracket]j\[RightDoubleBracket]\ vec + 
          offset + \@rsqr\ Cos[
              thetas\[LeftDoubleBracket]
                j\[RightDoubleBracket]]\ w1 + \@rsqr\ Sin[
              thetas\[LeftDoubleBracket]j\[RightDoubleBracket]]\ w2 + 
          randomNoise3D[0.001], {j, numpts}]; \)}], "Input",
  CellLabel->"In[191]:="],

Cell["First we will get a set of candidate starting values.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[a, b, c, d, rsqr]\), "\n", 
    \(perps = 
      Table[perp[points[\([\)\(j\)\(]\)], vec, offset], {j, 
          numpts}]; \), "\[IndentingNewLine]", 
    \(exprs = 
      Map[Numerator[Together[Rationalize[# . #, 0] - rsqr]] &, 
        Take[perps, 5]]; \), "\n", 
    \(Timing[solns = NSolve[exprs, {a, b, c, d, rsqr}]]\)}], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({0.22999999999999965`\ Second, {{a \[Rule] \(-0.12642190903501244`\) - 
              0.7175534961925252`\ \[ImaginaryI], 
          b \[Rule] \(\(15.055482836608396`\)\(\[InvisibleSpace]\)\) + 
              8.168327703609839`\ \[ImaginaryI], 
          c \[Rule] \(-0.07735507674340361`\) + 
              0.7272944238742823`\ \[ImaginaryI], 
          d \[Rule] \(\(24.63628340146688`\)\(\[InvisibleSpace]\)\) - 
              0.30763690569413715`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(96.4499905138585`\)\(\[InvisibleSpace]\)\) + 
              59.8042441510249`\ \[ImaginaryI]}, {a \[Rule] \
\(-0.12642190903501244`\) + 0.7175534961925252`\ \[ImaginaryI], 
          b \[Rule] \(\(15.055482836608396`\)\(\[InvisibleSpace]\)\) - 
              8.168327703609839`\ \[ImaginaryI], 
          c \[Rule] \(-0.07735507674340361`\) - 
              0.7272944238742823`\ \[ImaginaryI], 
          d \[Rule] \(\(24.63628340146688`\)\(\[InvisibleSpace]\)\) + 
              0.30763690569413715`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(96.4499905138585`\)\(\[InvisibleSpace]\)\) - 
              59.8042441510249`\ \[ImaginaryI]}, {a \[Rule] 
            2.1016953242034884`, b \[Rule] 9.661388723934518`, 
          c \[Rule] 2.3574420606850977`, d \[Rule] 9.43689713275277`, 
          rsqr \[Rule] 
            35.09182455918772`}, {a \[Rule] \(\(3.520011010350671`\)\(\
\[InvisibleSpace]\)\) - 2.7711998850958763`\ \[ImaginaryI], 
          b \[Rule] \(\(5.330615235557268`\)\(\[InvisibleSpace]\)\) + 
              23.81305240580601`\ \[ImaginaryI], 
          c \[Rule] \(\(7.312718431286581`\)\(\[InvisibleSpace]\)\) - 
              2.0863566287893986`\ \[ImaginaryI], 
          d \[Rule] \(-12.763892276319261`\) + 
              30.839594840746297`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(7.678784410477583`\)\(\[InvisibleSpace]\)\) + 
              13.838884741558`\ \[ImaginaryI]}, {a \[Rule] \
\(\(3.520011010350671`\)\(\[InvisibleSpace]\)\) + 
              2.7711998850958763`\ \[ImaginaryI], 
          b \[Rule] \(\(5.330615235557268`\)\(\[InvisibleSpace]\)\) - 
              23.81305240580601`\ \[ImaginaryI], 
          c \[Rule] \(\(7.312718431286581`\)\(\[InvisibleSpace]\)\) + 
              2.0863566287893986`\ \[ImaginaryI], 
          d \[Rule] \(-12.763892276319261`\) - 
              30.839594840746297`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(7.678784410477583`\)\(\[InvisibleSpace]\)\) - 
              13.838884741558`\ \[ImaginaryI]}, {a \[Rule] 
            3.0005704505494206`, b \[Rule] 1.9901153734963137`, 
          c \[Rule] 3.9987215022546496`, d \[Rule] \(-1.0167583637304154`\), 
          rsqr \[Rule] 21.037775061193134`}}}\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell["\<\
Next we select the best candidate by calculating values of the six \
implicit equations at all points, summing absolute values for each equation \
over all points, and using the parameters that correspond to the implicit \
equation that yields the smallest such sum.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(squaresums\  = 
      Apply[Plus, \ 
        Abs[\((generalImplicitForm\  /. \ solns)\)\  /. \ \n
            Map[Thread[{x, y, z} \[Rule] #] &, points]]]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \({195.80491055519275`, 195.80491055519275`, 240.62263641970196`, 
      10682.993202729576`, 10682.993202729576`, 
      2.208725957114666`}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell["\<\
Clearly the sixth solution is the one to use. This may be found \
programmatically as below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(candidate\  = \ 
      solns[\([\)\(\(Position[squaresums, Min[squaresums]]\)[\([\)\(1, 
          1\)\(]\)]\)\(]\)]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \({a \[Rule] 3.0005704505494206`, b \[Rule] 1.9901153734963137`, 
      c \[Rule] 3.9987215022546496`, d \[Rule] \(-1.0167583637304154`\), 
      rsqr \[Rule] 21.037775061193134`}\)], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell["Now we form our sum of squares and minimize it.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(sumsquarelens = 
      Plus @@ \(\((\((\@\(#1 . #1\) - r)\)\^2 &)\) /@ perps\); \), "\n", 
    \(startvals = \((List @@ #1 &)\) /@ candidate; \), "\n", 
    \(newstartvals = 
      startvals /. \[InvisibleSpace]{rsqr, 
            v_} \[RuleDelayed] {r, \@v}; \), "\n", 
    \({min, ee} = 
      FindMinimum[Evaluate[sumsquarelens], 
        Evaluate[Sequence @@ newstartvals]]\)}], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \({8.482222152523983`*^-8, {a \[Rule] 2.999896484727409`, 
        b \[Rule] 1.9992565666695186`, c \[Rule] 3.9998508994803794`, 
        d \[Rule] \(-1.0017913773675433`\), 
        r \[Rule] 4.582781974616135`}}\)], "Output",
  CellLabel->"Out[86]="]
}, Open  ]],

Cell["\<\
As a general remark, attempts with different optimization methods \
indicate that this sort of expression is quite problematic to minimize \
without reasonable starting points.\
\>", "Text"],

Cell["\<\
There is an interesting application that can make use of the this. \
In the industrial realm of geometric tolerancing one wishes to measure how \
well an object conforms to specifications. The cylinder is of course a very \
common object in manufacture. A good approach to metrology involving \
cylinders may be found in [14]. The technology discussed therein is \
especially effective when the object in question is small and may be readily \
positioned, but one might accept a cruder approach e.g. to check an \
underground pipeline. For this sort of task one could probe five points, \
obtain from them a set of approximate cylinder parameters, then probe several \
others and obtain parameters for a least\[Hyphen]squares nearest cylinder as \
above. One can then simply check whether all probed points are within \
specification tolerance in actual radial measure from the computed axial \
line.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Visualization of the real cylinders containing a set of \
points\
\>", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell[TextData[{
  "It can be a challenge to visualize how a given set of points fit on the \
cylinders that are computed to contain those points. Below we present a \
viable approach. The idea is to draw the cylinder, its axis, and the points \
connected by segments. We then decrease the radius of the drawn cylinder to \
",
  Cell[BoxData[
      \(70\)]],
  "% of its actual value as this frequently maintains visibility and also \
more readily shows how the points belong on the cylinder. Another idea would \
be to punch holes in the cylinder where points are obscured, so that they \
might be made visible, but this involves considerably more programming \
effort."
}], "Text"],

Cell[BoxData[
    \(showlines[points_List, rest___] := 
      Module[{plotpoints, plotlines, len = Length[points]}, 
        plotpoints = 
          Table[Graphics3D[{Blue, PointSize[0.03], 
                Point[points\[LeftDoubleBracket]
                    j\[RightDoubleBracket]]}], {j, 1, len}]; 
        plotlines = 
          Table[Graphics3D[{Hue[1\/26\ \((j\^2 + k - 4)\)], 
                Line[{points\[LeftDoubleBracket]j\[RightDoubleBracket], 
                    points\[LeftDoubleBracket]k\[RightDoubleBracket]}]}], {k, 
              1, len - 1}, {j, k + 1, len}]; 
        Show[plotpoints, plotlines, rest, DisplayFunction \[Rule] Identity, 
          Boxed \[Rule] False, Axes \[Rule] False, Shading \[Rule] False, 
          ViewPoint \[Rule] {\(-\(1\/2\)\), 2, 1}, 
          ImageSize \[Rule] {300, 480}]]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(cylinderplot[rt_, pts_List, vec_, offset_, showcyl_ : True] := 
      Module[{r, vec2, lin, x, theta, w1, w2, circ, cylplot, axis}, 
        r = \@\(rsqr /. \[InvisibleSpace]rt\); 
        vec2 = vec /. \[InvisibleSpace]rt; 
        lin = x\ vec + offset /. \[InvisibleSpace]rt; 
        pair = NullSpace[{vec2}]; {w1, w2} = GramSchmidt[pair]; 
        circ = 0.7\ r\ Cos[theta]\ w1 + 
              0.7\ r\ Sin[theta]\ w2 /. \[InvisibleSpace]rt; 
        cylplot = 
          ParametricPlot3D[
            Evaluate[lin + circ], {x, \(-3\), 3}, {theta, \(-0.5\)\ \[Pi], 
              0.85\ \[Pi]}, Shading \[Rule] True, 
            DisplayFunction \[Rule] Identity]; 
        axis = ParametricPlot3D[lin, {x, \(-3.5\), 3.5}, 
            DisplayFunction \[Rule] Identity]; 
        If[showcyl, 
          showlines[pts, axis, cylplot, DisplayFunction \[Rule] Identity], 
          showlines[pts, axis, DisplayFunction \[Rule] Identity]]]\)], "Input",\

  CellLabel->"In[30]:="],

Cell[TextData[{
  "Let us look at an illustrative configuation. One notes that it is hardly \
generic in the sense that the points form a double regular tetrahedron (with \
edge length of ",
  Cell[BoxData[
      \(\@3\)]],
  "). In fact it was necessary to change the direction and offset parameters \
to get all six solutions for this example."
}], "Text"],

Cell[BoxData[
    \(dpoints = {{1, 0, 0}, {\(-\(1\/2\)\), \@3\/2, 
          0}, {\(-\(1\/2\)\), \(-\(\@3\/2\)\), 0}, {0, 0, \@2}, {0, 
          0, \(-\@2\)}}; \)], "Input",
  CellLabel->"(math50) In[90]:="],

Cell[BoxData[
    \(vec = {a, c, 1}; offset = {b, d, 0}; \)], "Input"],

Cell[BoxData[
    \(solveCylinders[pts_List, vec_, offset_, prec_ : Automatic] := 
      Module[{exprs, k, perps}, 
        perps = Table[
            perp[pts\[LeftDoubleBracket]k\[RightDoubleBracket], vec, 
              offset], {k, 5}]; 
        exprs = \((Numerator[Together[#1 . #1 - rsqr]] &)\) /@ perps; 
        solns = NSolve[exprs, {a, b, c, d, rsqr}, 
            WorkingPrecision \[Rule] prec]; 
        rs = N[rsqr /. \[InvisibleSpace]solns]]\)], "Input",
  CellLabel->"(math50) In[100]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(solveCylinders[dpoints, vec, offset]\)], "Input",
  CellLabel->"(math50) In[101]:="],

Cell[BoxData[
    \({0.81`, 0.81`, 0.81`, 0.81`, 0.81`, 0.81`}\)], "Output",
  CellLabel->"(math50) Out[101]="]
}, Open  ]],

Cell[TextData[{
  "We see that the radii are all equal for this configuration. In fact (as \
may be verified by setting the optional fourth argument to ",
  Cell[BoxData[
      \(\[Infinity]\)]],
  ") the radii are all ",
  Cell[BoxData[
      \(9\/10\)]],
  "."
}], "Text"],

Cell[TextData[{
  "We used a global variable, ",
  Cell[BoxData[
      \(solns\)],
    FontSlant->"Italic"],
  ", as a convenience so that we can make further use of the full solution \
set. While this is poor programming style, it suits our immediate purpose."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nsols\  = \ N[solns]\)], "Input",
  CellLabel->"(math50) In[102]:="],

Cell[BoxData[
    \({{rsqr \[Rule] 0.81`, d \[Rule] 0.`, b \[Rule] 0.1`, a \[Rule] 0.`, 
        c \[Rule] 0.816496580927726`}, {rsqr \[Rule] 0.81`, d \[Rule] 0.`, 
        b \[Rule] 0.1`, a \[Rule] 0.`, 
        c \[Rule] \(-0.816496580927726`\)}, {rsqr \[Rule] 0.81`, 
        d \[Rule] 0.08660254037844387`, b \[Rule] \(-0.05`\), 
        a \[Rule] 0.7071067811865476`, 
        c \[Rule] 0.408248290463863`}, {rsqr \[Rule] 0.81`, 
        d \[Rule] \(-0.08660254037844387`\), b \[Rule] \(-0.05`\), 
        a \[Rule] \(-0.7071067811865476`\), 
        c \[Rule] 0.408248290463863`}, {rsqr \[Rule] 0.81`, 
        d \[Rule] \(-0.08660254037844387`\), b \[Rule] \(-0.05`\), 
        a \[Rule] 0.7071067811865476`, 
        c \[Rule] \(-0.408248290463863`\)}, {rsqr \[Rule] 0.81`, 
        d \[Rule] 0.08660254037844387`, b \[Rule] \(-0.05`\), 
        a \[Rule] \(-0.7071067811865476`\), 
        c \[Rule] \(-0.408248290463863`\)}}\)], "Output",
  CellLabel->"(math50) Out[102]="]
}, Open  ]],

Cell["Here are plots of two of the cylinders.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nsols\  = \ N[solns]; \), "\n", 
    \(Show[
      GraphicsArray[
        Table[cylinderplot[nsols[\([\)\(j\)\(]\)], dpoints, vec, offset, 
            True], {j, 2}]]]; \)}], "Input",
  CellLabel->"In[36]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29624 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0308628 0.47619 [
[ 0 0 0 0 ]
[ 1 1.29624 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29624 L
0 1.29624 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0308628 0.477324 1.26537 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.880577 2.92634 3.14419e-17 2.92634 [
[ 0 0 0 0 ]
[ 1 2.72209 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.72209 L
0 2.72209 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.77452 1.00824 m
.77114 1.01812 L
s
.77114 1.01812 m
.76772 1.02811 L
s
.76772 1.02811 m
.76427 1.0382 L
s
1 g
.73863 1.23827 m .75065 1.2009 L .78353 1.20012 L p F P
0 g
s
1 g
.78353 1.20012 m .77209 1.23751 L .73863 1.23827 L p F P
0 g
s
1 g
.77209 1.23751 m .78353 1.20012 L .81517 1.19253 L p F P
0 g
s
.76427 1.0382 m
.76078 1.0484 L
s
1 g
.81517 1.19253 m .80428 1.22986 L .77209 1.23751 L p F P
0 g
s
1 g
.80428 1.22986 m .81517 1.19253 L .84404 1.17848 L p F P
0 g
s
1 g
.84404 1.17848 m .83364 1.21564 L .80428 1.22986 L p F P
0 g
s
1 g
.83364 1.21564 m .84404 1.17848 L .86872 1.15859 L p F P
0 g
s
.76078 1.0484 m
.75726 1.05871 L
s
1 g
.86872 1.15859 m .85875 1.19549 L .83364 1.21564 L p F P
0 g
s
1 g
.85875 1.19549 m .86872 1.15859 L .88798 1.13378 L p F P
0 g
s
1 g
.88798 1.13378 m .87832 1.17035 L .85875 1.19549 L p F P
0 g
s
1 g
.87832 1.17035 m .88798 1.13378 L .90082 1.10524 L p F P
0 g
s
.75726 1.05871 m
.7537 1.06913 L
s
1 g
.90082 1.10524 m .89136 1.14141 L .87832 1.17035 L p F P
0 g
s
1 g
.89136 1.14141 m .90082 1.10524 L .90653 1.07435 L p F P
0 g
s
1 g
.62996 .99572 m .64417 .962 L .62504 .98721 L p F P
0 g
s
1 g
.62504 .98721 m .61053 1.02128 L .62996 .99572 L p F P
0 g
s
.7537 1.06913 m
.7501 1.07967 L
s
1 g
.90653 1.07435 m .89716 1.11007 L .89136 1.14141 L p F P
0 g
s
1 g
.89716 1.11007 m .90653 1.07435 L .90478 1.04265 L p F P
0 g
s
1 g
.72617 1.277 m .73863 1.23827 L .77209 1.23751 L p F P
0 g
s
1 g
.77209 1.23751 m .76023 1.27628 L .72617 1.277 L p F P
0 g
s
1 g
.76023 1.27628 m .77209 1.23751 L .80428 1.22986 L p F P
0 g
s
1 g
.65522 .97507 m .66902 .94163 L .64417 .962 L p F P
0 g
s
1 g
.64417 .962 m .62996 .99572 L .65522 .97507 L p F P
0 g
s
1 g
.90478 1.04265 m .89534 1.07789 L .89716 1.11007 L p F P
0 g
s
1 g
.89534 1.07789 m .90478 1.04265 L .89557 1.01171 L p F P
0 g
s
1 g
.80428 1.22986 m .79298 1.26856 L .76023 1.27628 L p F P
0 g
s
1 g
.79298 1.26856 m .80428 1.22986 L .83364 1.21564 L p F P
0 g
s
1 g
.68508 .96044 m .69837 .92719 L .66902 .94163 L p F P
0 g
s
1 g
.66902 .94163 m .65522 .97507 L .68508 .96044 L p F P
0 g
s
.7501 1.07967 m
.74645 1.09032 L
s
1 g
.89557 1.01171 m .88593 1.04648 L .89534 1.07789 L p F P
0 g
s
1 g
.88593 1.04648 m .89557 1.01171 L .87932 .98314 L p F P
0 g
s
1 g
.83364 1.21564 m .82286 1.25418 L .79298 1.26856 L p F P
0 g
s
1 g
.82286 1.25418 m .83364 1.21564 L .85875 1.19549 L p F P
0 g
s
1 g
.71803 .95261 m .73074 .91944 L .69837 .92719 L p F P
0 g
s
1 g
.69837 .92719 m .68508 .96044 L .71803 .95261 L p F P
0 g
s
1 g
.87932 .98314 m .86937 1.01746 L .88593 1.04648 L p F P
0 g
s
1 g
.86937 1.01746 m .87932 .98314 L .85683 .95842 L p F P
0 g
s
1 g
.7524 .95202 m .7645 .91882 L .73074 .91944 L p F P
0 g
s
1 g
.73074 .91944 m .71803 .95261 L .7524 .95202 L p F P
0 g
s
1 g
.85875 1.19549 m .8484 1.23376 L .82286 1.25418 L p F P
0 g
s
1 g
.8484 1.23376 m .85875 1.19549 L .87832 1.17035 L p F P
0 g
s
1 g
.85683 .95842 m .84644 .99233 L .86937 1.01746 L p F P
0 g
s
1 g
.84644 .99233 m .85683 .95842 L .82922 .93882 L p F P
0 g
s
1 g
.78642 .95873 m .79791 .92539 L .7645 .91882 L p F P
0 g
s
1 g
.7645 .91882 m .7524 .95202 L .78642 .95873 L p F P
0 g
s
1 g
.82922 .93882 m .81831 .9724 L .84644 .99233 L p F P
0 g
s
1 g
.81831 .9724 m .82922 .93882 L .79791 .92539 L p F P
0 g
s
1 g
.79791 .92539 m .78642 .95873 L .81831 .9724 L p F P
0 g
s
.74645 1.09032 m
.74277 1.10108 L
s
1 g
.87832 1.17035 m .86831 1.20828 L .8484 1.23376 L p F P
0 g
s
1 g
.86831 1.20828 m .87832 1.17035 L .89136 1.14141 L p F P
0 g
s
1 g
.89136 1.14141 m .88156 1.17892 L .86831 1.20828 L p F P
0 g
s
1 g
.88156 1.17892 m .89136 1.14141 L .89716 1.11007 L p F P
0 g
s
.74277 1.10108 m
.73905 1.11197 L
s
1 g
.61522 1.0307 m .62996 .99572 L .61053 1.02128 L p F P
0 g
s
1 g
.61053 1.02128 m .59547 1.05663 L .61522 1.0307 L p F P
0 g
s
1 g
.89716 1.11007 m .88743 1.14712 L .88156 1.17892 L p F P
0 g
s
1 g
.88743 1.14712 m .89716 1.11007 L .89534 1.07789 L p F P
0 g
s
1 g
.71325 1.31718 m .72617 1.277 L .76023 1.27628 L p F P
0 g
s
1 g
.76023 1.27628 m .74792 1.3165 L .71325 1.31718 L p F P
0 g
s
1 g
.74792 1.3165 m .76023 1.27628 L .79298 1.26856 L p F P
0 g
s
1 g
.64092 1.00977 m .65522 .97507 L .62996 .99572 L p F P
0 g
s
1 g
.62996 .99572 m .61522 1.0307 L .64092 1.00977 L p F P
0 g
s
1 g
.89534 1.07789 m .88554 1.11445 L .88743 1.14712 L p F P
0 g
s
1 g
.88554 1.11445 m .89534 1.07789 L .88593 1.04648 L p F P
0 g
s
1 g
.79298 1.26856 m .78127 1.30872 L .74792 1.3165 L p F P
0 g
s
1 g
.78127 1.30872 m .79298 1.26856 L .82286 1.25418 L p F P
0 g
s
.73905 1.11197 m
.73529 1.12297 L
s
1 g
.6713 .99494 m .68508 .96044 L .65522 .97507 L p F P
0 g
s
1 g
.65522 .97507 m .64092 1.00977 L .6713 .99494 L p F P
0 g
s
1 g
.88593 1.04648 m .87594 1.08255 L .88554 1.11445 L p F P
0 g
s
1 g
.87594 1.08255 m .88593 1.04648 L .86937 1.01746 L p F P
0 g
s
1 g
.82286 1.25418 m .81168 1.29416 L .78127 1.30872 L p F P
0 g
s
1 g
.81168 1.29416 m .82286 1.25418 L .8484 1.23376 L p F P
0 g
s
1 g
.70485 .98703 m .71803 .95261 L .68508 .96044 L p F P
0 g
s
1 g
.68508 .96044 m .6713 .99494 L .70485 .98703 L p F P
0 g
s
1 g
.86937 1.01746 m .85904 1.05306 L .87594 1.08255 L p F P
0 g
s
1 g
.85904 1.05306 m .86937 1.01746 L .84644 .99233 L p F P
0 g
s
1 g
.73985 .98647 m .7524 .95202 L .71803 .95261 L p F P
0 g
s
1 g
.71803 .95261 m .70485 .98703 L .73985 .98647 L p F P
0 g
s
1 g
.8484 1.23376 m .83767 1.27348 L .81168 1.29416 L p F P
0 g
s
1 g
.83767 1.27348 m .8484 1.23376 L .86831 1.20828 L p F P
0 g
s
.73529 1.12297 m
.73149 1.1341 L
s
1 g
.84644 .99233 m .83567 1.02751 L .85904 1.05306 L p F P
0 g
s
1 g
.83567 1.02751 m .84644 .99233 L .81831 .9724 L p F P
0 g
s
1 g
.77449 .99332 m .78642 .95873 L .7524 .95202 L p F P
0 g
s
1 g
.7524 .95202 m .73985 .98647 L .77449 .99332 L p F P
0 g
s
1 g
.81831 .9724 m .80699 1.00725 L .83567 1.02751 L p F P
0 g
s
1 g
.80699 1.00725 m .81831 .9724 L .78642 .95873 L p F P
0 g
s
1 g
.78642 .95873 m .77449 .99332 L .80699 1.00725 L p F P
0 g
s
1 g
.86831 1.20828 m .85792 1.24763 L .83767 1.27348 L p F P
0 g
s
1 g
.85792 1.24763 m .86831 1.20828 L .88156 1.17892 L p F P
0 g
s
.73149 1.1341 m
.72764 1.14535 L
s
1 g
.88156 1.17892 m .87138 1.21785 L .85792 1.24763 L p F P
0 g
s
1 g
.87138 1.21785 m .88156 1.17892 L .88743 1.14712 L p F P
0 g
s
1 g
.59992 1.06701 m .61522 1.0307 L .59547 1.05663 L p F P
0 g
s
1 g
.59547 1.05663 m .57984 1.09331 L .59992 1.06701 L p F P
0 g
s
1 g
.88743 1.14712 m .87733 1.18558 L .87138 1.21785 L p F P
0 g
s
1 g
.87733 1.18558 m .88743 1.14712 L .88554 1.11445 L p F P
0 g
s
1 g
.69983 1.35889 m .71325 1.31718 L .74792 1.3165 L p F P
0 g
s
1 g
.74792 1.3165 m .73515 1.35825 L .69983 1.35889 L p F P
0 g
s
1 g
.73515 1.35825 m .74792 1.3165 L .78127 1.30872 L p F P
0 g
s
.72764 1.14535 m
.72375 1.15673 L
s
1 g
.62606 1.04578 m .64092 1.00977 L .61522 1.0307 L p F P
0 g
s
1 g
.61522 1.0307 m .59992 1.06701 L .62606 1.04578 L p F P
0 g
s
1 g
.88554 1.11445 m .87538 1.1524 L .87733 1.18558 L p F P
0 g
s
1 g
.87538 1.1524 m .88554 1.11445 L .87594 1.08255 L p F P
0 g
s
1 g
.78127 1.30872 m .76911 1.3504 L .73515 1.35825 L p F P
0 g
s
1 g
.76911 1.3504 m .78127 1.30872 L .81168 1.29416 L p F P
0 g
s
1 g
.65699 1.03076 m .6713 .99494 L .64092 1.00977 L p F P
0 g
s
1 g
.64092 1.00977 m .62606 1.04578 L .65699 1.03076 L p F P
0 g
s
1 g
.87594 1.08255 m .86556 1.12 L .87538 1.1524 L p F P
0 g
s
1 g
.86556 1.12 m .87594 1.08255 L .85904 1.05306 L p F P
0 g
s
1 g
.81168 1.29416 m .80007 1.33566 L .76911 1.3504 L p F P
0 g
s
1 g
.80007 1.33566 m .81168 1.29416 L .83767 1.27348 L p F P
0 g
s
1 g
.69115 1.02277 m .70485 .98703 L .6713 .99494 L p F P
0 g
s
1 g
.6713 .99494 m .65699 1.03076 L .69115 1.02277 L p F P
0 g
s
.72375 1.15673 m
.71982 1.16824 L
s
1 g
.85904 1.05306 m .84831 1.09003 L .86556 1.12 L p F P
0 g
s
1 g
.84831 1.09003 m .85904 1.05306 L .83567 1.02751 L p F P
0 g
s
1 g
.72681 1.02224 m .73985 .98647 L .70485 .98703 L p F P
0 g
s
1 g
.70485 .98703 m .69115 1.02277 L .72681 1.02224 L p F P
0 g
s
1 g
.83767 1.27348 m .82652 1.31471 L .80007 1.33566 L p F P
0 g
s
1 g
.82652 1.31471 m .83767 1.27348 L .85792 1.24763 L p F P
0 g
s
1 g
.83567 1.02751 m .82447 1.06405 L .84831 1.09003 L p F P
0 g
s
1 g
.82447 1.06405 m .83567 1.02751 L .80699 1.00725 L p F P
0 g
s
1 g
.76211 1.02925 m .77449 .99332 L .73985 .98647 L p F P
0 g
s
1 g
.73985 .98647 m .72681 1.02224 L .76211 1.02925 L p F P
0 g
s
1 g
.80699 1.00725 m .79524 1.04343 L .82447 1.06405 L p F P
0 g
s
1 g
.79524 1.04343 m .80699 1.00725 L .77449 .99332 L p F P
0 g
s
1 g
.77449 .99332 m .76211 1.02925 L .79524 1.04343 L p F P
0 g
s
1 g
.85792 1.24763 m .84712 1.28851 L .82652 1.31471 L p F P
0 g
s
1 g
.84712 1.28851 m .85792 1.24763 L .87138 1.21785 L p F P
0 g
s
.71982 1.16824 m
.71584 1.17987 L
s
1 g
.87138 1.21785 m .86081 1.25829 L .84712 1.28851 L p F P
0 g
s
1 g
.86081 1.25829 m .87138 1.21785 L .87733 1.18558 L p F P
0 g
s
1 g
.58402 1.10473 m .59992 1.06701 L .57984 1.09331 L p F P
0 g
s
1 g
.57984 1.09331 m .56361 1.13142 L .58402 1.10473 L p F P
0 g
s
.71584 1.17987 m
.71181 1.19165 L
s
1 g
.87733 1.18558 m .86684 1.22552 L .86081 1.25829 L p F P
0 g
s
1 g
.86684 1.22552 m .87733 1.18558 L .87538 1.1524 L p F P
0 g
s
1 g
.6859 1.40222 m .69983 1.35889 L .73515 1.35825 L p F P
0 g
s
1 g
.73515 1.35825 m .72188 1.40162 L .6859 1.40222 L p F P
0 g
s
1 g
.72188 1.40162 m .73515 1.35825 L .76911 1.3504 L p F P
0 g
s
1 g
.61063 1.0832 m .62606 1.04578 L .59992 1.06701 L p F P
0 g
s
1 g
.59992 1.06701 m .58402 1.10473 L .61063 1.0832 L p F P
0 g
s
1 g
.87538 1.1524 m .86482 1.19183 L .86684 1.22552 L p F P
0 g
s
1 g
.86482 1.19183 m .87538 1.1524 L .86556 1.12 L p F P
0 g
s
1 g
.76911 1.3504 m .75647 1.3937 L .72188 1.40162 L p F P
0 g
s
1 g
.75647 1.3937 m .76911 1.3504 L .80007 1.33566 L p F P
0 g
s
1 g
.64212 1.06799 m .65699 1.03076 L .62606 1.04578 L p F P
0 g
s
1 g
.62606 1.04578 m .61063 1.0832 L .64212 1.06799 L p F P
0 g
s
.71181 1.19165 m
.70774 1.20355 L
s
1 g
.86556 1.12 m .85478 1.1589 L .86482 1.19183 L p F P
0 g
s
1 g
.85478 1.1589 m .86556 1.12 L .84831 1.09003 L p F P
0 g
s
1 g
.80007 1.33566 m .78801 1.37879 L .75647 1.3937 L p F P
0 g
s
1 g
.78801 1.37879 m .80007 1.33566 L .82652 1.31471 L p F P
0 g
s
1 g
.67692 1.05991 m .69115 1.02277 L .65699 1.03076 L p F P
0 g
s
1 g
.65699 1.03076 m .64212 1.06799 L .67692 1.05991 L p F P
0 g
s
1 g
.84831 1.09003 m .83717 1.12844 L .85478 1.1589 L p F P
0 g
s
1 g
.83717 1.12844 m .84831 1.09003 L .82447 1.06405 L p F P
0 g
s
1 g
.71326 1.05942 m .72681 1.02224 L .69115 1.02277 L p F P
0 g
s
1 g
.69115 1.02277 m .67692 1.05991 L .71326 1.05942 L p F P
0 g
s
1 g
.82652 1.31471 m .81494 1.35756 L .78801 1.37879 L p F P
0 g
s
1 g
.81494 1.35756 m .82652 1.31471 L .84712 1.28851 L p F P
0 g
s
1 g
.82447 1.06405 m .81284 1.10202 L .83717 1.12844 L p F P
0 g
s
1 g
.81284 1.10202 m .82447 1.06405 L .79524 1.04343 L p F P
0 g
s
1 g
.74925 1.06658 m .76211 1.02925 L .72681 1.02224 L p F P
0 g
s
1 g
.72681 1.02224 m .71326 1.05942 L .74925 1.06658 L p F P
0 g
s
1 g
.79524 1.04343 m .78303 1.08103 L .81284 1.10202 L p F P
0 g
s
1 g
.78303 1.08103 m .79524 1.04343 L .76211 1.02925 L p F P
0 g
s
1 g
.76211 1.02925 m .74925 1.06658 L .78303 1.08103 L p F P
0 g
s
.70774 1.20355 m
.70362 1.2156 L
s
1 g
.84712 1.28851 m .83591 1.33098 L .81494 1.35756 L p F P
0 g
s
1 g
.83591 1.33098 m .84712 1.28851 L .86081 1.25829 L p F P
0 g
s
1 g
.86081 1.25829 m .84983 1.30032 L .83591 1.33098 L p F P
0 g
s
1 g
.84983 1.30032 m .86081 1.25829 L .86684 1.22552 L p F P
0 g
s
.70362 1.2156 m
.69946 1.22778 L
s
1 g
.5675 1.14394 m .58402 1.10473 L .56361 1.13142 L p F P
0 g
s
1 g
.56361 1.13142 m .54674 1.17103 L .5675 1.14394 L p F P
0 g
s
1 g
.86684 1.22552 m .85593 1.26705 L .84983 1.30032 L p F P
0 g
s
1 g
.85593 1.26705 m .86684 1.22552 L .86482 1.19183 L p F P
0 g
s
1 g
.67141 1.44725 m .6859 1.40222 L .72188 1.40162 L p F P
0 g
s
1 g
.72188 1.40162 m .70809 1.44671 L .67141 1.44725 L p F P
0 g
s
1 g
.70809 1.44671 m .72188 1.40162 L .75647 1.3937 L p F P
0 g
s
1 g
.59458 1.12211 m .61063 1.0832 L .58402 1.10473 L p F P
0 g
s
1 g
.58402 1.10473 m .5675 1.14394 L .59458 1.12211 L p F P
0 g
s
1 g
.86482 1.19183 m .85384 1.23282 L .85593 1.26705 L p F P
0 g
s
1 g
.85384 1.23282 m .86482 1.19183 L .85478 1.1589 L p F P
0 g
s
.69946 1.22778 m
.69524 1.24011 L
s
1 g
.75647 1.3937 m .74334 1.43872 L .70809 1.44671 L p F P
0 g
s
1 g
.74334 1.43872 m .75647 1.3937 L .78801 1.37879 L p F P
0 g
s
1 g
.62666 1.10669 m .64212 1.06799 L .61063 1.0832 L p F P
0 g
s
1 g
.61063 1.0832 m .59458 1.12211 L .62666 1.10669 L p F P
0 g
s
1 g
.85478 1.1589 m .84357 1.19936 L .85384 1.23282 L p F P
0 g
s
1 g
.84357 1.19936 m .85478 1.1589 L .83717 1.12844 L p F P
0 g
s
1 g
.78801 1.37879 m .77546 1.42364 L .74334 1.43872 L p F P
0 g
s
1 g
.77546 1.42364 m .78801 1.37879 L .81494 1.35756 L p F P
0 g
s
1 g
.66212 1.09853 m .67692 1.05991 L .64212 1.06799 L p F P
0 g
s
1 g
.64212 1.06799 m .62666 1.10669 L .66212 1.09853 L p F P
0 g
s
1 g
.83717 1.12844 m .82558 1.16838 L .84357 1.19936 L p F P
0 g
s
1 g
.82558 1.16838 m .83717 1.12844 L .81284 1.10202 L p F P
0 g
s
1 g
.69917 1.09808 m .71326 1.05942 L .67692 1.05991 L p F P
0 g
s
1 g
.67692 1.05991 m .66212 1.09853 L .69917 1.09808 L p F P
0 g
s
1 g
.81494 1.35756 m .80289 1.40212 L .77546 1.42364 L p F P
0 g
s
1 g
.80289 1.40212 m .81494 1.35756 L .83591 1.33098 L p F P
0 g
s
.69524 1.24011 m
.69098 1.25259 L
s
1 g
.81284 1.10202 m .80075 1.14151 L .82558 1.16838 L p F P
0 g
s
1 g
.80075 1.14151 m .81284 1.10202 L .78303 1.08103 L p F P
0 g
s
1 g
.73587 1.10541 m .74925 1.06658 L .71326 1.05942 L p F P
0 g
s
1 g
.71326 1.05942 m .69917 1.09808 L .73587 1.10541 L p F P
0 g
s
1 g
.78303 1.08103 m .77033 1.12014 L .80075 1.14151 L p F P
0 g
s
1 g
.77033 1.12014 m .78303 1.08103 L .74925 1.06658 L p F P
0 g
s
1 g
.74925 1.06658 m .73587 1.10541 L .77033 1.12014 L p F P
0 g
s
1 g
.83591 1.33098 m .82424 1.37516 L .80289 1.40212 L p F P
0 g
s
1 g
.82424 1.37516 m .83591 1.33098 L .84983 1.30032 L p F P
0 g
s
.69098 1.25259 m
.68666 1.26521 L
s
1 g
.84983 1.30032 m .8384 1.34404 L .82424 1.37516 L p F P
0 g
s
1 g
.8384 1.34404 m .84983 1.30032 L .85593 1.26705 L p F P
0 g
s
1 g
.55031 1.18474 m .5675 1.14394 L .54674 1.17103 L p F P
0 g
s
1 g
.54674 1.17103 m .52919 1.21224 L .55031 1.18474 L p F P
0 g
s
1 g
.85593 1.26705 m .84459 1.31025 L .8384 1.34404 L p F P
0 g
s
1 g
.84459 1.31025 m .85593 1.26705 L .85384 1.23282 L p F P
0 g
s
1 g
.65634 1.49411 m .67141 1.44725 L .70809 1.44671 L p F P
0 g
s
.68666 1.26521 m
.6823 1.27798 L
s
1 g
.70809 1.44671 m .69373 1.49362 L .65634 1.49411 L p F P
0 g
s
1 g
.69373 1.49362 m .70809 1.44671 L .74334 1.43872 L p F P
0 g
s
1 g
.57788 1.16259 m .59458 1.12211 L .5675 1.14394 L p F P
0 g
s
1 g
.5675 1.14394 m .55031 1.18474 L .57788 1.16259 L p F P
0 g
s
1 g
.85384 1.23282 m .84241 1.27547 L .84459 1.31025 L p F P
0 g
s
1 g
.84241 1.27547 m .85384 1.23282 L .84357 1.19936 L p F P
0 g
s
1 g
.74334 1.43872 m .72967 1.48557 L .69373 1.49362 L p F P
0 g
s
1 g
.72967 1.48557 m .74334 1.43872 L .77546 1.42364 L p F P
0 g
s
1 g
.61057 1.14697 m .62666 1.10669 L .59458 1.12211 L p F P
0 g
s
1 g
.59458 1.12211 m .57788 1.16259 L .61057 1.14697 L p F P
0 g
s
1 g
.84357 1.19936 m .8319 1.24146 L .84241 1.27547 L p F P
0 g
s
1 g
.8319 1.24146 m .84357 1.19936 L .82558 1.16838 L p F P
0 g
s
1 g
.77546 1.42364 m .76241 1.4703 L .72967 1.48557 L p F P
0 g
s
1 g
.76241 1.4703 m .77546 1.42364 L .80289 1.40212 L p F P
0 g
s
1 g
.64672 1.13872 m .66212 1.09853 L .62666 1.10669 L p F P
0 g
s
1 g
.62666 1.10669 m .61057 1.14697 L .64672 1.13872 L p F P
0 g
s
.6823 1.27798 m
.67788 1.2909 L
s
1 g
.82558 1.16838 m .81352 1.20995 L .8319 1.24146 L p F P
0 g
s
1 g
.81352 1.20995 m .82558 1.16838 L .80075 1.14151 L p F P
0 g
s
1 g
.6845 1.13832 m .69917 1.09808 L .66212 1.09853 L p F P
0 g
s
1 g
.66212 1.09853 m .64672 1.13872 L .6845 1.13832 L p F P
0 g
s
1 g
.80289 1.40212 m .79036 1.44849 L .76241 1.4703 L p F P
0 g
s
1 g
.79036 1.44849 m .80289 1.40212 L .82424 1.37516 L p F P
0 g
s
1 g
.80075 1.14151 m .78816 1.1826 L .81352 1.20995 L p F P
0 g
s
1 g
.78816 1.1826 m .80075 1.14151 L .77033 1.12014 L p F P
0 g
s
1 g
.72194 1.14582 m .73587 1.10541 L .69917 1.09808 L p F P
0 g
s
1 g
.69917 1.09808 m .6845 1.13832 L .72194 1.14582 L p F P
0 g
s
1 g
.77033 1.12014 m .75711 1.16084 L .78816 1.1826 L p F P
0 g
s
1 g
.75711 1.16084 m .77033 1.12014 L .73587 1.10541 L p F P
0 g
s
1 g
.73587 1.10541 m .72194 1.14582 L .75711 1.16084 L p F P
0 g
s
1 g
.82424 1.37516 m .8121 1.42114 L .79036 1.44849 L p F P
0 g
s
1 g
.8121 1.42114 m .82424 1.37516 L .8384 1.34404 L p F P
0 g
s
.67788 1.2909 m
.67341 1.30399 L
s
1 g
.8384 1.34404 m .8265 1.38954 L .8121 1.42114 L p F P
0 g
s
1 g
.8265 1.38954 m .8384 1.34404 L .84459 1.31025 L p F P
0 g
s
1 g
.53241 1.22722 m .55031 1.18474 L .52919 1.21224 L p F P
0 g
s
1 g
.52919 1.21224 m .51092 1.25514 L .53241 1.22722 L p F P
0 g
s
.67341 1.30399 m
.66888 1.31723 L
s
1 g
.84459 1.31025 m .83278 1.35523 L .8265 1.38954 L p F P
0 g
s
1 g
.83278 1.35523 m .84459 1.31025 L .84241 1.27547 L p F P
0 g
s
1 g
.64065 1.54289 m .65634 1.49411 L .69373 1.49362 L p F P
0 g
s
1 g
.69373 1.49362 m .67879 1.54246 L .64065 1.54289 L p F P
0 g
s
1 g
.67879 1.54246 m .69373 1.49362 L .72967 1.48557 L p F P
0 g
s
1 g
.5605 1.20475 m .57788 1.16259 L .55031 1.18474 L p F P
0 g
s
1 g
.55031 1.18474 m .53241 1.22722 L .5605 1.20475 L p F P
0 g
s
1 g
.84241 1.27547 m .83052 1.31988 L .83278 1.35523 L p F P
0 g
s
1 g
.83052 1.31988 m .84241 1.27547 L .8319 1.24146 L p F P
0 g
s
1 g
.72967 1.48557 m .71544 1.53435 L .67879 1.54246 L p F P
0 g
s
1 g
.71544 1.53435 m .72967 1.48557 L .76241 1.4703 L p F P
0 g
s
1 g
.59381 1.18891 m .61057 1.14697 L .57788 1.16259 L p F P
0 g
s
1 g
.57788 1.16259 m .5605 1.20475 L .59381 1.18891 L p F P
0 g
s
.66888 1.31723 m
.6643 1.33063 L
s
1 g
.8319 1.24146 m .81975 1.28529 L .83052 1.31988 L p F P
0 g
s
1 g
.81975 1.28529 m .8319 1.24146 L .81352 1.20995 L p F P
0 g
s
1 g
.76241 1.4703 m .74882 1.51889 L .71544 1.53435 L p F P
0 g
s
1 g
.74882 1.51889 m .76241 1.4703 L .79036 1.44849 L p F P
0 g
s
1 g
.63068 1.18058 m .64672 1.13872 L .61057 1.14697 L p F P
0 g
s
1 g
.61057 1.14697 m .59381 1.18891 L .63068 1.18058 L p F P
0 g
s
1 g
.81352 1.20995 m .80096 1.25324 L .81975 1.28529 L p F P
0 g
s
1 g
.80096 1.25324 m .81352 1.20995 L .78816 1.1826 L p F P
0 g
s
1 g
.66922 1.18023 m .6845 1.13832 L .64672 1.13872 L p F P
0 g
s
1 g
.64672 1.13872 m .63068 1.18058 L .66922 1.18023 L p F P
0 g
s
1 g
.79036 1.44849 m .7773 1.49679 L .74882 1.51889 L p F P
0 g
s
1 g
.7773 1.49679 m .79036 1.44849 L .8121 1.42114 L p F P
0 g
s
1 g
.78816 1.1826 m .77505 1.2254 L .80096 1.25324 L p F P
0 g
s
1 g
.77505 1.2254 m .78816 1.1826 L .75711 1.16084 L p F P
0 g
s
1 g
.70744 1.18791 m .72194 1.14582 L .6845 1.13832 L p F P
0 g
s
1 g
.6845 1.13832 m .66922 1.18023 L .70744 1.18791 L p F P
0 g
s
1 g
.75711 1.16084 m .74334 1.20323 L .77505 1.2254 L p F P
0 g
s
1 g
.74334 1.20323 m .75711 1.16084 L .72194 1.14582 L p F P
0 g
s
1 g
.72194 1.14582 m .70744 1.18791 L .74334 1.20323 L p F P
0 g
s
.6643 1.33063 m
.65966 1.3442 L
s
1 g
.8121 1.42114 m .79945 1.46904 L .7773 1.49679 L p F P
0 g
s
1 g
.79945 1.46904 m .8121 1.42114 L .8265 1.38954 L p F P
0 g
s
1 g
.8265 1.38954 m .81411 1.43696 L .79945 1.46904 L p F P
0 g
s
1 g
.81411 1.43696 m .8265 1.38954 L .83278 1.35523 L p F P
0 g
s
.65966 1.3442 m
.65496 1.35793 L
s
1 g
.51375 1.27149 m .53241 1.22722 L .51092 1.25514 L p F P
0 g
s
1 g
.51092 1.25514 m .49188 1.29983 L .51375 1.27149 L p F P
0 g
s
1 g
.83278 1.35523 m .82047 1.40209 L .81411 1.43696 L p F P
0 g
s
1 g
.82047 1.40209 m .83278 1.35523 L .83052 1.31988 L p F P
0 g
s
1 g
.6243 1.59373 m .64065 1.54289 L .67879 1.54246 L p F P
0 g
s
1 g
.67879 1.54246 m .66322 1.59336 L .6243 1.59373 L p F P
0 g
s
1 g
.66322 1.59336 m .67879 1.54246 L .71544 1.53435 L p F P
0 g
s
1 g
.54237 1.24869 m .5605 1.20475 L .53241 1.22722 L p F P
0 g
s
1 g
.53241 1.22722 m .51375 1.27149 L .54237 1.24869 L p F P
0 g
s
1 g
.83052 1.31988 m .81812 1.36616 L .82047 1.40209 L p F P
0 g
s
1 g
.81812 1.36616 m .83052 1.31988 L .81975 1.28529 L p F P
0 g
s
.65496 1.35793 m
.65021 1.37184 L
s
1 g
.71544 1.53435 m .7006 1.58518 L .66322 1.59336 L p F P
0 g
s
1 g
.7006 1.58518 m .71544 1.53435 L .74882 1.51889 L p F P
0 g
s
1 g
.57635 1.23264 m .59381 1.18891 L .5605 1.20475 L p F P
0 g
s
1 g
.5605 1.20475 m .54237 1.24869 L .57635 1.23264 L p F P
0 g
s
1 g
.81975 1.28529 m .80709 1.33099 L .81812 1.36616 L p F P
0 g
s
1 g
.80709 1.33099 m .81975 1.28529 L .80096 1.25324 L p F P
0 g
s
1 g
.74882 1.51889 m .73465 1.56955 L .7006 1.58518 L p F P
0 g
s
1 g
.73465 1.56955 m .74882 1.51889 L .7773 1.49679 L p F P
0 g
s
1 g
.61396 1.22422 m .63068 1.18058 L .59381 1.18891 L p F P
0 g
s
1 g
.59381 1.18891 m .57635 1.23264 L .61396 1.22422 L p F P
0 g
s
1 g
.80096 1.25324 m .78787 1.29837 L .80709 1.33099 L p F P
0 g
s
1 g
.78787 1.29837 m .80096 1.25324 L .77505 1.2254 L p F P
0 g
s
1 g
.6533 1.22392 m .66922 1.18023 L .63068 1.18058 L p F P
0 g
s
1 g
.63068 1.18058 m .61396 1.22422 L .6533 1.22392 L p F P
0 g
s
1 g
.7773 1.49679 m .76369 1.54714 L .73465 1.56955 L p F P
0 g
s
1 g
.76369 1.54714 m .7773 1.49679 L .79945 1.46904 L p F P
0 g
s
.65021 1.37184 m
.64539 1.38592 L
s
1 g
.77505 1.2254 m .76139 1.27002 L .78787 1.29837 L p F P
0 g
s
1 g
.76139 1.27002 m .77505 1.2254 L .74334 1.20323 L p F P
0 g
s
1 g
.69231 1.23179 m .70744 1.18791 L .66922 1.18023 L p F P
0 g
s
1 g
.66922 1.18023 m .6533 1.22392 L .69231 1.23179 L p F P
0 g
s
1 0 .462 r
.64614 1.10156 m
.6816 1.18264 L
s
.6816 1.18264 m
.68319 1.18626 L
s
.80324 1.46074 m
.80337 1.46104 L
s
.80337 1.46104 m
.83946 1.54356 L
s
0 .538 1 r
.82676 1.56336 m
.83946 1.54356 L
s
0 0 1 r
.03 w
.83946 1.54356 Mdot
.5 Mabswid
1 g
.74334 1.20323 m .72898 1.24743 L .76139 1.27002 L p F P
0 g
s
1 g
.72898 1.24743 m .74334 1.20323 L .70744 1.18791 L p F P
0 g
s
1 g
.70744 1.18791 m .69231 1.23179 L .72898 1.24743 L p F P
0 g
s
1 0 .462 r
.70557 1.23744 m
.80279 1.4597 L
s
1 0 .231 r
.64614 1.10156 m
.64684 1.20815 L
s
1 0 .923 r
.37087 1.48627 m
.38645 1.4645 L
s
.57248 1.20452 m
.64614 1.10156 L
s
.55881 1.22361 m
.57248 1.20452 L
s
.55111 1.23437 m
.55881 1.22361 L
s
.54872 1.23771 m
.55111 1.23437 L
s
0 0 1 r
.03 w
.64614 1.10156 Mdot
.5 Mabswid
1 g
.79945 1.46904 m .78626 1.51898 L .76369 1.54714 L p F P
0 g
s
.615 1 0 r
.77307 1.53544 m
.83946 1.54356 L
s
1 g
.78626 1.51898 m .79945 1.46904 L .81411 1.43696 L p F P
0 g
s
.64539 1.38592 m
.64052 1.40017 L
s
1 g
.81411 1.43696 m .80119 1.4864 L .78626 1.51898 L p F P
0 g
s
1 g
.80119 1.4864 m .81411 1.43696 L .82047 1.40209 L p F P
0 g
s
1 g
.4943 1.31766 m .51375 1.27149 L .49188 1.29983 L p F P
0 g
s
1 g
.49188 1.29983 m .47202 1.34645 L .4943 1.31766 L p F P
0 g
s
1 0 .923 r
.38645 1.4645 m
.47364 1.34264 L
s
1 g
.82047 1.40209 m .80763 1.45097 L .80119 1.4864 L p F P
0 g
s
.385 1 0 r
.81146 1.48522 m
.83946 1.54356 L
s
1 g
.80763 1.45097 m .82047 1.40209 L .81812 1.36616 L p F P
0 g
s
1 g
.60724 1.64674 m .6243 1.59373 L .66322 1.59336 L p F P
0 g
s
.64052 1.40017 m
.63558 1.41461 L
s
1 g
.66322 1.59336 m .64698 1.64644 L .60724 1.64674 L p F P
0 g
s
1 g
.64698 1.64644 m .66322 1.59336 L .7006 1.58518 L p F P
0 g
s
1 g
.52347 1.29452 m .54237 1.24869 L .51375 1.27149 L p F P
0 g
s
1 g
.51375 1.27149 m .4943 1.31766 L .52347 1.29452 L p F P
0 g
s
1 g
.81812 1.36616 m .80519 1.41444 L .80763 1.45097 L p F P
0 g
s
1 g
.80519 1.41444 m .81812 1.36616 L .80709 1.33099 L p F P
0 g
s
1 g
.7006 1.58518 m .68513 1.63821 L .64698 1.64644 L p F P
0 g
s
1 g
.68513 1.63821 m .7006 1.58518 L .73465 1.56955 L p F P
0 g
s
1 g
.55812 1.27825 m .57635 1.23264 L .54237 1.24869 L p F P
0 g
s
1 g
.54237 1.24869 m .52347 1.29452 L .55812 1.27825 L p F P
0 g
s
1 g
.80709 1.33099 m .79388 1.37865 L .80519 1.41444 L p F P
0 g
s
1 g
.79388 1.37865 m .80709 1.33099 L .78787 1.29837 L p F P
0 g
s
1 g
.73465 1.56955 m .71987 1.62239 L .68513 1.63821 L p F P
0 g
s
1 g
.71987 1.62239 m .73465 1.56955 L .76369 1.54714 L p F P
0 g
s
1 g
.59652 1.26975 m .61396 1.22422 L .57635 1.23264 L p F P
0 g
s
1 g
.57635 1.23264 m .55812 1.27825 L .59652 1.26975 L p F P
0 g
s
.63558 1.41461 m
.63059 1.42923 L
s
1 g
.78787 1.29837 m .77421 1.34545 L .79388 1.37865 L p F P
0 g
s
1 g
.77421 1.34545 m .78787 1.29837 L .76139 1.27002 L p F P
0 g
s
1 g
.63668 1.26951 m .6533 1.22392 L .61396 1.22422 L p F P
0 g
s
1 g
.61396 1.22422 m .59652 1.26975 L .63668 1.26951 L p F P
0 g
s
1 g
.76369 1.54714 m .74949 1.59967 L .71987 1.62239 L p F P
0 g
s
1 g
.74949 1.59967 m .76369 1.54714 L .78626 1.51898 L p F P
0 g
s
1 g
.76139 1.27002 m .74713 1.31658 L .77421 1.34545 L p F P
0 g
s
1 g
.74713 1.31658 m .76139 1.27002 L .72898 1.24743 L p F P
0 g
s
1 g
.67654 1.27758 m .69231 1.23179 L .6533 1.22392 L p F P
0 g
s
1 g
.6533 1.22392 m .63668 1.26951 L .67654 1.27758 L p F P
0 g
s
1 g
.72898 1.24743 m .714 1.29354 L .74713 1.31658 L p F P
0 g
s
1 g
.714 1.29354 m .72898 1.24743 L .69231 1.23179 L p F P
0 g
s
1 g
.69231 1.23179 m .67654 1.27758 L .714 1.29354 L p F P
0 g
s
1 g
.78626 1.51898 m .7725 1.57109 L .74949 1.59967 L p F P
0 g
s
.615 1 0 r
.37087 1.48627 m
.75173 1.53283 L
s
1 g
.7725 1.57109 m .78626 1.51898 L .80119 1.4864 L p F P
0 g
s
0 .538 1 r
.65099 1.83746 m
.69574 1.76767 L
s
0 g
.63059 1.42923 m
.62552 1.44404 L
s
0 1 1 r
.37087 1.48627 m
.55777 1.72058 L
s
1 .231 0 r
.37087 1.48627 m
.37286 1.48541 L
s
0 0 1 r
.03 w
.37087 1.48627 Mdot
.5 Mabswid
1 g
.80119 1.4864 m .7877 1.538 L .7725 1.57109 L p F P
0 g
s
1 g
.7877 1.538 m .80119 1.4864 L .80763 1.45097 L p F P
0 g
s
.385 1 0 r
.80677 1.47546 m
.81146 1.48522 L
s
1 g
.47398 1.36587 m .4943 1.31766 L .47202 1.34645 L p F P
0 g
s
1 g
.47202 1.34645 m .4513 1.3951 L .47398 1.36587 L p F P
0 g
s
.62552 1.44404 m
.62039 1.45905 L
s
1 g
.80763 1.45097 m .79423 1.50199 L .7877 1.538 L p F P
0 g
s
1 g
.79423 1.50199 m .80763 1.45097 L .80519 1.41444 L p F P
0 g
s
.385 1 0 r
.80376 1.46919 m
.80677 1.47546 L
s
1 g
.58944 1.70208 m .60724 1.64674 L .64698 1.64644 L p F P
0 g
s
1 g
.64698 1.64644 m .63002 1.70186 L .58944 1.70208 L p F P
0 g
s
1 g
.63002 1.70186 m .64698 1.64644 L .68513 1.63821 L p F P
0 g
s
1 g
.50373 1.34237 m .52347 1.29452 L .4943 1.31766 L p F P
0 g
s
1 g
.4943 1.31766 m .47398 1.36587 L .50373 1.34237 L p F P
0 g
s
1 g
.80519 1.41444 m .79169 1.46484 L .79423 1.50199 L p F P
0 g
s
1 g
.79169 1.46484 m .80519 1.41444 L .79388 1.37865 L p F P
0 g
s
1 g
.68513 1.63821 m .66898 1.69357 L .63002 1.70186 L p F P
0 g
s
1 g
.66898 1.69357 m .68513 1.63821 L .71987 1.62239 L p F P
0 g
s
1 g
.5391 1.32588 m .55812 1.27825 L .52347 1.29452 L p F P
0 g
s
1 g
.52347 1.29452 m .50373 1.34237 L .5391 1.32588 L p F P
0 g
s
.62039 1.45905 m
.6152 1.47424 L
s
1 g
.79388 1.37865 m .78009 1.42842 L .79169 1.46484 L p F P
0 g
s
1 g
.78009 1.42842 m .79388 1.37865 L .77421 1.34545 L p F P
0 g
s
1 g
.71987 1.62239 m .70444 1.67756 L .66898 1.69357 L p F P
0 g
s
1 g
.70444 1.67756 m .71987 1.62239 L .74949 1.59967 L p F P
0 g
s
1 g
.5783 1.3173 m .59652 1.26975 L .55812 1.27825 L p F P
0 g
s
1 g
.55812 1.27825 m .5391 1.32588 L .5783 1.3173 L p F P
0 g
s
1 g
.77421 1.34545 m .75994 1.39462 L .78009 1.42842 L p F P
0 g
s
1 g
.75994 1.39462 m .77421 1.34545 L .74713 1.31658 L p F P
0 g
s
1 g
.61933 1.31712 m .63668 1.26951 L .59652 1.26975 L p F P
0 g
s
1 g
.59652 1.26975 m .5783 1.3173 L .61933 1.31712 L p F P
0 g
s
1 g
.74949 1.59967 m .73466 1.65453 L .70444 1.67756 L p F P
0 g
s
1 g
.73466 1.65453 m .74949 1.59967 L .7725 1.57109 L p F P
0 g
s
1 g
.74713 1.31658 m .73224 1.3652 L .75994 1.39462 L p F P
0 g
s
1 0 .692 r
.64614 1.10156 m
.6644 1.14758 L
s
1 g
.73224 1.3652 m .74713 1.31658 L .714 1.29354 L p F P
0 g
s
1 g
.66006 1.3254 m .67654 1.27758 L .63668 1.26951 L p F P
0 g
s
1 g
.63668 1.26951 m .61933 1.31712 L .66006 1.3254 L p F P
0 g
s
1 g
.714 1.29354 m .69836 1.34171 L .73224 1.3652 L p F P
0 g
s
1 g
.69836 1.34171 m .714 1.29354 L .67654 1.27758 L p F P
0 g
s
1 g
.67654 1.27758 m .66006 1.3254 L .69836 1.34171 L p F P
0 g
s
.6152 1.47424 m
.60993 1.48964 L
s
1 g
.7725 1.57109 m .75813 1.62552 L .73466 1.65453 L p F P
0 g
s
1 g
.75813 1.62552 m .7725 1.57109 L .7877 1.538 L p F P
0 g
s
1 g
.7877 1.538 m .77361 1.59191 L .75813 1.62552 L p F P
0 g
s
1 g
.77361 1.59191 m .7877 1.538 L .79423 1.50199 L p F P
0 g
s
0 .538 1 r
.76714 1.65634 m
.82676 1.56336 L
s
0 g
.60993 1.48964 m
.6046 1.50524 L
s
1 g
.45276 1.41623 m .47398 1.36587 L .4513 1.3951 L p F P
0 g
s
1 g
.4513 1.3951 m .42965 1.44593 L .45276 1.41623 L p F P
0 g
s
1 g
.79423 1.50199 m .78024 1.5553 L .77361 1.59191 L p F P
0 g
s
1 g
.78024 1.5553 m .79423 1.50199 L .79169 1.46484 L p F P
0 g
s
1 g
.57084 1.75991 m .58944 1.70208 L .63002 1.70186 L p F P
0 g
s
1 g
.63002 1.70186 m .61231 1.75977 L .57084 1.75991 L p F P
0 g
s
0 1 1 r
.55777 1.72058 m
.5761 1.74356 L
s
1 g
.61231 1.75977 m .63002 1.70186 L .66898 1.69357 L p F P
0 g
s
1 g
.48311 1.39238 m .50373 1.34237 L .47398 1.36587 L p F P
0 g
s
1 g
.47398 1.36587 m .45276 1.41623 L .48311 1.39238 L p F P
0 g
s
1 g
.79169 1.46484 m .77758 1.51751 L .78024 1.5553 L p F P
0 g
s
1 g
.77758 1.51751 m .79169 1.46484 L .78009 1.42842 L p F P
0 g
s
.6046 1.50524 m
.5992 1.52105 L
s
1 g
.66898 1.69357 m .6521 1.75143 L .61231 1.75977 L p F P
0 g
s
1 0 .231 r
.65043 1.75178 m
.65099 1.83746 L
s
.6476 1.32286 m
.6502 1.71671 L
s
1 g
.6521 1.75143 m .66898 1.69357 L .70444 1.67756 L p F P
0 g
s
0 .538 1 r
.69574 1.76767 m
.76714 1.65634 L
s
1 g
.51921 1.37566 m .5391 1.32588 L .50373 1.34237 L p F P
0 g
s
1 g
.50373 1.34237 m .48311 1.39238 L .51921 1.37566 L p F P
0 g
s
1 g
.78009 1.42842 m .76567 1.48044 L .77758 1.51751 L p F P
0 g
s
1 g
.76567 1.48044 m .78009 1.42842 L .75994 1.39462 L p F P
0 g
s
.385 1 0 r
.76765 1.39396 m
.7692 1.39721 L
s
.7692 1.39721 m
.77589 1.41114 L
s
1 g
.70444 1.67756 m .68831 1.73523 L .6521 1.75143 L p F P
0 g
s
1 g
.68831 1.73523 m .70444 1.67756 L .73466 1.65453 L p F P
0 g
s
1 g
.55925 1.367 m .5783 1.3173 L .5391 1.32588 L p F P
0 g
s
1 g
.5391 1.32588 m .51921 1.37566 L .55925 1.367 L p F P
0 g
s
1 g
.75994 1.39462 m .74504 1.44601 L .76567 1.48044 L p F P
0 g
s
1 g
.74504 1.44601 m .75994 1.39462 L .73224 1.3652 L p F P
0 g
s
1 g
.60119 1.36689 m .61933 1.31712 L .5783 1.3173 L p F P
0 g
s
1 g
.5783 1.3173 m .55925 1.367 L .60119 1.36689 L p F P
0 g
s
1 g
.73466 1.65453 m .71916 1.71187 L .68831 1.73523 L p F P
0 g
s
1 g
.71916 1.71187 m .73466 1.65453 L .75813 1.62552 L p F P
0 g
s
.5992 1.52105 m
.59372 1.53706 L
s
1 g
.73224 1.3652 m .71667 1.41602 L .74504 1.44601 L p F P
0 g
s
.385 1 0 r
.73585 1.32774 m
.76765 1.39396 L
s
1 g
.71667 1.41602 m .73224 1.3652 L .69836 1.34171 L p F P
0 g
s
1 g
.64283 1.37539 m .66006 1.3254 L .61933 1.31712 L p F P
0 g
s
1 g
.61933 1.31712 m .60119 1.36689 L .64283 1.37539 L p F P
0 g
s
1 .231 0 r
.37286 1.48541 m
.63149 1.37307 L
s
1 g
.69836 1.34171 m .682 1.39206 L .71667 1.41602 L p F P
0 g
s
1 g
.682 1.39206 m .69836 1.34171 L .66006 1.3254 L p F P
0 g
s
1 g
.66006 1.3254 m .64283 1.37539 L .682 1.39206 L p F P
0 g
s
1 0 .692 r
.6644 1.14758 m
.73585 1.32774 L
s
1 .231 0 r
.66561 1.35825 m
.67929 1.35231 L
s
.66232 1.35968 m
.66561 1.35825 L
s
.67929 1.35231 m
.73585 1.32774 L
s
1 g
.75813 1.62552 m .7431 1.68243 L .71916 1.71187 L p F P
0 g
s
1 g
.7431 1.68243 m .75813 1.62552 L .77361 1.59191 L p F P
0 g
s
.59372 1.53706 m
.58817 1.5533 L
s
1 g
.77361 1.59191 m .75887 1.64827 L .7431 1.68243 L p F P
0 g
s
1 g
.75887 1.64827 m .77361 1.59191 L .78024 1.5553 L p F P
0 g
s
1 g
.43056 1.46891 m .45276 1.41623 L .42965 1.44593 L p F P
0 g
s
1 g
.42965 1.44593 m .407 1.49909 L .43056 1.46891 L p F P
0 g
s
1 g
.78024 1.5553 m .76559 1.61105 L .75887 1.64827 L p F P
0 g
s
1 g
.76559 1.61105 m .78024 1.5553 L .77758 1.51751 L p F P
0 g
s
1 g
.55139 1.82039 m .57084 1.75991 L .61231 1.75977 L p F P
0 g
s
0 1 1 r
.59933 1.77269 m
.65099 1.83746 L
s
0 .769 1 r
.66636 1.74514 m
.66638 1.74504 L
s
0 g
.58817 1.5533 m
.58255 1.56975 L
s
1 g
.61231 1.75977 m .59378 1.82034 L .55139 1.82039 L p F P
0 g
s
1 g
.59378 1.82034 m .61231 1.75977 L .6521 1.75143 L p F P
0 g
s
0 .769 1 r
.65099 1.83746 m
.66636 1.74514 L
s
1 g
.46153 1.4447 m .48311 1.39238 L .45276 1.41623 L p F P
0 g
s
1 g
.45276 1.41623 m .43056 1.46891 L .46153 1.4447 L p F P
0 g
s
1 g
.77758 1.51751 m .76282 1.5726 L .76559 1.61105 L p F P
0 g
s
1 g
.76282 1.5726 m .77758 1.51751 L .76567 1.48044 L p F P
0 g
s
1 g
.6521 1.75143 m .63444 1.81195 L .59378 1.82034 L p F P
0 g
s
1 g
.63444 1.81195 m .6521 1.75143 L .68831 1.73523 L p F P
0 g
s
1 g
.4984 1.42775 m .51921 1.37566 L .48311 1.39238 L p F P
0 g
s
1 g
.48311 1.39238 m .46153 1.4447 L .4984 1.42775 L p F P
0 g
s
1 g
.76567 1.48044 m .75059 1.53486 L .76282 1.5726 L p F P
0 g
s
1 g
.75059 1.53486 m .76567 1.48044 L .74504 1.44601 L p F P
0 g
s
1 g
.68831 1.73523 m .67143 1.79556 L .63444 1.81195 L p F P
0 g
s
1 g
.67143 1.79556 m .68831 1.73523 L .71916 1.71187 L p F P
0 g
s
.58255 1.56975 m
.57684 1.58643 L
s
1 g
.53933 1.41901 m .55925 1.367 L .51921 1.37566 L p F P
0 g
s
1 g
.51921 1.37566 m .4984 1.42775 L .53933 1.41901 L p F P
0 g
s
1 g
.74504 1.44601 m .72943 1.49978 L .75059 1.53486 L p F P
0 g
s
1 g
.72943 1.49978 m .74504 1.44601 L .71667 1.41602 L p F P
0 g
s
1 g
.5822 1.41898 m .60119 1.36689 L .55925 1.367 L p F P
0 g
s
1 g
.55925 1.367 m .53933 1.41901 L .5822 1.41898 L p F P
0 g
s
1 g
.71916 1.71187 m .70294 1.77188 L .67143 1.79556 L p F P
0 g
s
1 g
.70294 1.77188 m .71916 1.71187 L .7431 1.68243 L p F P
0 g
s
1 g
.71667 1.41602 m .70038 1.4692 L .72943 1.49978 L p F P
0 g
s
0 .769 1 r
.66703 1.74115 m
.71053 1.47988 L
s
.71952 1.42585 m
.73585 1.32774 L
s
1 g
.70038 1.4692 m .71667 1.41602 L .682 1.39206 L p F P
0 g
s
1 g
.6248 1.4277 m .64283 1.37539 L .60119 1.36689 L p F P
0 g
s
1 g
.60119 1.36689 m .5822 1.41898 L .6248 1.4277 L p F P
0 g
s
1 g
.682 1.39206 m .66489 1.44474 L .70038 1.4692 L p F P
0 g
s
1 g
.66489 1.44474 m .682 1.39206 L .64283 1.37539 L p F P
0 g
s
1 g
.64283 1.37539 m .6248 1.4277 L .66489 1.44474 L p F P
0 g
s
1 g
.7431 1.68243 m .72737 1.74198 L .70294 1.77188 L p F P
0 g
s
1 g
.72737 1.74198 m .7431 1.68243 L .75887 1.64827 L p F P
0 g
s
.57684 1.58643 m
.57106 1.60333 L
s
0 0 1 r
.03 w
.73585 1.32774 Mdot
.5 Mabswid
1 g
.75887 1.64827 m .74345 1.70728 L .72737 1.74198 L p F P
0 g
s
1 g
.74345 1.70728 m .75887 1.64827 L .76559 1.61105 L p F P
0 g
s
1 g
.40732 1.52407 m .43056 1.46891 L .407 1.49909 L p F P
0 g
s
1 g
.407 1.49909 m .3833 1.55474 L .40732 1.52407 L p F P
0 g
s
.57106 1.60333 m
.5652 1.62047 L
s
1 g
.76559 1.61105 m .75027 1.66942 L .74345 1.70728 L p F P
0 g
s
1 g
.75027 1.66942 m .76559 1.61105 L .76282 1.5726 L p F P
0 g
s
1 g
.53102 1.88371 m .55139 1.82039 L .59378 1.82034 L p F P
0 g
s
1 g
.59378 1.82034 m .57437 1.88376 L .53102 1.88371 L p F P
0 g
s
1 g
.57437 1.88376 m .59378 1.82034 L .63444 1.81195 L p F P
0 g
s
1 g
.43893 1.49949 m .46153 1.4447 L .43056 1.46891 L p F P
0 g
s
1 g
.43056 1.46891 m .40732 1.52407 L .43893 1.49949 L p F P
0 g
s
1 g
.76282 1.5726 m .74737 1.63029 L .75027 1.66942 L p F P
0 g
s
1 g
.74737 1.63029 m .76282 1.5726 L .75059 1.53486 L p F P
0 g
s
1 g
.63444 1.81195 m .61595 1.87532 L .57437 1.88376 L p F P
0 g
s
1 g
.61595 1.87532 m .63444 1.81195 L .67143 1.79556 L p F P
0 g
s
1 g
.47661 1.48231 m .4984 1.42775 L .46153 1.4447 L p F P
0 g
s
1 g
.46153 1.4447 m .43893 1.49949 L .47661 1.48231 L p F P
0 g
s
.5652 1.62047 m
.55926 1.63785 L
s
1 g
.75059 1.53486 m .7348 1.59185 L .74737 1.63029 L p F P
0 g
s
1 g
.7348 1.59185 m .75059 1.53486 L .72943 1.49978 L p F P
0 g
s
1 g
.67143 1.79556 m .65376 1.85874 L .61595 1.87532 L p F P
0 g
s
1 g
.65376 1.85874 m .67143 1.79556 L .70294 1.77188 L p F P
0 g
s
1 g
.51845 1.47348 m .53933 1.41901 L .4984 1.42775 L p F P
0 g
s
1 g
.4984 1.42775 m .47661 1.48231 L .51845 1.47348 L p F P
0 g
s
1 g
.72943 1.49978 m .71309 1.5561 L .7348 1.59185 L p F P
0 g
s
1 g
.71309 1.5561 m .72943 1.49978 L .70038 1.4692 L p F P
0 g
s
1 g
.56231 1.47354 m .5822 1.41898 L .53933 1.41901 L p F P
0 g
s
1 g
.53933 1.41901 m .51845 1.47348 L .56231 1.47354 L p F P
0 g
s
1 g
.70294 1.77188 m .68595 1.83473 L .65376 1.85874 L p F P
0 g
s
1 g
.68595 1.83473 m .70294 1.77188 L .72737 1.74198 L p F P
0 g
s
1 g
.70038 1.4692 m .68331 1.52491 L .71309 1.5561 L p F P
0 g
s
1 g
.68331 1.52491 m .70038 1.4692 L .66489 1.44474 L p F P
0 g
s
1 g
.60591 1.48251 m .6248 1.4277 L .5822 1.41898 L p F P
0 g
s
1 g
.5822 1.41898 m .56231 1.47354 L .60591 1.48251 L p F P
0 g
s
1 g
.66489 1.44474 m .64696 1.49994 L .68331 1.52491 L p F P
0 g
s
1 g
.64696 1.49994 m .66489 1.44474 L .6248 1.4277 L p F P
0 g
s
1 g
.6248 1.4277 m .60591 1.48251 L .64696 1.49994 L p F P
0 g
s
.55926 1.63785 m
.55324 1.65548 L
s
1 g
.72737 1.74198 m .7109 1.80438 L .68595 1.83473 L p F P
0 g
s
1 g
.7109 1.80438 m .72737 1.74198 L .74345 1.70728 L p F P
0 g
s
1 g
.74345 1.70728 m .72729 1.7691 L .7109 1.80438 L p F P
0 g
s
1 g
.72729 1.7691 m .74345 1.70728 L .75027 1.66942 L p F P
0 g
s
.55324 1.65548 m
.54713 1.67335 L
s
1 g
.38295 1.58189 m .40732 1.52407 L .3833 1.55474 L p F P
0 g
s
1 g
.3833 1.55474 m .35846 1.61306 L .38295 1.58189 L p F P
0 g
s
1 g
.75027 1.66942 m .7342 1.7306 L .72729 1.7691 L p F P
0 g
s
1 g
.7342 1.7306 m .75027 1.66942 L .74737 1.63029 L p F P
0 g
s
1 g
.50968 1.95007 m .53102 1.88371 L .57437 1.88376 L p F P
0 g
s
1 g
.57437 1.88376 m .55404 1.95023 L .50968 1.95007 L p F P
0 g
s
1 g
.55404 1.95023 m .57437 1.88376 L .61595 1.87532 L p F P
0 g
s
1 g
.41524 1.55693 m .43893 1.49949 L .40732 1.52407 L p F P
0 g
s
1 g
.40732 1.52407 m .38295 1.58189 L .41524 1.55693 L p F P
0 g
s
1 g
.74737 1.63029 m .73117 1.69076 L .7342 1.7306 L p F P
0 g
s
1 g
.73117 1.69076 m .74737 1.63029 L .7348 1.59185 L p F P
0 g
s
.54713 1.67335 m
.54093 1.69147 L
s
1 g
.61595 1.87532 m .59657 1.94176 L .55404 1.95023 L p F P
0 g
s
1 g
.59657 1.94176 m .61595 1.87532 L .65376 1.85874 L p F P
0 g
s
1 g
.45376 1.53951 m .47661 1.48231 L .43893 1.49949 L p F P
0 g
s
1 g
.43893 1.49949 m .41524 1.55693 L .45376 1.53951 L p F P
0 g
s
1 g
.7348 1.59185 m .71824 1.65161 L .73117 1.69076 L p F P
0 g
s
1 g
.71824 1.65161 m .7348 1.59185 L .71309 1.5561 L p F P
0 g
s
1 g
.65376 1.85874 m .63523 1.92498 L .59657 1.94176 L p F P
0 g
s
1 g
.63523 1.92498 m .65376 1.85874 L .68595 1.83473 L p F P
0 g
s
1 g
.49656 1.53061 m .51845 1.47348 L .47661 1.48231 L p F P
0 g
s
1 g
.47661 1.48231 m .45376 1.53951 L .49656 1.53061 L p F P
0 g
s
1 g
.71309 1.5561 m .69596 1.61516 L .71824 1.65161 L p F P
0 g
s
1 g
.69596 1.61516 m .71309 1.5561 L .68331 1.52491 L p F P
0 g
s
.54093 1.69147 m
.53465 1.70986 L
s
1 g
.54146 1.53076 m .56231 1.47354 L .51845 1.47348 L p F P
0 g
s
1 g
.51845 1.47348 m .49656 1.53061 L .54146 1.53076 L p F P
0 g
s
1 g
.68595 1.83473 m .66813 1.90064 L .63523 1.92498 L p F P
0 g
s
1 g
.66813 1.90064 m .68595 1.83473 L .7109 1.80438 L p F P
0 g
s
1 g
.68331 1.52491 m .66542 1.58333 L .69596 1.61516 L p F P
0 g
s
1 g
.66542 1.58333 m .68331 1.52491 L .64696 1.49994 L p F P
0 g
s
1 g
.5861 1.53998 m .60591 1.48251 L .56231 1.47354 L p F P
0 g
s
1 g
.56231 1.47354 m .54146 1.53076 L .5861 1.53998 L p F P
0 g
s
1 g
.64696 1.49994 m .62816 1.55782 L .66542 1.58333 L p F P
0 g
s
1 g
.62816 1.55782 m .64696 1.49994 L .60591 1.48251 L p F P
0 g
s
1 g
.60591 1.48251 m .5861 1.53998 L .62816 1.55782 L p F P
0 g
s
1 g
.7109 1.80438 m .69361 1.86982 L .66813 1.90064 L p F P
0 g
s
1 g
.69361 1.86982 m .7109 1.80438 L .72729 1.7691 L p F P
0 g
s
.53465 1.70986 m
.52827 1.72851 L
s
1 g
.72729 1.7691 m .71033 1.83396 L .69361 1.86982 L p F P
0 g
s
1 g
.71033 1.83396 m .72729 1.7691 L .7342 1.7306 L p F P
0 g
s
1 g
.35738 1.64256 m .38295 1.58189 L .35846 1.61306 L p F P
0 g
s
1 g
.35846 1.61306 m .33239 1.67424 L .35738 1.64256 L p F P
0 g
s
1 g
.7342 1.7306 m .71735 1.79478 L .71033 1.83396 L p F P
0 g
s
1 g
.71735 1.79478 m .7342 1.7306 L .73117 1.69076 L p F P
0 g
s
1 g
.48728 2.0197 m .50968 1.95007 L .55404 1.95023 L p F P
0 g
s
.52827 1.72851 m
.5218 1.74743 L
s
1 g
.55404 1.95023 m .5327 2.01999 L .48728 2.0197 L p F P
0 g
s
1 g
.5327 2.01999 m .55404 1.95023 L .59657 1.94176 L p F P
0 g
s
1 g
.39038 1.61721 m .41524 1.55693 L .38295 1.58189 L p F P
0 g
s
1 g
.38295 1.58189 m .35738 1.64256 L .39038 1.61721 L p F P
0 g
s
1 g
.73117 1.69076 m .71417 1.75422 L .71735 1.79478 L p F P
0 g
s
1 g
.71417 1.75422 m .73117 1.69076 L .71824 1.65161 L p F P
0 g
s
1 g
.59657 1.94176 m .57622 2.01148 L .5327 2.01999 L p F P
0 g
s
1 g
.57622 2.01148 m .59657 1.94176 L .63523 1.92498 L p F P
0 g
s
1 g
.42977 1.59955 m .45376 1.53951 L .41524 1.55693 L p F P
0 g
s
1 g
.41524 1.55693 m .39038 1.61721 L .42977 1.59955 L p F P
0 g
s
1 g
.71824 1.65161 m .70086 1.71432 L .71417 1.75422 L p F P
0 g
s
1 g
.70086 1.71432 m .71824 1.65161 L .69596 1.61516 L p F P
0 g
s
1 g
.63523 1.92498 m .61578 1.99452 L .57622 2.01148 L p F P
0 g
s
1 g
.61578 1.99452 m .63523 1.92498 L .66813 1.90064 L p F P
0 g
s
.5218 1.74743 m
.51524 1.76663 L
s
1 g
.47358 1.59058 m .49656 1.53061 L .45376 1.53951 L p F P
0 g
s
1 g
.45376 1.53951 m .42977 1.59955 L .47358 1.59058 L p F P
0 g
s
1 g
.69596 1.61516 m .67797 1.67715 L .70086 1.71432 L p F P
0 g
s
1 g
.67797 1.67715 m .69596 1.61516 L .66542 1.58333 L p F P
0 g
s
1 g
.51956 1.59083 m .54146 1.53076 L .49656 1.53061 L p F P
0 g
s
1 g
.49656 1.53061 m .47358 1.59058 L .51956 1.59083 L p F P
0 g
s
1 g
.66813 1.90064 m .64943 1.96983 L .61578 1.99452 L p F P
0 g
s
1 g
.64943 1.96983 m .66813 1.90064 L .69361 1.86982 L p F P
0 g
s
1 g
.66542 1.58333 m .64663 1.64467 L .67797 1.67715 L p F P
0 g
s
1 g
.64663 1.64467 m .66542 1.58333 L .62816 1.55782 L p F P
0 g
s
1 g
.56531 1.60033 m .5861 1.53998 L .54146 1.53076 L p F P
0 g
s
1 g
.54146 1.53076 m .51956 1.59083 L .56531 1.60033 L p F P
0 g
s
1 g
.62816 1.55782 m .60842 1.6186 L .64663 1.64467 L p F P
0 g
s
1 g
.60842 1.6186 m .62816 1.55782 L .5861 1.53998 L p F P
0 g
s
1 g
.5861 1.53998 m .56531 1.60033 L .60842 1.6186 L p F P
0 g
s
1 g
.69361 1.86982 m .67547 1.93854 L .64943 1.96983 L p F P
0 g
s
1 g
.67547 1.93854 m .69361 1.86982 L .71033 1.83396 L p F P
0 g
s
.51524 1.76663 m
.50858 1.78611 L
s
1 g
.71033 1.83396 m .69253 1.90208 L .67547 1.93854 L p F P
0 g
s
1 g
.69253 1.90208 m .71033 1.83396 L .71735 1.79478 L p F P
0 g
s
1 g
.33052 1.70631 m .35738 1.64256 L .33239 1.67424 L p F P
0 g
s
1 g
.33239 1.67424 m .30502 1.73852 L .33052 1.70631 L p F P
0 g
s
.50858 1.78611 m
.50182 1.80588 L
s
1 g
.71735 1.79478 m .69964 1.86221 L .69253 1.90208 L p F P
0 g
s
1 g
.69964 1.86221 m .71735 1.79478 L .71417 1.75422 L p F P
0 g
s
1 g
.46375 2.09285 m .48728 2.0197 L .5327 2.01999 L p F P
0 g
s
1 g
.5327 2.01999 m .51027 2.09327 L .46375 2.09285 L p F P
0 g
s
1 g
.51027 2.09327 m .5327 2.01999 L .57622 2.01148 L p F P
0 g
s
1 g
.36425 1.68056 m .39038 1.61721 L .35738 1.64256 L p F P
0 g
s
1 g
.35738 1.64256 m .33052 1.70631 L .36425 1.68056 L p F P
0 g
s
1 g
.71417 1.75422 m .69631 1.8209 L .69964 1.86221 L p F P
0 g
s
1 g
.69631 1.8209 m .71417 1.75422 L .70086 1.71432 L p F P
0 g
s
1 g
.57622 2.01148 m .55485 2.08474 L .51027 2.09327 L p F P
0 g
s
1 g
.55485 2.08474 m .57622 2.01148 L .61578 1.99452 L p F P
0 g
s
1 g
.40456 1.66266 m .42977 1.59955 L .39038 1.61721 L p F P
0 g
s
1 g
.39038 1.61721 m .36425 1.68056 L .40456 1.66266 L p F P
0 g
s
.50182 1.80588 m
.49496 1.82594 L
s
1 g
.70086 1.71432 m .68259 1.78023 L .69631 1.8209 L p F P
0 g
s
1 g
.68259 1.78023 m .70086 1.71432 L .67797 1.67715 L p F P
0 g
s
1 g
.61578 1.99452 m .59534 2.06759 L .55485 2.08474 L p F P
0 g
s
1 g
.59534 2.06759 m .61578 1.99452 L .64943 1.96983 L p F P
0 g
s
1 g
.44943 1.65362 m .47358 1.59058 L .42977 1.59955 L p F P
0 g
s
1 g
.42977 1.59955 m .40456 1.66266 L .44943 1.65362 L p F P
0 g
s
1 g
.67797 1.67715 m .65907 1.74231 L .68259 1.78023 L p F P
0 g
s
1 g
.65907 1.74231 m .67797 1.67715 L .64663 1.64467 L p F P
0 g
s
1 g
.49654 1.65398 m .51956 1.59083 L .47358 1.59058 L p F P
0 g
s
1 g
.47358 1.59058 m .44943 1.65362 L .49654 1.65398 L p F P
0 g
s
1 g
.64943 1.96983 m .62977 2.04257 L .59534 2.06759 L p F P
0 g
s
1 g
.62977 2.04257 m .64943 1.96983 L .67547 1.93854 L p F P
0 g
s
1 g
.64663 1.64467 m .62689 1.70914 L .65907 1.74231 L p F P
0 g
s
1 g
.62689 1.70914 m .64663 1.64467 L .60842 1.6186 L p F P
0 g
s
1 g
.54345 1.66377 m .56531 1.60033 L .51956 1.59083 L p F P
0 g
s
1 g
.51956 1.59083 m .49654 1.65398 L .54345 1.66377 L p F P
0 g
s
1 g
.60842 1.6186 m .58767 1.68249 L .62689 1.70914 L p F P
0 g
s
1 g
.58767 1.68249 m .60842 1.6186 L .56531 1.60033 L p F P
0 g
s
1 g
.56531 1.60033 m .54345 1.66377 L .58767 1.68249 L p F P
0 g
s
.49496 1.82594 m
.48799 1.84631 L
s
1 g
.67547 1.93854 m .65639 2.01078 L .62977 2.04257 L p F P
0 g
s
1 g
.65639 2.01078 m .67547 1.93854 L .69253 1.90208 L p F P
0 g
s
1 g
.69253 1.90208 m .6738 1.97371 L .65639 2.01078 L p F P
0 g
s
1 g
.6738 1.97371 m .69253 1.90208 L .69964 1.86221 L p F P
0 g
s
.48799 1.84631 m
.48092 1.86699 L
s
1 g
.30227 1.77336 m .33052 1.70631 L .30502 1.73852 L p F P
0 g
s
1 g
.30502 1.73852 m .27622 1.80611 L .30227 1.77336 L p F P
0 g
s
1 g
.69964 1.86221 m .68101 1.93313 L .6738 1.97371 L p F P
0 g
s
1 g
.68101 1.93313 m .69964 1.86221 L .69631 1.8209 L p F P
0 g
s
1 g
.439 2.1698 m .46375 2.09285 L .51027 2.09327 L p F P
0 g
s
1 g
.51027 2.09327 m .48669 2.17036 L .439 2.1698 L p F P
0 g
s
1 g
.48669 2.17036 m .51027 2.09327 L .55485 2.08474 L p F P
0 g
s
1 g
.33676 1.74721 m .36425 1.68056 L .33052 1.70631 L p F P
0 g
s
1 g
.33052 1.70631 m .30227 1.77336 L .33676 1.74721 L p F P
0 g
s
1 g
.69631 1.8209 m .67752 1.89105 L .68101 1.93313 L p F P
0 g
s
1 g
.67752 1.89105 m .69631 1.8209 L .68259 1.78023 L p F P
0 g
s
.48092 1.86699 m
.47375 1.88799 L
s
1 g
.55485 2.08474 m .53236 2.16181 L .48669 2.17036 L p F P
0 g
s
1 g
.53236 2.16181 m .55485 2.08474 L .59534 2.06759 L p F P
0 g
s
1 g
.37803 1.72907 m .40456 1.66266 L .36425 1.68056 L p F P
0 g
s
1 g
.36425 1.68056 m .33676 1.74721 L .37803 1.72907 L p F P
0 g
s
1 g
.68259 1.78023 m .66337 1.84958 L .67752 1.89105 L p F P
0 g
s
1 g
.66337 1.84958 m .68259 1.78023 L .65907 1.74231 L p F P
0 g
s
1 g
.59534 2.06759 m .57383 2.14448 L .53236 2.16181 L p F P
0 g
s
1 g
.57383 2.14448 m .59534 2.06759 L .62977 2.04257 L p F P
0 g
s
1 g
.42401 1.71997 m .44943 1.65362 L .40456 1.66266 L p F P
0 g
s
1 g
.40456 1.66266 m .37803 1.72907 L .42401 1.71997 L p F P
0 g
s
1 g
.65907 1.74231 m .63918 1.81089 L .66337 1.84958 L p F P
0 g
s
1 g
.63918 1.81089 m .65907 1.74231 L .62689 1.70914 L p F P
0 g
s
.47375 1.88799 m
.46646 1.9093 L
s
1 g
.47232 1.72045 m .49654 1.65398 L .44943 1.65362 L p F P
0 g
s
1 g
.44943 1.65362 m .42401 1.71997 L .47232 1.72045 L p F P
0 g
s
1 g
.62977 2.04257 m .60907 2.11911 L .57383 2.14448 L p F P
0 g
s
1 g
.60907 2.11911 m .62977 2.04257 L .65639 2.01078 L p F P
0 g
s
1 g
.62689 1.70914 m .6061 1.777 L .63918 1.81089 L p F P
0 g
s
1 g
.6061 1.777 m .62689 1.70914 L .58767 1.68249 L p F P
0 g
s
1 g
.52043 1.73054 m .54345 1.66377 L .49654 1.65398 L p F P
0 g
s
1 g
.49654 1.65398 m .47232 1.72045 L .52043 1.73054 L p F P
0 g
s
1 g
.58767 1.68249 m .56582 1.74973 L .6061 1.777 L p F P
0 g
s
1 g
.56582 1.74973 m .58767 1.68249 L .54345 1.66377 L p F P
0 g
s
1 g
.54345 1.66377 m .52043 1.73054 L .56582 1.74973 L p F P
0 g
s
1 g
.65639 2.01078 m .63631 2.08683 L .60907 2.11911 L p F P
0 g
s
1 g
.63631 2.08683 m .65639 2.01078 L .6738 1.97371 L p F P
0 g
s
.46646 1.9093 m
.45906 1.93095 L
s
1 g
.6738 1.97371 m .65409 2.04914 L .63631 2.08683 L p F P
0 g
s
1 g
.65409 2.04914 m .6738 1.97371 L .68101 1.93313 L p F P
0 g
s
1 g
.27251 1.84399 m .30227 1.77336 L .27622 1.80611 L p F P
0 g
s
1 g
.27622 1.80611 m .2459 1.87729 L .27251 1.84399 L p F P
0 g
s
1 g
.68101 1.93313 m .6614 2.00783 L .65409 2.04914 L p F P
0 g
s
1 g
.6614 2.00783 m .68101 1.93313 L .67752 1.89105 L p F P
0 g
s
1 g
.41293 2.25083 m .439 2.1698 L .48669 2.17036 L p F P
0 g
s
.45906 1.93095 m
.45154 1.95294 L
s
1 g
.48669 2.17036 m .46185 2.25156 L .41293 2.25083 L p F P
0 g
s
1 g
.46185 2.25156 m .48669 2.17036 L .53236 2.16181 L p F P
0 g
s
1 g
.3078 1.81742 m .33676 1.74721 L .30227 1.77336 L p F P
0 g
s
1 g
.30227 1.77336 m .27251 1.84399 L .3078 1.81742 L p F P
0 g
s
1 g
.67752 1.89105 m .65773 1.96494 L .6614 2.00783 L p F P
0 g
s
1 g
.65773 1.96494 m .67752 1.89105 L .66337 1.84958 L p F P
0 g
s
1 g
.53236 2.16181 m .50867 2.24301 L .46185 2.25156 L p F P
0 g
s
1 g
.50867 2.24301 m .53236 2.16181 L .57383 2.14448 L p F P
0 g
s
1 g
.35008 1.79904 m .37803 1.72907 L .33676 1.74721 L p F P
0 g
s
1 g
.33676 1.74721 m .3078 1.81742 L .35008 1.79904 L p F P
0 g
s
1 g
.66337 1.84958 m .64312 1.92265 L .65773 1.96494 L p F P
0 g
s
1 g
.64312 1.92265 m .66337 1.84958 L .63918 1.81089 L p F P
0 g
s
1 g
.57383 2.14448 m .55117 2.2255 L .50867 2.24301 L p F P
0 g
s
1 g
.55117 2.2255 m .57383 2.14448 L .60907 2.11911 L p F P
0 g
s
.45154 1.95294 m
.4439 1.97528 L
s
1 g
.39722 1.78988 m .42401 1.71997 L .37803 1.72907 L p F P
0 g
s
1 g
.37803 1.72907 m .35008 1.79904 L .39722 1.78988 L p F P
0 g
s
1 g
.63918 1.81089 m .61821 1.88315 L .64312 1.92265 L p F P
0 g
s
1 g
.61821 1.88315 m .63918 1.81089 L .6061 1.777 L p F P
0 g
s
1 g
.44678 1.7905 m .47232 1.72045 L .42401 1.71997 L p F P
0 g
s
1 g
.42401 1.71997 m .39722 1.78988 L .44678 1.7905 L p F P
0 g
s
1 g
.60907 2.11911 m .58727 2.19978 L .55117 2.2255 L p F P
0 g
s
1 g
.58727 2.19978 m .60907 2.11911 L .63631 2.08683 L p F P
0 g
s
1 g
.6061 1.777 m .5842 1.84851 L .61821 1.88315 L p F P
0 g
s
1 g
.5842 1.84851 m .6061 1.777 L .56582 1.74973 L p F P
0 g
s
1 g
.49618 1.80092 m .52043 1.73054 L .47232 1.72045 L p F P
0 g
s
1 g
.47232 1.72045 m .44678 1.7905 L .49618 1.80092 L p F P
0 g
s
1 g
.56582 1.74973 m .5428 1.82061 L .5842 1.84851 L p F P
0 g
s
1 g
.5428 1.82061 m .56582 1.74973 L .52043 1.73054 L p F P
0 g
s
1 g
.52043 1.73054 m .49618 1.80092 L .5428 1.82061 L p F P
0 g
s
1 g
.63631 2.08683 m .61514 2.167 L .58727 2.19978 L p F P
0 g
s
1 g
.61514 2.167 m .63631 2.08683 L .65409 2.04914 L p F P
0 g
s
.4439 1.97528 m
.43615 1.99797 L
s
1 g
.65409 2.04914 m .6333 2.12866 L .61514 2.167 L p F P
0 g
s
1 g
.6333 2.12866 m .65409 2.04914 L .6614 2.00783 L p F P
0 g
s
1 g
.24111 1.91849 m .27251 1.84399 L .2459 1.87729 L p F P
0 g
s
1 g
.2459 1.87729 m .21393 1.95235 L .24111 1.91849 L p F P
0 g
s
.43615 1.99797 m
.42826 2.02103 L
s
1 g
.6614 2.00783 m .64071 2.0866 L .6333 2.12866 L p F P
0 g
s
1 g
.64071 2.0866 m .6614 2.00783 L .65773 1.96494 L p F P
0 g
s
1 g
.27725 1.8915 m .3078 1.81742 L .27251 1.84399 L p F P
0 g
s
1 g
.27251 1.84399 m .24111 1.91849 L .27725 1.8915 L p F P
0 g
s
1 g
.65773 1.96494 m .63685 2.04289 L .64071 2.0866 L p F P
0 g
s
1 g
.63685 2.04289 m .65773 1.96494 L .64312 1.92265 L p F P
0 g
s
1 g
.32059 1.87288 m .35008 1.79904 L .3078 1.81742 L p F P
0 g
s
1 g
.3078 1.81742 m .27725 1.8915 L .32059 1.87288 L p F P
0 g
s
.42826 2.02103 m
.42025 2.04446 L
s
1 g
.64312 1.92265 m .62176 1.99974 L .63685 2.04289 L p F P
0 g
s
1 g
.62176 1.99974 m .64312 1.92265 L .61821 1.88315 L p F P
0 g
s
1 g
.36895 1.86367 m .39722 1.78988 L .35008 1.79904 L p F P
0 g
s
1 g
.35008 1.79904 m .32059 1.87288 L .36895 1.86367 L p F P
0 g
s
1 g
.61821 1.88315 m .59609 1.9594 L .62176 1.99974 L p F P
0 g
s
1 g
.59609 1.9594 m .61821 1.88315 L .5842 1.84851 L p F P
0 g
s
1 g
.41983 1.86444 m .44678 1.7905 L .39722 1.78988 L p F P
0 g
s
1 g
.39722 1.78988 m .36895 1.86367 L .41983 1.86444 L p F P
0 g
s
1 g
.5842 1.84851 m .56108 1.92399 L .59609 1.9594 L p F P
0 g
s
1 g
.56108 1.92399 m .5842 1.84851 L .5428 1.82061 L p F P
0 g
s
1 g
.47058 1.87521 m .49618 1.80092 L .44678 1.7905 L p F P
0 g
s
1 g
.44678 1.7905 m .41983 1.86444 L .47058 1.87521 L p F P
0 g
s
1 g
.5428 1.82061 m .5185 1.89541 L .56108 1.92399 L p F P
0 g
s
1 g
.5185 1.89541 m .5428 1.82061 L .49618 1.80092 L p F P
0 g
s
.42025 2.04446 m
.41211 2.06827 L
s
1 g
.49618 1.80092 m .47058 1.87521 L .5185 1.89541 L p F P
0 g
s
.41211 2.06827 m
.40384 2.09247 L
s
.40384 2.09247 m
.39543 2.11707 L
s
.39543 2.11707 m
.38687 2.14209 L
s
.38687 2.14209 m
.37818 2.16752 L
s
.37818 2.16752 m
.36933 2.19339 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0308628 0.97619 1.26537 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.883907 2.9306 -3.68737e-16 2.9306 [
[ 0 0 0 0 ]
[ 1 2.73158 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.73158 L
0 2.73158 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
1 g
.65545 2.35829 m .67193 2.45988 L .64643 2.47502 L p F P
0 g
s
1 g
.64643 2.47502 m .62974 2.37296 L .65545 2.35829 L p F P
0 g
s
1 g
.63881 2.25571 m .65545 2.35829 L .62974 2.37296 L p F P
0 g
s
1 g
.62974 2.37296 m .64643 2.47502 L .62739 2.49153 L p F P
0 g
s
1 g
.62974 2.37296 m .61289 2.26991 L .63881 2.25571 L p F P
0 g
s
1 g
.62201 2.15214 m .63881 2.25571 L .61289 2.26991 L p F P
0 g
s
1 g
.62739 2.49153 m .6105 2.3889 L .62974 2.37296 L p F P
0 g
s
1 g
.61289 2.26991 m .62974 2.37296 L .6105 2.3889 L p F P
0 g
s
1 g
.6105 2.3889 m .62739 2.49153 L .61583 2.50866 L p F P
0 g
s
1 g
.61289 2.26991 m .59587 2.16585 L .62201 2.15214 L p F P
0 g
s
1 g
.60504 2.04755 m .62201 2.15214 L .59587 2.16585 L p F P
0 g
s
1 g
.6105 2.3889 m .59344 2.28526 L .61289 2.26991 L p F P
0 g
s
1 g
.59587 2.16585 m .61289 2.26991 L .59344 2.28526 L p F P
0 g
s
1 g
.61583 2.50866 m .59876 2.40537 L .6105 2.3889 L p F P
0 g
s
1 g
.59344 2.28526 m .6105 2.3889 L .59876 2.40537 L p F P
0 g
s
1 g
.59876 2.40537 m .61583 2.50866 L .61247 2.52559 L p F P
0 g
s
.80545 2.63177 m
.81026 2.66239 L
s
1 g
.59587 2.16585 m .57868 2.06076 L .60504 2.04755 L p F P
0 g
s
1 g
.58791 1.94193 m .60504 2.04755 L .57868 2.06076 L p F P
0 g
s
1 g
.59344 2.28526 m .57622 2.1806 L .59587 2.16585 L p F P
0 g
s
1 g
.57868 2.06076 m .59587 2.16585 L .57622 2.1806 L p F P
0 g
s
1 g
.95016 2.45916 m .9347 2.35545 L .94176 2.37013 L p F P
0 g
s
1 g
.94176 2.37013 m .9573 2.47457 L .95016 2.45916 L p F P
0 g
s
.80062 2.60105 m
.80545 2.63177 L
s
1 g
.59876 2.40537 m .58152 2.30105 L .59344 2.28526 L p F P
0 g
s
1 g
.57622 2.1806 m .59344 2.28526 L .58152 2.30105 L p F P
0 g
s
.79578 2.57025 m
.80062 2.60105 L
s
.79093 2.53935 m
.79578 2.57025 L
s
1 g
.61247 2.52559 m .59525 2.42159 L .59876 2.40537 L p F P
0 g
s
1 g
.58152 2.30105 m .59876 2.40537 L .59525 2.42159 L p F P
0 g
s
1 g
.57868 2.06076 m .56133 1.95464 L .58791 1.94193 L p F P
0 g
s
1 g
.57061 1.83527 m .58791 1.94193 L .56133 1.95464 L p F P
0 g
s
1 g
.57622 2.1806 m .55882 2.0749 L .57868 2.06076 L p F P
0 g
s
1 g
.56133 1.95464 m .57868 2.06076 L .55882 2.0749 L p F P
0 g
s
.78606 2.50837 m
.79093 2.53935 L
s
1 g
.9347 2.35545 m .9191 2.25071 L .92607 2.26464 L p F P
0 g
s
1 g
.92607 2.26464 m .94176 2.37013 L .9347 2.35545 L p F P
0 g
s
1 g
.58152 2.30105 m .56411 2.1957 L .57622 2.1806 L p F P
0 g
s
1 g
.55882 2.0749 m .57622 2.1806 L .56411 2.1957 L p F P
0 g
s
1 g
.59525 2.42159 m .61247 2.52559 L .61766 2.54149 L p F P
0 g
s
.78117 2.47729 m
.78606 2.50837 L
s
.77627 2.44612 m
.78117 2.47729 L
s
1 g
.9573 2.47457 m .94176 2.37013 L .94025 2.38629 L p F P
0 g
s
1 g
.94025 2.38629 m .95591 2.49147 L .9573 2.47457 L p F P
0 g
s
1 g
.59525 2.42159 m .57786 2.31654 L .58152 2.30105 L p F P
0 g
s
1 g
.56411 2.1957 m .58152 2.30105 L .57786 2.31654 L p F P
0 g
s
1 g
.56133 1.95464 m .5438 1.84746 L .57061 1.83527 L p F P
0 g
s
1 g
.55313 1.72755 m .57061 1.83527 L .5438 1.84746 L p F P
0 g
s
.77136 2.41486 m
.77627 2.44612 L
s
1 g
.55882 2.0749 m .54125 1.96814 L .56133 1.95464 L p F P
0 g
s
1 g
.5438 1.84746 m .56133 1.95464 L .54125 1.96814 L p F P
0 g
s
1 g
.9191 2.25071 m .90334 2.14492 L .91022 2.15809 L p F P
0 g
s
1 g
.91022 2.15809 m .92607 2.26464 L .9191 2.25071 L p F P
0 g
s
.76643 2.3835 m
.77136 2.41486 L
s
1 g
.56411 2.1957 m .54652 2.0893 L .55882 2.0749 L p F P
0 g
s
1 g
.54125 1.96814 m .55882 2.0749 L .54652 2.0893 L p F P
0 g
s
1 g
.61766 2.54149 m .60033 2.43675 L .59525 2.42159 L p F P
0 g
s
1 g
.57786 2.31654 m .59525 2.42159 L .60033 2.43675 L p F P
0 g
s
.76149 2.35205 m
.76643 2.3835 L
s
1 g
.94176 2.37013 m .92607 2.26464 L .92443 2.28006 L p F P
0 g
s
1 g
.92443 2.28006 m .94025 2.38629 L .94176 2.37013 L p F P
0 g
s
1 g
.57786 2.31654 m .56029 2.21045 L .56411 2.1957 L p F P
0 g
s
1 g
.54652 2.0893 m .56411 2.1957 L .56029 2.21045 L p F P
0 g
s
.75653 2.32051 m
.76149 2.35205 L
s
1 g
.5438 1.84746 m .52609 1.7392 L .55313 1.72755 L p F P
0 g
s
1 g
.53548 1.61875 m .55313 1.72755 L .52609 1.7392 L p F P
0 g
s
1 g
.60033 2.43675 m .61766 2.54149 L .63134 2.55551 L p F P
0 g
s
1 g
.54125 1.96814 m .52351 1.86032 L .5438 1.84746 L p F P
0 g
s
1 g
.52609 1.7392 m .5438 1.84746 L .52351 1.86032 L p F P
0 g
s
1 g
.90334 2.14492 m .88742 2.03808 L .89421 2.05047 L p F P
0 g
s
1 g
.89421 2.05047 m .91022 2.15809 L .90334 2.14492 L p F P
0 g
s
.75156 2.28887 m
.75653 2.32051 L
s
1 g
.95591 2.49147 m .94025 2.38629 L .93004 2.40316 L p F P
0 g
s
1 g
.93004 2.40316 m .94587 2.50902 L .95591 2.49147 L p F P
0 g
s
1 g
.54652 2.0893 m .52876 1.98183 L .54125 1.96814 L p F P
0 g
s
1 g
.52351 1.86032 m .54125 1.96814 L .52876 1.98183 L p F P
0 g
s
1 g
.60033 2.43675 m .58283 2.33095 L .57786 2.31654 L p F P
0 g
s
1 g
.56029 2.21045 m .57786 2.31654 L .58283 2.33095 L p F P
0 g
s
.74657 2.25714 m
.75156 2.28887 L
s
1 g
.92607 2.26464 m .91022 2.15809 L .90844 2.17276 L p F P
0 g
s
1 g
.90844 2.17276 m .92443 2.28006 L .92607 2.26464 L p F P
0 g
s
.74157 2.22531 m
.74657 2.25714 L
s
1 g
.56029 2.21045 m .54255 2.10329 L .54652 2.0893 L p F P
0 g
s
1 g
.52876 1.98183 m .54652 2.0893 L .54255 2.10329 L p F P
0 g
s
1 0 .462 r
.64805 1.10638 m
.84245 1.55085 L
s
0 0 1 r
.03 w
.84245 1.55085 Mdot
.5 Mabswid
1 g
.52609 1.7392 m .50821 1.62986 L .53548 1.61875 L p F P
0 g
s
1 g
.51766 1.50886 m .53548 1.61875 L .50821 1.62986 L p F P
0 g
s
1 g
.63134 2.55551 m .61395 2.45005 L .60033 2.43675 L p F P
0 g
s
1 g
.58283 2.33095 m .60033 2.43675 L .61395 2.45005 L p F P
0 g
s
1 g
.52351 1.86032 m .50558 1.75142 L .52609 1.7392 L p F P
0 g
s
1 g
.50821 1.62986 m .52609 1.7392 L .50558 1.75142 L p F P
0 g
s
.73656 2.19339 m
.74157 2.22531 L
s
1 g
.88742 2.03808 m .87134 1.93016 L .87804 1.94176 L p F P
0 g
s
1 g
.87804 1.94176 m .89421 2.05047 L .88742 2.03808 L p F P
0 g
s
1 g
.94025 2.38629 m .92443 2.28006 L .91405 2.29622 L p F P
0 g
s
1 g
.91405 2.29622 m .93004 2.40316 L .94025 2.38629 L p F P
0 g
s
1 g
.52876 1.98183 m .51082 1.87328 L .52351 1.86032 L p F P
0 g
s
1 g
.50558 1.75142 m .52351 1.86032 L .51082 1.87328 L p F P
0 g
s
1 g
.58283 2.33095 m .56515 2.22409 L .56029 2.21045 L p F P
0 g
s
1 g
.54255 2.10329 m .56029 2.21045 L .56515 2.22409 L p F P
0 g
s
.73152 2.16137 m
.73656 2.19339 L
s
1 g
.61395 2.45005 m .63134 2.55551 L .65299 2.56689 L p F P
0 g
s
.72648 2.12926 m
.73152 2.16137 L
s
1 g
.91022 2.15809 m .89421 2.05047 L .8923 2.06436 L p F P
0 g
s
1 g
.8923 2.06436 m .90844 2.17276 L .91022 2.15809 L p F P
0 g
s
1 g
.94587 2.50902 m .93004 2.40316 L .91147 2.41986 L p F P
0 g
s
1 g
.91147 2.41986 m .9275 2.52634 L .94587 2.50902 L p F P
0 g
s
1 g
.54255 2.10329 m .52463 1.99504 L .52876 1.98183 L p F P
0 g
s
1 g
.51082 1.87328 m .52876 1.98183 L .52463 1.99504 L p F P
0 g
s
1 g
.50821 1.62986 m .49015 1.51942 L .51766 1.50886 L p F P
0 g
s
1 g
.49965 1.39785 m .51766 1.50886 L .49015 1.51942 L p F P
0 g
s
1 g
.61395 2.45005 m .59639 2.34353 L .58283 2.33095 L p F P
0 g
s
1 g
.56515 2.22409 m .58283 2.33095 L .59639 2.34353 L p F P
0 g
s
.72141 2.09705 m
.72648 2.12926 L
s
1 g
.50558 1.75142 m .48748 1.64141 L .50821 1.62986 L p F P
0 g
s
1 g
.49015 1.51942 m .50821 1.62986 L .48748 1.64141 L p F P
0 g
s
1 g
.87134 1.93016 m .8551 1.82116 L .8617 1.83194 L p F P
0 g
s
1 g
.8617 1.83194 m .87804 1.94176 L .87134 1.93016 L p F P
0 g
s
1 g
.92443 2.28006 m .90844 2.17276 L .89789 2.1882 L p F P
0 g
s
1 g
.89789 2.1882 m .91405 2.29622 L .92443 2.28006 L p F P
0 g
s
.71634 2.06474 m
.72141 2.09705 L
s
1 g
.51082 1.87328 m .4927 1.76362 L .50558 1.75142 L p F P
0 g
s
1 g
.48748 1.64141 m .50558 1.75142 L .4927 1.76362 L p F P
0 g
s
1 g
.56515 2.22409 m .54729 2.11615 L .54255 2.10329 L p F P
0 g
s
1 g
.52463 1.99504 m .54255 2.10329 L .54729 2.11615 L p F P
0 g
s
1 g
.65299 2.56689 m .63559 2.46077 L .61395 2.45005 L p F P
0 g
s
1 g
.59639 2.34353 m .61395 2.45005 L .63559 2.46077 L p F P
0 g
s
.71124 2.03233 m
.71634 2.06474 L
s
1 g
.89421 2.05047 m .87804 1.94176 L .87599 1.95486 L p F P
0 g
s
1 g
.87599 1.95486 m .8923 2.06436 L .89421 2.05047 L p F P
0 g
s
1 g
.93004 2.40316 m .91405 2.29622 L .89528 2.3123 L p F P
0 g
s
1 g
.89528 2.3123 m .91147 2.41986 L .93004 2.40316 L p F P
0 g
s
1 g
.63559 2.46077 m .65299 2.56689 L .68162 2.57498 L p F P
0 g
s
1 g
.52463 1.99504 m .50653 1.88569 L .51082 1.87328 L p F P
0 g
s
1 g
.4927 1.76362 m .51082 1.87328 L .50653 1.88569 L p F P
0 g
s
.70614 1.99983 m
.71124 2.03233 L
s
1 g
.49015 1.51942 m .4719 1.40785 L .49965 1.39785 L p F P
0 g
s
1 g
.48146 1.28573 m .49965 1.39785 L .4719 1.40785 L p F P
0 g
s
1 g
.59639 2.34353 m .57864 2.23592 L .56515 2.22409 L p F P
0 g
s
1 g
.54729 2.11615 m .56515 2.22409 L .57864 2.23592 L p F P
0 g
s
1 g
.48748 1.64141 m .46919 1.53028 L .49015 1.51942 L p F P
0 g
s
1 g
.4719 1.40785 m .49015 1.51942 L .46919 1.53028 L p F P
0 g
s
1 g
.9275 2.52634 m .91147 2.41986 L .88537 2.43552 L p F P
0 g
s
1 g
.88537 2.43552 m .90162 2.5425 L .9275 2.52634 L p F P
0 g
s
1 g
.8551 1.82116 m .83869 1.71104 L .8452 1.721 L p F P
0 g
s
0 .538 1 r
.81483 1.59401 m
.84245 1.55085 L
s
1 g
.8452 1.721 m .8617 1.83194 L .8551 1.82116 L p F P
0 g
s
.70101 1.96722 m
.70614 1.99983 L
s
1 g
.90844 2.17276 m .8923 2.06436 L .88157 2.07907 L p F P
0 g
s
1 g
.88157 2.07907 m .89789 2.1882 L .90844 2.17276 L p F P
0 g
s
1 g
.4927 1.76362 m .4744 1.65285 L .48748 1.64141 L p F P
0 g
s
1 g
.46919 1.53028 m .48748 1.64141 L .4744 1.65285 L p F P
0 g
s
1 g
.54729 2.11615 m .52925 2.00711 L .52463 1.99504 L p F P
0 g
s
1 g
.50653 1.88569 m .52463 1.99504 L .52925 2.00711 L p F P
0 g
s
1 g
.63559 2.46077 m .61801 2.35357 L .59639 2.34353 L p F P
0 g
s
1 g
.57864 2.23592 m .59639 2.34353 L .61801 2.35357 L p F P
0 g
s
.69587 1.93452 m
.70101 1.96722 L
s
1 g
.87804 1.94176 m .8617 1.83194 L .85951 1.84423 L p F P
0 g
s
1 g
.85951 1.84423 m .87599 1.95486 L .87804 1.94176 L p F P
0 g
s
1 g
.91405 2.29622 m .89789 2.1882 L .87892 2.20364 L p F P
0 g
s
1 g
.87892 2.20364 m .89528 2.3123 L .91405 2.29622 L p F P
0 g
s
1 g
.68162 2.57498 m .66427 2.46829 L .63559 2.46077 L p F P
0 g
s
1 g
.61801 2.35357 m .63559 2.46077 L .66427 2.46829 L p F P
0 g
s
.69072 1.90172 m
.69587 1.93452 L
s
1 g
.50653 1.88569 m .48824 1.77523 L .4927 1.76362 L p F P
0 g
s
1 g
.4744 1.65285 m .4927 1.76362 L .48824 1.77523 L p F P
0 g
s
1 g
.66427 2.46829 m .68162 2.57498 L .71582 2.57929 L p F P
0 g
s
1 g
.4719 1.40785 m .45347 1.29515 L .48146 1.28573 L p F P
0 g
s
1 g
.46309 1.17246 m .48146 1.28573 L .45347 1.29515 L p F P
0 g
s
1 0 .923 r
.47417 1.34952 m
.64805 1.10638 L
s
1 g
.57864 2.23592 m .56072 2.12721 L .54729 2.11615 L p F P
0 g
s
1 g
.52925 2.00711 m .54729 2.11615 L .56072 2.12721 L p F P
0 g
s
1 g
.46919 1.53028 m .45071 1.41802 L .4719 1.40785 L p F P
0 g
s
1 g
.45347 1.29515 m .4719 1.40785 L .45071 1.41802 L p F P
0 g
s
1 g
.91147 2.41986 m .89528 2.3123 L .86895 2.32744 L p F P
0 g
s
1 g
.86895 2.32744 m .88537 2.43552 L .91147 2.41986 L p F P
0 g
s
.68555 1.86882 m
.69072 1.90172 L
s
1 g
.90162 2.5425 m .88537 2.43552 L .85302 2.44926 L p F P
0 g
s
1 g
.85302 2.44926 m .8695 2.5566 L .90162 2.5425 L p F P
0 g
s
1 g
.83869 1.71104 m .82212 1.5998 L .82853 1.60892 L p F P
0 g
s
1 g
.82853 1.60892 m .8452 1.721 L .83869 1.71104 L p F P
0 g
s
1 g
.8923 2.06436 m .87599 1.95486 L .86508 1.96882 L p F P
0 g
s
1 g
.86508 1.96882 m .88157 2.07907 L .8923 2.06436 L p F P
0 g
s
1 g
.4744 1.65285 m .4559 1.54094 L .46919 1.53028 L p F P
0 g
s
1 g
.45071 1.41802 m .46919 1.53028 L .4559 1.54094 L p F P
0 g
s
.615 1 0 r
.46267 1.50451 m
.84245 1.55085 L
s
.44114 1.50188 m
.45432 1.50349 L
s
1 g
.52925 2.00711 m .51103 1.89695 L .50653 1.88569 L p F P
0 g
s
1 g
.48824 1.77523 m .50653 1.88569 L .51103 1.89695 L p F P
0 g
s
.68036 1.83582 m
.68555 1.86882 L
s
1 g
.61801 2.35357 m .60026 2.24527 L .57864 2.23592 L p F P
0 g
s
1 g
.56072 2.12721 m .57864 2.23592 L .60026 2.24527 L p F P
0 g
s
.67516 1.80271 m
.68036 1.83582 L
s
1 g
.8617 1.83194 m .8452 1.721 L .84286 1.73246 L p F P
0 g
s
1 g
.84286 1.73246 m .85951 1.84423 L .8617 1.83194 L p F P
0 g
s
1 g
.89789 2.1882 m .88157 2.07907 L .86239 2.09385 L p F P
0 g
s
1 g
.86239 2.09385 m .87892 2.20364 L .89789 2.1882 L p F P
0 g
s
1 g
.66427 2.46829 m .64674 2.3605 L .61801 2.35357 L p F P
0 g
s
1 g
.60026 2.24527 m .61801 2.35357 L .64674 2.3605 L p F P
0 g
s
1 g
.69857 2.47215 m .71582 2.57929 L .75381 2.57953 L p F P
0 g
s
1 g
.71582 2.57929 m .69857 2.47215 L .66427 2.46829 L p F P
0 g
s
1 g
.48824 1.77523 m .46976 1.66363 L .4744 1.65285 L p F P
0 g
s
1 g
.4559 1.54094 m .4744 1.65285 L .46976 1.66363 L p F P
0 g
s
1 g
.64674 2.3605 m .66427 2.46829 L .69857 2.47215 L p F P
0 g
s
1 g
.45347 1.29515 m .43485 1.18129 L .46309 1.17246 L p F P
0 g
s
1 g
.44452 1.05803 m .46309 1.17246 L .43485 1.18129 L p F P
0 g
s
1 g
.8695 2.5566 m .85302 2.44926 L .8161 2.46032 L p F P
0 g
s
1 g
.8161 2.46032 m .83281 2.56787 L .8695 2.5566 L p F P
0 g
s
1 g
.56072 2.12721 m .54261 2.01739 L .52925 2.00711 L p F P
0 g
s
1 g
.51103 1.89695 m .52925 2.00711 L .54261 2.01739 L p F P
0 g
s
.66994 1.76951 m
.67516 1.80271 L
s
1 g
.45071 1.41802 m .43205 1.30461 L .45347 1.29515 L p F P
0 g
s
1 g
.43485 1.18129 m .45347 1.29515 L .43205 1.30461 L p F P
0 g
s
1 g
.89528 2.3123 m .87892 2.20364 L .85237 2.21825 L p F P
0 g
s
1 g
.85237 2.21825 m .86895 2.32744 L .89528 2.3123 L p F P
0 g
s
1 g
.88537 2.43552 m .86895 2.32744 L .83637 2.34081 L p F P
0 g
s
1 g
.83637 2.34081 m .85302 2.44926 L .88537 2.43552 L p F P
0 g
s
1 g
.82212 1.5998 m .80538 1.48742 L .81168 1.49568 L p F P
0 g
s
1 g
.81168 1.49568 m .82853 1.60892 L .82212 1.5998 L p F P
0 g
s
1 g
.87599 1.95486 m .85951 1.84423 L .84843 1.85742 L p F P
0 g
s
1 g
.84843 1.85742 m .86508 1.96882 L .87599 1.95486 L p F P
0 g
s
.66471 1.7362 m
.66994 1.76951 L
s
1 g
.7367 2.47208 m .75381 2.57953 L .79353 2.57566 L p F P
0 g
s
1 g
.75381 2.57953 m .7367 2.47208 L .69857 2.47215 L p F P
0 g
s
1 g
.4559 1.54094 m .43722 1.42789 L .45071 1.41802 L p F P
0 g
s
.615 1 0 r
.3713 1.49336 m
.44114 1.50188 L
s
1 g
.43205 1.30461 m .45071 1.41802 L .43722 1.42789 L p F P
0 g
s
1 0 .923 r
.3713 1.49336 m
.43616 1.40267 L
s
1 g
.51103 1.89695 m .49262 1.78565 L .48824 1.77523 L p F P
0 g
s
1 g
.46976 1.66363 m .48824 1.77523 L .49262 1.78565 L p F P
0 g
s
1 g
.83281 2.56787 m .8161 2.46032 L .7766 2.46807 L p F P
0 g
s
1 g
.7766 2.46807 m .79353 2.57566 L .83281 2.56787 L p F P
0 g
s
1 g
.60026 2.24527 m .58232 2.13586 L .56072 2.12721 L p F P
0 g
s
1 g
.54261 2.01739 m .56072 2.12721 L .58232 2.13586 L p F P
0 g
s
1 g
.79353 2.57566 m .7766 2.46807 L .7367 2.47208 L p F P
0 g
s
.65946 1.7028 m
.66471 1.7362 L
s
1 g
.8452 1.721 m .82853 1.60892 L .82604 1.61953 L p F P
0 g
s
1 g
.82604 1.61953 m .84286 1.73246 L .8452 1.721 L p F P
0 g
s
1 .231 0 r
.3713 1.49336 m
.43025 1.46783 L
s
0 0 1 r
.03 w
.3713 1.49336 Mdot
.5 Mabswid
1 g
.88157 2.07907 m .86508 1.96882 L .84569 1.98293 L p F P
0 g
s
1 g
.84569 1.98293 m .86239 2.09385 L .88157 2.07907 L p F P
0 g
s
1 g
.64674 2.3605 m .62903 2.25161 L .60026 2.24527 L p F P
0 g
s
1 g
.58232 2.13586 m .60026 2.24527 L .62903 2.25161 L p F P
0 g
s
1 g
.68114 2.3639 m .69857 2.47215 L .7367 2.47208 L p F P
0 g
s
1 g
.69857 2.47215 m .68114 2.3639 L .64674 2.3605 L p F P
0 g
s
1 g
.46976 1.66363 m .4511 1.55088 L .4559 1.54094 L p F P
0 g
s
1 g
.43722 1.42789 m .4559 1.54094 L .4511 1.55088 L p F P
0 g
s
.65419 1.66929 m
.65946 1.7028 L
s
1 g
.62903 2.25161 m .64674 2.3605 L .68114 2.3639 L p F P
0 g
s
1 g
.43485 1.18129 m .41604 1.06626 L .44452 1.05803 L p F P
0 g
s
1 g
.42577 .94242 m .44452 1.05803 L .41604 1.06626 L p F P
0 g
s
1 g
.85302 2.44926 m .83637 2.34081 L .79922 2.35166 L p F P
0 g
s
1 g
.79922 2.35166 m .8161 2.46032 L .85302 2.44926 L p F P
0 g
s
1 g
.54261 2.01739 m .52431 1.90643 L .51103 1.89695 L p F P
0 g
s
1 g
.49262 1.78565 m .51103 1.89695 L .52431 1.90643 L p F P
0 g
s
1 g
.43205 1.30461 m .41319 1.19002 L .43485 1.18129 L p F P
0 g
s
1 g
.41604 1.06626 m .43485 1.18129 L .41319 1.19002 L p F P
0 g
s
1 g
.87892 2.20364 m .86239 2.09385 L .83561 2.10793 L p F P
0 g
s
1 g
.83561 2.10793 m .85237 2.21825 L .87892 2.20364 L p F P
0 g
s
1 g
.86895 2.32744 m .85237 2.21825 L .81954 2.23124 L p F P
0 g
s
1 g
.81954 2.23124 m .83637 2.34081 L .86895 2.32744 L p F P
0 g
s
1 g
.80538 1.48742 m .78846 1.37389 L .79466 1.38126 L p F P
0 g
s
1 g
.79466 1.38126 m .81168 1.49568 L .80538 1.48742 L p F P
0 g
s
.385 1 0 r
.80976 1.48275 m
.84245 1.55085 L
s
0 g
.64891 1.63567 m
.65419 1.66929 L
s
1 g
.85951 1.84423 m .84286 1.73246 L .83159 1.74487 L p F P
0 g
s
1 g
.83159 1.74487 m .84843 1.85742 L .85951 1.84423 L p F P
0 g
s
1 g
.71941 2.36353 m .7367 2.47208 L .7766 2.46807 L p F P
0 g
s
1 g
.7367 2.47208 m .71941 2.36353 L .68114 2.3639 L p F P
0 g
s
1 g
.43722 1.42789 m .41834 1.31366 L .43205 1.30461 L p F P
0 g
s
1 g
.41319 1.19002 m .43205 1.30461 L .41834 1.31366 L p F P
0 g
s
1 g
.49262 1.78565 m .47401 1.6732 L .46976 1.66363 L p F P
0 g
s
1 g
.4511 1.55088 m .46976 1.66363 L .47401 1.6732 L p F P
0 g
s
1 g
.8161 2.46032 m .79922 2.35166 L .75951 2.35938 L p F P
0 g
s
1 g
.75951 2.35938 m .7766 2.46807 L .8161 2.46032 L p F P
0 g
s
1 g
.58232 2.13586 m .5642 2.02532 L .54261 2.01739 L p F P
0 g
s
1 g
.52431 1.90643 m .54261 2.01739 L .5642 2.02532 L p F P
0 g
s
.64361 1.60196 m
.64891 1.63567 L
s
1 g
.7766 2.46807 m .75951 2.35938 L .71941 2.36353 L p F P
0 g
s
1 g
.82853 1.60892 m .81168 1.49568 L .80905 1.50543 L p F P
0 g
s
1 g
.80905 1.50543 m .82604 1.61953 L .82853 1.60892 L p F P
0 g
s
1 g
.86508 1.96882 m .84843 1.85742 L .82882 1.87086 L p F P
0 g
s
1 g
.82882 1.87086 m .84569 1.98293 L .86508 1.96882 L p F P
0 g
s
1 g
.62903 2.25161 m .61113 2.14159 L .58232 2.13586 L p F P
0 g
s
1 g
.5642 2.02532 m .58232 2.13586 L .61113 2.14159 L p F P
0 g
s
1 g
.66352 2.25454 m .68114 2.3639 L .71941 2.36353 L p F P
0 g
s
1 g
.68114 2.3639 m .66352 2.25454 L .62903 2.25161 L p F P
0 g
s
.63829 1.56813 m
.64361 1.60196 L
s
1 g
.4511 1.55088 m .43224 1.43696 L .43722 1.42789 L p F P
0 g
s
1 g
.41834 1.31366 m .43722 1.42789 L .43224 1.43696 L p F P
0 g
s
1 g
.61113 2.14159 m .62903 2.25161 L .66352 2.25454 L p F P
0 g
s
1 g
.41604 1.06626 m .39703 .95004 L .42577 .94242 L p F P
0 g
s
1 g
.40682 .82561 m .42577 .94242 L .39703 .95004 L p F P
0 g
s
1 g
.83637 2.34081 m .81954 2.23124 L .78216 2.24187 L p F P
0 g
s
1 g
.78216 2.24187 m .79922 2.35166 L .83637 2.34081 L p F P
0 g
s
1 g
.52431 1.90643 m .50583 1.79432 L .49262 1.78565 L p F P
0 g
s
1 g
.47401 1.6732 m .49262 1.78565 L .50583 1.79432 L p F P
0 g
s
1 g
.41319 1.19002 m .39414 1.07425 L .41604 1.06626 L p F P
0 g
s
1 g
.39703 .95004 m .41604 1.06626 L .39414 1.07425 L p F P
0 g
s
1 g
.86239 2.09385 m .84569 1.98293 L .81868 1.99646 L p F P
0 g
s
1 g
.81868 1.99646 m .83561 2.10793 L .86239 2.09385 L p F P
0 g
s
.63296 1.53421 m
.63829 1.56813 L
s
1 g
.85237 2.21825 m .83561 2.10793 L .80255 2.12053 L p F P
0 g
s
1 g
.80255 2.12053 m .81954 2.23124 L .85237 2.21825 L p F P
0 g
s
1 g
.78846 1.37389 m .77137 1.25917 L .77746 1.26564 L p F P
0 g
s
1 g
.77746 1.26564 m .79466 1.38126 L .78846 1.37389 L p F P
0 g
s
1 g
.84286 1.73246 m .82604 1.61953 L .81459 1.63114 L p F P
0 g
s
1 g
.81459 1.63114 m .83159 1.74487 L .84286 1.73246 L p F P
0 g
s
1 g
.70195 2.25385 m .71941 2.36353 L .75951 2.35938 L p F P
0 g
s
1 g
.71941 2.36353 m .70195 2.25385 L .66352 2.25454 L p F P
0 g
s
1 g
.41834 1.31366 m .39926 1.19824 L .41319 1.19002 L p F P
0 g
s
1 g
.39414 1.07425 m .41319 1.19002 L .39926 1.19824 L p F P
0 g
s
1 g
.47401 1.6732 m .45522 1.55958 L .4511 1.55088 L p F P
0 g
s
0 1 1 r
.43677 1.57544 m
.45199 1.59453 L
s
1 g
.43224 1.43696 m .4511 1.55088 L .45522 1.55958 L p F P
0 g
s
0 1 1 r
.3713 1.49336 m
.43677 1.57544 L
s
1 .231 0 r
.43025 1.46783 m
.4368 1.46499 L
s
.4368 1.46499 m
.43687 1.46496 L
s
0 g
.62761 1.50018 m
.63296 1.53421 L
s
1 g
.79922 2.35166 m .78216 2.24187 L .74223 2.24955 L p F P
0 g
s
1 g
.74223 2.24955 m .75951 2.35938 L .79922 2.35166 L p F P
0 g
s
1 g
.5642 2.02532 m .54589 1.91362 L .52431 1.90643 L p F P
0 g
s
1 g
.50583 1.79432 m .52431 1.90643 L .54589 1.91362 L p F P
0 g
s
1 g
.75951 2.35938 m .74223 2.24955 L .70195 2.25385 L p F P
0 g
s
.62225 1.46604 m
.62761 1.50018 L
s
1 g
.81168 1.49568 m .79466 1.38126 L .79188 1.39013 L p F P
0 g
s
1 g
.79188 1.39013 m .80905 1.50543 L .81168 1.49568 L p F P
0 g
s
1 g
.84843 1.85742 m .83159 1.74487 L .81177 1.75761 L p F P
0 g
s
1 g
.81177 1.75761 m .82882 1.87086 L .84843 1.85742 L p F P
0 g
s
1 g
.61113 2.14159 m .59305 2.03042 L .5642 2.02532 L p F P
0 g
s
1 g
.54589 1.91362 m .5642 2.02532 L .59305 2.03042 L p F P
0 g
s
1 g
.64573 2.14403 m .66352 2.25454 L .70195 2.25385 L p F P
0 g
s
1 g
.66352 2.25454 m .64573 2.14403 L .61113 2.14159 L p F P
0 g
s
1 g
.43224 1.43696 m .41318 1.32185 L .41834 1.31366 L p F P
0 g
s
1 g
.39926 1.19824 m .41834 1.31366 L .41318 1.32185 L p F P
0 g
s
1 g
.59305 2.03042 m .61113 2.14159 L .64573 2.14403 L p F P
0 g
s
1 g
.39703 .95004 m .37782 .8326 L .40682 .82561 L p F P
0 g
s
1 g
.38768 .70759 m .40682 .82561 L .37782 .8326 L p F P
0 g
s
1 g
.81954 2.23124 m .80255 2.12053 L .76492 2.13094 L p F P
0 g
s
1 g
.76492 2.13094 m .78216 2.24187 L .81954 2.23124 L p F P
0 g
s
1 g
.50583 1.79432 m .48715 1.68104 L .47401 1.6732 L p F P
0 g
s
1 g
.45522 1.55958 m .47401 1.6732 L .48715 1.68104 L p F P
0 g
s
.61687 1.4318 m
.62225 1.46604 L
s
1 g
.39414 1.07425 m .37488 .95727 L .39703 .95004 L p F P
0 g
s
1 g
.37782 .8326 m .39703 .95004 L .37488 .95727 L p F P
0 g
s
1 g
.84569 1.98293 m .82882 1.87086 L .80157 1.88382 L p F P
0 g
s
1 g
.80157 1.88382 m .81868 1.99646 L .84569 1.98293 L p F P
0 g
s
1 g
.83561 2.10793 m .81868 1.99646 L .78537 2.00866 L p F P
0 g
s
1 g
.78537 2.00866 m .80255 2.12053 L .83561 2.10793 L p F P
0 g
s
1 g
.77137 1.25917 m .7541 1.14326 L .76008 1.14881 L p F P
0 g
s
1 g
.76008 1.14881 m .77746 1.26564 L .77137 1.25917 L p F P
0 g
s
1 g
.82604 1.61953 m .80905 1.50543 L .7974 1.51622 L p F P
0 g
s
1 g
.7974 1.51622 m .81459 1.63114 L .82604 1.61953 L p F P
0 g
s
.61147 1.39745 m
.61687 1.4318 L
s
1 g
.6843 2.14302 m .70195 2.25385 L .74223 2.24955 L p F P
0 g
s
1 g
.70195 2.25385 m .6843 2.14302 L .64573 2.14403 L p F P
0 g
s
1 g
.39926 1.19824 m .37999 1.08162 L .39414 1.07425 L p F P
0 g
s
1 g
.37488 .95727 m .39414 1.07425 L .37999 1.08162 L p F P
0 g
s
1 g
.45522 1.55958 m .43622 1.44477 L .43224 1.43696 L p F P
0 g
s
1 g
.41318 1.32185 m .43224 1.43696 L .43622 1.44477 L p F P
0 g
s
1 g
.78216 2.24187 m .76492 2.13094 L .72477 2.13858 L p F P
0 g
s
1 g
.72477 2.13858 m .74223 2.24955 L .78216 2.24187 L p F P
0 g
s
1 g
.54589 1.91362 m .52738 1.80076 L .50583 1.79432 L p F P
0 g
s
1 g
.48715 1.68104 m .50583 1.79432 L .52738 1.80076 L p F P
0 g
s
1 g
.74223 2.24955 m .72477 2.13858 L .6843 2.14302 L p F P
0 g
s
.60605 1.36299 m
.61147 1.39745 L
s
1 g
.79466 1.38126 m .77746 1.26564 L .77452 1.27361 L p F P
0 g
s
1 g
.77452 1.27361 m .79188 1.39013 L .79466 1.38126 L p F P
0 g
s
1 g
.83159 1.74487 m .81459 1.63114 L .79454 1.64316 L p F P
0 g
s
1 g
.79454 1.64316 m .81177 1.75761 L .83159 1.74487 L p F P
0 g
s
1 g
.59305 2.03042 m .57478 1.91809 L .54589 1.91362 L p F P
0 g
s
1 g
.52738 1.80076 m .54589 1.91362 L .57478 1.91809 L p F P
0 g
s
1 g
.62775 2.03238 m .64573 2.14403 L .6843 2.14302 L p F P
0 g
s
1 g
.64573 2.14403 m .62775 2.03238 L .59305 2.03042 L p F P
0 g
s
1 g
.41318 1.32185 m .39392 1.20553 L .39926 1.19824 L p F P
0 g
s
1 g
.37999 1.08162 m .39926 1.19824 L .39392 1.20553 L p F P
0 g
s
.60062 1.32843 m
.60605 1.36299 L
s
1 g
.57478 1.91809 m .59305 2.03042 L .62775 2.03238 L p F P
0 g
s
1 g
.37782 .8326 m .35842 .71394 L .38768 .70759 L p F P
0 g
s
1 g
.36833 .58833 m .38768 .70759 L .35842 .71394 L p F P
0 g
s
1 g
.80255 2.12053 m .78537 2.00866 L .74751 2.01884 L p F P
0 g
s
1 g
.74751 2.01884 m .76492 2.13094 L .80255 2.12053 L p F P
0 g
s
1 g
.48715 1.68104 m .46827 1.56658 L .45522 1.55958 L p F P
0 g
s
0 1 1 r
.46444 1.61013 m
.47137 1.61882 L
s
.45199 1.59453 m
.46444 1.61013 L
s
1 g
.43622 1.44477 m .45522 1.55958 L .46827 1.56658 L p F P
0 g
s
1 g
.37488 .95727 m .35543 .83906 L .37782 .8326 L p F P
0 g
s
1 g
.35842 .71394 m .37782 .8326 L .35543 .83906 L p F P
0 g
s
1 g
.82882 1.87086 m .81177 1.75761 L .78428 1.77 L p F P
0 g
s
1 g
.78428 1.77 m .80157 1.88382 L .82882 1.87086 L p F P
0 g
s
1 g
.81868 1.99646 m .80157 1.88382 L .76801 1.89561 L p F P
0 g
s
1 g
.76801 1.89561 m .78537 2.00866 L .81868 1.99646 L p F P
0 g
s
1 g
.7541 1.14326 m .73665 1.02613 L .74252 1.03074 L p F P
0 g
s
1 g
.74252 1.03074 m .76008 1.14881 L .7541 1.14326 L p F P
0 g
s
.59517 1.29376 m
.60062 1.32843 L
s
1 g
.80905 1.50543 m .79188 1.39013 L .78003 1.40008 L p F P
0 g
s
1 g
.78003 1.40008 m .7974 1.51622 L .80905 1.50543 L p F P
0 g
s
1 g
.66647 2.03104 m .6843 2.14302 L .72477 2.13858 L p F P
0 g
s
1 g
.6843 2.14302 m .66647 2.03104 L .62775 2.03238 L p F P
0 g
s
1 g
.37999 1.08162 m .36051 .96377 L .37488 .95727 L p F P
0 g
s
1 g
.35543 .83906 m .37488 .95727 L .36051 .96377 L p F P
0 g
s
1 g
.43622 1.44477 m .41703 1.32876 L .41318 1.32185 L p F P
0 g
s
1 g
.39392 1.20553 m .41318 1.32185 L .41703 1.32876 L p F P
0 g
s
1 g
.76492 2.13094 m .74751 2.01884 L .70713 2.02645 L p F P
0 g
s
1 g
.70713 2.02645 m .72477 2.13858 L .76492 2.13094 L p F P
0 g
s
1 g
.52738 1.80076 m .50868 1.68672 L .48715 1.68104 L p F P
0 g
s
1 g
.46827 1.56658 m .48715 1.68104 L .50868 1.68672 L p F P
0 g
s
.58971 1.25897 m
.59517 1.29376 L
s
1 g
.72477 2.13858 m .70713 2.02645 L .66647 2.03104 L p F P
0 g
s
1 g
.77746 1.26564 m .76008 1.14881 L .75698 1.15586 L p F P
0 g
s
1 g
.75698 1.15586 m .77452 1.27361 L .77746 1.26564 L p F P
0 g
s
1 g
.81459 1.63114 m .7974 1.51622 L .77713 1.52751 L p F P
0 g
s
1 g
.77713 1.52751 m .79454 1.64316 L .81459 1.63114 L p F P
0 g
s
1 g
.57478 1.91809 m .55632 1.80458 L .52738 1.80076 L p F P
0 g
s
1 g
.50868 1.68672 m .52738 1.80076 L .55632 1.80458 L p F P
0 g
s
1 g
.60958 1.91955 m .62775 2.03238 L .66647 2.03104 L p F P
0 g
s
1 g
.62775 2.03238 m .60958 1.91955 L .57478 1.91809 L p F P
0 g
s
.58422 1.22409 m
.58971 1.25897 L
s
1 g
.39392 1.20553 m .37446 1.08799 L .37999 1.08162 L p F P
0 g
s
1 g
.36051 .96377 m .37999 1.08162 L .37446 1.08799 L p F P
0 g
s
1 g
.55632 1.80458 m .57478 1.91809 L .60958 1.91955 L p F P
0 g
s
1 g
.35842 .71394 m .33881 .59403 L .36833 .58833 L p F P
0 g
s
1 g
.34878 .46782 m .36833 .58833 L .33881 .59403 L p F P
0 g
s
1 g
.78537 2.00866 m .76801 1.89561 L .72991 1.90557 L p F P
0 g
s
1 g
.72991 1.90557 m .74751 2.01884 L .78537 2.00866 L p F P
0 g
s
1 g
.46827 1.56658 m .4492 1.4509 L .43622 1.44477 L p F P
0 g
s
1 g
.41703 1.32876 m .43622 1.44477 L .4492 1.4509 L p F P
0 g
s
1 g
.35543 .83906 m .33577 .71961 L .35842 .71394 L p F P
0 g
s
1 g
.33881 .59403 m .35842 .71394 L .33577 .71961 L p F P
0 g
s
1 g
.81177 1.75761 m .79454 1.64316 L .76681 1.65497 L p F P
0 g
s
0 .538 1 r
.7792 1.6497 m
.79242 1.62904 L
s
1 g
.76681 1.65497 m .78428 1.77 L .81177 1.75761 L p F P
0 g
s
.57872 1.18909 m
.58422 1.22409 L
s
1 g
.80157 1.88382 m .78428 1.77 L .75047 1.78137 L p F P
0 g
s
1 g
.75047 1.78137 m .76801 1.89561 L .80157 1.88382 L p F P
0 g
s
1 g
.73665 1.02613 m .71901 .90778 L .72477 .91142 L p F P
0 g
s
1 g
.72477 .91142 m .74252 1.03074 L .73665 1.02613 L p F P
0 g
s
1 g
.79188 1.39013 m .77452 1.27361 L .76248 1.28271 L p F P
0 g
s
1 g
.76248 1.28271 m .78003 1.40008 L .79188 1.39013 L p F P
0 g
s
1 g
.64845 1.91787 m .66647 2.03104 L .70713 2.02645 L p F P
0 g
s
1 g
.66647 2.03104 m .64845 1.91787 L .60958 1.91955 L p F P
0 g
s
1 g
.36051 .96377 m .34083 .84467 L .35543 .83906 L p F P
0 g
s
1 g
.33577 .71961 m .35543 .83906 L .34083 .84467 L p F P
0 g
s
1 g
.41703 1.32876 m .39764 1.21152 L .39392 1.20553 L p F P
0 g
s
1 g
.37446 1.08799 m .39392 1.20553 L .39764 1.21152 L p F P
0 g
s
.57321 1.15398 m
.57872 1.18909 L
s
1 g
.74751 2.01884 m .72991 1.90557 L .68931 1.91313 L p F P
0 g
s
1 g
.68931 1.91313 m .70713 2.02645 L .74751 2.01884 L p F P
0 g
s
1 g
.50868 1.68672 m .48979 1.57146 L .46827 1.56658 L p F P
0 g
s
1 g
.4492 1.4509 m .46827 1.56658 L .48979 1.57146 L p F P
0 g
s
1 g
.70713 2.02645 m .68931 1.91313 L .64845 1.91787 L p F P
0 g
s
.56767 1.11876 m
.57321 1.15398 L
s
1 g
.76008 1.14881 m .74252 1.03074 L .73926 1.03685 L p F P
0 g
s
1 g
.73926 1.03685 m .75698 1.15586 L .76008 1.14881 L p F P
0 g
s
1 g
.7974 1.51622 m .78003 1.40008 L .75954 1.41063 L p F P
0 g
s
1 g
.75954 1.41063 m .77713 1.52751 L .7974 1.51622 L p F P
0 g
s
1 g
.55632 1.80458 m .53766 1.68987 L .50868 1.68672 L p F P
0 g
s
1 g
.48979 1.57146 m .50868 1.68672 L .53766 1.68987 L p F P
0 g
s
1 g
.59121 1.80552 m .60958 1.91955 L .64845 1.91787 L p F P
0 g
s
1 g
.60958 1.91955 m .59121 1.80552 L .55632 1.80458 L p F P
0 g
s
1 g
.37446 1.08799 m .3548 .9692 L .36051 .96377 L p F P
0 g
s
1 g
.34083 .84467 m .36051 .96377 L .3548 .9692 L p F P
0 g
s
1 g
.53766 1.68987 m .55632 1.80458 L .59121 1.80552 L p F P
0 g
s
1 g
.33881 .59403 m .31899 .47285 L .34878 .46782 L p F P
0 g
s
1 g
.32903 .34603 m .34878 .46782 L .31899 .47285 L p F P
0 g
s
1 g
.76801 1.89561 m .75047 1.78137 L .71212 1.79109 L p F P
0 g
s
1 g
.71212 1.79109 m .72991 1.90557 L .76801 1.89561 L p F P
0 g
s
1 g
.4492 1.4509 m .42992 1.334 L .41703 1.32876 L p F P
0 g
s
1 g
.39764 1.21152 m .41703 1.32876 L .42992 1.334 L p F P
0 g
s
.56212 1.08343 m
.56767 1.11876 L
s
1 g
.33577 .71961 m .3159 .59889 L .33881 .59403 L p F P
0 g
s
1 g
.31899 .47285 m .33881 .59403 L .3159 .59889 L p F P
0 g
s
1 g
.79454 1.64316 m .77713 1.52751 L .74915 1.53872 L p F P
0 g
s
1 g
.74915 1.53872 m .76681 1.65497 L .79454 1.64316 L p F P
0 g
s
1 g
.78428 1.77 m .76681 1.65497 L .73275 1.66591 L p F P
0 g
s
1 g
.73275 1.66591 m .75047 1.78137 L .78428 1.77 L p F P
0 g
s
1 g
.71901 .90778 m .70119 .78816 L .70683 .79083 L p F P
0 g
s
1 g
.70683 .79083 m .72477 .91142 L .71901 .90778 L p F P
0 g
s
1 g
.77452 1.27361 m .75698 1.15586 L .74474 1.16409 L p F P
0 g
s
1 g
.74474 1.16409 m .76248 1.28271 L .77452 1.27361 L p F P
0 g
s
.55655 1.04798 m
.56212 1.08343 L
s
1 g
.63024 1.8035 m .64845 1.91787 L .68931 1.91313 L p F P
0 g
s
1 g
.64845 1.91787 m .63024 1.8035 L .59121 1.80552 L p F P
0 g
s
1 g
.34083 .84467 m .32094 .72431 L .33577 .71961 L p F P
0 g
s
1 g
.3159 .59889 m .33577 .71961 L .32094 .72431 L p F P
0 g
s
1 g
.39764 1.21152 m .37803 1.09303 L .37446 1.08799 L p F P
0 g
s
1 g
.3548 .9692 m .37446 1.08799 L .37803 1.09303 L p F P
0 g
s
1 g
.72991 1.90557 m .71212 1.79109 L .67129 1.79861 L p F P
0 g
s
1 g
.67129 1.79861 m .68931 1.91313 L .72991 1.90557 L p F P
0 g
s
1 g
.48979 1.57146 m .47069 1.45499 L .4492 1.4509 L p F P
0 g
s
1 g
.42992 1.334 m .4492 1.4509 L .47069 1.45499 L p F P
0 g
s
1 g
.68931 1.91313 m .67129 1.79861 L .63024 1.8035 L p F P
0 g
s
0 .538 1 r
.65312 1.84671 m
.67665 1.80995 L
s
0 g
.55096 1.01243 m
.55655 1.04798 L
s
1 g
.74252 1.03074 m .72477 .91142 L .72134 .91658 L p F P
0 g
s
1 g
.72134 .91658 m .73926 1.03685 L .74252 1.03074 L p F P
0 g
s
1 g
.78003 1.40008 m .76248 1.28271 L .74175 1.2925 L p F P
0 g
s
1 g
.74175 1.2925 m .75954 1.41063 L .78003 1.40008 L p F P
0 g
s
1 g
.53766 1.68987 m .51881 1.57394 L .48979 1.57146 L p F P
0 g
s
1 g
.47069 1.45499 m .48979 1.57146 L .51881 1.57394 L p F P
0 g
s
1 g
.57266 1.69029 m .59121 1.80552 L .63024 1.8035 L p F P
0 g
s
1 g
.59121 1.80552 m .57266 1.69029 L .53766 1.68987 L p F P
0 g
s
0 1 1 r
.55747 1.72678 m
.57147 1.74433 L
s
.5477 1.71452 m
.55546 1.72426 L
s
.55546 1.72426 m
.55747 1.72678 L
s
1 g
.3548 .9692 m .33492 .84915 L .34083 .84467 L p F P
0 g
s
1 g
.32094 .72431 m .34083 .84467 L .33492 .84915 L p F P
0 g
s
.54536 .97676 m
.55096 1.01243 L
s
1 g
.51881 1.57394 m .53766 1.68987 L .57266 1.69029 L p F P
0 g
s
1 g
.31899 .47285 m .29896 .35038 L .32903 .34603 L p F P
0 g
s
1 g
.75047 1.78137 m .73275 1.66591 L .69414 1.67539 L p F P
0 g
s
1 g
.69414 1.67539 m .71212 1.79109 L .75047 1.78137 L p F P
0 g
s
1 g
.42992 1.334 m .41044 1.21585 L .39764 1.21152 L p F P
0 g
s
1 g
.37803 1.09303 m .39764 1.21152 L .41044 1.21585 L p F P
0 g
s
1 g
.3159 .59889 m .29582 .47688 L .31899 .47285 L p F P
0 g
s
1 g
.29896 .35038 m .31899 .47285 L .29582 .47688 L p F P
0 g
s
1 g
.77713 1.52751 m .75954 1.41063 L .7313 1.42122 L p F P
0 g
s
.385 1 0 r
.77509 1.41054 m
.77842 1.41746 L
s
1 g
.7313 1.42122 m .74915 1.53872 L .77713 1.52751 L p F P
0 g
s
1 g
.76681 1.65497 m .74915 1.53872 L .71483 1.54922 L p F P
0 g
s
1 g
.71483 1.54922 m .73275 1.66591 L .76681 1.65497 L p F P
0 g
s
1 g
.70119 .78816 m .68318 .66728 L .6887 .66895 L p F P
0 g
s
1 g
.6887 .66895 m .70683 .79083 L .70119 .78816 L p F P
0 g
s
.53973 .94098 m
.54536 .97676 L
s
1 g
.75698 1.15586 m .73926 1.03685 L .72681 1.04419 L p F P
0 g
s
1 g
.72681 1.04419 m .74474 1.16409 L .75698 1.15586 L p F P
0 g
s
1 g
.61184 1.68792 m .63024 1.8035 L .67129 1.79861 L p F P
0 g
s
1 g
.63024 1.8035 m .61184 1.68792 L .57266 1.69029 L p F P
0 g
s
1 g
.32094 .72431 m .30084 .60267 L .3159 .59889 L p F P
0 g
s
1 g
.29582 .47688 m .3159 .59889 L .30084 .60267 L p F P
0 g
s
1 g
.37803 1.09303 m .35822 .97327 L .3548 .9692 L p F P
0 g
s
1 g
.33492 .84915 m .3548 .9692 L .35822 .97327 L p F P
0 g
s
1 g
.71212 1.79109 m .69414 1.67539 L .65309 1.68286 L p F P
0 g
s
0 1 1 r
.57147 1.74433 m
.58835 1.7655 L
s
1 g
.65309 1.68286 m .67129 1.79861 L .71212 1.79109 L p F P
0 g
s
0 .538 1 r
.67665 1.80995 m
.68897 1.79069 L
s
.68897 1.79069 m
.69163 1.78654 L
s
1 g
.47069 1.45499 m .45139 1.33727 L .42992 1.334 L p F P
0 g
s
1 g
.41044 1.21585 m .42992 1.334 L .45139 1.33727 L p F P
0 g
s
.53409 .90508 m
.53973 .94098 L
s
1 g
.67129 1.79861 m .65309 1.68286 L .61184 1.68792 L p F P
0 g
s
0 1 1 r
.58835 1.7655 m
.65312 1.84671 L
s
1 0 .231 r
.65237 1.73696 m
.65312 1.84671 L
s
.64805 1.10638 m
.652 1.683 L
s
.6523 1.72576 m
.65237 1.73696 L
s
1 g
.72477 .91142 m .70683 .79083 L .70323 .795 L p F P
0 g
s
1 g
.70323 .795 m .72134 .91658 L .72477 .91142 L p F P
0 g
s
1 g
.76248 1.28271 m .74474 1.16409 L .72377 1.17309 L p F P
0 g
s
1 g
.72377 1.17309 m .74175 1.2925 L .76248 1.28271 L p F P
0 g
s
1 g
.51881 1.57394 m .49975 1.45677 L .47069 1.45499 L p F P
0 g
s
1 g
.45139 1.33727 m .47069 1.45499 L .49975 1.45677 L p F P
0 g
s
1 g
.5539 1.57383 m .57266 1.69029 L .61184 1.68792 L p F P
0 g
s
1 g
.57266 1.69029 m .5539 1.57383 L .51881 1.57394 L p F P
0 g
s
.52843 .86907 m
.53409 .90508 L
s
1 g
.33492 .84915 m .31483 .72781 L .32094 .72431 L p F P
0 g
s
1 g
.30084 .60267 m .32094 .72431 L .31483 .72781 L p F P
0 g
s
1 g
.49975 1.45677 m .51881 1.57394 L .5539 1.57383 L p F P
0 g
s
1 g
.73275 1.66591 m .71483 1.54922 L .67598 1.55845 L p F P
0 g
s
1 g
.67598 1.55845 m .69414 1.67539 L .73275 1.66591 L p F P
0 g
s
1 g
.41044 1.21585 m .39075 1.09644 L .37803 1.09303 L p F P
0 g
s
1 g
.35822 .97327 m .37803 1.09303 L .39075 1.09644 L p F P
0 g
s
1 g
.29582 .47688 m .27553 .35357 L .29896 .35038 L p F P
0 g
s
1 g
.75954 1.41063 m .74175 1.2925 L .71326 1.30246 L p F P
0 g
s
.385 1 0 r
.77483 1.40999 m
.77509 1.41054 L
s
1 g
.71326 1.30246 m .7313 1.42122 L .75954 1.41063 L p F P
0 g
s
.385 1 0 r
.73849 1.3343 m
.77483 1.40999 L
s
0 g
.52276 .83295 m
.52843 .86907 L
s
1 g
.74915 1.53872 m .7313 1.42122 L .69672 1.43128 L p F P
0 g
s
1 g
.69672 1.43128 m .71483 1.54922 L .74915 1.53872 L p F P
0 g
s
1 g
.68318 .66728 m .66498 .5451 L .67037 .54575 L p F P
0 g
s
1 g
.67037 .54575 m .6887 .66895 L .68318 .66728 L p F P
0 g
s
1 g
.73926 1.03685 m .72134 .91658 L .70868 .923 L p F P
0 g
s
1 g
.70868 .923 m .72681 1.04419 L .73926 1.03685 L p F P
0 g
s
1 g
.59323 1.5711 m .61184 1.68792 L .65309 1.68286 L p F P
0 g
s
1 g
.61184 1.68792 m .59323 1.5711 L .5539 1.57383 L p F P
0 g
s
1 g
.30084 .60267 m .28052 .47972 L .29582 .47688 L p F P
0 g
s
1 g
.27553 .35357 m .29582 .47688 L .28052 .47972 L p F P
0 g
s
1 g
.35822 .97327 m .3382 .85223 L .33492 .84915 L p F P
0 g
s
1 g
.31483 .72781 m .33492 .84915 L .3382 .85223 L p F P
0 g
s
.51706 .79671 m
.52276 .83295 L
s
1 g
.69414 1.67539 m .67598 1.55845 L .63469 1.56588 L p F P
0 g
s
1 g
.63469 1.56588 m .65309 1.68286 L .69414 1.67539 L p F P
0 g
s
1 g
.45139 1.33727 m .43188 1.21828 L .41044 1.21585 L p F P
0 g
s
1 g
.39075 1.09644 m .41044 1.21585 L .43188 1.21828 L p F P
0 g
s
1 g
.65309 1.68286 m .63469 1.56588 L .59323 1.5711 L p F P
0 g
s
.51135 .76035 m
.51706 .79671 L
s
1 g
.70683 .79083 m .6887 .66895 L .68493 .67211 L p F P
0 g
s
1 g
.68493 .67211 m .70323 .795 L .70683 .79083 L p F P
0 g
s
1 g
.74474 1.16409 m .72681 1.04419 L .7056 1.0524 L p F P
0 g
s
1 g
.7056 1.0524 m .72377 1.17309 L .74474 1.16409 L p F P
0 g
s
1 g
.49975 1.45677 m .48049 1.33834 L .45139 1.33727 L p F P
0 g
s
1 g
.43188 1.21828 m .45139 1.33727 L .48049 1.33834 L p F P
0 g
s
1 g
.53494 1.45611 m .5539 1.57383 L .59323 1.5711 L p F P
0 g
s
1 g
.5539 1.57383 m .53494 1.45611 L .49975 1.45677 L p F P
0 g
s
1 g
.31483 .72781 m .29453 .60516 L .30084 .60267 L p F P
0 g
s
1 g
.28052 .47972 m .30084 .60267 L .29453 .60516 L p F P
0 g
s
1 g
.48049 1.33834 m .49975 1.45677 L .53494 1.45611 L p F P
0 g
s
1 g
.71483 1.54922 m .69672 1.43128 L .65761 1.44025 L p F P
0 g
s
1 g
.65761 1.44025 m .67598 1.55845 L .71483 1.54922 L p F P
0 g
s
1 g
.39075 1.09644 m .37085 .97574 L .35822 .97327 L p F P
0 g
s
1 g
.3382 .85223 m .35822 .97327 L .37085 .97574 L p F P
0 g
s
.50561 .72388 m
.51135 .76035 L
s
1 g
.74175 1.2925 m .72377 1.17309 L .69503 1.18241 L p F P
0 g
s
1 g
.69503 1.18241 m .71326 1.30246 L .74175 1.2925 L p F P
0 g
s
1 0 .692 r
.71994 1.28755 m
.72197 1.29267 L
s
.64805 1.10638 m
.70545 1.25103 L
s
1 g
.7313 1.42122 m .71326 1.30246 L .67842 1.31206 L p F P
0 g
s
1 g
.67842 1.31206 m .69672 1.43128 L .7313 1.42122 L p F P
0 g
s
1 0 .692 r
.72982 1.31245 m
.73849 1.3343 L
s
.72197 1.29267 m
.72982 1.31245 L
s
1 g
.66498 .5451 m .64658 .42161 L .65184 .42121 L p F P
0 g
s
1 g
.65184 .42121 m .67037 .54575 L .66498 .5451 L p F P
0 g
s
.49986 .68729 m
.50561 .72388 L
s
1 g
.72134 .91658 m .70323 .795 L .69036 .8005 L p F P
0 g
s
1 g
.69036 .8005 m .70868 .923 L .72134 .91658 L p F P
0 g
s
1 g
.57443 1.45302 m .59323 1.5711 L .63469 1.56588 L p F P
0 g
s
1 g
.59323 1.5711 m .57443 1.45302 L .53494 1.45611 L p F P
0 g
s
1 g
.28052 .47972 m .25998 .35544 L .27553 .35357 L p F P
0 g
s
1 g
.3382 .85223 m .31796 .72988 L .31483 .72781 L p F P
0 g
s
1 g
.29453 .60516 m .31483 .72781 L .31796 .72988 L p F P
0 g
s
1 g
.67598 1.55845 m .65761 1.44025 L .61609 1.44764 L p F P
0 g
s
1 g
.61609 1.44764 m .63469 1.56588 L .67598 1.55845 L p F P
0 g
s
1 g
.43188 1.21828 m .41217 1.09802 L .39075 1.09644 L p F P
0 g
s
1 g
.37085 .97574 m .39075 1.09644 L .41217 1.09802 L p F P
0 g
s
1 g
.63469 1.56588 m .61609 1.44764 L .57443 1.45302 L p F P
0 g
s
.4941 .65058 m
.49986 .68729 L
s
1 g
.6887 .66895 m .67037 .54575 L .66643 .54789 L p F P
0 g
s
1 g
.66643 .54789 m .68493 .67211 L .6887 .66895 L p F P
0 g
s
1 g
.72681 1.04419 m .70868 .923 L .68724 .9304 L p F P
0 g
s
1 g
.68724 .9304 m .7056 1.0524 L .72681 1.04419 L p F P
0 g
s
1 g
.48049 1.33834 m .46102 1.21864 L .43188 1.21828 L p F P
0 g
s
1 g
.41217 1.09802 m .43188 1.21828 L .46102 1.21864 L p F P
0 g
s
1 g
.51578 1.33713 m .53494 1.45611 L .57443 1.45302 L p F P
0 g
s
1 .231 0 r
.52198 1.42809 m
.52988 1.42467 L
s
1 g
.53494 1.45611 m .51578 1.33713 L .48049 1.33834 L p F P
0 g
s
1 g
.29453 .60516 m .274 .48119 L .28052 .47972 L p F P
0 g
s
1 g
.25998 .35544 m .28052 .47972 L .274 .48119 L p F P
0 g
s
.48831 .61376 m
.4941 .65058 L
s
1 g
.46102 1.21864 m .48049 1.33834 L .51578 1.33713 L p F P
0 g
s
1 g
.69672 1.43128 m .67842 1.31206 L .63905 1.32077 L p F P
0 g
s
1 g
.63905 1.32077 m .65761 1.44025 L .69672 1.43128 L p F P
0 g
s
1 .231 0 r
.67964 1.35979 m
.73849 1.3343 L
s
.6687 1.36453 m
.67964 1.35979 L
s
.55465 1.41393 m
.64729 1.37381 L
s
.66438 1.3664 m
.6687 1.36453 L
s
1 g
.37085 .97574 m .35073 .85374 L .3382 .85223 L p F P
0 g
s
1 g
.31796 .72988 m .3382 .85223 L .35073 .85374 L p F P
0 g
s
1 g
.72377 1.17309 m .7056 1.0524 L .67659 1.06106 L p F P
0 g
s
1 g
.67659 1.06106 m .69503 1.18241 L .72377 1.17309 L p F P
0 g
s
1 g
.71326 1.30246 m .69503 1.18241 L .65992 1.19155 L p F P
0 g
s
1 g
.65992 1.19155 m .67842 1.31206 L .71326 1.30246 L p F P
0 g
s
1 g
.64658 .42161 m .62798 .29678 L .63312 .29531 L p F P
0 g
s
1 g
.63312 .29531 m .65184 .42121 L .64658 .42161 L p F P
0 g
s
.4825 .57681 m
.48831 .61376 L
s
1 g
.70323 .795 m .68493 .67211 L .67184 .67665 L p F P
0 g
s
1 g
.67184 .67665 m .69036 .8005 L .70323 .795 L p F P
0 g
s
0 0 1 r
.03 w
.65312 1.84671 Mdot
.5 Mabswid
1 g
.55543 1.33366 m .57443 1.45302 L .61609 1.44764 L p F P
0 g
s
1 g
.57443 1.45302 m .55543 1.33366 L .51578 1.33713 L p F P
0 g
s
1 g
.31796 .72988 m .2975 .60621 L .29453 .60516 L p F P
0 g
s
1 g
.274 .48119 m .29453 .60516 L .2975 .60621 L p F P
0 g
s
1 g
.65761 1.44025 m .63905 1.32077 L .59728 1.32811 L p F P
0 g
s
1 g
.59728 1.32811 m .61609 1.44764 L .65761 1.44025 L p F P
0 g
s
0 .769 1 r
.65312 1.84671 m
.73849 1.3343 L
s
1 g
.41217 1.09802 m .39224 .97645 L .37085 .97574 L p F P
0 g
s
1 g
.35073 .85374 m .37085 .97574 L .39224 .97645 L p F P
0 g
s
.47668 .53975 m
.4825 .57681 L
s
1 g
.61609 1.44764 m .59728 1.32811 L .55543 1.33366 L p F P
0 g
s
1 g
.67037 .54575 m .65184 .42121 L .64772 .4223 L p F P
0 g
s
1 g
.64772 .4223 m .66643 .54789 L .67037 .54575 L p F P
0 g
s
1 g
.70868 .923 m .69036 .8005 L .66867 .80706 L p F P
0 g
s
1 g
.66867 .80706 m .68724 .9304 L .70868 .923 L p F P
0 g
s
1 g
.46102 1.21864 m .44134 1.09763 L .41217 1.09802 L p F P
0 g
s
1 g
.39224 .97645 m .41217 1.09802 L .44134 1.09763 L p F P
0 g
s
1 g
.49641 1.21685 m .51578 1.33713 L .55543 1.33366 L p F P
0 g
s
1 g
.51578 1.33713 m .49641 1.21685 L .46102 1.21864 L p F P
0 g
s
.47083 .50257 m
.47668 .53975 L
s
1 g
.274 .48119 m .25325 .35586 L .25998 .35544 L p F P
0 g
s
1 g
.44134 1.09763 m .46102 1.21864 L .49641 1.21685 L p F P
0 g
s
1 g
.67842 1.31206 m .65992 1.19155 L .62028 1.19999 L p F P
0 g
s
1 g
.62028 1.19999 m .63905 1.32077 L .67842 1.31206 L p F P
0 g
s
1 g
.35073 .85374 m .33039 .7304 L .31796 .72988 L p F P
0 g
s
1 g
.2975 .60621 m .31796 .72988 L .33039 .7304 L p F P
0 g
s
1 g
.7056 1.0524 m .68724 .9304 L .65796 .93839 L p F P
0 g
s
1 g
.65796 .93839 m .67659 1.06106 L .7056 1.0524 L p F P
0 g
s
.46497 .46526 m
.47083 .50257 L
s
1 g
.69503 1.18241 m .67659 1.06106 L .64121 1.06972 L p F P
0 g
s
1 g
.64121 1.06972 m .65992 1.19155 L .69503 1.18241 L p F P
0 g
s
1 g
.68493 .67211 m .66643 .54789 L .65312 .55145 L p F P
0 g
s
1 g
.65312 .55145 m .67184 .67665 L .68493 .67211 L p F P
0 g
s
1 g
.53622 1.21301 m .55543 1.33366 L .59728 1.32811 L p F P
0 g
s
1 g
.55543 1.33366 m .53622 1.21301 L .49641 1.21685 L p F P
0 g
s
1 g
.2975 .60621 m .27681 .48118 L .274 .48119 L p F P
0 g
s
1 g
.25325 .35586 m .274 .48119 L .27681 .48118 L p F P
0 g
s
.45909 .42784 m
.46497 .46526 L
s
1 g
.63905 1.32077 m .62028 1.19999 L .57828 1.20728 L p F P
0 g
s
1 g
.57828 1.20728 m .59728 1.32811 L .63905 1.32077 L p F P
0 g
s
1 g
.39224 .97645 m .37209 .85355 L .35073 .85374 L p F P
0 g
s
1 g
.33039 .7304 m .35073 .85374 L .37209 .85355 L p F P
0 g
s
1 g
.59728 1.32811 m .57828 1.20728 L .53622 1.21301 L p F P
0 g
s
.45319 .39029 m
.45909 .42784 L
s
1 g
.65184 .42121 m .63312 .29531 L .62881 .29533 L p F P
0 g
s
1 g
.62881 .29533 m .64772 .4223 L .65184 .42121 L p F P
0 g
s
1 g
.69036 .8005 m .67184 .67665 L .6499 .68237 L p F P
0 g
s
1 g
.6499 .68237 m .66867 .80706 L .69036 .8005 L p F P
0 g
s
1 g
.44134 1.09763 m .42144 .9753 L .39224 .97645 L p F P
0 g
s
1 g
.37209 .85355 m .39224 .97645 L .42144 .9753 L p F P
0 g
s
1 g
.47683 1.09527 m .49641 1.21685 L .53622 1.21301 L p F P
0 g
s
1 g
.49641 1.21685 m .47683 1.09527 L .44134 1.09763 L p F P
0 g
s
1 g
.42144 .9753 m .44134 1.09763 L .47683 1.09527 L p F P
0 g
s
1 g
.65992 1.19155 m .64121 1.06972 L .60131 1.07789 L p F P
0 g
s
1 g
.60131 1.07789 m .62028 1.19999 L .65992 1.19155 L p F P
0 g
s
1 g
.33039 .7304 m .30983 .60572 L .2975 .60621 L p F P
0 g
s
1 g
.27681 .48118 m .2975 .60621 L .30983 .60572 L p F P
0 g
s
.44727 .35262 m
.45319 .39029 L
s
1 g
.68724 .9304 m .66867 .80706 L .63912 .81436 L p F P
0 g
s
1 g
.63912 .81436 m .65796 .93839 L .68724 .9304 L p F P
0 g
s
1 g
.67659 1.06106 m .65796 .93839 L .6223 .94655 L p F P
0 g
s
1 g
.6223 .94655 m .64121 1.06972 L .67659 1.06106 L p F P
0 g
s
.44133 .31482 m
.44727 .35262 L
s
1 g
.66643 .54789 m .64772 .4223 L .63419 .42487 L p F P
0 g
s
1 g
.63419 .42487 m .65312 .55145 L .66643 .54789 L p F P
0 g
s
1 g
.51679 1.09103 m .53622 1.21301 L .57828 1.20728 L p F P
0 g
s
1 g
.53622 1.21301 m .51679 1.09103 L .47683 1.09527 L p F P
0 g
s
1 g
.27681 .48118 m .2559 .35478 L .25325 .35586 L p F P
0 g
s
1 g
.62028 1.19999 m .60131 1.07789 L .55906 1.08513 L p F P
0 g
s
1 g
.55906 1.08513 m .57828 1.20728 L .62028 1.19999 L p F P
0 g
s
1 g
.37209 .85355 m .35172 .7293 L .33039 .7304 L p F P
0 g
s
1 g
.30983 .60572 m .33039 .7304 L .35172 .7293 L p F P
0 g
s
1 g
.57828 1.20728 m .55906 1.08513 L .51679 1.09103 L p F P
0 g
s
.43537 .27691 m
.44133 .31482 L
s
1 g
.67184 .67665 m .65312 .55145 L .63092 .5563 L p F P
0 g
s
1 g
.63092 .5563 m .6499 .68237 L .67184 .67665 L p F P
0 g
s
1 g
.42144 .9753 m .40133 .85163 L .37209 .85355 L p F P
0 g
s
1 g
.35172 .7293 m .37209 .85355 L .40133 .85163 L p F P
0 g
s
1 g
.45703 .97235 m .47683 1.09527 L .51679 1.09103 L p F P
0 g
s
1 g
.47683 1.09527 m .45703 .97235 L .42144 .9753 L p F P
0 g
s
.42939 .23887 m
.43537 .27691 L
s
1 g
.40133 .85163 m .42144 .9753 L .45703 .97235 L p F P
0 g
s
1 g
.64121 1.06972 m .6223 .94655 L .58213 .95445 L p F P
0 g
s
1 g
.58213 .95445 m .60131 1.07789 L .64121 1.06972 L p F P
0 g
s
1 g
.30983 .60572 m .28905 .47966 L .27681 .48118 L p F P
0 g
s
1 g
.2559 .35478 m .27681 .48118 L .28905 .47966 L p F P
0 g
s
1 g
.66867 .80706 m .6499 .68237 L .62007 .68897 L p F P
0 g
s
1 g
.62007 .68897 m .63912 .81436 L .66867 .80706 L p F P
0 g
s
1 g
.65796 .93839 m .63912 .81436 L .60318 .82203 L p F P
0 g
s
1 g
.60318 .82203 m .6223 .94655 L .65796 .93839 L p F P
0 g
s
0 0 1 r
.03 w
.73849 1.3343 Mdot
0 g
.5 Mabswid
.42339 .2007 m
.42939 .23887 L
s
1 g
.64772 .4223 m .62881 .29533 L .61505 .29689 L p F P
0 g
s
1 g
.61505 .29689 m .63419 .42487 L .64772 .4223 L p F P
0 g
s
1 g
.49716 .96771 m .51679 1.09103 L .55906 1.08513 L p F P
0 g
s
1 g
.51679 1.09103 m .49716 .96771 L .45703 .97235 L p F P
0 g
s
1 g
.60131 1.07789 m .58213 .95445 L .53964 .96163 L p F P
0 g
s
1 g
.53964 .96163 m .55906 1.08513 L .60131 1.07789 L p F P
0 g
s
1 g
.35172 .7293 m .33112 .60368 L .30983 .60572 L p F P
0 g
s
1 g
.28905 .47966 m .30983 .60572 L .33112 .60368 L p F P
0 g
s
.41738 .16241 m
.42339 .2007 L
s
1 g
.55906 1.08513 m .53964 .96163 L .49716 .96771 L p F P
0 g
s
1 g
.65312 .55145 m .63419 .42487 L .61173 .42882 L p F P
0 g
s
1 g
.61173 .42882 m .63092 .5563 L .65312 .55145 L p F P
0 g
s
1 g
.40133 .85163 m .38099 .7266 L .35172 .7293 L p F P
0 g
s
1 g
.33112 .60368 m .35172 .7293 L .38099 .7266 L p F P
0 g
s
1 g
.43702 .84807 m .45703 .97235 L .49716 .96771 L p F P
0 g
s
1 g
.45703 .97235 m .43702 .84807 L .40133 .85163 L p F P
0 g
s
.41134 .12399 m
.41738 .16241 L
s
1 g
.38099 .7266 m .40133 .85163 L .43702 .84807 L p F P
0 g
s
1 g
.6223 .94655 m .60318 .82203 L .56274 .82964 L p F P
0 g
s
1 g
.56274 .82964 m .58213 .95445 L .6223 .94655 L p F P
0 g
s
1 g
.28905 .47966 m .26803 .35221 L .2559 .35478 L p F P
0 g
s
1 g
.6499 .68237 m .63092 .5563 L .60082 .56218 L p F P
0 g
s
1 g
.60082 .56218 m .62007 .68897 L .6499 .68237 L p F P
0 g
s
1 g
.63912 .81436 m .62007 .68897 L .58385 .69612 L p F P
0 g
s
1 g
.58385 .69612 m .60318 .82203 L .63912 .81436 L p F P
0 g
s
1 g
.4773 .84303 m .49716 .96771 L .53964 .96163 L p F P
0 g
s
1 g
.49716 .96771 m .4773 .84303 L .43702 .84807 L p F P
0 g
s
1 g
.58213 .95445 m .56274 .82964 L .51999 .83677 L p F P
0 g
s
1 g
.51999 .83677 m .53964 .96163 L .58213 .95445 L p F P
0 g
s
1 g
.33112 .60368 m .3103 .47667 L .28905 .47966 L p F P
0 g
s
1 g
.26803 .35221 m .28905 .47966 L .3103 .47667 L p F P
0 g
s
1 g
.53964 .96163 m .51999 .83677 L .4773 .84303 L p F P
0 g
s
1 g
.63419 .42487 m .61505 .29689 L .59232 .29993 L p F P
0 g
s
1 g
.59232 .29993 m .61173 .42882 L .63419 .42487 L p F P
0 g
s
1 g
.38099 .7266 m .36043 .60017 L .33112 .60368 L p F P
0 g
s
1 g
.3103 .47667 m .33112 .60368 L .36043 .60017 L p F P
0 g
s
1 g
.41678 .72241 m .43702 .84807 L .4773 .84303 L p F P
0 g
s
1 g
.43702 .84807 m .41678 .72241 L .38099 .7266 L p F P
0 g
s
1 g
.36043 .60017 m .38099 .7266 L .41678 .72241 L p F P
0 g
s
1 g
.60318 .82203 m .58385 .69612 L .54313 .70344 L p F P
0 g
s
1 g
.54313 .70344 m .56274 .82964 L .60318 .82203 L p F P
0 g
s
1 g
.63092 .5563 m .61173 .42882 L .58134 .43397 L p F P
0 g
s
1 g
.58134 .43397 m .60082 .56218 L .63092 .5563 L p F P
0 g
s
1 g
.62007 .68897 m .60082 .56218 L .5643 .56881 L p F P
0 g
s
1 g
.5643 .56881 m .58385 .69612 L .62007 .68897 L p F P
0 g
s
1 g
.45723 .71695 m .4773 .84303 L .51999 .83677 L p F P
0 g
s
1 g
.4773 .84303 m .45723 .71695 L .41678 .72241 L p F P
0 g
s
1 g
.56274 .82964 m .54313 .70344 L .50013 .71051 L p F P
0 g
s
1 g
.50013 .71051 m .51999 .83677 L .56274 .82964 L p F P
0 g
s
1 g
.3103 .47667 m .28924 .34824 L .26803 .35221 L p F P
0 g
s
1 g
.51999 .83677 m .50013 .71051 L .45723 .71695 L p F P
0 g
s
1 g
.36043 .60017 m .33964 .47234 L .3103 .47667 L p F P
0 g
s
1 g
.28924 .34824 m .3103 .47667 L .33964 .47234 L p F P
0 g
s
1 g
.39632 .59536 m .41678 .72241 L .45723 .71695 L p F P
0 g
s
1 g
.41678 .72241 m .39632 .59536 L .36043 .60017 L p F P
0 g
s
1 g
.33964 .47234 m .36043 .60017 L .39632 .59536 L p F P
0 g
s
1 g
.58385 .69612 m .5643 .56881 L .52331 .57582 L p F P
0 g
s
1 g
.52331 .57582 m .54313 .70344 L .58385 .69612 L p F P
0 g
s
1 g
.61173 .42882 m .59232 .29993 L .56165 .30433 L p F P
0 g
s
1 g
.56165 .30433 m .58134 .43397 L .61173 .42882 L p F P
0 g
s
1 g
.60082 .56218 m .58134 .43397 L .54454 .44006 L p F P
0 g
s
1 g
.54454 .44006 m .5643 .56881 L .60082 .56218 L p F P
0 g
s
1 g
.43693 .58947 m .45723 .71695 L .50013 .71051 L p F P
0 g
s
1 g
.45723 .71695 m .43693 .58947 L .39632 .59536 L p F P
0 g
s
1 g
.54313 .70344 m .52331 .57582 L .48005 .58284 L p F P
0 g
s
1 g
.48005 .58284 m .50013 .71051 L .54313 .70344 L p F P
0 g
s
1 g
.50013 .71051 m .48005 .58284 L .43693 .58947 L p F P
0 g
s
1 g
.33964 .47234 m .31861 .34307 L .28924 .34824 L p F P
0 g
s
1 g
.37563 .46687 m .39632 .59536 L .43693 .58947 L p F P
0 g
s
1 g
.39632 .59536 m .37563 .46687 L .33964 .47234 L p F P
0 g
s
1 g
.31861 .34307 m .33964 .47234 L .37563 .46687 L p F P
0 g
s
1 g
.5643 .56881 m .54454 .44006 L .50326 .44677 L p F P
0 g
s
1 g
.50326 .44677 m .52331 .57582 L .5643 .56881 L p F P
0 g
s
1 g
.58134 .43397 m .56165 .30433 L .52455 .30987 L p F P
0 g
s
1 g
.52455 .30987 m .54454 .44006 L .58134 .43397 L p F P
0 g
s
1 g
.4164 .46056 m .43693 .58947 L .48005 .58284 L p F P
0 g
s
1 g
.43693 .58947 m .4164 .46056 L .37563 .46687 L p F P
0 g
s
1 g
.52331 .57582 m .50326 .44677 L .45974 .45373 L p F P
0 g
s
1 g
.45974 .45373 m .48005 .58284 L .52331 .57582 L p F P
0 g
s
1 g
.48005 .58284 m .45974 .45373 L .4164 .46056 L p F P
0 g
s
1 g
.35471 .33694 m .37563 .46687 L .4164 .46056 L p F P
0 g
s
1 g
.37563 .46687 m .35471 .33694 L .31861 .34307 L p F P
0 g
s
1 g
.54454 .44006 m .52455 .30987 L .48298 .31626 L p F P
0 g
s
1 g
.48298 .31626 m .50326 .44677 L .54454 .44006 L p F P
0 g
s
1 g
.39564 .33018 m .4164 .46056 L .45974 .45373 L p F P
0 g
s
1 g
.4164 .46056 m .39564 .33018 L .35471 .33694 L p F P
0 g
s
1 g
.50326 .44677 m .48298 .31626 L .4392 .32316 L p F P
0 g
s
1 g
.4392 .32316 m .45974 .45373 L .50326 .44677 L p F P
0 g
s
1 g
.45974 .45373 m .4392 .32316 L .39564 .33018 L p F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{262.812, 340.5},
  ImageMargins->{{50, 0}, {0, 7}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000460001E2000`400?l00000o`00003oooooool7
ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7
ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7
ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7
ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7
ooooo`00ooooool7ooooo`00ooooool7ooooo`00^Oooool00ol0003oooooooooo`1:ooooo`00^Ooo
ool00ol0003oooooooooo`1:ooooo`00^_ooool00ol0003oooooooooo`19ooooo`00^_ooool00ol0
003oooooooooo`19ooooo`00^_ooool00ol0003oooooooooo`19ooooo`00^_ooool00ol0003ooooo
ooooo`19ooooo`00^_ooool00ol0003oooooooooo`19ooooo`00^oooool00ol0003oooooooooo`18
ooooo`00^oooool00ol0003oooooooooo`18ooooo`00^oooool00ol0003oooooooooo`18ooooo`00
^oooool00ol0003oooooooooo`18ooooo`00^oooool00ol0003oooooooooo`18ooooo`00^oooool0
0ol0003oooooooooo`18ooooo`00^oooool00ol0003oooooooooo`18ooooo`00^oooool00ol0003o
ooooooooo`18ooooo`00^oooool00ol0003oooooooooo`18ooooo`00_?ooool00ol0003ooooooooo
o`17ooooo`00_?ooool00ol0003oooooooooo`17ooooo`00_?ooool00ol0003oooooooooo`17oooo
o`00_?ooool00ol0003oooooooooo`17ooooo`00_Oooool00ol0003oooooooooo`0@ooooo`Co0000
<_ooool00;gooooo00?o0000ooooooooool02Oooool7o`000004ooooool0003oooooo`0003;ooooo
002mooooo`03o`000?oooooooooo00Gooooo1?l00002ooooo`09o`000?ooooooooooooooool0003o
ooooo`000?oooooo000003;ooooo002jooooo`_o00000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00ol0000aooooo`00]Oooool5o`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01_l0
003oooooooooool0003oooooo`00037ooooo002`ooooo`Go00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo0000037ooooo002Zooooo`Ko0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo0000037ooooo002Vooooo`Co000000Goooooo`000?ooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
0000ooooool00000<Oooool00:Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0ol0000`ooooo`00Y_ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
0000<?ooool00:Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?o0000<?ooool00:Sooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l0000a
ooooo`00Z?ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`00033o
oooo002Wooooo`?o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol0000_oooo
o`00Yoooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o0000;oooool0
0:Sooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000ol0000_ooooo`00Z?oo
ool01Ol0003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooooooool0003ooooo1?l000001?oooooo0000o`000?l0000_ooooo`00Z?ooool0
1Ol0003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08o`0000;ooooo
00?o0000ooooooooool00ol0000_ooooo`00Z?ooool00ol0003oooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Go00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00ol0000_ooooo`00Z?ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ol00002ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`?o0000;_ooool0
0:Wooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000Wo00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0ol0000^ooooo`00ZOooool01_l0003oooooo`000?oo
oooo0000ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03o`0002kooooo002Yooooo`Ko00000_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?o0000;_ooool00:Wooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ol0
000^ooooo`00ZOooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`03o`0002kooooo002Yooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`?o0000;_ooool00:[ooooo00Go0000ooooool0003oooooo`000003ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool0;_ooool00:[ooooo00Go0000ooooool0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo0ol0000]ooooo`00Z_ooool01Ol0003oooooo`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`?o0000;Oooool00:[ooooo00Go0000ooooool0003oooooo`000003oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00ol0000]ooooo`00Z_ooool3o`0000;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000
ooooo`04o`0002gooooo002Zooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002o`000004oooo
ool0003o0000o`0002gooooo002Zooooo`?o00000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wo000000Coooooo`000?oooooooooo0ol0000]ooooo`00Z_ooool3o`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05o`0000;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooo000002gooooo002[ooooo`05o`000?oooooo0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01Ol0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`?o0000;?ooool00:_ooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01Ol00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ol0000/ooooo`00
Zoooool3o`0000;ooooo00?o0000ooooool000001ol00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool3o`0002cooooo002[ooooo`Oo000000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool3o`0002cooooo002[ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooo000002cooooo002[ooooo`?o00000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool00000;?ooool00:cooooo00Go0000ooooool0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool0000/ooooo`00[Oooool2o`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003oooooooooool0003ooooo00;o0000:oooool00:gooooo0_l00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Oo0000ooooooooooooooooo`000?oooooo000002_ooooo002/ooooo`?o00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`06o`000?ooooooooooo`000?oooooo0000:oooool00:gooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000[ooooo`00[Oooool01Ol0003ooooo
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000oooooooooooo0000ooooo`04o`0002_ooooo002]ooooo`05o`000?oooooo0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooooooo
o`000?ooool3o`000004ooooool0003oooooo`0002_ooooo002]ooooo`05o`000?oooooo0000oooo
ool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000ol00000
1ooooooo0000oooooooooooo0000ooooool00000:oooool00:gooooo00?o0000ooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooo`000?l0000Zooooo`00[_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ol00002ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo0000
:_ooool00:kooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool5o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`0002[ooooo002^
ooooo`03o`000?oooooo000000co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool00000:_ooool00:kooooo0ol000000ooooooo0000ooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool0000Zooooo`00[_ooool01Ol0003oooooo`000?oooooo0000
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool01_l0003oooooooooool0003oooooo`0002[ooooo002^ooooo`03o`000?oooooo000000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003oooooo`000?oooooo000002[ooooo002`ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003oooooo`000?oooooo000002[ooooo002_ooooo`05o`000?oooooo0000ooooool0
00000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool09oooool00:oooooo00Go0000oooo
ool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Ko0000oooooooooooo0000ooooool0000Yooooo`00[oooool01Ol0003o
ooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01_l0003oooooooooool0003oooooo`0002Wooooo002_ooooo`03o`00
0?oooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002o`0002Wooooo002_ooooo`?o
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`?o000000?oooooo`000?ooool0:?ooool00:oooooo0ol00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooo
oooo0000ooooo`?o000000Coooooo`000?oooooo0000:Oooool00:oooooo0ol00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?l00002ooooo`05o`000?oooooo0000oooo
ool00000:Oooool00;3ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`0Vooooo`00/?ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Go00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`0002Sooooo002`ooooo`?o
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Go00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?oooooo0000ooooool00000:?ooool00;3ooooo3ol00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003oooooo`000?oooooo000002Sooooo002`ooooo`?o00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?oooooo0000ooooool00000:?ooool00;3ooooo0ol00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooool0003oooooo`00000Xooooo`00/Oooool2o`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003oooooo`000?oooooo000002Sooooo002cooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooo`000?ooool2o`0002Oooooo002aooooo`03o`000?oooooo000000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01_l0003oooooooooool0003oooooo`0002Oooooo002aooooo`?o00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?oooooo0000ooooool000009oooool00;;ooooo0_l00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`09o`000?ooooooooooooooool0
003oooooo`000?oooooo000002Oooooo001Kooooo`So0000Coooool2o`0000;ooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool5o`0002Oooooo
001Hooooo`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`03o`0004cooooo0_l0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000
ooooo`?o000000Coooooo`000?oooooo00009oooool005Kooooo0_l000001Ooooooo0000oooooooo
oooo000000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0004[ooooo0_l00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003o`0000;ooooo00Go0000
ooooool0003oooooo`00000Wooooo`00EOooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000004Wooooo0_l00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?l00002ooooo`05o`000?oooooooooo
ooooool000000_ooool3o`0002Kooooo001Cooooo`?o00000_ooool:o`000003ooooool0003ooooo
00?ooooo0ol00018ooooo`;o00000_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`05o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`06o`000?ooooooooooo`000?oooooo00009_ooool005;ooooo00Co0000ooooool0
003ooooo0ol00002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000?ooooo00Co0000
oooooooooooo0000Aoooool2o`0000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000;ooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`00000Vooooo`00DOooool2
o`000005ooooool0003o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooooooool0003ooooo0ol00003ooooo`;o0000A_ooool2o`0000;ooooo00Co0000oooooooo
oooo00000_ooool9o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool00000
9_ooool0057ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool0
0000AOooool:o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooool0003oooooo`00000Vooooo`00D?ooool4o`0000;ooooo2ol000000ooooooo0000ooooo`03
ooooo`Co00000oooool00ol0003oooooooooo`12ooooo`;o00000_ooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
00009_ooool0053ooooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03o`0000?ooooo00Co0000oooooooooooo00000oooool2o`00
04?ooooo0_l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l0000Vooooo`00Coooool2
o`000003ooooool0003o000000;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooool000000_l00003ooooo`;o00000_ooool2o`0004Cooooo0_l000000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo0ol0000Uooooo`00Coooool2o`000005ooooool0003oooooooooool0
00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01_l0
003ooooooooooooooooo0000ooooo`;o00000_ooool00ol0003oooooooooo`11ooooo`;o00000_oo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooo000002Gooooo001>ooooo`;o000000Goooooo`000?l0
003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`Co00000oooool01?l0003oooooooooool00013ooooo`;o00000_ooool01?l0003ooooooooo
ool00004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000002Gooooo001>ooooo`Co00000_ooool00ol0003oooooo`00000;o`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o000000?oooooo`000?l00000@_ooool2o`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00009Oooool004gooooo00Co0000ooooool0003ooooo1Ol00002ooooo`05
o`000?ooooooooooooooool000000oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo0_l0
0002ooooo`?o000000?oooooo`000?ooool0@Oooool01Ol0003oooooo`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002
ooooo`;o00009Oooool004gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000ooooool0003o0000
0_ooool00ol0003oooooo`000012ooooo`05o`000?oooooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003o
oooo00?o00009Oooool004cooooo1Ol00002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Cooooo0ol000000ooooooo0000ooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo0000@_ooool01Ol0003oooooo`000?oooooo000000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_l00000
0ooooooo0000o`00000Uooooo`00C?ooool01?l0003oooooo`000?l00003ooooo`[o00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000oooool2o`000004ooooool0003o
0000o`0004;ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`Co000000Coooooo`000?oooooooooo0ol0000Tooooo`00C?ooool2o`00
0003ooooool0003ooooo00?o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo1?l00002
ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000ooooo`02o`000003ooooool0
003o000004?ooooo0_l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
1?l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000009?ooool004cooooo
1Ol000001Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000002o`0000Cooooo0_l000001_oooooo0000oooooooooooo0000ooooo`;o0000@oooool0
1Ol0003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?l00002ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool2o`0002Cooooo001;ooooo`;o000000Goooooo`000?oooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000o`0004?ooooo
00Go0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool:o`00
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`0002Cooooo001;ooooo`Co00000_ooool01?l0003o003oo`00ool00004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool3o`000005ooooool0003oooooooooool00000
0oooool01?l0003oooooo`000?l00013ooooo`oo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo0_l0000Tooooo`00Boooool00ol0003oooooo`000002ooooo`04
o`000?ooooooo`2do`00o`_o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00000
0ooooooo0000ooooo`03o`0004?ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo0_l0000Tooooo`00B_ooool2o`000003ooooool0003o000000;o000000Coo`3^ool0>Ooo0;Co
00001?ooool01_l0003ooooooooooooooooo0000ooooo`;o000000?oooooo`000?ooool00_ooool2
o`0000;ooooo0_l000000ooooooo0000ooooo`03o`0004?ooooo00Go0000ooooool0003oooooo`00
0003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`00
00;ooooo0ol0000Sooooo`00B_ooool01?l0003oooooo`000?l00002ooooo`04o`000?oo0>koo`0i
ool0]0Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Co
0000ooooool0003o00000_ooool00ol0003oooooooooo`03o`0004Gooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000002?ooooo0019ooooo`Co00000_ooool01_l0003oo`3^oooooooo
03Wo0000ool0]0?ooooo00Go0000ooooooooooooooooo`000004ooooo`?o000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`02o`000003ooooool0003o000004Gooooo00Go0000ooooool0
003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Ko0000oooooooooooo0000ooooool0000Sooooo`00BOooool3o`0000?ooooo
00Koo`3^o`000?l0003oo`0io`000?oo0;@5o`000003ooooool0003ooooo00Cooooo00?o0000oooo
ooooool00_l00003ooooo`;o000000Coooooo`000?l0003ooooo0_l00015ooooo`05o`000?oooooo
0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooooooo`;o00008oooool004Wooooo00Co0000ooooool0
003ooooo0_l000001?oo0>kooooooooooooo03T2ooooo`03ool0]?oooooo000000;ooooo0ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00002ooooo`?o0000AOoo
ool01Ol0003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0002?ooooo0018ooooo`Go
000000?oooooool0k_ooool00_ooool01Ooo03Wooooooooooooo0;Co000000Cooooo00Ko0000oooo
ool0003o0000ooooool00004ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`?o0000
AOooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0_l0000Soooo
o`00B?ooool00ol0003oooooo`000002ooooo`06ool0k_ooooooooooooooool0003oo`0i0oooool0
0ooo0;Coooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003ooooooooo
o`02o`0000;ooooo00?o0000ooooooooool00_l00016ooooo`?o00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
ooooool0003ooooo00?o00008oooool004Oooooo1?l00002ooooo`06ool0k_ooooooooooooooool0
003oo`0i0_ooool00ol0003oo`2dooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000002o`0004Kooooo0ol00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooo
oooooooo0000ooooo`?o000000Coooooo`000?l0003o00008_ooool004Oooooo0ol00002ooooo`03
ool0k_oooooooooo00?o000000Koo`0io`000?l0003o0000ool0]?oo07<2ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_l00004ooooo`;o000000?oooooo`000?l000000_l00018
ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000ol000001?oooooo0000ooooooooool3o`0002;ooooo0016ooooo`;o000000Co
ooooo`000?ooooooo`3^0ol00002ooooo`07o`000?oo03Woooooooooool0003oooooool0]004o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`08o`000?oooooo0000o`000?oooooo0000
ooooool00018ooooo`05o`000?oooooo0000ooooool000000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Co00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000002;ooooo0016
ooooo`Go000000?oo`3^o`000?ooool00_ooool01Ol0003oooooool0>Ooooooo000000;ooooo00Go
o`2doooooooooooo0000ooooo`03o`0000Cooooo0_l00002ooooo`08o`000?ooooooooooo`000?oo
oooo0000ooooool00018ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o00008_ooool004Gooooo
0_l000001Ooooooo0000oooooooo0>ko000000Cooooo00Go0000oooooooo03Woooooo`000003oooo
o`03ool0]?l0003ooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00003
ooooo`05o`000?oooooo0000ooooool00000B?ooool3o`0000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go00000_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03o`00027o
oooo0015ooooo`Co000000?oo`3^ooooool000001?ooool01?l0003oooooool0>Ol00004ooooo`03
ool0]?l0003ooooo00?ooooo0ol000000ooooooo0000ooooo`02ooooo`06o`000?oooooooooooooo
ool0003ooooo0_l00019oooooaCo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`?o00008Ooo
ool004Cooooo1?l000001?oo0>koooooooooool00003ooooo`03o`000?oooooo000000Co00000_oo
ool00ooo0;Coooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`000006oooo
ool0003oooooo`000?oooooo0000BOooool3o`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`03o`00027ooooo0014ooooo`;o000000Goooooo`000?oo0>koooooo`000002ooooo`Co00000_oo
ool00ol0003oooooooooo`03o`000005ool0]?ooooooooooooooool000001?ooool01?l0003ooooo
ooooooooool2o`000006ooooool0003oooooo`000?oooooo0000BOooool3o`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02o`0002;ooooo0013ooooo`Co000000?oo`3^o`000?l000000ol0
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ool0]?l000000_l00005ooooo`;o0000
00Goooooo`000?ooooooooooo`000002ooooo`03o`000?oooooo000004[ooooo0_l00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00008oooool004?ooooo0_l000000ooooooo0000o`000002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?ooooooo`2d00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool0
0ol0001:ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003oooooooooool0003o
oooo00;o00008?ooool004;ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooool0]?ooool00ol0
0002ooooo`05o`000?ooooooooooooooool000000_ooool2o`000003ooooool0003o000004_ooooo
0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0ol0000Pooooo`00@_ooool4o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooo`2do`000003ooooo`;o00001?ooool2o`000003ooooool0003o000000;o0000C?oo
ool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`03o`00023ooooo0011ooooo`05o`00
0?oooooo0000ooooool000000_ooool00ol0003oooooooooo`09o`0000;ooooo00Ko0000oooooooo
ooooooooool0]?l00004ooooo`06o`000?ooooooooooooooool0003ooooo0_l00002ooooo`?o0000
Boooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool3o`00023ooooo0011ooooo`?o000000?oooooo`00
0?ooool01?l00002ooooo`05o`000?ooooooooooooooool000000_ooool4o`0000?ooooo00?oo`2d
ooooooooool00_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool3o`0004_ooooo0ol0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooool000000ol0000Pooooo`00@Oooool2o`000006ooooool0003o0000o`00
0?oooooo00000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000000_l0
00001Ooo0;Cooooooooooooooooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo00;o0000
C?ooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooo
ooooool0003oo`2d0ol000001?oooooo0000o`000?l0000Pooooo`00@?ooool3o`000005ooooool0
003oooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooool0]002ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000002o`0004gooooo0_l00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000003o`000004ool0]?l0003oooooooooo`;o000000?oooooo`000?ooool0
7_ooool0043ooooo1Ol00002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l000001?oo0;Coooooooooool00003ooooo`;o
00000_ooool5o`0004gooooo0ol00002ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?l00002ooooo`04o`000?ooooooo`2do`0000;ooooo00Co0000ooooool0003o00007oooool0
043ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo0;@00_l00004
ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`02o`0004gooooo0ol00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00Go00000_ooool02?l0003ooooooooooooooooo0000oooooooo0;Co00000oooool3o`0001oooooo
000oooooo`;o00000_ooool01Ol0003oooooooooool0003ooooo00[o000000?oooooool0>Ol00000
1?ooool01?l0003oooooooooooooool2o`00o`Cooooo00So0000ooooool0003o0000ooooool0003o
ooooo`0004kooooo0ol00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool2o`00o`;ooooo0ol0000Oooooo`00?oooool2o`0000;ooooo00?o0000ooooool0
00000_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ol00002ooooo`04
o`000?oooooooooooolh00;o003o0_l000000ooooooo0000ooooo`02ooooo`05o`000?oooooo0000
ooooool00000C_ooool7o`000004ooooool0003oooooooooo`Wo00000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oocP0o`00
ool00?l2ooooo`?o00007oooool003kooooo0_l00002ooooo`?o000000Goooooo`000?oooooooooo
o`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ol00002oolh0003oooo
ool0a_ooH_l000;ooooo0_l00003ooooo`04o`000?oooooo0000o`0004oooooo0ol00002ooooo`03
o`000?oooooo000000?o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;oocP000?oooooo`36
ool000000_ooool3o`0001oooooo000nooooo`;o000000?oooooo`000?l000000_ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`;oocP00_l000000ooooooo0<Koof;o0003ooooo`08o`000?ooooooooooo`000?oooooo0000oooo
ool0001@ooooo`;o00000_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00So0000oolh
0?oo>03oooooo`000?oooooo0<Koof;o00;ooooo0_l0000Pooooo`00?Oooool00ooo0>ko0000o`00
0002o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?ooooooocP000;oocP000So0000ooooooooooooooooo`36ool0003oooooof;o00;ooooo0_l00000
1_oooooo0000ooooool0003oooooo`00057ooooo0_l000001Ooooooo0000oooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo0_oo>003ooooo`04o`000?oooooo0<Koof;o00;ooooo00Co0000oooooooooooo0000
7_ooool003gooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo2Ol00002ooooo`03o`00
0?ooooooocP000?ooooo01;o0000ooooooooooooooooo`36ool0003oooooof;o0?oooooo0000oooo
ool0003oooooo`000?oooooo0000ooooool0001@ooooo`?o00000_ooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`06o`00
0?ooooooocP0oolh0?oooooo00000oooool02?l0003o0<Koooooool0003oH_l0ooooool0003ooooo
0_l0000Nooooo`00??ooool01Ooo0>ko0000o`000?oooooo000000?ooooo0ol000000ooooooo0000
ooooo`03ooooo`03o`000?oooooooooo00Co00001?ooool01Ol0003ooooooooooooooooo0<Ko00;o
000000?oooooof;o0?l000000_ooool00ol0003oooooooooo`03o`00053ooooo0ol00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool02Ol0003ooooooooooooooooo0000o`36oooooooo
0000of;o0002ooooo`?o00007_ooool003_ooooo00?oo`3^o`000?l000000_ooool5o`0000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`06o`000?oooooo0000o`000?oo
oooo00001?ooool01_l0a_ooooooooooool0003oH_l0o`0000;ooooo00?o0000ooooool000000_l0
001Booooo`;o00000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooo
ooooooooo`000?l0a_l2ooooo`03o`000?mRo`3ooooo00?o00007_ooool003[ooooo00Goo`3^oooo
ool0003o0000ooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0<Koooooooooool00_l0
00001OmRo`3oooooooooool0003ooooo00?o0000D_ooool01Ol0003oooooo`000?oooooo000000;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Ko0<Kooooo
oooooooo0000of;o0?ooool3o`0001kooooo000jooooo`03ool0k_l0003o000000?o00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`?o00000_ooool02Ol0a_oooooooooooooooooo0000of;o0?oooooo
0000ooooo`04o`0005;ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06o`36ooooooooooooo`000?ooooooH_l0
0ol0000Nooooo`00>Oooool01_oo0>koooooo`000?l0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01_l0003ooooooooooooooooo0000o`36o`Cooooo0_l000001_mRo`3o0000ooooool0
003oooooo`0005?ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01_l0003ooooooooooooooooo0<Koooooo`?o000000CoH_l0o`000?l0003o0000
7_ooool003Sooooo00Coo`3^ooooool0003o00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool03Ol0003ooooooooooooooooo0000ooooool0003oH_l0o`00
0?oooooo0000ooooool00000Doooool01Ooo0>ko0000o`000?oooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`36o`;o000000Soooooo`000?oooooooooo
of;o0?l0003oooooo`0001gooooo000hooooo`06ool0k_oooooo0000o`000?oooooo00000oooool0
0ol0003oooooooooo`0:o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000005;ooooo00Co
o`3^ooooool0003o00000_ooool01?l0003oooooooooool00002ooooo`03oolh0?oooooo000000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo0ol000001Ol0a_oo0000oooooooooooo000000;ooooo00Co0000ooooool0003o00007Oooool0
03Oooooo00Coo`3^oooooooooooo00000_ooool00ol0003oooooooooo`04o`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04o`0000Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_l0001Booooo`08ool0k_oo
ooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ol00002
ooooo`05o`36ool0003oooooooooool000000oooool3o`0001gooooo000fooooo`03ool0k_oooooo
oooo00;o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01_l0003oooooo`000?l0003oooooo`0000Cooooo
00?o0000ooooooooool00_l00003ooooo`;o000000?oooooo`000?l00000DOooool01?oo0>kooooo
ooooooooool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00[o00000_ooool01Ol0003oooooooooool0a_oo000000?ooooo00?o0000
ooooooooool00ol0000Mooooo`00=Oooool01?oo0>koooooooooooooool2o`000003ooooool0003o
000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`?o000000?oooooo`000?ooool0D?ooool01_oo0>kooooooooooooooooo0000ooooo`Go
000000?oooooo`000?ooool02Ol00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01_l0003oooooooooool0a_ooooooo`0000;ooooo00?o0000ooooooooool00ol0000M
ooooo`00=Oooool01?oo0>koooooooooooooool4o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool3o`0000;ooooo00Co
0000oooooooooooooooo0_l00002ooooo`05o`000?oooooo0000ooooool00000D?ooool00ooo0>ko
ooooooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1_l0003oooooooooool0a_ooooooo`0000;ooooo00?o0000ooooooooool00ol0000Mooooo`00=?oo
ool01?oo0>koooooooooooooool4o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool2o`0000?ooooo00?o0000ooooooooool00_l00002ooooo`?o0000Coooool01?oo0>ko
ooooooooooooool2oolh0005o`000?oooooo0000ooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000o`36ooooooooooooo`000002ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?ooool06oooool003?ooooo00?oo`3^ooooooooool00_oo>002o`000003ooooool0
003ooooo00;ooooo00?o0000ooooool000002_l00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`03o`00
0?mRo`3ooooo04kooooo00?oo`3^ooooooooool00_oo>003ooooo`;o000000?oooooo`000?ooool0
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000o`36ooooooooooooo`000002oooo
o`05o`000?ooooooooooo`000?ooool00_l0000Looooo`00<Oooool2o`00o`04ool0k_oo>03oocP0
ooooo`?o000000?oooooo`000?ooool01?l00002ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`06o`000?oo
ooooooooooooool0003ooooo0ol000000omRo`3oooooooooo`1;ooooo`;o003o0_oo>005ooooo`05
o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
o`36ooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool00_l0000Looooo`00<Ooo
ool00ol00?ooocP0oolh0003oico00;o000000Koooooo`000?l0003o0000ooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003oooooo`000?l0003ooooo
o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooo000000;o000000?oH_l0
ooooooooool0Boooool00ol0oooo003ooico0002oico00Cooooo00Go0000ooooool0003oooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o0<Kooooooooooooo000000;o
oooo00Co0000oooooooooooooooo0ol0000Looooo`00<oooool02?l0ooooooooooooool0003ooooo
o`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000ol000000oooooooH_l0ooooo`1<ooooo`04o`3o
ooooooooooooooooo`CoW?l000Go0000ooooool0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000
ooooooooooooooooo`000?l0a_l2ooooo`05o`000?ooooooooooooooool000000_ooool3o`0001co
oooo000dooooo`03o`3ooooooooo000000Co00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`?o0000
0_ooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000ooooool0003oooooo`000002oooo
o`03of;o0?oooooooooo04cooooo00?o0?ooooooooooool01?ooool01Ol0003oooooo`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000o`36o`?ooooo00Co0000oooooooo
oooo00000_ooool3o`000003of;o0?oooooooooo01Wooooo000dooooo`06o`3oool0003oooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000ooo
ool02_l0003oooooooooool0003oooooo`000?oooooo0000ooooool00003ooooo`03of;o0?oooooo
oooo04_ooooo00?o0?ooooooooooool01?ooool01Ol0003oooooo`000?oooooo000000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01_l0003ooooooooooooooooo0<Koo`0000?ooooo00Go0000oooooooooooo0000ooooo`04
o`000003of;o0?oooooooooo01Wooooo000eooooo`;o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l0
0002ooooo`?o00000oooool00omRo`3oooooooooo`1<ooooo`03o`3ooooooooooooo00?ooooo00Go
0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`36ool00003
ooooo`03o`000?oooooo000000;o000000Koooooo`000?l0003oooooo`000?mRo`0Jooooo`00=?oo
ool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool02_l00002ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00Ko0000oooooooooooooooo
o`000?ooool3o`0000;oW?l00oooool00omRo`3oooooooooo`1<ooooo`03o`3ooooooooooooo00?o
oooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`36ool0
003ooooo00Co000000Koooooo`000?ooooooooooo`000?ooool2o`000003of;o0?oooooooooo01So
oooo000dooooo`;o00000_ooool00ol0003oooooooooo`04o`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04o`0000Cooooo00?o0000ooooooooool00_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooool000000_l00002ooooo`?oW?l000?oH_l0o`00
ooooool0COooool00ol0ooooooooooooo`02ooooo`05o`000?oooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`36o`;o00000_ooool01?l0003oooooooooool00002ooooo`07
o`000?oooooo0000o`000?ooooooH_l0o`00o`0Hooooo`00<oooool3o`000003ooooool0003ooooo
00;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Ko0000ooooool0003o0000ooooool00005ooooo`03o`000?oooooooooo00;o00000ooo
ool2o`000004ooooool0003o0000o`0000Gooooo0_l00?m?ooooo`09o`3oooooooooooooooooool0
003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool3o`000003o`36ool0003ooooo00;ooooo00Go
0000ooooooooooooooooo`000002ooooo`?o000000?oW?l0of;o0?l00?l06?ooool003?ooooo0_l0
0002ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000ol00004ooooo`03o`29oooooooooooo04oooooo
00Co0?oooooooooooooooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`08o`0000;ooooo00?o0<Koo`000?ooool00_ooool01Ol0
003ooooooooooooooooo000000;ooooo0ol000000ol0ROooooooooooo`0Hooooo`00<oooool5o`00
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool3o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`04o`000?oo
oooo0000ooooo`;o00001?ooool00ol0ROooooooooooo`1@ooooo`05o`3oooooooooooooo`000?oo
ool04_l00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0a_ooooooo`000004oooo
o`04o`000?ooooooooooo`0000;ooooo0ol000000ol0ROooooooooooo`0Hooooo`00<_ooool3o`00
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3
o`0000?ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo00001?ooool00ol0
ROooooooooooo`1Booooo`07o`3ooooooooo0000ooooool0003oooooo`000003ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool0a_l00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_l0000Looooo`00<_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool00ol0
003oooooo`000004ooooo`03o`29oooooooooooo05?ooooo00Ko0?oooooooooooooo0000ooooool0
0003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool0a_l00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Ko0000ooooool0003o0000ooooool0000Jooooo`00<Oooool3o`000003ooooool0003ooooo
00;ooooo00?o0000ooooooooool02ol00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool2o`0000;ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o0000
0oooool00ol0ROooooooooooo`1Eooooo`03o`3oool0003o000000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003o0<Kooooooooooooo000000?ooooo00So0000ooooooooooooooooo`000?oo
oooo0000ooooo`;o00006_ooool0037ooooo0_l00002ooooo`03o`000?oooooooooo00Co00000_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Co00001?ooool00ol0003ooooo
ooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooo`000?ooool2
o`0000;ooooo00?o08Woooooooooool0Eoooool01Ol0ooooooooo`000?oooooo000000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003o0<Kooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`?o00006_ooool0033ooooo0ol000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`06o`000?oooooo0000o`00
0?oooooo00001Oooool00ol0003oooooooooo`02o`0000?ooooo0_l000001?oooooo0000ooooool0
0003ooooo`03o`29oooooooooooo05Oooooo00Go0?ooooooool0003oooooo`000003ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000o`36ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool3
o`0001[ooooo000`ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000ooooo`;o000000Go
ooooo`000?ooooooooooo`29o`1Jooooo`05o`000?l0oooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`36ooooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo0ol0
000Jooooo`00<?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo00Co0000ooooool0003ooooo0_l00002ooooo`03o`29oooo
oooooooo05Sooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0<Kooooooooooooo
ooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo0ol0000Jooooo`00;oooool3o`00
0003ooooool0003ooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000Cooooo00Wo
0000oooooooooooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo08Woooooo`1Koooo
o`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`36oooooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`Go00006_ooool002oooooo0_l00002ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_l00002ooooo`05o`000?oooooo0000ooooool0ROl0GOooool2o`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0a_oo0000ooooo`02ooooo`06o`000?oooooooooooooo
ool0003ooooo0ol000001Ooooooo0000o`000?oooooo000001Wooooo000^ooooo`?o00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`?o000000?oooooo`29ooooool0G?ooool3o`000005oooo
ool0003oooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Ko0000ooooooooooooooooo`36ool00003ooooo`03o`000?oooooo000000?o00000_ooool0
1?l0003oooooo`000?ooool2o`0001Wooooo000^ooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo2ol00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool3o`000003o`29
oooooooooooo05cooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`07o`000?ooooooooooooooool0a_oo0000ooooo`04
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00006Oooool002gooooo0ol00002
ooooo`03o`000?oooooooooo00Co00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Co00001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00001?oo
ool3o`000003ooooool0003o08Wo05oooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`36o`?o
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ol0000Ioooo
o`00;Oooool01_l0003oooooo`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooool0003o0000oooo
ool00005ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
0003ooooool0003o08Wo05oooooo1?l000001Ooooooo0000oooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05o`000003o`36oooooooo000000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooo000000;o00006Oooool002gooooo0_l00002
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`02
ooooo`;o00000_ooool01_l0003oooooooooool0003oooooo`00063ooooo0ol000000ooooooo0000
o`00000>o`0000;ooooo00Ko0000oooooooooooo0<Koooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0001Wooooo000/ooooo`03o`000?oooooo
000000?o00000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool00ol0003oooooooooo`03o`00067ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`36oooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000ooooool0003o0000oooo
ool0000Hooooo`00;?ooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03o`0000Cooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o
0000H_ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0<Ko0_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o00006?ooool002co
oooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l00002ooooo`?o0000H_ooool3o`00
0006ooooool0003oooooooooool0003o0?oo0_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool0a_l00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o00006?ooool002_ooooo0ol00002oooo
o`04o`000?ooooooooooo`0000;ooooo2_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`?o0000H_oo
ool3o`0000;ooooo00Go0000oooooooooooo0000o`3oo`02ooooo`03o`000?oooooooooo00;ooooo
00Oo0000ooooooooooooooooool0>Ol0003o0<Ko00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool3o`0001Sooooo000[ooooo`;o00000_ooool0
1?l0003oooooooooooooool3o`0000;ooooo00?o0000ooooooooool00oooool01_l0003oooooo`00
0?l0003oooooo`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002ooooo`09
o`000?ooooooooooooooool0003oooooo`000?oooooo000006?ooooo0ol00002ooooo`08o`000?oo
ooooooooo`000?oooooo0?ooooooool00004ooooo`07o`000?oooooooooooooooooo03Wo0000o`36
o`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000;o00006?ooool002[ooooo0ol00002ooooo`03o`000?oooooo000000;o00000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooooooo0_l00004ooooo`?o000000?oooooo`000?ooool0
H_ooool3o`0000;ooooo00So0000oooooooooooo0000ooooool0ooooooooo`0000Cooooo00Oo0000
ooooooooooooooooool0>Ol0003o0<Ko00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000000_l0000Hooooo`00:_ooool01?l0003ooooo
o`000?ooool3o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool01?ooool00ol0003o
ooooooooo`02ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`03o`000?oooooo
oooo06;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0?ooo`000?ooool00ooo
ool01ol0003oooooooooooooooooo`0io`000?l0a_l00oooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooooooo1Ol0000Hooooo`00:_ooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool0
1?l0003oooooo`000?ooool2o`0006Cooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0?ooooooooooool00_ooool01ol0003oooooooooooooooooo`0io`000?l0a_l00oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool2o`000004ooooool0003o
0000o`0001Sooooo000Yooooo`03o`000?oooooo000000?o00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`;o00000_ooool01Ol0003oooooo`000?oo
oooo000006Gooooo0ol000001Ooooooo0000oooooooooooo000000?ooooo00?o0000o`3oooooool0
0_ooool01ol0003oooooooooooooooooo`0io`000?l0a_l01?ooool01Ol0003ooooooooooooooooo
000000?ooooo0ol000001_oooooo0000ooooool0003oooooo`0001Sooooo000Yooooo`?o000000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`?o0000
1?ooool02_l0003oooooooooool0003oooooo`000?oooooo0000ooooool0001Uooooo`?o00000_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooo0?oo00;ooooo00Oo0000oooooooooooooooo
ool0>Ol0a_oo000000Cooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000?ooooo00Go0000
ooooool0003oooooo`00000Hooooo`00:?ooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;o000000?oooooo`000?ooool00_l0001Uooooo`?o00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooo0?oo00;ooooo00Ko0000ooooooooooooo`0io`36ool00004oooo
o`03o`000?oooooo000000?o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol0000G
ooooo`00:?ooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`;o00000oooool02?l0003ooooooooooooooooo0000ooooool0003ooooo
0_l0001Uooooo`Co000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooo0?oo00;o
oooo00So0000ooooooooooooo`0io`36ool0003oooooo`29o`Co00000_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooool000000_l0000Gooooo`009oooool3o`0000;ooooo00Co
0000oooooooooooo00000_ooool=o`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Wo0000ooooooooooooooooo`000?oooooo
0000ooooool00000I_ooool3o`000006ooooool0003o0000o`000?oooooo00000oooool01_l0003o
ooooooooool0ooooooooo`0000;ooooo00Goo`0io`36ool0003o0000o`29o`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o0000
5oooool002Oooooo00Go0000ooooool0003oooooo`000002ooooo`Co00000oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooooooo`Co00001?ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000oooool01_l0003oooooo`000?l0003oooooo`0006Oooooo0_l0
0002ooooo`03o`000?oooooo000000So000000So0?ooo`000?l0003o0000ool0>Ol0a_oo0000o`29
o`?ooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo
0ol0000Gooooo`009_ooool00ol0003oooooo`000002ooooo`?o000000?oooooo`000?ooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooool0003o0000
ooooool00006ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000;ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000001?ooool01_l0oooooooooooooooo03Wo0<Koo`29o`Cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0003oooooo`00
000Gooooo`009_ooool01?l0003oooooo`000?ooool2o`0000;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool2o`0000Gooooo00?o0000ooooooooool00oooool02?l0003ooooooooooooooooo0000ooooool0
003ooooo0_l0001Wooooo`?o000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000o`3ooooooooo0<Koooooool0ROl5ooooo`05o`000?ooooooooooooooool0
00000oooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`00000Gooooo`009Oooool0
0ol0003oooooo`000003o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000
ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooool00000J?oo
ool3o`0000;ooooo00Co0000oooooooooooo00000oooool02ol0003ooooooooooooooooo0000o`3o
oooooooo0<Koo`29oooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0001Oooooo000Uooooo`05o`000?oooooo0000ooooool0
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003o
ooooooooo`02ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooo`00001Xoooo
o`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Ko0000
o`3oool0a_oo003oooooool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo0_l0000Gooooo`009Oooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000ooooool0003o0000J?ooool2o`000004ooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`000004ooooo`06o`000?oooooo0<Koo`00oooooooo00001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`00
0?l0000Gooooo`009?ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000ooooool0003o0000JOooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Ko0000ooooooooooooooooo`000?ooool3o`00
01Kooooo000Tooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`Go00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
000006[ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo1Ol0000Fooooo`008oooool3o`0000;ooooo
00Ko0000ooooooooooooooooo`000?ooool3o`0000Gooooo1_l00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooooooo`;o000000Coooooo`000?oooooo0000J_ooool3o`000003ooooool0003ooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo0ol00000
1?oooooo0000ooooool0000Fooooo`008oooool2o`0000?ooooo00?o0000ooooooooool00ol0000>
ooooo`Co00001?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000ooo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo06Sooooo0ol000000ooooooo0000oooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo00Go0000oooo
ool0003oooooo`00000Fooooo`008oooool2o`0000;ooooo00Co0000ooooool0003o00004oooool0
1_l0003oooooo`000?l0003oooooo`0000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000ooooool0003o0000J_ooool2o`000004ooooool0003ooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03o`0000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00005_ooool002;ooooo0_l00003ooooo`;o00005Oooool01?l0003ooooooooo
ooooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0000;ooooo00Ko0000oooooooooooo
0000ooooool0001[ooooo`Co000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`?o000000?ooooo
o`000?ooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000Fooooo`008_ooool2
o`000003ooooool0003o000001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`00
0?oooooo000006cooooo00?o0000ooooool000000_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o00000oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooool000000_l0000Eooooo`008Oooool4o`0001So
oooo00?o0000ooooooooool01?ooool3o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02o`0000?ooooo00?o0000ooooool00000K?ooool01?l0003oooooo`000?oooolDo`00
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo
0ol0000Eooooo`008Oooool2o`0001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02o`0000Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo0000o`0006co
oooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0003oooooo`00000Eooooo`008?oo
ool2o`0001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0006go
oooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooool0003oooooo`00000Eooooo`008?ooool2
o`0001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00000oooool0
0ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooo0000K_ooool01?l0003oooooo`00
0?l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`0001Gooooo000Oooooo`;o00006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool02ol0003ooooooooooooo
oooo0000ooooool0003oooooo`000?oooooo000006kooooo00Go0000ooooool0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0001Gooooo000Oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1?ooool8o`000003ooooool0003o000000Cooooo00Go0000oooooooooooo0000ooooo`02o`0006ko
oooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_l0000Dooooo`00>oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000Koooool01Ol0003ooooo
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Ko0000
ooooooooooooooooo`000?ooool3o`0001Cooooo000jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000oooool01_l0003ooooooooo
ool0003oooooo`0006oooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000004ooooo`04o`000?ooooooooooooooo`Go00005?ooool003[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000003o`00073ooooo0_l000000ooooooo0000oooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000oooo
o`?o000000Coooooo`000?oooooo00005?ooool003[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`Co0000L?ooool01?l0003oooooo`000?l00003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000001Cooooo000ioooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?o00000_ooool3o`00077ooooo00Go0000ooooool0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`02o`0001Cooooo000iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool01_l0003ooooooooooooooooo0000ooooo`;o000000?oooooo`000?l000000_ooool3o`00077o
oooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_l00003oooo
o`05o`000?ooooooooooooooool000000_ooool3o`0001?ooooo000iooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04o`0000;ooooo00Ko0000oooo
ool0003oooooo`000?ooool2o`00077ooooo00?o0000ooooool000000_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co0000
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool000000_l0000Cooooo`00
>Oooool00ol0003oooooooooo`04ooooo`So00000_ooool02ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000?oooooo000007;ooooo00Co0000ooooool0003ooooo1ol000000ooooooo0000
ooooo`0:o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?oooooooooooooo
ool0003ooooo0ol0000Cooooo`00>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00000
0ooooooo0000ooooo`1aooooo`05o`000?oooooo0000ooooool000000oooool00ol0003ooooooooo
o`03o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001?ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`00000C
ooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l000000ooooooo0000ooooo`1c
ooooo`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?oooooo0000ooooool000004oooool003Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000002ooooo`;o000000?oooooo`000?ooool0Loooool01?l0003o
ooooo`000?l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0001?ooooo000hooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Go0000
00?oooooo`000?ooool0Loooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool2o`0001?ooooo000g
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;o00000_ooool2o`000003ooooool0003ooooo07?ooooo00Go0000
ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00Co0000ooooool0003o00004oooool003Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_l00002ooooo`04o`000?ooooooooooo`0007Gooooo00Go0000ooooool0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Co0000ooooool0003o00004oooool003Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0ol000001_oooooo0000oooooooooooo0000oooo
o`;o0000MOooool01Ol0003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooooooo1Ol0000Booooo`00=_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?l00003ooooo`05o`00
0?ooooooooooo`000?ooool00_l0001fooooo`;o000000?oooooo`000?ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000Cooooo
o`000?oooooo00004_ooool003Kooooo00?o0000ooooooooool01?ooool8o`0000?ooooo00Co0000
oooooooooooo00000oooool4o`0007Kooooo00Co0000ooooool0003o00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000oooool3o`000006ooooool0003oooooo`000?oooooo00004_oo
ool003Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo0000ooooool00000
M_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo
0000ooooo`?o00000oooool00ol0003oooooooooo`02o`0001;ooooo000eooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000_ooool4o`0007Oooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000000ol00002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0001;o
oooo000eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooo`000?l0001goooo
o`03o`000?oooooo000000;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04o`0000;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?oooooo0000o`0001;ooooo000eooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooool0003o
oooo0ol000000ooooooo0000o`00001gooooo`04o`000?oooooo0000ooooo`?o000000?oooooo`00
0?ooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo1Ol00002ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o00004Ooo
ool003Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo07Oooooo00?o0000ooooool000000_ooool<o`0000;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Wo0000ooooooooooooooooo`000?oooooo0000
ooooool000004Oooool003Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?oooooo0000
o`0007Wooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0003oooooo`00000Aooooo`00
=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00Co0000ooooool0003o0000NOooool0
1Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`;o00004Oooool003?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo07Sooooo00Go0000ooooool0003oooooo`000002
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`00017ooooo000cooooo`03o`000?oooooooooo00Cooooo2?l00003ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooo`00001kooooo`05o`000?oooooo0000oooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`04o`000?oooooo0000o`00017ooooo000cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00001looooo`05o`000?oooooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000;o00004?ooool003;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000O_ooool2
o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooooooo1Ol0000@ooooo`00<_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool0OOooool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`000004ooooool0003oooooo`00013ooooo000iooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`?o0000
P?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000?ooooo0ol0
00001_oooooo0000ooooool0003oooooo`00013ooooo000hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0008;ooooo00Go0000ooooool0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000?ooooo
00?o0000ooooooooool00_l0000@ooooo`00>?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_l00023ooooo`?o00000_ooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000?o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000@oooo
o`00>?ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooooooool0003ooooo0_l00025
ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000002ooooo`Co00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00ol0000?ooooo`00=oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`?o0000Qoooool01?l0003oooooo`000?ooool3o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000oo
oooo000gooooo`Co00000_ooool01?l0003oooooo`000?l0002;ooooo`;o00000_ooool00ol0003o
ooooo`00000;o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000?ooooo`00>oooool4o`00
08gooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooool0003oooooo`00000?ooooo`00c?ooool01Ol0003o
ooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00003oooool00<cooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo0_l0000?ooooo`00c?ooool00ol0003oooooo`000002ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000oo
oooo003<ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00003_ooool00<gooooo0_l00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Ko
00003_ooool00<gooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool0000>ooooo`00
cOooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000?ooooo1?l0
0002ooooo`03o`000?oooooo000000kooooo003=ooooo`?o00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooooooool0003ooooo0ol00002ooooo`04o`000?oooooooooooooo
o`;o00003_ooool00<gooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
000000?o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000>ooooo`00coooool4
o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
0_ooool4o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
00003Oooool00<oooooo00?o0000ooooooooool01_l000000ooooooo0000ooooo`03ooooo`03o`00
0?oooooo000000Co00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00000_ooool3o`0000gooooo003>ooooo`;o00000_ooool01?l0003oooooooooool00002oooo
o`So00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000gooooo003>ooooo`05o`000?oooooo
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002oooo
o`06o`000?ooooooooooo`000?oooooo00003Oooool00<kooooo00?o0000ooooool000000_ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0005ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`;o
00003Oooool00<kooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000=
ooooo`00coooool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`?o00003?ooool00<oooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooo`000?ooool01?l0
000<ooooo`00coooool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_l000001?oooooo0000ooooool0000<ooooo`00coooool3o`000005
ooooool0003oooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Co00000_oo
ool00ol0003oooooo`00000<ooooo`00coooool3o`0000;ooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00002ooooo`06o`000?ooooooooooo`000?oooooo00003?ooool00<oo
oooo0ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00000
1Ooooooo0000oooooooooooo000000;ooooo00?o0000ooooool000003?ooool00=3ooooo0ol00000
1Ooooooo0000oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooool000000_l00003ooooo`08o`000?ooooooooooooooool0
003oooooo`000?ooool2o`0000_ooooo003@ooooo`;o000000Koooooo`000?l0003o0000ooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`Co0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ol0000;ooooo`00
d?ooool2o`0000;ooooo00?o0000ooooool000000ol000000ooooooo0000ooooo`03ooooo`03o`00
0?oooooo000000Co00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`00000;ooooo`00d?ooool2o`0000;ooooo00Co0000oooooooo
oooo00000_ooool8o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000;ooooo`00d?ooool3
o`000005ooooool0003oooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01_l0003oooooooooool0003oooooo`0000_ooooo003@ooooo`?o00000_ooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooo000000_ooooo003Aooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000000oooool01_l0003ooooooooooooooooo0000ooooo`;o00003?ooool00=7ooooo0_l00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`07o`000?oooooooooooooo
ool0003oooooo`00000=ooooo`00dOooool2o`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool00_l0000>ooooo`00dOooool2o`0000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00003oooool0
0=;ooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ooooool3o`00013ooooo003Booooo`;o00000_ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0001;ooooo003Cooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooooooooooo
ool3o`0001Cooooo003Cooooo`;o000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo000000;o0000
5_ooool00=Gooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000002ooooo`Co00006Oooool00=Sooooo4Ol0000Mooooo`00ioooool0
0ol0003oooooooooo`0Looooo`00ioooool00ol0003oooooooooo`0Looooo`00ioooool00ol0003o
ooooooooo`0Looooo`00ioooool00ol0003oooooooooo`0Looooo`00j?ooool00ol0003ooooooooo
o`0Kooooo`00j?ooool00ol0003oooooooooo`0Kooooo`00j?ooool00ol0003oooooooooo`0Koooo
o`00j?ooool00ol0003oooooooooo`0Kooooo`00j?ooool00ol0003oooooooooo`0Kooooo`00j?oo
ool00ol0003oooooooooo`0Kooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00
ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00
ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00
ooooool7ooooo`00ooooool7ooooo`00ooooool7ooooo`00\
\>"],
  ImageRangeCache->{{{198.562, 460.375}, {492.875, 153.375}} -> {-1.6427, \
1.1649, 0.0080211, 0.0080211}, {{204.75, 323.5}, {484.688, 161.5}} -> \
{-0.288432, 0.417881, 0.00287821, 0.00287821}, {{335.375, 454.125}, {484.688, \
161.5}} -> {-0.666252, 0.418728, 0.00288405, 0.00288405}}]
}, Open  ]],

Cell["\<\
It is interesting to note that from this double regular tetrahedron \
construction one may obtain twelve real cylinders of a certain radius that \
intersect four particular points. Such an example was first presented in \
[26]; here we show how it arises naturally from our construction above. We \
begin with a regular tetrahedron and this time glue four others onto it, one \
on each face. The vertices of the original tetrahedron will be our four \
points. Clearly from one of the glued on tetrahedra we get the six cylinders \
from above, each intersecting those four points and all having the same \
radius. Indeed, each glued tetrahedron gives rise to six cylinders, but they \
pair off so that the actual total is twelve. We remark that computational \
techniques essentially identical to those we have shown can also be used to \
solve for cylinder parameters for this problem. A different approach, using \
homotopy continuation methods as described e.g. in [30], was employed in \
chapter 4 of [15]. A generalization of finding a the cylinder of given radius \
through four points has been studied by [19].\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Real cylinders: probabilities and configurations", "Section"],

Cell[CellGroupData[{

Cell["Enumerating real cylinders", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell["\<\
We now investigate cases in which a configuration of five points \
will give rise to the various possible numbers of real cylinders containing \
it. First we note one obvious situation for which there can be no real \
cylinders: if one point is inside the convex hull of the other four then no \
cylinder can contain all five, because right circular cylinders are convex. \
It would be interesting to know how frequently this arises. To this end we \
employ a simple simulation. More than 4000 random examples were run to get \
some idea of how frequently one gets zero, two, four, or six real cylinders, \
given a certain random distribution for the configuration parameters.\
\>", \
"Text"],

Cell[BoxData[{
    \(Clear[a, b, c, d, rsq]; \), "\n", 
    \(vec = {1, a, c}; offset = {0, b, d}; \), "\n", 
    \(pair = NullSpace[{vec}]; \), "\n", 
    \({w1, w2} = GramSchmidt[pair]; \), "\n", 
    \(vars = {a, b, c, d, rsqr}; \)}], "Input"],

Cell[BoxData[{
    \(SeedRandom[1111]; \), "\n", 
    \(len = 2\^12; \), "\n", 
    \(intpoints = 
      Table[Table[
          Random[Integer, {\(-100\), 100}], {5}, {3}], {len}]; \)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      rvals = Table[
          perps = Table[
              perp[intpoints[\([\)\(j, k\)\(]\)], vec, offset], {k, 
                5}]; \[IndentingNewLine]exprs = 
            Map[Numerator[Together[# . # - rsqr]] &, 
              perps]; \[IndentingNewLine]solns = 
            NSolve[exprs, {a, b, c, d, rsqr}]; \[IndentingNewLine]rs = 
            N[rsqr /. solns]; \[IndentingNewLine]{j, Cases[rs, _Real]}, {j, 
            len}]; ]\)], "Input"],

Cell[BoxData[
    \({1113.48`\ Second, Null}\)], "Output",
  CellLabel->"Out[99]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(rvals2 = 
      Sort[rvals, 
        Length[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] \[LessEqual] 
            Length[#2\[LeftDoubleBracket]2\[RightDoubleBracket]] &]; \), "\n\
", 
    \(lens = \((Length[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] &)\) /@ 
        rvals2; \), "\n", 
    \(lenlens = Length /@ Split[lens]\)}], "Input"],

Cell[BoxData[
    \({931, 2206, 865, 94}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Roughly ",
  Cell[BoxData[
      \(23\)]],
  "% of the cases give no real cylinders. It is natural to ask whether these \
are all cases in which one point is enclosed by the other four. This turns \
out not to be so. We first discuss the frequency of random examples for which \
one point is enclosed by the hull of the other four. Later we will see an \
open set in the configuration space for which no point lies inside the hull \
of the rest, and for which there are no real cylinders through all points."
}], "Text"],

Cell["\<\
Below is a simulation of the one\[Hyphen]enclosed\[Hyphen]by\
\[Hyphen]four situation. The code below will generate random configurations \
and then check to see in how many cases one point lies within the convex hull \
of the rest.\
\>", "Text"],

Cell[BoxData[{
    \(plane[p1_, p2_, p3_]\  := \ 
      With[{norm = Cross[p1 - p2, p1 - p3]}, \[IndentingNewLine]{norm, 
          norm . p1}]\), "\n", 
    \(sameside[{p1_, p2_, p3_}, p4_, p5_]\  := \ 
      Module[{norm, d}, \[IndentingNewLine]{norm, d}\  = \ 
          plane[p1, p2, 
            p3]; \[IndentingNewLine]\((norm . p4 - d)\)*\((norm . p5 - 
                d)\)\  > \ 0]\), "\n", 
    \(encloses[pnts : {p1_, p2_, p3_, p4_}, p5_]\  := 
      Module[{combos, j}, \[IndentingNewLine]combos\  = \ 
          Table[{Drop[pnts, {j}], pnts[\([\)\(j\)\(]\)]}, \ {j, 
              Length[pnts]}]; \[IndentingNewLine]Apply[And, 
          Map[sameside[#[\([\)\(1\)\(]\)], #[\([\)\(2\)\(]\)], p5] &, \ 
            combos]]]\), "\n", 
    \(anyenclosed[pnts : {p1_, p2_, p3_, p4_, p5_}]\  := \ 
      Module[{combos, j}, \[IndentingNewLine]combos\  = \ 
          Table[{Drop[pnts, {j}], pnts[\([\)\(j\)\(]\)]}, \ {j, 
              Length[pnts]}]; \[IndentingNewLine]Apply[Or, 
          Map[encloses[#[\([\)\(1\)\(]\)], #[\([\)\(2\)\(]\)]] &, \ 
            combos]]]\)}], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[{
    \(SeedRandom[1111]; \), "\n", 
    \(len = 2\^14; \), "\n", 
    \(realpoints = 
      Table[Table[
          Random[Real, {\(-100\), 100}], {5}, {3}], {len}]; \)}], "Input",
  CellLabel->"In[125]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      enclosedlist = 
        Transpose[{Range[len], Map[anyenclosed, realpoints]}]; ]\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \({140.66000000000003`\ Second, Null}\)], "Output",
  CellLabel->"Out[128]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(hasenclosed\  = \ 
      Cases[enclosedlist, \ {_, True}]; \), "\[IndentingNewLine]", 
    \(numenclosed\  = \ Length[hasenclosed]\), "\[IndentingNewLine]", 
    \(N[numenclosed/len]\)}], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(1147\)], "Output",
  CellLabel->"Out[130]="],

Cell[BoxData[
    \(0.07000732421875`\)], "Output",
  CellLabel->"Out[131]="]
}, Open  ]],

Cell["\<\
In this simulation run between six and seven per cent of the \
examples had one point enclosed by the hull of the other four. Thus, for the \
no\[Hyphen]real\[Hyphen]cylinder examples, we surmise that roughly three out \
of four cases do not arise in this way. We will return to this when we \
discuss enumerative geometry aspects of this cylinder problem.\
\>", "Text"],

Cell[TextData[{
  "The frequency of one point being enclosed by the others is related to some \
old problems in integral geometry. One way to pose this is as a three \
dimensional version of Sylvester's problem [11]: What is the probability that \
five points chosen at random in a unit cube all lie on the convex hull they \
define? Another variant is to find the expected volume of a random \
tetrahedron in the unit cube (several other variations are posed in the \
reference). We will call this expected volume ",
  Cell[BoxData[
      \(vTet\)],
    FontSlant->"Italic"],
  ". To see how these problems are related, we order the five random points, \
then ask what is the probability that the first is enclosed by the others. \
This is exactly that expected volume. Now observe that the expected \
likelihood that any one point is enclosed by the other four is ",
  Cell[BoxData[
      RowBox[{"5", " ", 
        StyleBox["vTet",
          FontSlant->"Italic"]}]]],
  ", as these are each pairwise exclusive events. Indeed, by taking the \
average of the five cases of one\[Hyphen]point\[Hyphen]enclosed\[Hyphen]by\
\[Hyphen]the\[Hyphen]rest one obtains a Monte Carlo simulation of ",
  Cell[BoxData[
      StyleBox["vTet",
        FontSlant->"Italic"]]],
  ": it appears to be in the ballpark of ",
  Cell[BoxData[
      \(1\/70\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Taking this another step we might refine the estimate with a low precision \
quadrature. The option settings used below were obtained by trial and error, \
and the nondefault ",
  Cell[BoxData[
      \(MaxPoints\)],
    FontWeight->"Bold"],
  " setting causes ",
  Cell[BoxData[
      \(NIntegrate\)],
    FontWeight->"Bold"],
  " to do a quasi\[Hyphen]Monte Carlo evaluation. The result is clearly in \
accord with that above."
}], "Text"],

Cell[BoxData[
    \(vol[p1_, p2_, p3_, p4_]\  := \ 
      Abs[\((p2 - p1)\) . Cross[p3 - p1, p4 - p1]]/6\)], "Input",
  CellLabel->"In[241]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[
      Evaluate[vol[{x1, y1, z1}, {x2, y2, z2}, {x3, y3, z3}, {x4, y4, 
            z4}]], \[IndentingNewLine]\ {x1, 0, 1}, {y1, 0, 1}, {z1, 0, 
        1}, \ {x2, 0, 1}, {y2, 0, 1}, {z2, 0, 1}, \[IndentingNewLine]\ {x3, 
        0, 1}, {y3, 0, 1}, {z3, 0, 1}, \ {x4, 0, 1}, {y4, 0, 1}, {z4, 0, 
        1}, \[IndentingNewLine]\ PrecisionGoal \[Rule] 2, \ 
      AccuracyGoal \[Rule] 6, \ MaxPoints \[Rule] 1000000]\)], "Input",
  CellLabel->"In[242]:="],

Cell[BoxData[
    \(0.013642896025737287`\)], "Output",
  CellLabel->"Out[242]="]
}, Open  ]],

Cell[TextData[{
  "The problem of finding the expected volume of a tetrahedron with vertices \
independently and uniformly distributed inside a cube was recently solved \
[34] using an elaborate breakdown of the region and many multivariate \
integral computations. The actual value is ",
  Cell[BoxData[
      \(3977\/216000 - \[Pi]\^2\/2160\)]],
  ", or approximately ",
  Cell[BoxData[
      \(TraditionalForm\` .013843\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Configurations that give six real cylinders", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell[TextData[{
  "We previously obtained six real cylinders above by starting with a regular \
tetrahedron and gluing a copy of itself to one face to obtain five points. If \
the common face is in the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          StyleBox["x",
            FontSlant->"Italic"], "\[Hyphen]", 
          StyleBox["y",
            FontSlant->"Italic"]}]]]],
  " plane (so that one tetrahedron points up, the other down), then three \
cylinders intersect the three faces of the upper tetrahedron (and cut through \
the edges of the lower), while the other three do just the opposite. In fact \
it is quite clear by symmetry that if we have one real cylinder then we must \
have six: we get two \"conjugates\" by rotating, and three more by reflecting \
through the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          StyleBox["x",
            FontSlant->"Italic"], "\[Hyphen]", 
          StyleBox["y",
            FontSlant->"Italic"]}]]]],
  " plane. There is another configuration, from [29], that can be seen to \
give six cylinders. We have four points forming vertices of a square in the \
",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          StyleBox["x",
            FontSlant->"Italic"], "\[Hyphen]", 
          StyleBox["y",
            FontSlant->"Italic"]}]]]],
  " plane. This is the base of a pyramid with the fifth point as its apex \
above the centroid of this square. We obtain two horizontal cylinders each \
passing through a pair of opposite triangular faces of the pyramid. The \
remaining four each pass through a triangular face, angled upward, and an \
edge of the base. Some are illustrated below. Note that we again must take \
care in our choice of axis direction vector and offset, because once again we \
have a nongeneric choice of coordinates for illustrative purposes. \
Accordingly the code for ",
  Cell[BoxData[
      StyleBox["showlines",
        FontWeight->"Bold"]]],
  " has been altered to use a ",
  Cell[BoxData[
      \(ViewPoint\)],
    FontWeight->"Bold"],
  " of ",
  Cell[BoxData[
      \({0, 0, 1}\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(dpoints\  = \ {{1, 0, 0}, \ {\(-1\), 0, 0}, {0, 1, 0}, \ {0, \(-1\), 
          0}, \ {0, 0, 3/2}}; \), "\n", 
    \(vec\  = \ {1, a, c}; offset\  = \ {0, b, d}; \), "\n", 
    \(solveCylinders[dpoints, vec, offset]\), "\n", 
    \(nsols\  = \ N[solns]; \)}], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \({0.8181818181818182`, 0.8181818181818182`, 0.8181818181818182`, 
      0.8181818181818182`, 0.8402777777777778`, 
      0.8402777777777778`}\)], "Output",
  CellLabel->"Out[91]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      GraphicsArray[
        Map[cylinderplot[nsols[\([\)\(#\)\(]\)], dpoints, vec, offset, 
              True] &, {3, 5}]]]; \)], "Input",
  CellLabel->"In[48]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .76934 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0183176 0.47619 [
[ 0 0 0 0 ]
[ 1 .76934 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .76934 L
0 .76934 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0183176 0.477324 0.751023 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.29246 1.6699 8.59772e-17 1.6699 [
[ 0 0 0 0 ]
[ 1 1.61561 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.61561 L
0 1.61561 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
1 g
.31372 1.38419 m .29246 1.44923 L .28425 1.45045 L p F P
0 g
s
1 g
.28425 1.45045 m .30557 1.38518 L .31372 1.38419 L p F P
0 g
s
1 g
.33509 1.3188 m .31372 1.38419 L .30557 1.38518 L p F P
0 g
s
1 g
.30557 1.38518 m .28425 1.45045 L .2784 1.45293 L p F P
0 g
s
1 g
.38811 1.48529 m .40972 1.42007 L .41262 1.4252 L p F P
0 g
s
1 g
.41262 1.4252 m .39091 1.49068 L .38811 1.48529 L p F P
0 g
s
1 g
.30557 1.38518 m .327 1.31956 L .33509 1.3188 L p F P
0 g
s
1 g
.35658 1.25307 m .33509 1.3188 L .327 1.31956 L p F P
0 g
s
1 g
.2784 1.45293 m .29979 1.3874 L .30557 1.38518 L p F P
0 g
s
1 g
.327 1.31956 m .30557 1.38518 L .29979 1.3874 L p F P
0 g
s
1 g
.40972 1.42007 m .43144 1.3545 L .43444 1.35938 L p F P
0 g
s
1 g
.43444 1.35938 m .41262 1.4252 L .40972 1.42007 L p F P
0 g
s
1 g
.29979 1.3874 m .2784 1.45293 L .27521 1.45658 L p F P
0 g
s
.30548 1.55972 m
.29907 1.57922 L
s
1 g
.327 1.31956 m .34855 1.25358 L .35658 1.25307 L p F P
0 g
s
1 g
.37818 1.18698 m .35658 1.25307 L .34855 1.25358 L p F P
0 g
s
1 g
.39091 1.49068 m .41262 1.4252 L .41266 1.42963 L p F P
0 g
s
1 g
.41266 1.42963 m .39087 1.49537 L .39091 1.49068 L p F P
0 g
s
.3119 1.5402 m
.30548 1.55972 L
s
1 g
.29979 1.3874 m .32129 1.32152 L .327 1.31956 L p F P
0 g
s
1 g
.34855 1.25358 m .327 1.31956 L .32129 1.32152 L p F P
0 g
s
.31834 1.52064 m
.3119 1.5402 L
s
1 g
.43144 1.3545 m .45328 1.28858 L .45637 1.2932 L p F P
0 g
s
1 g
.45637 1.2932 m .43444 1.35938 L .43144 1.3545 L p F P
0 g
s
.32478 1.50105 m
.31834 1.52064 L
s
1 g
.27521 1.45658 m .29668 1.39077 L .29979 1.3874 L p F P
0 g
s
1 g
.32129 1.32152 m .29979 1.3874 L .29668 1.39077 L p F P
0 g
s
1 g
.34855 1.25358 m .37021 1.18726 L .37818 1.18698 L p F P
0 g
s
1 g
.3999 1.12054 m .37818 1.18698 L .37021 1.18726 L p F P
0 g
s
1 g
.41262 1.4252 m .43444 1.35938 L .43458 1.36353 L p F P
0 g
s
1 g
.43458 1.36353 m .41266 1.42963 L .41262 1.4252 L p F P
0 g
s
.33123 1.48142 m
.32478 1.50105 L
s
1 g
.32129 1.32152 m .34291 1.25528 L .34855 1.25358 L p F P
0 g
s
1 g
.37021 1.18726 m .34855 1.25358 L .34291 1.25528 L p F P
0 g
s
.3377 1.46177 m
.33123 1.48142 L
s
1 g
.29668 1.39077 m .27521 1.45658 L .27488 1.46121 L p F P
0 g
s
1 g
.45328 1.28858 m .47524 1.2223 L .47843 1.22666 L p F P
0 g
s
1 g
.47843 1.22666 m .45637 1.2932 L .45328 1.28858 L p F P
0 g
s
1 g
.39087 1.49537 m .41266 1.42963 L .40982 1.43312 L p F P
0 g
s
1 g
.40982 1.43312 m .38794 1.49914 L .39087 1.49537 L p F P
0 g
s
.34417 1.44209 m
.3377 1.46177 L
s
1 g
.29668 1.39077 m .31827 1.32461 L .32129 1.32152 L p F P
0 g
s
1 g
.34291 1.25528 m .32129 1.32152 L .31827 1.32461 L p F P
0 g
s
1 g
.37021 1.18726 m .39199 1.12057 L .3999 1.12054 L p F P
0 g
s
1 g
.42174 1.05374 m .3999 1.12054 L .39199 1.12057 L p F P
0 g
s
.35066 1.42237 m
.34417 1.44209 L
s
1 g
.43444 1.35938 m .45637 1.2932 L .45661 1.29707 L p F P
0 g
s
1 g
.45661 1.29707 m .43458 1.36353 L .43444 1.35938 L p F P
0 g
s
1 g
.34291 1.25528 m .36464 1.18869 L .37021 1.18726 L p F P
0 g
s
1 g
.39199 1.12057 m .37021 1.18726 L .36464 1.18869 L p F P
0 g
s
.35715 1.40262 m
.35066 1.42237 L
s
1 g
.27488 1.46121 m .29644 1.39513 L .29668 1.39077 L p F P
0 g
s
1 g
.31827 1.32461 m .29668 1.39077 L .29644 1.39513 L p F P
0 g
s
1 g
.47524 1.2223 m .49731 1.15567 L .5006 1.15976 L p F P
0 g
s
1 g
.5006 1.15976 m .47843 1.22666 L .47524 1.2223 L p F P
0 g
s
.36366 1.38284 m
.35715 1.40262 L
s
1 g
.41266 1.42963 m .43458 1.36353 L .43182 1.36674 L p F P
0 g
s
1 g
.43182 1.36674 m .40982 1.43312 L .41266 1.42963 L p F P
0 g
s
1 g
.31827 1.32461 m .33997 1.2581 L .34291 1.25528 L p F P
0 g
s
1 g
.36464 1.18869 m .34291 1.25528 L .33997 1.2581 L p F P
0 g
s
.37018 1.36303 m
.36366 1.38284 L
s
1 g
.39199 1.12057 m .41388 1.05353 L .42174 1.05374 L p F P
0 g
s
1 g
.44369 .98658 m .42174 1.05374 L .41388 1.05353 L p F P
0 g
s
1 g
.29644 1.39513 m .27488 1.46121 L .27745 1.46661 L p F P
0 g
s
1 g
.45637 1.2932 m .47843 1.22666 L .47876 1.23026 L p F P
0 g
s
1 g
.47876 1.23026 m .45661 1.29707 L .45637 1.2932 L p F P
0 g
s
.3767 1.34318 m
.37018 1.36303 L
s
1 g
.38794 1.49914 m .40982 1.43312 L .40419 1.43548 L p F P
0 g
s
1 g
.40419 1.43548 m .38223 1.50176 L .38794 1.49914 L p F P
0 g
s
1 g
.36464 1.18869 m .3865 1.12174 L .39199 1.12057 L p F P
0 g
s
1 g
.41388 1.05353 m .39199 1.12057 L .3865 1.12174 L p F P
0 g
s
1 g
.29644 1.39513 m .31812 1.3287 L .31827 1.32461 L p F P
0 g
s
1 g
.33997 1.2581 m .31827 1.32461 L .31812 1.3287 L p F P
0 g
s
.38324 1.32331 m
.3767 1.34318 L
s
1 g
.49731 1.15567 m .51951 1.08868 L .5229 1.0925 L p F P
0 g
s
1 g
.5229 1.0925 m .5006 1.15976 L .49731 1.15567 L p F P
0 g
s
1 g
.43458 1.36353 m .45661 1.29707 L .45394 1.30001 L p F P
0 g
s
1 g
.45394 1.30001 m .43182 1.36674 L .43458 1.36353 L p F P
0 g
s
.38979 1.3034 m
.38324 1.32331 L
s
1 g
.33997 1.2581 m .3618 1.19122 L .36464 1.18869 L p F P
0 g
s
1 g
.3865 1.12174 m .36464 1.18869 L .3618 1.19122 L p F P
0 g
s
1 g
.41388 1.05353 m .4359 .98612 L .44369 .98658 L p F P
0 g
s
1 g
.46577 .91906 m .44369 .98658 L .4359 .98612 L p F P
0 g
s
1 g
.27745 1.46661 m .29911 1.40027 L .29644 1.39513 L p F P
0 g
s
1 g
.31812 1.3287 m .29644 1.39513 L .29911 1.40027 L p F P
0 g
s
1 g
.47843 1.22666 m .5006 1.15976 L .50104 1.16308 L p F P
0 g
s
1 g
.50104 1.16308 m .47876 1.23026 L .47843 1.22666 L p F P
0 g
s
.39635 1.28346 m
.38979 1.3034 L
s
1 g
.40982 1.43312 m .43182 1.36674 L .42627 1.36884 L p F P
0 g
s
1 g
.42627 1.36884 m .40419 1.43548 L .40982 1.43312 L p F P
0 g
s
1 g
.3865 1.12174 m .40847 1.05442 L .41388 1.05353 L p F P
0 g
s
1 g
.4359 .98612 m .41388 1.05353 L .40847 1.05442 L p F P
0 g
s
.40292 1.26348 m
.39635 1.28346 L
s
1 g
.31812 1.3287 m .33992 1.2619 L .33997 1.2581 L p F P
0 g
s
1 g
.3618 1.19122 m .33997 1.2581 L .33992 1.2619 L p F P
0 g
s
1 g
.51951 1.08868 m .54182 1.02132 L .54532 1.02487 L p F P
0 g
s
1 g
.54532 1.02487 m .5229 1.0925 L .51951 1.08868 L p F P
0 g
s
1 g
.29911 1.40027 m .27745 1.46661 L .28284 1.47251 L p F P
0 g
s
1 g
.45661 1.29707 m .47876 1.23026 L .47618 1.23291 L p F P
0 g
s
1 g
.47618 1.23291 m .45394 1.30001 L .45661 1.29707 L p F P
0 g
s
.4095 1.24348 m
.40292 1.26348 L
s
1 g
.38223 1.50176 m .40419 1.43548 L .39604 1.43659 L p F P
0 g
s
1 g
.39604 1.43659 m .37402 1.50311 L .38223 1.50176 L p F P
0 g
s
1 g
.3618 1.19122 m .38374 1.12399 L .3865 1.12174 L p F P
0 g
s
1 g
.40847 1.05442 m .3865 1.12174 L .38374 1.12399 L p F P
0 g
s
1 g
.4359 .98612 m .45803 .91835 L .46577 .91906 L p F P
0 g
s
1 g
.48796 .85117 m .46577 .91906 L .45803 .91835 L p F P
0 g
s
.41609 1.22344 m
.4095 1.24348 L
s
1 g
.29911 1.40027 m .32089 1.33358 L .31812 1.3287 L p F P
0 g
s
1 g
.33992 1.2619 m .31812 1.3287 L .32089 1.33358 L p F P
0 g
s
1 g
.5006 1.15976 m .5229 1.0925 L .52343 1.09553 L p F P
0 g
s
1 g
.52343 1.09553 m .50104 1.16308 L .5006 1.15976 L p F P
0 g
s
1 g
.43182 1.36674 m .45394 1.30001 L .44847 1.30183 L p F P
0 g
s
1 g
.44847 1.30183 m .42627 1.36884 L .43182 1.36674 L p F P
0 g
s
1 g
.40847 1.05442 m .43056 .98674 L .4359 .98612 L p F P
0 g
s
1 g
.45803 .91835 m .4359 .98612 L .43056 .98674 L p F P
0 g
s
.42269 1.20337 m
.41609 1.22344 L
s
1 g
.33992 1.2619 m .36184 1.19475 L .3618 1.19122 L p F P
0 g
s
1 g
.38374 1.12399 m .3618 1.19122 L .36184 1.19475 L p F P
0 g
s
1 g
.54182 1.02132 m .56426 .9536 L .56786 .95688 L p F P
0 g
s
1 g
.56786 .95688 m .54532 1.02487 L .54182 1.02132 L p F P
0 g
s
1 g
.28284 1.47251 m .3046 1.40595 L .29911 1.40027 L p F P
0 g
s
1 g
.32089 1.33358 m .29911 1.40027 L .3046 1.40595 L p F P
0 g
s
.4293 1.18327 m
.42269 1.20337 L
s
1 g
.47876 1.23026 m .50104 1.16308 L .49855 1.16544 L p F P
0 g
s
1 g
.49855 1.16544 m .47618 1.23291 L .47876 1.23026 L p F P
0 g
s
1 g
.40419 1.43548 m .42627 1.36884 L .41817 1.3697 L p F P
0 g
s
1 g
.41817 1.3697 m .39604 1.43659 L .40419 1.43548 L p F P
0 g
s
1 g
.38374 1.12399 m .40579 1.05638 L .40847 1.05442 L p F P
0 g
s
1 g
.43056 .98674 m .40847 1.05442 L .40579 1.05638 L p F P
0 g
s
.43592 1.16313 m
.4293 1.18327 L
s
1 g
.45803 .91835 m .48028 .85021 L .48796 .85117 L p F P
0 g
s
0 1 1 r
.48436 .85609 m
.56668 .87714 L
s
1 g
.51027 .78292 m .48796 .85117 L .48028 .85021 L p F P
0 g
s
1 g
.3046 1.40595 m .28284 1.47251 L .2908 1.47863 L p F P
0 g
s
1 g
.32089 1.33358 m .34279 1.26652 L .33992 1.2619 L p F P
0 g
s
1 g
.36184 1.19475 m .33992 1.2619 L .34279 1.26652 L p F P
0 g
s
1 g
.5229 1.0925 m .54532 1.02487 L .54595 1.02761 L p F P
0 g
s
1 g
.54595 1.02761 m .52343 1.09553 L .5229 1.0925 L p F P
0 g
s
1 g
.37402 1.50311 m .39604 1.43659 L .38574 1.43636 L p F P
0 g
s
1 g
.38574 1.43636 m .36369 1.50309 L .37402 1.50311 L p F P
0 g
s
.44256 1.14296 m
.43592 1.16313 L
s
1 g
.45394 1.30001 m .47618 1.23291 L .47079 1.23446 L p F P
0 g
s
1 g
.47079 1.23446 m .44847 1.30183 L .45394 1.30001 L p F P
0 g
s
1 g
.43056 .98674 m .45277 .91868 L .45803 .91835 L p F P
0 g
s
1 g
.48028 .85021 m .45803 .91835 L .45277 .91868 L p F P
0 g
s
1 g
.36184 1.19475 m .38387 1.12722 L .38374 1.12399 L p F P
0 g
s
1 g
.40579 1.05638 m .38374 1.12399 L .38387 1.12722 L p F P
0 g
s
.4492 1.12276 m
.44256 1.14296 L
s
1 g
.56426 .9536 m .58681 .88551 L .59052 .88851 L p F P
0 g
s
1 g
.59052 .88851 m .56786 .95688 L .56426 .9536 L p F P
0 g
s
1 g
.3046 1.40595 m .32647 1.33901 L .32089 1.33358 L p F P
0 g
s
1 g
.34279 1.26652 m .32089 1.33358 L .32647 1.33901 L p F P
0 g
s
1 g
.50104 1.16308 m .52343 1.09553 L .52103 1.0976 L p F P
0 g
s
1 g
.52103 1.0976 m .49855 1.16544 L .50104 1.16308 L p F P
0 g
s
1 g
.42627 1.36884 m .44847 1.30183 L .44043 1.30245 L p F P
0 g
s
1 g
.44043 1.30245 m .41817 1.3697 L .42627 1.36884 L p F P
0 g
s
.45586 1.10253 m
.4492 1.12276 L
s
1 g
.40579 1.05638 m .42797 .98841 L .43056 .98674 L p F P
0 g
s
1 g
.45277 .91868 m .43056 .98674 L .42797 .98841 L p F P
0 g
s
1 g
.48028 .85021 m .50266 .78169 L .51027 .78292 L p F P
0 g
s
1 g
.53271 .71429 m .51027 .78292 L .50266 .78169 L p F P
0 g
s
1 g
.2908 1.47863 m .31265 1.41186 L .3046 1.40595 L p F P
0 g
s
1 g
.32647 1.33901 m .3046 1.40595 L .31265 1.41186 L p F P
0 g
s
1 g
.34279 1.26652 m .3648 1.19909 L .36184 1.19475 L p F P
0 g
s
1 g
.38387 1.12722 m .36184 1.19475 L .3648 1.19909 L p F P
0 g
s
1 g
.54532 1.02487 m .56786 .95688 L .56859 .95933 L p F P
0 g
s
1 g
.56859 .95933 m .54595 1.02761 L .54532 1.02487 L p F P
0 g
s
1 g
.31265 1.41186 m .2908 1.47863 L .30094 1.48463 L p F P
0 g
s
.46252 1.08226 m
.45586 1.10253 L
s
1 g
.39604 1.43659 m .41817 1.3697 L .40792 1.36927 L p F P
0 g
s
1 g
.40792 1.36927 m .38574 1.43636 L .39604 1.43659 L p F P
0 g
s
1 g
.36369 1.50309 m .38574 1.43636 L .37383 1.4348 L p F P
0 g
s
1 g
.37383 1.4348 m .35175 1.50168 L .36369 1.50309 L p F P
0 g
s
1 g
.47618 1.23291 m .49855 1.16544 L .49323 1.16672 L p F P
0 g
s
1 g
.49323 1.16672 m .47079 1.23446 L .47618 1.23291 L p F P
0 g
s
1 g
.45277 .91868 m .4751 .85026 L .48028 .85021 L p F P
0 g
s
1 g
.50266 .78169 m .48028 .85021 L .4751 .85026 L p F P
0 g
s
.4692 1.06196 m
.46252 1.08226 L
s
1 g
.38387 1.12722 m .40603 1.05933 L .40579 1.05638 L p F P
0 g
s
1 g
.42797 .98841 m .40579 1.05638 L .40603 1.05933 L p F P
0 g
s
1 g
.58681 .88551 m .60949 .81705 L .61331 .81977 L p F P
0 g
s
0 .769 1 r
.56668 .87714 m
.5782 .86909 L
s
.5782 .86909 m
.59649 .8563 L
s
1 g
.61331 .81977 m .59052 .88851 L .58681 .88551 L p F P
0 g
s
1 g
.32647 1.33901 m .34847 1.27172 L .34279 1.26652 L p F P
0 g
s
1 g
.3648 1.19909 m .34279 1.26652 L .34847 1.27172 L p F P
0 g
s
1 g
.52343 1.09553 m .54595 1.02761 L .54364 1.0294 L p F P
0 g
s
1 g
.54364 1.0294 m .52103 1.0976 L .52343 1.09553 L p F P
0 g
s
.47589 1.04163 m
.4692 1.06196 L
s
1 g
.44847 1.30183 m .47079 1.23446 L .46281 1.23483 L p F P
0 g
s
1 g
.46281 1.23483 m .44043 1.30245 L .44847 1.30183 L p F P
0 g
s
1 g
.42797 .98841 m .45027 .92006 L .45277 .91868 L p F P
0 g
s
1 g
.4751 .85026 m .45277 .91868 L .45027 .92006 L p F P
0 g
s
0 1 1 r
.44813 .84683 m
.47397 .85344 L
s
1 g
.50266 .78169 m .52516 .71281 L .53271 .71429 L p F P
0 g
s
1 g
.55527 .64528 m .53271 .71429 L .52516 .71281 L p F P
0 g
s
1 g
.31265 1.41186 m .33461 1.34474 L .32647 1.33901 L p F P
0 g
s
1 g
.34847 1.27172 m .32647 1.33901 L .33461 1.34474 L p F P
0 g
s
1 g
.32286 1.41772 m .30094 1.48463 L .31274 1.49021 L p F P
0 g
s
1 g
.30094 1.48463 m .32286 1.41772 L .31265 1.41186 L p F P
0 g
s
.48259 1.02126 m
.47589 1.04163 L
s
1 g
.3648 1.19909 m .38694 1.1313 L .38387 1.12722 L p F P
0 g
s
1 g
.40603 1.05933 m .38387 1.12722 L .38694 1.1313 L p F P
0 g
s
1 g
.56786 .95688 m .59052 .88851 L .59135 .89066 L p F P
0 g
s
1 g
.59135 .89066 m .56859 .95933 L .56786 .95688 L p F P
0 g
s
1 g
.35175 1.50168 m .37383 1.4348 L .3609 1.43199 L p F P
0 g
s
1 g
.3609 1.43199 m .33883 1.49897 L .35175 1.50168 L p F P
0 g
s
1 g
.33461 1.34474 m .31265 1.41186 L .32286 1.41772 L p F P
0 g
s
1 g
.41817 1.3697 m .44043 1.30245 L .43021 1.30181 L p F P
0 g
s
1 g
.43021 1.30181 m .40792 1.36927 L .41817 1.3697 L p F P
0 g
s
1 g
.38574 1.43636 m .40792 1.36927 L .39602 1.36756 L p F P
0 g
s
1 g
.39602 1.36756 m .37383 1.4348 L .38574 1.43636 L p F P
0 g
s
1 g
.49855 1.16544 m .52103 1.0976 L .51579 1.09861 L p F P
0 g
s
1 g
.51579 1.09861 m .49323 1.16672 L .49855 1.16544 L p F P
0 g
s
.4893 1.00086 m
.48259 1.02126 L
s
1 g
.4751 .85026 m .49755 .78146 L .50266 .78169 L p F P
0 g
s
1 g
.52516 .71281 m .50266 .78169 L .49755 .78146 L p F P
0 g
s
1 g
.40603 1.05933 m .42831 .99106 L .42797 .98841 L p F P
0 g
s
1 g
.45027 .92006 m .42797 .98841 L .42831 .99106 L p F P
0 g
s
.615 1 0 r
.44813 .84683 m
.47003 .83028 L
s
1 .231 0 r
.61969 .82813 m
.63995 .82593 L
s
0 0 1 r
.03 w
.44813 .84683 Mdot
.5 Mabswid
1 g
.60949 .81705 m .6323 .74822 L .63622 .75065 L p F P
0 g
s
1 g
.63622 .75065 m .61331 .81977 L .60949 .81705 L p F P
0 g
s
1 g
.33473 1.42322 m .31274 1.49021 L .32559 1.49508 L p F P
0 g
s
1 g
.31274 1.49021 m .33473 1.42322 L .32286 1.41772 L p F P
0 g
s
1 g
.34847 1.27172 m .37058 1.20405 L .3648 1.19909 L p F P
0 g
s
1 g
.38694 1.1313 m .3648 1.19909 L .37058 1.20405 L p F P
0 g
s
1 g
.33883 1.49897 m .3609 1.43199 L .34763 1.42806 L p F P
0 g
s
1 g
.34763 1.42806 m .32559 1.49508 L .33883 1.49897 L p F P
0 g
s
.49602 .98043 m
.4893 1.00086 L
s
1 g
.54595 1.02761 m .56859 .95933 L .56638 .96081 L p F P
0 g
s
1 g
.56638 .96081 m .54364 1.0294 L .54595 1.02761 L p F P
0 g
s
1 g
.32559 1.49508 m .34763 1.42806 L .33473 1.42322 L p F P
0 g
s
1 g
.47079 1.23446 m .49323 1.16672 L .48531 1.16684 L p F P
0 g
s
1 g
.48531 1.16684 m .46281 1.23483 L .47079 1.23446 L p F P
0 g
s
1 g
.45027 .92006 m .4727 .85134 L .4751 .85026 L p F P
0 g
s
1 g
.49755 .78146 m .4751 .85026 L .4727 .85134 L p F P
0 g
s
1 .231 0 r
.44813 .84683 m
.47536 .84387 L
s
0 g
.50275 .95996 m
.49602 .98043 L
s
1 g
.52516 .71281 m .54778 .64354 L .55527 .64528 L p F P
0 g
s
1 g
.57795 .5759 m .55527 .64528 L .54778 .64354 L p F P
0 g
s
1 g
.33461 1.34474 m .3567 1.27724 L .34847 1.27172 L p F P
0 g
s
1 g
.37058 1.20405 m .34847 1.27172 L .3567 1.27724 L p F P
0 g
s
1 g
.34491 1.35045 m .32286 1.41772 L .33473 1.42322 L p F P
0 g
s
1 g
.32286 1.41772 m .34491 1.35045 L .33461 1.34474 L p F P
0 g
s
1 g
.38694 1.1313 m .4092 1.06313 L .40603 1.05933 L p F P
0 g
s
1 g
.42831 .99106 m .40603 1.05933 L .4092 1.06313 L p F P
0 g
s
1 g
.59052 .88851 m .61331 .81977 L .61424 .82162 L p F P
0 g
s
1 g
.61424 .82162 m .59135 .89066 L .59052 .88851 L p F P
0 g
s
1 g
.37383 1.4348 m .39602 1.36756 L .38309 1.36464 L p F P
0 g
s
1 g
.38309 1.36464 m .3609 1.43199 L .37383 1.4348 L p F P
0 g
s
1 g
.3567 1.27724 m .33461 1.34474 L .34491 1.35045 L p F P
0 g
s
1 g
.44043 1.30245 m .46281 1.23483 L .45263 1.23398 L p F P
0 g
s
1 g
.45263 1.23398 m .43021 1.30181 L .44043 1.30245 L p F P
0 g
s
.50949 .93946 m
.50275 .95996 L
s
1 g
.40792 1.36927 m .43021 1.30181 L .41833 1.29994 L p F P
0 g
s
1 g
.41833 1.29994 m .39602 1.36756 L .40792 1.36927 L p F P
0 g
s
1 g
.52103 1.0976 m .54364 1.0294 L .53848 1.03012 L p F P
0 g
s
1 g
.53848 1.03012 m .51579 1.09861 L .52103 1.0976 L p F P
0 g
s
1 g
.49755 .78146 m .52013 .71228 L .52516 .71281 L p F P
0 g
s
1 g
.54778 .64354 m .52516 .71281 L .52013 .71228 L p F P
0 g
s
1 g
.42831 .99106 m .45071 .92242 L .45027 .92006 L p F P
0 g
s
1 g
.4727 .85134 m .45027 .92006 L .45071 .92242 L p F P
0 g
s
1 0 .923 r
.4639 .86766 m
.46608 .87055 L
s
.44813 .84683 m
.4639 .86766 L
s
0 g
.51625 .91893 m
.50949 .93946 L
s
1 g
.6323 .74822 m .65523 .679 L .65926 .68115 L p F P
0 g
s
1 g
.65926 .68115 m .63622 .75065 L .6323 .74822 L p F P
0 g
s
1 g
.35684 1.35586 m .33473 1.42322 L .34763 1.42806 L p F P
0 g
s
1 g
.33473 1.42322 m .35684 1.35586 L .34491 1.35045 L p F P
0 g
s
1 g
.37058 1.20405 m .39282 1.13601 L .38694 1.1313 L p F P
0 g
s
1 g
.4092 1.06313 m .38694 1.1313 L .39282 1.13601 L p F P
0 g
s
1 g
.3609 1.43199 m .38309 1.36464 L .3698 1.36067 L p F P
0 g
s
1 g
.3698 1.36067 m .34763 1.42806 L .3609 1.43199 L p F P
0 g
s
1 g
.56859 .95933 m .59135 .89066 L .58923 .89185 L p F P
0 g
s
1 g
.58923 .89185 m .56638 .96081 L .56859 .95933 L p F P
0 g
s
1 g
.34763 1.42806 m .3698 1.36067 L .35684 1.35586 L p F P
0 g
s
1 g
.49323 1.16672 m .51579 1.09861 L .50794 1.09847 L p F P
0 g
s
1 g
.50794 1.09847 m .48531 1.16684 L .49323 1.16672 L p F P
0 g
s
.52301 .89836 m
.51625 .91893 L
s
1 g
.4727 .85134 m .49525 .78224 L .49755 .78146 L p F P
0 g
s
1 g
.52013 .71228 m .49755 .78146 L .49525 .78224 L p F P
0 g
s
1 g
.54778 .64354 m .57052 .57389 L .57795 .5759 L p F P
0 g
s
1 g
.60075 .50613 m .57795 .5759 L .57052 .57389 L p F P
0 g
s
1 g
.3567 1.27724 m .37891 1.20938 L .37058 1.20405 L p F P
0 g
s
1 g
.39282 1.13601 m .37058 1.20405 L .37891 1.20938 L p F P
0 g
s
1 g
.36708 1.28281 m .34491 1.35045 L .35684 1.35586 L p F P
0 g
s
1 g
.34491 1.35045 m .36708 1.28281 L .3567 1.27724 L p F P
0 g
s
1 g
.4092 1.06313 m .43158 .99459 L .42831 .99106 L p F P
0 g
s
1 g
.45071 .92242 m .42831 .99106 L .43158 .99459 L p F P
0 g
s
1 g
.61331 .81977 m .63622 .75065 L .63726 .7522 L p F P
0 g
s
1 g
.63726 .7522 m .61424 .82162 L .61331 .81977 L p F P
0 g
s
1 g
.39602 1.36756 m .41833 1.29994 L .4054 1.29692 L p F P
0 g
s
1 g
.4054 1.29692 m .38309 1.36464 L .39602 1.36756 L p F P
0 g
s
.52979 .87776 m
.52301 .89836 L
s
1 g
.37891 1.20938 m .3567 1.27724 L .36708 1.28281 L p F P
0 g
s
1 g
.46281 1.23483 m .48531 1.16684 L .47518 1.16578 L p F P
0 g
s
1 g
.47518 1.16578 m .45263 1.23398 L .46281 1.23483 L p F P
0 g
s
1 g
.43021 1.30181 m .45263 1.23398 L .44077 1.23195 L p F P
0 g
s
1 g
.44077 1.23195 m .41833 1.29994 L .43021 1.30181 L p F P
0 g
s
1 g
.54364 1.0294 m .56638 .96081 L .56129 .96125 L p F P
0 g
s
1 g
.56129 .96125 m .53848 1.03012 L .54364 1.0294 L p F P
0 g
s
1 g
.52013 .71228 m .54283 .64273 L .54778 .64354 L p F P
0 g
s
1 g
.57052 .57389 m .54778 .64354 L .54283 .64273 L p F P
0 g
s
.53658 .85712 m
.52979 .87776 L
s
1 g
.45071 .92242 m .47323 .8534 L .4727 .85134 L p F P
0 g
s
1 0 .923 r
.46608 .87055 m
.46649 .87109 L
s
1 g
.49525 .78224 m .4727 .85134 L .47323 .8534 L p F P
0 g
s
1 g
.65523 .679 m .67829 .60941 L .68242 .61126 L p F P
0 g
s
1 g
.68242 .61126 m .65926 .68115 L .65523 .679 L p F P
0 g
s
1 g
.37908 1.28813 m .35684 1.35586 L .3698 1.36067 L p F P
0 g
s
1 g
.35684 1.35586 m .37908 1.28813 L .36708 1.28281 L p F P
0 g
s
1 g
.39282 1.13601 m .41518 1.0676 L .4092 1.06313 L p F P
0 g
s
1 g
.43158 .99459 m .4092 1.06313 L .41518 1.0676 L p F P
0 g
s
1 g
.38309 1.36464 m .4054 1.29692 L .39208 1.29292 L p F P
0 g
s
1 g
.39208 1.29292 m .3698 1.36067 L .38309 1.36464 L p F P
0 g
s
1 g
.59135 .89066 m .61424 .82162 L .61222 .82251 L p F P
0 g
s
1 .231 0 r
.61302 .82886 m
.61969 .82813 L
s
0 .769 1 r
.60463 .85061 m
.60881 .84769 L
s
1 g
.61222 .82251 m .58923 .89185 L .59135 .89066 L p F P
0 g
s
.54338 .83645 m
.53658 .85712 L
s
1 g
.3698 1.36067 m .39208 1.29292 L .37908 1.28813 L p F P
0 g
s
1 g
.51579 1.09861 m .53848 1.03012 L .53069 1.02973 L p F P
0 g
s
1 g
.53069 1.02973 m .50794 1.09847 L .51579 1.09861 L p F P
0 g
s
1 g
.49525 .78224 m .51792 .71276 L .52013 .71228 L p F P
0 g
s
1 g
.54283 .64273 m .52013 .71228 L .51792 .71276 L p F P
0 g
s
1 g
.57052 .57389 m .59339 .50386 L .60075 .50613 L p F P
0 g
s
1 g
.62369 .43598 m .60075 .50613 L .59339 .50386 L p F P
0 g
s
1 g
.37891 1.20938 m .40124 1.14114 L .39282 1.13601 L p F P
0 g
s
1 g
.41518 1.0676 m .39282 1.13601 L .40124 1.14114 L p F P
0 g
s
1 g
.38937 1.21479 m .36708 1.28281 L .37908 1.28813 L p F P
0 g
s
1 g
.36708 1.28281 m .38937 1.21479 L .37891 1.20938 L p F P
0 g
s
.55018 .81575 m
.54338 .83645 L
s
1 g
.43158 .99459 m .45408 .92567 L .45071 .92242 L p F P
0 g
s
1 g
.47323 .8534 m .45071 .92242 L .45408 .92567 L p F P
0 g
s
1 g
.63622 .75065 m .65926 .68115 L .6604 .68239 L p F P
0 g
s
1 g
.6604 .68239 m .63726 .7522 L .63622 .75065 L p F P
0 g
s
1 g
.41833 1.29994 m .44077 1.23195 L .42783 1.22883 L p F P
0 g
s
1 g
.42783 1.22883 m .4054 1.29692 L .41833 1.29994 L p F P
0 g
s
1 g
.40124 1.14114 m .37891 1.20938 L .38937 1.21479 L p F P
0 g
s
1 g
.48531 1.16684 m .50794 1.09847 L .49785 1.0972 L p F P
0 g
s
1 g
.49785 1.0972 m .47518 1.16578 L .48531 1.16684 L p F P
0 g
s
1 g
.45263 1.23398 m .47518 1.16578 L .46333 1.16359 L p F P
0 g
s
1 g
.46333 1.16359 m .44077 1.23195 L .45263 1.23398 L p F P
0 g
s
1 g
.56638 .96081 m .58923 .89185 L .58423 .892 L p F P
0 g
s
1 g
.58423 .892 m .56129 .96125 L .56638 .96081 L p F P
0 g
s
.55701 .79501 m
.55018 .81575 L
s
1 g
.54283 .64273 m .56566 .57278 L .57052 .57389 L p F P
0 g
s
1 g
.59339 .50386 m .57052 .57389 L .56566 .57278 L p F P
0 g
s
1 g
.47323 .8534 m .49588 .784 L .49525 .78224 L p F P
0 g
s
1 g
.51792 .71276 m .49525 .78224 L .49588 .784 L p F P
0 g
s
1 g
.67829 .60941 m .70147 .53943 L .70572 .54099 L p F P
0 g
s
1 g
.70572 .54099 m .68242 .61126 L .67829 .60941 L p F P
0 g
s
1 g
.40144 1.22002 m .37908 1.28813 L .39208 1.29292 L p F P
0 g
s
1 g
.37908 1.28813 m .40144 1.22002 L .38937 1.21479 L p F P
0 g
s
1 g
.41518 1.0676 m .43766 .99881 L .43158 .99459 L p F P
0 g
s
1 g
.45408 .92567 m .43158 .99459 L .43766 .99881 L p F P
0 g
s
.56384 .77424 m
.55701 .79501 L
s
1 g
.4054 1.29692 m .42783 1.22883 L .41449 1.22478 L p F P
0 g
s
1 g
.41449 1.22478 m .39208 1.29292 L .4054 1.29692 L p F P
0 g
s
1 g
.61424 .82162 m .63726 .7522 L .63533 .75278 L p F P
0 g
s
1 g
.63533 .75278 m .61222 .82251 L .61424 .82162 L p F P
0 g
s
1 g
.39208 1.29292 m .41449 1.22478 L .40144 1.22002 L p F P
0 g
s
1 g
.53848 1.03012 m .56129 .96125 L .55357 .9606 L p F P
0 g
s
1 g
.55357 .9606 m .53069 1.02973 L .53848 1.03012 L p F P
0 g
s
1 g
.51792 .71276 m .54071 .64289 L .54283 .64273 L p F P
0 g
s
1 g
.56566 .57278 m .54283 .64273 L .54071 .64289 L p F P
0 g
s
.57068 .75343 m
.56384 .77424 L
s
1 g
.59339 .50386 m .61639 .43344 L .62369 .43598 L p F P
0 g
s
1 g
.64674 .36545 m .62369 .43598 L .61639 .43344 L p F P
0 g
s
1 g
.40124 1.14114 m .42369 1.07252 L .41518 1.0676 L p F P
0 g
s
1 g
.43766 .99881 m .41518 1.0676 L .42369 1.07252 L p F P
0 g
s
1 g
.41178 1.1464 m .38937 1.21479 L .40144 1.22002 L p F P
0 g
s
1 g
.38937 1.21479 m .41178 1.1464 L .40124 1.14114 L p F P
0 g
s
1 g
.45408 .92567 m .47671 .85636 L .47323 .8534 L p F P
0 g
s
1 g
.49588 .784 m .47323 .8534 L .47671 .85636 L p F P
0 g
s
1 g
.65926 .68115 m .68242 .61126 L .68367 .6122 L p F P
0 g
s
1 g
.68367 .6122 m .6604 .68239 L .65926 .68115 L p F P
0 g
s
1 g
.44077 1.23195 m .46333 1.16359 L .45039 1.16036 L p F P
0 g
s
1 g
.45039 1.16036 m .42783 1.22883 L .44077 1.23195 L p F P
0 g
s
1 g
.42369 1.07252 m .40124 1.14114 L .41178 1.1464 L p F P
0 g
s
1 g
.50794 1.09847 m .53069 1.02973 L .52064 1.02824 L p F P
0 g
s
1 g
.52064 1.02824 m .49785 1.0972 L .50794 1.09847 L p F P
0 g
s
.57754 .73259 m
.57068 .75343 L
s
1 g
.47518 1.16578 m .49785 1.0972 L .48602 1.09484 L p F P
0 g
s
1 g
.48602 1.09484 m .46333 1.16359 L .47518 1.16578 L p F P
0 g
s
1 g
.58923 .89185 m .61222 .82251 L .6073 .82237 L p F P
0 g
s
1 .231 0 r
.61143 .82903 m
.61302 .82886 L
s
.6105 .82914 m
.61143 .82903 L
s
0 .769 1 r
.61669 .84218 m
.63995 .82593 L
s
.60881 .84769 m
.61669 .84218 L
s
1 g
.6073 .82237 m .58423 .892 L .58923 .89185 L p F P
0 g
s
1 .231 0 r
.48016 .84334 m
.60486 .82975 L
s
1 g
.56566 .57278 m .58862 .50245 L .59339 .50386 L p F P
0 g
s
1 g
.61639 .43344 m .59339 .50386 L .58862 .50245 L p F P
0 g
s
1 g
.49588 .784 m .51865 .71422 L .51792 .71276 L p F P
0 g
s
1 g
.54071 .64289 m .51792 .71276 L .51865 .71422 L p F P
0 g
s
.5844 .71172 m
.57754 .73259 L
s
1 g
.70147 .53943 m .72478 .46906 L .72914 .47033 L p F P
0 g
s
1 g
.72914 .47033 m .70572 .54099 L .70147 .53943 L p F P
0 g
s
1 g
.42392 1.15154 m .40144 1.22002 L .41449 1.22478 L p F P
0 g
s
1 g
.40144 1.22002 m .42392 1.15154 L .41178 1.1464 L p F P
0 g
s
1 g
.43766 .99881 m .46027 .92963 L .45408 .92567 L p F P
0 g
s
1 g
.47671 .85636 m .45408 .92567 L .46027 .92963 L p F P
0 g
s
1 g
.42783 1.22883 m .45039 1.16036 L .43702 1.15628 L p F P
0 g
s
1 g
.43702 1.15628 m .41449 1.22478 L .42783 1.22883 L p F P
0 g
s
1 g
.63726 .7522 m .6604 .68239 L .65857 .68266 L p F P
0 g
s
1 g
.65857 .68266 m .63533 .75278 L .63726 .7522 L p F P
0 g
s
1 g
.41449 1.22478 m .43702 1.15628 L .42392 1.15154 L p F P
0 g
s
.59128 .69081 m
.5844 .71172 L
s
1 g
.56129 .96125 m .58423 .892 L .57657 .89109 L p F P
0 g
s
1 g
.57657 .89109 m .55357 .9606 L .56129 .96125 L p F P
0 g
s
1 g
.54071 .64289 m .56364 .57264 L .56566 .57278 L p F P
0 g
s
1 g
.58862 .50245 m .56566 .57278 L .56364 .57264 L p F P
0 g
s
1 g
.61639 .43344 m .63952 .36263 L .64674 .36545 L p F P
0 g
s
1 g
.66993 .29452 m .64674 .36545 L .63952 .36263 L p F P
0 g
s
1 g
.42369 1.07252 m .44627 1.00352 L .43766 .99881 L p F P
0 g
s
1 g
.46027 .92963 m .43766 .99881 L .44627 1.00352 L p F P
0 g
s
1 g
.43432 1.07763 m .41178 1.1464 L .42392 1.15154 L p F P
0 g
s
1 g
.41178 1.1464 m .43432 1.07763 L .42369 1.07252 L p F P
0 g
s
1 g
.47671 .85636 m .49947 .78667 L .49588 .784 L p F P
0 g
s
1 g
.51865 .71422 m .49588 .784 L .49947 .78667 L p F P
0 g
s
1 g
.68242 .61126 m .70572 .54099 L .70708 .54161 L p F P
0 g
s
1 g
.70708 .54161 m .68367 .6122 L .68242 .61126 L p F P
0 g
s
1 g
.46333 1.16359 m .48602 1.09484 L .47307 1.09151 L p F P
0 g
s
1 g
.47307 1.09151 m .45039 1.16036 L .46333 1.16359 L p F P
0 g
s
.59817 .66986 m
.59128 .69081 L
s
1 g
.44627 1.00352 m .42369 1.07252 L .43432 1.07763 L p F P
0 g
s
1 g
.53069 1.02973 m .55357 .9606 L .54356 .95889 L p F P
0 g
s
1 g
.54356 .95889 m .52064 1.02824 L .53069 1.02973 L p F P
0 g
s
1 g
.49785 1.0972 m .52064 1.02824 L .50884 1.02571 L p F P
0 g
s
1 g
.50884 1.02571 m .48602 1.09484 L .49785 1.0972 L p F P
0 g
s
1 g
.61222 .82251 m .63533 .75278 L .6305 .75234 L p F P
0 g
s
1 g
.6305 .75234 m .6073 .82237 L .61222 .82251 L p F P
0 g
s
1 g
.58862 .50245 m .6117 .43173 L .61639 .43344 L p F P
0 g
s
1 g
.63952 .36263 m .61639 .43344 L .6117 .43173 L p F P
0 g
s
.60507 .64888 m
.59817 .66986 L
s
1 g
.51865 .71422 m .54156 .64404 L .54071 .64289 L p F P
0 g
s
1 g
.56364 .57264 m .54071 .64289 L .54156 .64404 L p F P
0 g
s
0 0 1 r
.03 w
.63995 .82593 Mdot
.5 Mabswid
1 g
.72478 .46906 m .74822 .3983 L .75269 .39927 L p F P
0 g
s
1 g
.75269 .39927 m .72914 .47033 L .72478 .46906 L p F P
0 g
s
1 g
.44652 1.08268 m .42392 1.15154 L .43702 1.15628 L p F P
0 g
s
1 g
.42392 1.15154 m .44652 1.08268 L .43432 1.07763 L p F P
0 g
s
1 g
.46027 .92963 m .483 .86008 L .47671 .85636 L p F P
0 g
s
1 g
.49947 .78667 m .47671 .85636 L .483 .86008 L p F P
0 g
s
.615 1 0 r
.47003 .83028 m
.47755 .82459 L
s
1 g
.45039 1.16036 m .47307 1.09151 L .45967 1.08739 L p F P
0 g
s
1 g
.45967 1.08739 m .43702 1.15628 L .45039 1.16036 L p F P
0 g
s
1 g
.6604 .68239 m .68367 .6122 L .68195 .61216 L p F P
0 g
s
1 g
.68195 .61216 m .65857 .68266 L .6604 .68239 L p F P
0 g
s
.61198 .62787 m
.60507 .64888 L
s
1 g
.43702 1.15628 m .45967 1.08739 L .44652 1.08268 L p F P
0 g
s
1 g
.58423 .892 m .6073 .82237 L .5997 .82119 L p F P
0 g
s
1 g
.5997 .82119 m .57657 .89109 L .58423 .892 L p F P
0 g
s
1 g
.56364 .57264 m .58669 .50199 L .58862 .50245 L p F P
0 g
s
1 g
.6117 .43173 m .58862 .50245 L .58669 .50199 L p F P
0 g
s
1 g
.63952 .36263 m .66277 .29142 L .66993 .29452 L p F P
0 g
s
1 g
.69325 .2232 m .66993 .29452 L .66277 .29142 L p F P
0 g
s
1 g
.44627 1.00352 m .46897 .93414 L .46027 .92963 L p F P
0 g
s
1 g
.483 .86008 m .46027 .92963 L .46897 .93414 L p F P
0 g
s
1 g
.45698 1.00848 m .43432 1.07763 L .44652 1.08268 L p F P
0 g
s
1 g
.43432 1.07763 m .45698 1.00848 L .44627 1.00352 L p F P
0 g
s
.6189 .60682 m
.61198 .62787 L
s
1 g
.49947 .78667 m .52235 .7166 L .51865 .71422 L p F P
0 g
s
1 g
.54156 .64404 m .51865 .71422 L .52235 .7166 L p F P
0 g
s
1 g
.70572 .54099 m .72914 .47033 L .73061 .47063 L p F P
0 g
s
1 g
.73061 .47063 m .70708 .54161 L .70572 .54099 L p F P
0 g
s
1 g
.48602 1.09484 m .50884 1.02571 L .49588 1.02228 L p F P
0 g
s
1 g
.49588 1.02228 m .47307 1.09151 L .48602 1.09484 L p F P
0 g
s
1 g
.46897 .93414 m .44627 1.00352 L .45698 1.00848 L p F P
0 g
s
1 g
.55357 .9606 m .57657 .89109 L .56661 .88916 L p F P
0 g
s
1 g
.56661 .88916 m .54356 .95889 L .55357 .9606 L p F P
0 g
s
1 0 .231 r
.55573 .92207 m
.56668 .87714 L
s
1 g
.52064 1.02824 m .54356 .95889 L .53178 .9562 L p F P
0 g
s
1 0 .692 r
.63139 .83893 m
.63995 .82593 L
s
1 0 .923 r
.53356 .95972 m
.5404 .96877 L
s
.5404 .96877 m
.54339 .97272 L
s
1 0 .231 r
.54339 .97272 m
.54524 .96513 L
s
1 g
.53178 .9562 m .50884 1.02571 L .52064 1.02824 L p F P
0 g
s
1 g
.63533 .75278 m .65857 .68266 L .65383 .68193 L p F P
0 g
s
1 g
.65383 .68193 m .6305 .75234 L .63533 .75278 L p F P
0 g
s
.62584 .58573 m
.6189 .60682 L
s
1 g
.6117 .43173 m .63491 .36062 L .63952 .36263 L p F P
0 g
s
1 g
.66277 .29142 m .63952 .36263 L .63491 .36062 L p F P
0 g
s
1 g
.54156 .64404 m .56458 .57348 L .56364 .57264 L p F P
0 g
s
1 g
.58669 .50199 m .56364 .57264 L .56458 .57348 L p F P
0 g
s
1 g
.74822 .3983 m .7718 .32715 L .77638 .32781 L p F P
0 g
s
1 g
.77638 .32781 m .75269 .39927 L .74822 .3983 L p F P
0 g
s
1 g
.46926 1.01343 m .44652 1.08268 L .45967 1.08739 L p F P
0 g
s
1 g
.44652 1.08268 m .46926 1.01343 L .45698 1.00848 L p F P
0 g
s
1 g
.483 .86008 m .50586 .79013 L .49947 .78667 L p F P
0 g
s
1 g
.52235 .7166 m .49947 .78667 L .50586 .79013 L p F P
0 g
s
.63279 .56462 m
.62584 .58573 L
s
1 g
.47307 1.09151 m .49588 1.02228 L .48245 1.01811 L p F P
0 g
s
1 g
.48245 1.01811 m .45967 1.08739 L .47307 1.09151 L p F P
0 g
s
1 g
.68367 .6122 m .70708 .54161 L .70545 .54125 L p F P
0 g
s
1 g
.70545 .54125 m .68195 .61216 L .68367 .6122 L p F P
0 g
s
1 g
.45967 1.08739 m .48245 1.01811 L .46926 1.01343 L p F P
0 g
s
1 g
.6073 .82237 m .6305 .75234 L .62297 .75091 L p F P
0 g
s
1 g
.62297 .75091 m .5997 .82119 L .6073 .82237 L p F P
0 g
s
.385 1 0 r
.61148 .8183 m
.63995 .82593 L
s
.60661 .81699 m
.61148 .8183 L
s
.60388 .81626 m
.60661 .81699 L
s
1 g
.58669 .50199 m .60987 .43095 L .6117 .43173 L p F P
0 g
s
1 g
.63491 .36062 m .6117 .43173 L .60987 .43095 L p F P
0 g
s
.63974 .54346 m
.63279 .56462 L
s
1 g
.66277 .29142 m .68616 .21982 L .69325 .2232 L p F P
0 g
s
1 g
.71669 .15148 m .69325 .2232 L .68616 .21982 L p F P
0 g
s
1 g
.46897 .93414 m .4918 .86437 L .483 .86008 L p F P
0 g
s
1 g
.50586 .79013 m .483 .86008 L .4918 .86437 L p F P
0 g
s
.615 1 0 r
.47755 .82459 m
.48729 .81723 L
s
1 g
.47977 .93894 m .45698 1.00848 L .46926 1.01343 L p F P
0 g
s
1 g
.45698 1.00848 m .47977 .93894 L .46897 .93414 L p F P
0 g
s
1 g
.52235 .7166 m .54536 .64613 L .54156 .64404 L p F P
0 g
s
1 g
.56458 .57348 m .54156 .64404 L .54536 .64613 L p F P
0 g
s
1 g
.72914 .47033 m .75269 .39927 L .75427 .39926 L p F P
0 g
s
1 g
.75427 .39926 m .73061 .47063 L .72914 .47033 L p F P
0 g
s
1 g
.50884 1.02571 m .53178 .9562 L .51882 .95266 L p F P
0 g
s
1 g
.51882 .95266 m .49588 1.02228 L .50884 1.02571 L p F P
0 g
s
1 g
.4918 .86437 m .46897 .93414 L .47977 .93894 L p F P
0 g
s
1 g
.57657 .89109 m .5997 .82119 L .58979 .81904 L p F P
0 g
s
1 g
.58979 .81904 m .56661 .88916 L .57657 .89109 L p F P
0 g
s
.64671 .52227 m
.63974 .54346 L
s
1 g
.54356 .95889 m .56661 .88916 L .55485 .8863 L p F P
0 g
s
1 0 .231 r
.54804 .95365 m
.54817 .9531 L
s
1 g
.55485 .8863 m .53178 .9562 L .54356 .95889 L p F P
0 g
s
1 0 .231 r
.54758 .95552 m
.54804 .95365 L
s
1 g
.65857 .68266 m .68195 .61216 L .67728 .61112 L p F P
0 g
s
1 g
.67728 .61112 m .65383 .68193 L .65857 .68266 L p F P
0 g
s
1 g
.63491 .36062 m .65825 .2891 L .66277 .29142 L p F P
0 g
s
1 g
.68616 .21982 m .66277 .29142 L .65825 .2891 L p F P
0 g
s
1 g
.56458 .57348 m .58774 .50252 L .58669 .50199 L p F P
0 g
s
1 g
.60987 .43095 m .58669 .50199 L .58774 .50252 L p F P
0 g
s
.6537 .50105 m
.64671 .52227 L
s
1 g
.7718 .32715 m .7955 .2556 L .8002 .25595 L p F P
0 g
s
1 g
.8002 .25595 m .77638 .32781 L .7718 .32715 L p F P
0 g
s
1 g
.49212 .9438 m .46926 1.01343 L .48245 1.01811 L p F P
0 g
s
1 g
.46926 1.01343 m .49212 .9438 L .47977 .93894 L p F P
0 g
s
1 g
.50586 .79013 m .52885 .7198 L .52235 .7166 L p F P
0 g
s
1 g
.54536 .64613 m .52235 .7166 L .52885 .7198 L p F P
0 g
s
1 g
.49588 1.02228 m .51882 .95266 L .50536 .94845 L p F P
0 g
s
1 g
.50536 .94845 m .48245 1.01811 L .49588 1.02228 L p F P
0 g
s
1 g
.70708 .54161 m .73061 .47063 L .72908 .46995 L p F P
0 g
s
1 g
.72908 .46995 m .70545 .54125 L .70708 .54161 L p F P
0 g
s
1 g
.48245 1.01811 m .50536 .94845 L .49212 .9438 L p F P
0 g
s
.66069 .47979 m
.6537 .50105 L
s
1 g
.6305 .75234 m .65383 .68193 L .64636 .68022 L p F P
0 g
s
1 g
.64636 .68022 m .62297 .75091 L .6305 .75234 L p F P
0 g
s
1 g
.60987 .43095 m .63318 .35952 L .63491 .36062 L p F P
0 g
s
1 g
.65825 .2891 m .63491 .36062 L .63318 .35952 L p F P
0 g
s
1 g
.68616 .21982 m .70967 .14782 L .71669 .15148 L p F P
0 g
s
1 g
.4918 .86437 m .51476 .79421 L .50586 .79013 L p F P
0 g
s
1 g
.52885 .7198 m .50586 .79013 L .51476 .79421 L p F P
0 g
s
1 g
.50269 .86901 m .47977 .93894 L .49212 .9438 L p F P
0 g
s
1 0 .923 r
.48646 .89748 m
.49127 .90384 L
s
1 g
.47977 .93894 m .50269 .86901 L .4918 .86437 L p F P
0 g
s
1 g
.54536 .64613 m .56849 .57527 L .56458 .57348 L p F P
0 g
s
1 g
.58774 .50252 m .56458 .57348 L .56849 .57527 L p F P
0 g
s
1 g
.75269 .39927 m .77638 .32781 L .77807 .32748 L p F P
0 g
s
1 g
.77807 .32748 m .75427 .39926 L .75269 .39927 L p F P
0 g
s
.66769 .45849 m
.66069 .47979 L
s
1 g
.53178 .9562 m .55485 .8863 L .54189 .88265 L p F P
0 g
s
1 0 .692 r
.59957 .8873 m
.63139 .83893 L
s
1 0 .231 r
.54524 .96513 m
.54746 .95604 L
s
.54746 .95604 m
.54758 .95552 L
s
1 g
.54189 .88265 m .51882 .95266 L .53178 .9562 L p F P
0 g
s
1 0 .923 r
.52879 .95342 m
.53356 .95972 L
s
.49674 .91107 m
.52167 .94401 L
s
1 g
.51476 .79421 m .4918 .86437 L .50269 .86901 L p F P
0 g
s
1 g
.5997 .82119 m .62297 .75091 L .6131 .74852 L p F P
0 g
s
1 g
.6131 .74852 m .58979 .81904 L .5997 .82119 L p F P
0 g
s
1 g
.56661 .88916 m .58979 .81904 L .57805 .81601 L p F P
0 g
s
1 g
.57805 .81601 m .55485 .8863 L .56661 .88916 L p F P
0 g
s
1 0 .692 r
.54339 .97272 m
.59957 .8873 L
s
1 g
.68195 .61216 m .70545 .54125 L .70087 .53992 L p F P
0 g
s
1 g
.70087 .53992 m .67728 .61112 L .68195 .61216 L p F P
0 g
s
1 g
.65825 .2891 m .68172 .21719 L .68616 .21982 L p F P
0 g
s
1 g
.70967 .14782 m .68616 .21982 L .68172 .21719 L p F P
0 g
s
.67471 .43716 m
.66769 .45849 L
s
1 g
.58774 .50252 m .61103 .43116 L .60987 .43095 L p F P
0 g
s
1 g
.63318 .35952 m .60987 .43095 L .61103 .43116 L p F P
0 g
s
1 g
.7955 .2556 m .81934 .18365 L .82415 .18369 L p F P
0 g
s
1 g
.82415 .18369 m .8002 .25595 L .7955 .2556 L p F P
0 g
s
1 g
.5151 .87377 m .49212 .9438 L .50536 .94845 L p F P
0 g
s
1 g
.49212 .9438 m .5151 .87377 L .50269 .86901 L p F P
0 g
s
1 g
.52885 .7198 m .55196 .64907 L .54536 .64613 L p F P
0 g
s
1 g
.56849 .57527 m .54536 .64613 L .55196 .64907 L p F P
0 g
s
1 g
.51882 .95266 m .54189 .88265 L .5284 .8784 L p F P
0 g
s
1 g
.5284 .8784 m .50536 .94845 L .51882 .95266 L p F P
0 g
s
1 0 .923 r
.52416 .9473 m
.52486 .94823 L
s
1 g
.73061 .47063 m .75427 .39926 L .75285 .39825 L p F P
0 g
s
1 g
.75285 .39825 m .72908 .46995 L .73061 .47063 L p F P
0 g
s
.68174 .41579 m
.67471 .43716 L
s
1 g
.50536 .94845 m .5284 .8784 L .5151 .87377 L p F P
0 g
s
1 0 .923 r
.52486 .94823 m
.52879 .95342 L
s
1 g
.65383 .68193 m .67728 .61112 L .66989 .60914 L p F P
0 g
s
1 g
.66989 .60914 m .64636 .68022 L .65383 .68193 L p F P
0 g
s
1 g
.63318 .35952 m .65662 .28768 L .65825 .2891 L p F P
0 g
s
1 g
.68172 .21719 m .65825 .2891 L .65662 .28768 L p F P
0 g
s
1 g
.51476 .79421 m .53785 .72365 L .52885 .7198 L p F P
0 g
s
1 g
.55196 .64907 m .52885 .7198 L .53785 .72365 L p F P
0 g
s
1 g
.52573 .79869 m .50269 .86901 L .5151 .87377 L p F P
0 g
s
.615 1 0 r
.48729 .81723 m
.49257 .81324 L
s
1 g
.50269 .86901 m .52573 .79869 L .51476 .79421 L p F P
0 g
s
.615 1 0 r
.49257 .81324 m
.51028 .79985 L
s
0 g
.68878 .39439 m
.68174 .41579 L
s
1 g
.56849 .57527 m .59176 .50401 L .58774 .50252 L p F P
0 g
s
1 g
.61103 .43116 m .58774 .50252 L .59176 .50401 L p F P
0 g
s
1 g
.77638 .32781 m .8002 .25595 L .802 .25529 L p F P
0 g
s
1 g
.802 .25529 m .77807 .32748 L .77638 .32781 L p F P
0 g
s
1 g
.55485 .8863 m .57805 .81601 L .56508 .81225 L p F P
0 g
s
1 g
.56508 .81225 m .54189 .88265 L .55485 .8863 L p F P
0 g
s
1 g
.53785 .72365 m .51476 .79421 L .52573 .79869 L p F P
0 g
s
1 g
.62297 .75091 m .64636 .68022 L .63653 .67761 L p F P
0 g
s
1 g
.63653 .67761 m .6131 .74852 L .62297 .75091 L p F P
0 g
s
1 g
.58979 .81904 m .6131 .74852 L .60137 .74532 L p F P
0 g
s
1 g
.60137 .74532 m .57805 .81601 L .58979 .81904 L p F P
0 g
s
1 g
.70545 .54125 m .72908 .46995 L .72459 .46831 L p F P
0 g
s
1 g
.72459 .46831 m .70087 .53992 L .70545 .54125 L p F P
0 g
s
.69583 .37295 m
.68878 .39439 L
s
1 g
.68172 .21719 m .70532 .14487 L .70967 .14782 L p F P
0 g
s
1 g
.61103 .43116 m .63445 .3594 L .63318 .35952 L p F P
0 g
s
1 g
.65662 .28768 m .63318 .35952 L .63445 .3594 L p F P
0 g
s
1 g
.53822 .80336 m .5151 .87377 L .5284 .8784 L p F P
0 g
s
0 .538 1 r
.53565 .82297 m
.55209 .85167 L
s
1 g
.5151 .87377 m .53822 .80336 L .52573 .79869 L p F P
0 g
s
0 .538 1 r
.52567 .80554 m
.52615 .80639 L
s
.525 .80438 m
.52567 .80554 L
s
.52615 .80639 m
.52636 .80674 L
s
.51874 .79345 m
.525 .80438 L
s
.615 1 0 r
.51028 .79985 m
.51874 .79345 L
s
1 g
.55196 .64907 m .57521 .57794 L .56849 .57527 L p F P
0 g
s
1 g
.59176 .50401 m .56849 .57527 L .57521 .57794 L p F P
0 g
s
.70289 .35147 m
.69583 .37295 L
s
1 g
.54189 .88265 m .56508 .81225 L .55157 .80795 L p F P
0 g
s
1 g
.55157 .80795 m .5284 .8784 L .54189 .88265 L p F P
0 g
s
1 g
.75427 .39926 m .77807 .32748 L .77675 .32615 L p F P
0 g
s
1 g
.77675 .32615 m .75285 .39825 L .75427 .39926 L p F P
0 g
s
1 g
.5284 .8784 m .55157 .80795 L .53822 .80336 L p F P
0 g
s
1 g
.67728 .61112 m .70087 .53992 L .69354 .53766 L p F P
0 g
s
1 g
.69354 .53766 m .66989 .60914 L .67728 .61112 L p F P
0 g
s
1 g
.65662 .28768 m .68019 .21544 L .68172 .21719 L p F P
0 g
s
1 g
.70532 .14487 m .68172 .21719 L .68019 .21544 L p F P
0 g
s
.70997 .32996 m
.70289 .35147 L
s
1 g
.53785 .72365 m .56106 .6527 L .55196 .64907 L p F P
0 g
s
1 g
.57521 .57794 m .55196 .64907 L .56106 .6527 L p F P
0 g
s
1 g
.54891 .72798 m .52573 .79869 L .53822 .80336 L p F P
0 g
s
1 g
.52573 .79869 m .54891 .72798 L .53785 .72365 L p F P
0 g
s
.385 1 0 r
.51874 .79345 m
.53771 .79853 L
s
1 g
.59176 .50401 m .61516 .43235 L .61103 .43116 L p F P
0 g
s
1 g
.63445 .3594 m .61103 .43116 L .61516 .43235 L p F P
0 g
s
1 g
.8002 .25595 m .82415 .18369 L .82607 .1827 L p F P
0 g
s
1 g
.82607 .1827 m .802 .25529 L .8002 .25595 L p F P
0 g
s
1 g
.57805 .81601 m .60137 .74532 L .58841 .74145 L p F P
0 g
s
1 g
.58841 .74145 m .56508 .81225 L .57805 .81601 L p F P
0 g
s
1 g
.56106 .6527 m .53785 .72365 L .54891 .72798 L p F P
0 g
s
1 g
.64636 .68022 m .66989 .60914 L .66011 .6063 L p F P
0 g
s
1 g
.66011 .6063 m .63653 .67761 L .64636 .68022 L p F P
0 g
s
.71705 .30841 m
.70997 .32996 L
s
1 g
.6131 .74852 m .63653 .67761 L .62484 .67423 L p F P
0 g
s
1 g
.62484 .67423 m .60137 .74532 L .6131 .74852 L p F P
0 g
s
1 g
.72908 .46995 m .75285 .39825 L .74845 .3963 L p F P
0 g
s
1 g
.74845 .3963 m .72459 .46831 L .72908 .46995 L p F P
0 g
s
1 g
.63445 .3594 m .658 .28724 L .65662 .28768 L p F P
0 g
s
1 g
.68019 .21544 m .65662 .28768 L .658 .28724 L p F P
0 g
s
.72415 .28683 m
.71705 .30841 L
s
1 g
.56147 .73254 m .53822 .80336 L .55157 .80795 L p F P
0 g
s
1 g
.53822 .80336 m .56147 .73254 L .54891 .72798 L p F P
0 g
s
.385 1 0 r
.54228 .79976 m
.5508 .80204 L
s
.53771 .79853 m
.54228 .79976 L
s
1 0 .462 r
.51874 .79345 m
.53317 .8984 L
s
.53317 .8984 m
.54142 .9584 L
s
.54142 .9584 m
.54339 .97272 L
s
0 0 1 r
.03 w
.54339 .97272 Mdot
.5 Mabswid
1 g
.57521 .57794 m .59859 .50641 L .59176 .50401 L p F P
0 g
s
1 g
.61516 .43235 m .59176 .50401 L .59859 .50641 L p F P
0 g
s
1 g
.56508 .81225 m .58841 .74145 L .57487 .73711 L p F P
0 g
s
1 g
.57487 .73711 m .55157 .80795 L .56508 .81225 L p F P
0 g
s
1 g
.77807 .32748 m .802 .25529 L .80079 .25363 L p F P
0 g
s
1 g
.80079 .25363 m .77675 .32615 L .77807 .32748 L p F P
0 g
s
1 g
.55157 .80795 m .57487 .73711 L .56147 .73254 L p F P
0 g
s
.385 1 0 r
.55485 .80313 m
.55566 .80334 L
s
.5508 .80204 m
.55485 .80313 L
s
0 g
.73127 .26521 m
.72415 .28683 L
s
1 g
.70087 .53992 m .72459 .46831 L .71733 .46577 L p F P
0 g
s
1 g
.71733 .46577 m .69354 .53766 L .70087 .53992 L p F P
0 g
s
1 g
.68019 .21544 m .7039 .14279 L .70532 .14487 L p F P
0 g
s
1 g
.56106 .6527 m .58441 .58135 L .57521 .57794 L p F P
0 g
s
1 g
.59859 .50641 m .57521 .57794 L .58441 .58135 L p F P
0 g
s
1 g
.57221 .65686 m .54891 .72798 L .56147 .73254 L p F P
0 g
s
1 g
.54891 .72798 m .57221 .65686 L .56106 .6527 L p F P
0 g
s
1 g
.61516 .43235 m .63869 .36028 L .63445 .3594 L p F P
0 g
s
1 g
.658 .28724 m .63445 .3594 L .63869 .36028 L p F P
0 g
s
.73839 .24355 m
.73127 .26521 L
s
1 g
.60137 .74532 m .62484 .67423 L .61186 .67025 L p F P
0 g
s
1 g
.61186 .67025 m .58841 .74145 L .60137 .74532 L p F P
0 g
s
1 g
.58441 .58135 m .56106 .6527 L .57221 .65686 L p F P
0 g
s
1 g
.66989 .60914 m .69354 .53766 L .68381 .53458 L p F P
0 g
s
1 g
.68381 .53458 m .66011 .6063 L .66989 .60914 L p F P
0 g
s
1 g
.63653 .67761 m .66011 .6063 L .64843 .60274 L p F P
0 g
s
1 g
.64843 .60274 m .62484 .67423 L .63653 .67761 L p F P
0 g
s
1 g
.75285 .39825 m .77675 .32615 L .77244 .32388 L p F P
0 g
s
1 g
.77244 .32388 m .74845 .3963 L .75285 .39825 L p F P
0 g
s
.74552 .22186 m
.73839 .24355 L
s
1 g
.658 .28724 m .68168 .21466 L .68019 .21544 L p F P
0 g
s
1 g
.7039 .14279 m .68019 .21544 L .68168 .21466 L p F P
0 g
s
1 g
.58484 .66133 m .56147 .73254 L .57487 .73711 L p F P
0 g
s
1 g
.56147 .73254 m .58484 .66133 L .57221 .65686 L p F P
0 g
s
1 g
.59859 .50641 m .6221 .43447 L .61516 .43235 L p F P
0 g
s
1 g
.63869 .36028 m .61516 .43235 L .6221 .43447 L p F P
0 g
s
1 g
.58841 .74145 m .61186 .67025 L .5983 .66587 L p F P
0 g
s
1 g
.5983 .66587 m .57487 .73711 L .58841 .74145 L p F P
0 g
s
.75267 .20013 m
.74552 .22186 L
s
1 g
.802 .25529 m .82607 .1827 L .82496 .18071 L p F P
0 g
s
1 g
.82496 .18071 m .80079 .25363 L .802 .25529 L p F P
0 g
s
1 g
.57487 .73711 m .5983 .66587 L .58484 .66133 L p F P
0 g
s
1 g
.72459 .46831 m .74845 .3963 L .74126 .39348 L p F P
0 g
s
1 g
.74126 .39348 m .71733 .46577 L .72459 .46831 L p F P
0 g
s
1 g
.58441 .58135 m .60789 .5096 L .59859 .50641 L p F P
0 g
s
1 g
.6221 .43447 m .59859 .50641 L .60789 .5096 L p F P
0 g
s
1 g
.59565 .58535 m .57221 .65686 L .58484 .66133 L p F P
0 g
s
1 g
.57221 .65686 m .59565 .58535 L .58441 .58135 L p F P
0 g
s
.75983 .17837 m
.75267 .20013 L
s
1 g
.63869 .36028 m .66236 .28781 L .658 .28724 L p F P
0 g
s
1 g
.68168 .21466 m .658 .28724 L .66236 .28781 L p F P
0 g
s
1 g
.62484 .67423 m .64843 .60274 L .63545 .59864 L p F P
0 g
s
1 g
.63545 .59864 m .61186 .67025 L .62484 .67423 L p F P
0 g
s
1 g
.60789 .5096 m .58441 .58135 L .59565 .58535 L p F P
0 g
s
1 g
.69354 .53766 m .71733 .46577 L .70765 .46246 L p F P
0 g
s
1 g
.70765 .46246 m .68381 .53458 L .69354 .53766 L p F P
0 g
s
1 g
.66011 .6063 m .68381 .53458 L .67216 .53085 L p F P
0 g
s
1 g
.67216 .53085 m .64843 .60274 L .66011 .6063 L p F P
0 g
s
.767 .15656 m
.75983 .17837 L
s
1 g
.77675 .32615 m .80079 .25363 L .79657 .25105 L p F P
0 g
s
1 g
.79657 .25105 m .77244 .32388 L .77675 .32615 L p F P
0 g
s
1 g
.68168 .21466 m .7055 .14168 L .7039 .14279 L p F P
0 g
s
1 g
.60835 .58971 m .58484 .66133 L .5983 .66587 L p F P
0 g
s
1 g
.58484 .66133 m .60835 .58971 L .59565 .58535 L p F P
0 g
s
1 g
.6221 .43447 m .64574 .36213 L .63869 .36028 L p F P
0 g
s
1 g
.66236 .28781 m .63869 .36028 L .64574 .36213 L p F P
0 g
s
.77419 .13472 m
.767 .15656 L
s
1 g
.61186 .67025 m .63545 .59864 L .62186 .59422 L p F P
0 g
s
1 g
.62186 .59422 m .5983 .66587 L .61186 .67025 L p F P
0 g
s
1 g
.5983 .66587 m .62186 .59422 L .60835 .58971 L p F P
0 g
s
1 g
.74845 .3963 m .77244 .32388 L .76532 .32077 L p F P
0 g
s
1 g
.76532 .32077 m .74126 .39348 L .74845 .3963 L p F P
0 g
s
.78138 .11284 m
.77419 .13472 L
s
1 g
.60789 .5096 m .63151 .43744 L .6221 .43447 L p F P
0 g
s
1 g
.64574 .36213 m .6221 .43447 L .63151 .43744 L p F P
0 g
s
1 g
.61922 .51342 m .59565 .58535 L .60835 .58971 L p F P
0 g
s
1 g
.59565 .58535 m .61922 .51342 L .60789 .5096 L p F P
0 g
s
1 g
.66236 .28781 m .68616 .21492 L .68168 .21466 L p F P
0 g
s
1 g
.7055 .14168 m .68168 .21466 L .68616 .21492 L p F P
0 g
s
0 0 1 r
.03 w
.51874 .79345 Mdot
.5 Mabswid
1 g
.64843 .60274 m .67216 .53085 L .65918 .52664 L p F P
0 g
s
1 g
.65918 .52664 m .63545 .59864 L .64843 .60274 L p F P
0 g
s
1 g
.63151 .43744 m .60789 .5096 L .61922 .51342 L p F P
0 g
s
1 g
.71733 .46577 m .74126 .39348 L .73162 .38993 L p F P
0 g
s
1 g
.73162 .38993 m .70765 .46246 L .71733 .46577 L p F P
0 g
s
.78859 .09093 m
.78138 .11284 L
s
1 g
.68381 .53458 m .70765 .46246 L .69602 .45854 L p F P
0 g
s
1 g
.69602 .45854 m .67216 .53085 L .68381 .53458 L p F P
0 g
s
1 g
.80079 .25363 m .82496 .18071 L .82083 .1778 L p F P
0 g
s
1 g
.82083 .1778 m .79657 .25105 L .80079 .25363 L p F P
0 g
s
.79581 .06898 m
.78859 .09093 L
s
1 g
.632 .51769 m .60835 .58971 L .62186 .59422 L p F P
0 g
s
1 g
.60835 .58971 m .632 .51769 L .61922 .51342 L p F P
0 g
s
1 g
.64574 .36213 m .66951 .28938 L .66236 .28781 L p F P
0 g
s
1 g
.68616 .21492 m .66236 .28781 L .66951 .28938 L p F P
0 g
s
1 g
.63545 .59864 m .65918 .52664 L .64555 .52217 L p F P
0 g
s
1 g
.64555 .52217 m .62186 .59422 L .63545 .59864 L p F P
0 g
s
1 g
.62186 .59422 m .64555 .52217 L .632 .51769 L p F P
0 g
s
.80304 .04699 m
.79581 .06898 L
s
1 g
.77244 .32388 m .79657 .25105 L .78952 .24765 L p F P
0 g
s
1 g
.78952 .24765 m .76532 .32077 L .77244 .32388 L p F P
0 g
s
1 g
.63151 .43744 m .65525 .36487 L .64574 .36213 L p F P
0 g
s
1 g
.66951 .28938 m .64574 .36213 L .65525 .36487 L p F P
0 g
s
1 g
.64293 .44109 m .61922 .51342 L .632 .51769 L p F P
0 g
s
1 g
.61922 .51342 m .64293 .44109 L .63151 .43744 L p F P
0 g
s
1 g
.68616 .21492 m .71009 .14162 L .7055 .14168 L p F P
0 g
s
1 g
.67216 .53085 m .69602 .45854 L .68304 .45422 L p F P
0 g
s
1 g
.68304 .45422 m .65918 .52664 L .67216 .53085 L p F P
0 g
s
1 g
.65525 .36487 m .63151 .43744 L .64293 .44109 L p F P
0 g
s
1 g
.74126 .39348 m .76532 .32077 L .75574 .31698 L p F P
0 g
s
1 g
.75574 .31698 m .73162 .38993 L .74126 .39348 L p F P
0 g
s
1 g
.70765 .46246 m .73162 .38993 L .72002 .38583 L p F P
0 g
s
1 g
.72002 .38583 m .69602 .45854 L .70765 .46246 L p F P
0 g
s
1 g
.65578 .44526 m .632 .51769 L .64555 .52217 L p F P
0 g
s
1 g
.632 .51769 m .65578 .44526 L .64293 .44109 L p F P
0 g
s
1 g
.66951 .28938 m .69343 .21621 L .68616 .21492 L p F P
0 g
s
1 g
.71009 .14162 m .68616 .21492 L .69343 .21621 L p F P
0 g
s
1 g
.65918 .52664 m .68304 .45422 L .66938 .44971 L p F P
0 g
s
1 g
.66938 .44971 m .64555 .52217 L .65918 .52664 L p F P
0 g
s
1 g
.64555 .52217 m .66938 .44971 L .65578 .44526 L p F P
0 g
s
1 g
.79657 .25105 m .82083 .1778 L .81386 .17411 L p F P
0 g
s
1 g
.81386 .17411 m .78952 .24765 L .79657 .25105 L p F P
0 g
s
1 g
.65525 .36487 m .67913 .29188 L .66951 .28938 L p F P
0 g
s
1 g
.69343 .21621 m .66951 .28938 L .67913 .29188 L p F P
0 g
s
1 g
.66677 .36835 m .64293 .44109 L .65578 .44526 L p F P
0 g
s
1 g
.64293 .44109 m .66677 .36835 L .65525 .36487 L p F P
0 g
s
1 g
.69602 .45854 m .72002 .38583 L .70703 .38138 L p F P
0 g
s
1 g
.70703 .38138 m .68304 .45422 L .69602 .45854 L p F P
0 g
s
1 g
.67913 .29188 m .65525 .36487 L .66677 .36835 L p F P
0 g
s
1 g
.76532 .32077 m .78952 .24765 L .77999 .24362 L p F P
0 g
s
1 g
.77999 .24362 m .75574 .31698 L .76532 .32077 L p F P
0 g
s
1 g
.73162 .38993 m .75574 .31698 L .74415 .31269 L p F P
0 g
s
1 g
.74415 .31269 m .72002 .38583 L .73162 .38993 L p F P
0 g
s
1 g
.67969 .37241 m .65578 .44526 L .66938 .44971 L p F P
0 g
s
1 g
.65578 .44526 m .67969 .37241 L .66677 .36835 L p F P
0 g
s
1 g
.69343 .21621 m .71748 .14263 L .71009 .14162 L p F P
0 g
s
1 g
.68304 .45422 m .70703 .38138 L .69335 .37683 L p F P
0 g
s
1 g
.69335 .37683 m .66938 .44971 L .68304 .45422 L p F P
0 g
s
1 g
.66938 .44971 m .69335 .37683 L .67969 .37241 L p F P
0 g
s
1 g
.67913 .29188 m .70315 .21848 L .69343 .21621 L p F P
0 g
s
1 g
.71748 .14263 m .69343 .21621 L .70315 .21848 L p F P
0 g
s
1 g
.69074 .29519 m .66677 .36835 L .67969 .37241 L p F P
0 g
s
1 g
.66677 .36835 m .69074 .29519 L .67913 .29188 L p F P
0 g
s
1 g
.72002 .38583 m .74415 .31269 L .73117 .30813 L p F P
0 g
s
1 g
.73117 .30813 m .70703 .38138 L .72002 .38583 L p F P
0 g
s
1 g
.70315 .21848 m .67913 .29188 L .69074 .29519 L p F P
0 g
s
1 g
.78952 .24765 m .81386 .17411 L .80437 .16983 L p F P
0 g
s
1 g
.80437 .16983 m .77999 .24362 L .78952 .24765 L p F P
0 g
s
1 g
.75574 .31698 m .77999 .24362 L .76843 .23914 L p F P
0 g
s
1 g
.76843 .23914 m .74415 .31269 L .75574 .31698 L p F P
0 g
s
1 g
.70374 .29915 m .67969 .37241 L .69335 .37683 L p F P
0 g
s
1 g
.67969 .37241 m .70374 .29915 L .69074 .29519 L p F P
0 g
s
1 g
.70703 .38138 m .73117 .30813 L .71746 .30354 L p F P
0 g
s
1 g
.71746 .30354 m .69335 .37683 L .70703 .38138 L p F P
0 g
s
1 g
.69335 .37683 m .71746 .30354 L .70374 .29915 L p F P
0 g
s
1 g
.70315 .21848 m .72731 .14466 L .71748 .14263 L p F P
0 g
s
1 g
.71485 .22161 m .69074 .29519 L .70374 .29915 L p F P
0 g
s
1 g
.69074 .29519 m .71485 .22161 L .70315 .21848 L p F P
0 g
s
1 g
.74415 .31269 m .76843 .23914 L .75544 .23446 L p F P
0 g
s
1 g
.75544 .23446 m .73117 .30813 L .74415 .31269 L p F P
0 g
s
1 g
.72731 .14466 m .70315 .21848 L .71485 .22161 L p F P
0 g
s
1 g
.77999 .24362 m .80437 .16983 L .79284 .16517 L p F P
0 g
s
1 g
.79284 .16517 m .76843 .23914 L .77999 .24362 L p F P
0 g
s
1 g
.72793 .22546 m .70374 .29915 L .71746 .30354 L p F P
0 g
s
1 g
.70374 .29915 m .72793 .22546 L .71485 .22161 L p F P
0 g
s
1 g
.73117 .30813 m .75544 .23446 L .7417 .22982 L p F P
0 g
s
1 g
.7417 .22982 m .71746 .30354 L .73117 .30813 L p F P
0 g
s
1 g
.71746 .30354 m .7417 .22982 L .72793 .22546 L p F P
0 g
s
1 g
.73911 .14761 m .71485 .22161 L .72793 .22546 L p F P
0 g
s
1 g
.71485 .22161 m .73911 .14761 L .72731 .14466 L p F P
0 g
s
1 g
.76843 .23914 m .79284 .16517 L .77985 .16036 L p F P
0 g
s
1 g
.77985 .16036 m .75544 .23446 L .76843 .23914 L p F P
0 g
s
1 g
.75226 .15135 m .72793 .22546 L .7417 .22982 L p F P
0 g
s
1 g
.72793 .22546 m .75226 .15135 L .73911 .14761 L p F P
0 g
s
1 g
.75544 .23446 m .77985 .16036 L .76608 .15568 L p F P
0 g
s
1 g
.76608 .15568 m .7417 .22982 L .75544 .23446 L p F P
0 g
s
1 g
.7417 .22982 m .76608 .15568 L .75226 .15135 L p F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0183176 0.97619 0.751023 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.81893e-18 1.14595 -0.205014 1.14595 [
[ 0 0 0 0 ]
[ 1 .60476 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .60476 L
0 .60476 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.35544 .51533 m
.35051 .51897 L
s
.36042 .51166 m
.35544 .51533 L
s
.36545 .50794 m
.36042 .51166 L
s
1 g
.39719 .43273 m .37982 .44643 L .36831 .44515 L p F P
0 g
s
.37053 .50419 m
.36545 .50794 L
s
1 g
.38555 .43138 m .36831 .44515 L .35715 .44653 L p F P
0 g
s
1 g
.36831 .44515 m .38555 .43138 L .39719 .43273 L p F P
0 g
s
1 g
.42215 .53322 m .44038 .52092 L .43364 .52977 L p F P
0 g
s
1 g
.43364 .52977 m .41545 .54197 L .42215 .53322 L p F P
0 g
s
.37566 .5004 m
.37053 .50419 L
s
1 g
.37427 .43272 m .35715 .44653 L .34689 .45054 L p F P
0 g
s
1 g
.35715 .44653 m .37427 .43272 L .38555 .43138 L p F P
0 g
s
1 g
.41545 .54197 m .43364 .52977 L .42491 .53654 L p F P
0 g
s
1 g
.42491 .53654 m .40679 .54868 L .41545 .54197 L p F P
0 g
s
1 g
.3639 .43674 m .34689 .45054 L .33804 .45701 L p F P
0 g
s
1 g
.34689 .45054 m .3639 .43674 L .37427 .43272 L p F P
0 g
s
.38085 .49658 m
.37566 .5004 L
s
1 g
.40679 .54868 m .42491 .53654 L .4146 .54086 L p F P
0 g
s
1 g
.4146 .54086 m .39657 .55298 L .40679 .54868 L p F P
0 g
s
1 g
.33804 .45701 m .35498 .44326 L .3639 .43674 L p F P
0 g
s
1 g
.35498 .44326 m .33804 .45701 L .33106 .46565 L p F P
0 g
s
1 g
.41517 .41855 m .39719 .43273 L .38555 .43138 L p F P
0 g
s
.38608 .49271 m
.38085 .49658 L
s
1 g
.39657 .55298 m .4146 .54086 L .40319 .54249 L p F P
0 g
s
1 g
.40319 .54249 m .38529 .55463 L .39657 .55298 L p F P
0 g
s
1 g
.40339 .41712 m .38555 .43138 L .37427 .43272 L p F P
0 g
s
1 g
.38555 .43138 m .40339 .41712 L .41517 .41855 L p F P
0 g
s
1 g
.34796 .45199 m .33106 .46565 L .32634 .47605 L p F P
0 g
s
1 g
.33106 .46565 m .34796 .45199 L .35498 .44326 L p F P
0 g
s
.39138 .4888 m
.38608 .49271 L
s
1 g
.44038 .52092 m .45924 .50819 L .45248 .51714 L p F P
0 g
s
1 g
.45248 .51714 m .43364 .52977 L .44038 .52092 L p F P
0 g
s
1 g
.38529 .55463 m .40319 .54249 L .39127 .5413 L p F P
0 g
s
1 g
.39127 .5413 m .3735 .55351 L .38529 .55463 L p F P
0 g
s
1 g
.39199 .41844 m .37427 .43272 L .3639 .43674 L p F P
0 g
s
1 g
.37427 .43272 m .39199 .41844 L .40339 .41712 L p F P
0 g
s
1 g
.34322 .46252 m .32634 .47605 L .32414 .48771 L p F P
0 g
s
1 g
.32634 .47605 m .34322 .46252 L .34796 .45199 L p F P
0 g
s
.39672 .48485 m
.39138 .4888 L
s
1 g
.3735 .55351 m .39127 .5413 L .37944 .53733 L p F P
0 g
s
1 g
.37944 .53733 m .36183 .54964 L .3735 .55351 L p F P
0 g
s
1 g
.34104 .47434 m .32414 .48771 L .3246 .50002 L p F P
0 g
s
1 g
.32414 .48771 m .34104 .47434 L .34322 .46252 L p F P
0 g
s
1 g
.43364 .52977 m .45248 .51714 L .44368 .52397 L p F P
0 g
s
1 g
.44368 .52397 m .42491 .53654 L .43364 .52977 L p F P
0 g
s
1 g
.38152 .42246 m .3639 .43674 L .35498 .44326 L p F P
0 g
s
1 g
.3639 .43674 m .38152 .42246 L .39199 .41844 L p F P
0 g
s
1 g
.36183 .54964 m .37944 .53733 L .36832 .53076 L p F P
0 g
s
1 g
.36832 .53076 m .35087 .54321 L .36183 .54964 L p F P
0 g
s
1 g
.34156 .48683 m .3246 .50002 L .32772 .51236 L p F P
0 g
s
1 g
.3246 .50002 m .34156 .48683 L .34104 .47434 L p F P
0 g
s
1 g
.35087 .54321 m .36832 .53076 L .35851 .52192 L p F P
0 g
s
1 g
.35851 .52192 m .34121 .53454 L .35087 .54321 L p F P
0 g
s
.40213 .48086 m
.39672 .48485 L
s
1 g
.42491 .53654 m .44368 .52397 L .43326 .52831 L p F P
0 g
s
1 g
.43326 .52831 m .4146 .54086 L .42491 .53654 L p F P
0 g
s
1 g
.34477 .49936 m .32772 .51236 L .33335 .52407 L p F P
0 g
s
1 g
.32772 .51236 m .34477 .49936 L .34156 .48683 L p F P
0 g
s
1 g
.35498 .44326 m .37252 .42902 L .38152 .42246 L p F P
0 g
s
1 g
.37252 .42902 m .35498 .44326 L .34796 .45199 L p F P
0 g
s
1 g
.34121 .53454 m .35851 .52192 L .35052 .51127 L p F P
0 g
s
1 g
.35052 .51127 m .33335 .52407 L .34121 .53454 L p F P
0 g
s
1 g
.33335 .52407 m .35052 .51127 L .34477 .49936 L p F P
0 g
s
1 g
.43378 .40387 m .41517 .41855 L .40339 .41712 L p F P
0 g
s
1 g
.4146 .54086 m .43326 .52831 L .42173 .52991 L p F P
0 g
s
1 g
.42173 .52991 m .40319 .54249 L .4146 .54086 L p F P
0 g
s
1 g
.42186 .40237 m .40339 .41712 L .39199 .41844 L p F P
0 g
s
1 g
.40339 .41712 m .42186 .40237 L .43378 .40387 L p F P
0 g
s
.40759 .47683 m
.40213 .48086 L
s
1 g
.36545 .43785 m .34796 .45199 L .34322 .46252 L p F P
0 g
s
1 g
.34796 .45199 m .36545 .43785 L .37252 .42902 L p F P
0 g
s
1 g
.45924 .50819 m .47878 .49501 L .47198 .50405 L p F P
0 g
s
1 g
.47198 .50405 m .45248 .51714 L .45924 .50819 L p F P
0 g
s
1 g
.40319 .54249 m .42173 .52991 L .40967 .52866 L p F P
0 g
s
1 g
.40967 .52866 m .39127 .5413 L .40319 .54249 L p F P
0 g
s
1 g
.41034 .40364 m .39199 .41844 L .38152 .42246 L p F P
0 g
s
1 g
.39199 .41844 m .41034 .40364 L .42186 .40237 L p F P
0 g
s
1 g
.3607 .44851 m .34322 .46252 L .34104 .47434 L p F P
0 g
s
1 g
.34322 .46252 m .3607 .44851 L .36545 .43785 L p F P
0 g
s
.41311 .47276 m
.40759 .47683 L
s
1 g
.39127 .5413 m .40967 .52866 L .39768 .52458 L p F P
0 g
s
1 g
.39768 .52458 m .37944 .53733 L .39127 .5413 L p F P
0 g
s
1 g
.35855 .46048 m .34104 .47434 L .34156 .48683 L p F P
0 g
s
1 g
.34104 .47434 m .35855 .46048 L .3607 .44851 L p F P
0 g
s
1 g
.45248 .51714 m .47198 .50405 L .46312 .51094 L p F P
0 g
s
1 g
.46312 .51094 m .44368 .52397 L .45248 .51714 L p F P
0 g
s
1 g
.39977 .40766 m .38152 .42246 L .37252 .42902 L p F P
0 g
s
1 g
.38152 .42246 m .39977 .40766 L .41034 .40364 L p F P
0 g
s
1 g
.37944 .53733 m .39768 .52458 L .3864 .51786 L p F P
0 g
s
1 g
.3864 .51786 m .36832 .53076 L .37944 .53733 L p F P
0 g
s
.41868 .46864 m
.41311 .47276 L
s
1 g
.35912 .47316 m .34156 .48683 L .34477 .49936 L p F P
0 g
s
1 g
.34156 .48683 m .35912 .47316 L .35855 .46048 L p F P
0 g
s
1 g
.36832 .53076 m .3864 .51786 L .37643 .50885 L p F P
0 g
s
1 g
.37643 .50885 m .35851 .52192 L .36832 .53076 L p F P
0 g
s
1 g
.44368 .52397 m .46312 .51094 L .45261 .51531 L p F P
0 g
s
1 g
.45261 .51531 m .43326 .52831 L .44368 .52397 L p F P
0 g
s
1 g
.36243 .48589 m .34477 .49936 L .35052 .51127 L p F P
0 g
s
1 g
.34477 .49936 m .36243 .48589 L .35912 .47316 L p F P
0 g
s
1 g
.37252 .42902 m .39069 .41428 L .39977 .40766 L p F P
0 g
s
1 g
.39069 .41428 m .37252 .42902 L .36545 .43785 L p F P
0 g
s
1 g
.35851 .52192 m .37643 .50885 L .3683 .498 L p F P
0 g
s
1 g
.3683 .498 m .35052 .51127 L .35851 .52192 L p F P
0 g
s
1 g
.35052 .51127 m .3683 .498 L .36243 .48589 L p F P
0 g
s
1 g
.45307 .38866 m .43378 .40387 L .42186 .40237 L p F P
0 g
s
.42432 .46447 m
.41868 .46864 L
s
1 g
.43326 .52831 m .45261 .51531 L .44095 .51688 L p F P
0 g
s
1 g
.44095 .51688 m .42173 .52991 L .43326 .52831 L p F P
0 g
s
1 g
.44101 .38707 m .42186 .40237 L .41034 .40364 L p F P
0 g
s
1 g
.42186 .40237 m .44101 .38707 L .45307 .38866 L p F P
0 g
s
1 g
.38358 .42319 m .36545 .43785 L .3607 .44851 L p F P
0 g
s
1 g
.36545 .43785 m .38358 .42319 L .39069 .41428 L p F P
0 g
s
1 g
.47878 .49501 m .49903 .48134 L .49221 .49049 L p F P
0 g
s
1 g
.49221 .49049 m .47198 .50405 L .47878 .49501 L p F P
0 g
s
.43002 .46027 m
.42432 .46447 L
s
1 g
.42173 .52991 m .44095 .51688 L .42874 .51555 L p F P
0 g
s
1 g
.42874 .51555 m .40967 .52866 L .42173 .52991 L p F P
0 g
s
1 g
.42936 .3883 m .41034 .40364 L .39977 .40766 L p F P
0 g
s
1 g
.41034 .40364 m .42936 .3883 L .44101 .38707 L p F P
0 g
s
1 g
.37882 .43398 m .3607 .44851 L .35855 .46048 L p F P
0 g
s
1 g
.3607 .44851 m .37882 .43398 L .38358 .42319 L p F P
0 g
s
1 g
.40967 .52866 m .42874 .51555 L .41659 .51136 L p F P
0 g
s
1 g
.41659 .51136 m .39768 .52458 L .40967 .52866 L p F P
0 g
s
1 g
.37669 .44612 m .35855 .46048 L .35912 .47316 L p F P
0 g
s
1 g
.35855 .46048 m .37669 .44612 L .37882 .43398 L p F P
0 g
s
1 g
.47198 .50405 m .49221 .49049 L .48328 .49744 L p F P
0 g
s
1 g
.48328 .49744 m .46312 .51094 L .47198 .50405 L p F P
0 g
s
1 g
.41868 .39232 m .39977 .40766 L .39069 .41428 L p F P
0 g
s
1 g
.39977 .40766 m .41868 .39232 L .42936 .3883 L p F P
0 g
s
.43578 .45602 m
.43002 .46027 L
s
1 g
.39768 .52458 m .41659 .51136 L .40515 .50449 L p F P
0 g
s
1 g
.40515 .50449 m .3864 .51786 L .39768 .52458 L p F P
0 g
s
1 g
.37734 .45899 m .35912 .47316 L .36243 .48589 L p F P
0 g
s
1 g
.35912 .47316 m .37734 .45899 L .37669 .44612 L p F P
0 g
s
1 g
.3864 .51786 m .40515 .50449 L .39501 .49529 L p F P
0 g
s
1 g
.39501 .49529 m .37643 .50885 L .3864 .51786 L p F P
0 g
s
1 g
.46312 .51094 m .48328 .49744 L .47267 .50182 L p F P
0 g
s
1 g
.47267 .50182 m .45261 .51531 L .46312 .51094 L p F P
0 g
s
1 g
.38073 .47193 m .36243 .48589 L .3683 .498 L p F P
0 g
s
1 g
.36243 .48589 m .38073 .47193 L .37734 .45899 L p F P
0 g
s
1 g
.39069 .41428 m .40953 .39899 L .41868 .39232 L p F P
0 g
s
1 g
.40953 .39899 m .39069 .41428 L .38358 .42319 L p F P
0 g
s
1 g
.37643 .50885 m .39501 .49529 L .38673 .48424 L p F P
0 g
s
1 g
.38673 .48424 m .3683 .498 L .37643 .50885 L p F P
0 g
s
1 g
.3683 .498 m .38673 .48424 L .38073 .47193 L p F P
0 g
s
1 g
.47307 .3729 m .45307 .38866 L .44101 .38707 L p F P
0 g
s
.4416 .45172 m
.43578 .45602 L
s
1 g
.45261 .51531 m .47267 .50182 L .46088 .50336 L p F P
0 g
s
1 g
.46088 .50336 m .44095 .51688 L .45261 .51531 L p F P
0 g
s
1 g
.46086 .37121 m .44101 .38707 L .42936 .3883 L p F P
0 g
s
1 g
.44101 .38707 m .46086 .37121 L .47307 .3729 L p F P
0 g
s
1 g
.40238 .40799 m .38358 .42319 L .37882 .43398 L p F P
0 g
s
1 g
.38358 .42319 m .40238 .40799 L .40953 .39899 L p F P
0 g
s
.44749 .44737 m
.4416 .45172 L
s
1 g
.49903 .48134 m .52003 .46717 L .51318 .47642 L p F P
0 g
s
1 g
.51318 .47642 m .49221 .49049 L .49903 .48134 L p F P
0 g
s
1 g
.44095 .51688 m .46088 .50336 L .44852 .50196 L p F P
0 g
s
1 g
.44852 .50196 m .42874 .51555 L .44095 .51688 L p F P
0 g
s
1 g
.44908 .37239 m .42936 .3883 L .41868 .39232 L p F P
0 g
s
1 g
.42936 .3883 m .44908 .37239 L .46086 .37121 L p F P
0 g
s
1 g
.39761 .41892 m .37882 .43398 L .37669 .44612 L p F P
0 g
s
1 g
.37882 .43398 m .39761 .41892 L .40238 .40799 L p F P
0 g
s
.45344 .44298 m
.44749 .44737 L
s
1 g
.42874 .51555 m .44852 .50196 L .43621 .49764 L p F P
0 g
s
1 g
.43621 .49764 m .41659 .51136 L .42874 .51555 L p F P
0 g
s
1 g
.39552 .43123 m .37669 .44612 L .37734 .45899 L p F P
0 g
s
1 g
.37669 .44612 m .39552 .43123 L .39761 .41892 L p F P
0 g
s
1 g
.49221 .49049 m .51318 .47642 L .50419 .48343 L p F P
0 g
s
1 g
.50419 .48343 m .48328 .49744 L .49221 .49049 L p F P
0 g
s
1 g
.4383 .37641 m .41868 .39232 L .40953 .39899 L p F P
0 g
s
1 g
.41868 .39232 m .4383 .37641 L .44908 .37239 L p F P
0 g
s
1 g
.41659 .51136 m .43621 .49764 L .42459 .49061 L p F P
0 g
s
1 g
.42459 .49061 m .40515 .50449 L .41659 .51136 L p F P
0 g
s
1 g
.39623 .44429 m .37734 .45899 L .38073 .47193 L p F P
0 g
s
1 g
.37734 .45899 m .39623 .44429 L .39552 .43123 L p F P
0 g
s
.45945 .43853 m
.45344 .44298 L
s
1 g
.40515 .50449 m .42459 .49061 L .41429 .48123 L p F P
0 g
s
1 g
.41429 .48123 m .39501 .49529 L .40515 .50449 L p F P
0 g
s
1 g
.48328 .49744 m .50419 .48343 L .49348 .48782 L p F P
0 g
s
1 g
.49348 .48782 m .47267 .50182 L .48328 .49744 L p F P
0 g
s
1 g
.39973 .45744 m .38073 .47193 L .38673 .48424 L p F P
0 g
s
1 g
.38073 .47193 m .39973 .45744 L .39623 .44429 L p F P
0 g
s
1 g
.40953 .39899 m .42908 .38312 L .4383 .37641 L p F P
0 g
s
1 g
.42908 .38312 m .40953 .39899 L .40238 .40799 L p F P
0 g
s
1 g
.39501 .49529 m .41429 .48123 L .40586 .46997 L p F P
0 g
s
1 g
.40586 .46997 m .38673 .48424 L .39501 .49529 L p F P
0 g
s
1 g
.38673 .48424 m .40586 .46997 L .39973 .45744 L p F P
0 g
s
1 g
.49381 .35654 m .47307 .3729 L .46086 .37121 L p F P
0 g
s
1 g
.47267 .50182 m .49348 .48782 L .48157 .48933 L p F P
0 g
s
1 g
.48157 .48933 m .46088 .50336 L .47267 .50182 L p F P
0 g
s
1 g
.48146 .35475 m .46086 .37121 L .44908 .37239 L p F P
0 g
s
1 g
.46086 .37121 m .48146 .35475 L .49381 .35654 L p F P
0 g
s
.46554 .43404 m
.45945 .43853 L
s
1 g
.42188 .39222 m .40238 .40799 L .39761 .41892 L p F P
0 g
s
1 g
.40238 .40799 m .42188 .39222 L .42908 .38312 L p F P
0 g
s
1 g
.52003 .46717 m .54183 .45246 L .53495 .46182 L p F P
0 g
s
1 g
.53495 .46182 m .51318 .47642 L .52003 .46717 L p F P
0 g
s
1 g
.46088 .50336 m .48157 .48933 L .46905 .48785 L p F P
0 g
s
1 g
.46905 .48785 m .44852 .50196 L .46088 .50336 L p F P
0 g
s
1 g
.46955 .35588 m .44908 .37239 L .4383 .37641 L p F P
0 g
s
1 g
.44908 .37239 m .46955 .35588 L .48146 .35475 L p F P
0 g
s
1 g
.41712 .40328 m .39761 .41892 L .39552 .43123 L p F P
0 g
s
1 g
.39761 .41892 m .41712 .40328 L .42188 .39222 L p F P
0 g
s
.47169 .4295 m
.46554 .43404 L
s
1 g
.44852 .50196 m .46905 .48785 L .45657 .4834 L p F P
0 g
s
1 g
.45657 .4834 m .43621 .49764 L .44852 .50196 L p F P
0 g
s
1 g
.41505 .41577 m .39552 .43123 L .39623 .44429 L p F P
0 g
s
1 g
.39552 .43123 m .41505 .41577 L .41712 .40328 L p F P
0 g
s
1 g
.51318 .47642 m .53495 .46182 L .5259 .46889 L p F P
0 g
s
1 g
.5259 .46889 m .50419 .48343 L .51318 .47642 L p F P
0 g
s
1 g
.45867 .3599 m .4383 .37641 L .42908 .38312 L p F P
0 g
s
1 g
.4383 .37641 m .45867 .3599 L .46955 .35588 L p F P
0 g
s
1 g
.43621 .49764 m .45657 .4834 L .44478 .47621 L p F P
0 g
s
1 g
.44478 .47621 m .42459 .49061 L .43621 .49764 L p F P
0 g
s
.47791 .42491 m
.47169 .4295 L
s
1 g
.41584 .42903 m .39623 .44429 L .39973 .45744 L p F P
0 g
s
1 g
.39623 .44429 m .41584 .42903 L .41505 .41577 L p F P
0 g
s
1 g
.42459 .49061 m .44478 .47621 L .43431 .46663 L p F P
0 g
s
1 g
.43431 .46663 m .41429 .48123 L .42459 .49061 L p F P
0 g
s
1 g
.50419 .48343 m .5259 .46889 L .51509 .47329 L p F P
0 g
s
1 g
.51509 .47329 m .49348 .48782 L .50419 .48343 L p F P
0 g
s
1 g
.41945 .4424 m .39973 .45744 L .40586 .46997 L p F P
0 g
s
1 g
.39973 .45744 m .41945 .4424 L .41584 .42903 L p F P
0 g
s
1 g
.42908 .38312 m .44937 .36665 L .45867 .3599 L p F P
0 g
s
1 g
.44937 .36665 m .42908 .38312 L .42188 .39222 L p F P
0 g
s
1 g
.41429 .48123 m .43431 .46663 L .42571 .45516 L p F P
0 g
s
1 g
.42571 .45516 m .40586 .46997 L .41429 .48123 L p F P
0 g
s
1 g
.40586 .46997 m .42571 .45516 L .41945 .4424 L p F P
0 g
s
1 g
.51535 .33955 m .49381 .35654 L .48146 .35475 L p F P
0 g
s
.4842 .42026 m
.47791 .42491 L
s
1 g
.49348 .48782 m .51509 .47329 L .50305 .47476 L p F P
0 g
s
1 g
.50305 .47476 m .48157 .48933 L .49348 .48782 L p F P
0 g
s
1 g
.50285 .33767 m .48146 .35475 L .46955 .35588 L p F P
0 g
s
1 g
.48146 .35475 m .50285 .33767 L .51535 .33955 L p F P
0 g
s
1 g
.44214 .37585 m .42188 .39222 L .41712 .40328 L p F P
0 g
s
1 g
.42188 .39222 m .44214 .37585 L .44937 .36665 L p F P
0 g
s
1 g
.54183 .45246 m .56446 .43719 L .55757 .44665 L p F P
0 g
s
1 g
.55757 .44665 m .53495 .46182 L .54183 .45246 L p F P
0 g
s
.49056 .41556 m
.4842 .42026 L
s
1 g
.48157 .48933 m .50305 .47476 L .49038 .47319 L p F P
0 g
s
1 g
.49038 .47319 m .46905 .48785 L .48157 .48933 L p F P
0 g
s
1 g
.49081 .33873 m .46955 .35588 L .45867 .3599 L p F P
0 g
s
1 g
.46955 .35588 m .49081 .33873 L .50285 .33767 L p F P
0 g
s
1 g
.43737 .38705 m .41712 .40328 L .41505 .41577 L p F P
0 g
s
1 g
.41712 .40328 m .43737 .38705 L .44214 .37585 L p F P
0 g
s
1 g
.46905 .48785 m .49038 .47319 L .47772 .46861 L p F P
0 g
s
1 g
.47772 .46861 m .45657 .4834 L .46905 .48785 L p F P
0 g
s
1 g
.43535 .39971 m .41505 .41577 L .41584 .42903 L p F P
0 g
s
1 g
.41505 .41577 m .43535 .39971 L .43737 .38705 L p F P
0 g
s
1 g
.53495 .46182 m .55757 .44665 L .54845 .45378 L p F P
0 g
s
1 g
.54845 .45378 m .5259 .46889 L .53495 .46182 L p F P
0 g
s
1 g
.47982 .34274 m .45867 .3599 L .44937 .36665 L p F P
0 g
s
1 g
.45867 .3599 m .47982 .34274 L .49081 .33873 L p F P
0 g
s
.497 .41081 m
.49056 .41556 L
s
1 g
.45657 .4834 m .47772 .46861 L .46575 .46125 L p F P
0 g
s
1 g
.46575 .46125 m .44478 .47621 L .45657 .4834 L p F P
0 g
s
1 g
.43621 .41318 m .41584 .42903 L .41945 .4424 L p F P
0 g
s
1 g
.41584 .42903 m .43621 .41318 L .43535 .39971 L p F P
0 g
s
1 g
.44478 .47621 m .46575 .46125 L .4551 .45146 L p F P
0 g
s
1 g
.4551 .45146 m .43431 .46663 L .44478 .47621 L p F P
0 g
s
1 g
.5259 .46889 m .54845 .45378 L .53755 .45819 L p F P
0 g
s
1 g
.53755 .45819 m .51509 .47329 L .5259 .46889 L p F P
0 g
s
1 g
.43993 .42677 m .41945 .4424 L .42571 .45516 L p F P
0 g
s
1 g
.41945 .4424 m .43993 .42677 L .43621 .41318 L p F P
0 g
s
1 g
.44937 .36665 m .47045 .34954 L .47982 .34274 L p F P
0 g
s
1 g
.47045 .34954 m .44937 .36665 L .44214 .37585 L p F P
0 g
s
1 g
.43431 .46663 m .4551 .45146 L .44634 .43976 L p F P
0 g
s
1 g
.44634 .43976 m .42571 .45516 L .43431 .46663 L p F P
0 g
s
1 g
.42571 .45516 m .44634 .43976 L .43993 .42677 L p F P
0 g
s
1 g
.53773 .3219 m .51535 .33955 L .50285 .33767 L p F P
0 g
s
.50351 .40601 m
.497 .41081 L
s
0 .769 1 r
.59733 .34536 m
.67665 .28734 L
s
1 g
.51509 .47329 m .53755 .45819 L .52538 .45962 L p F P
0 g
s
1 g
.52538 .45962 m .50305 .47476 L .51509 .47329 L p F P
0 g
s
1 g
.52507 .31991 m .50285 .33767 L .49081 .33873 L p F P
0 g
s
1 g
.50285 .33767 m .52507 .31991 L .53773 .3219 L p F P
0 g
s
0 1 1 r
.47191 .31142 m
.489 .31605 L
s
1 g
.46318 .35883 m .44214 .37585 L .43737 .38705 L p F P
0 g
s
1 g
.44214 .37585 m .46318 .35883 L .47045 .34954 L p F P
0 g
s
.51009 .40114 m
.50351 .40601 L
s
1 g
.56446 .43719 m .58799 .42131 L .58107 .43088 L p F P
0 g
s
1 g
.58107 .43088 m .55757 .44665 L .56446 .43719 L p F P
0 g
s
1 g
.50305 .47476 m .52538 .45962 L .51255 .45796 L p F P
0 g
s
1 g
.51255 .45796 m .49038 .47319 L .50305 .47476 L p F P
0 g
s
1 g
.5129 .32092 m .49081 .33873 L .47982 .34274 L p F P
0 g
s
1 g
.49081 .33873 m .5129 .32092 L .52507 .31991 L p F P
0 g
s
1 g
.45842 .37017 m .43737 .38705 L .43535 .39971 L p F P
0 g
s
1 g
.43737 .38705 m .45842 .37017 L .46318 .35883 L p F P
0 g
s
.51675 .39623 m
.51009 .40114 L
s
1 g
.49038 .47319 m .51255 .45796 L .49971 .45324 L p F P
0 g
s
1 g
.49971 .45324 m .47772 .46861 L .49038 .47319 L p F P
0 g
s
1 g
.45644 .38301 m .43535 .39971 L .43621 .41318 L p F P
0 g
s
1 g
.43535 .39971 m .45644 .38301 L .45842 .37017 L p F P
0 g
s
1 g
.55757 .44665 m .58107 .43088 L .5719 .43807 L p F P
0 g
s
1 g
.5719 .43807 m .54845 .45378 L .55757 .44665 L p F P
0 g
s
1 g
.50181 .32491 m .47982 .34274 L .47045 .34954 L p F P
0 g
s
1 g
.47982 .34274 m .50181 .32491 L .5129 .32092 L p F P
0 g
s
0 1 1 r
.51221 .32233 m
.59733 .34536 L
s
1 g
.47772 .46861 m .49971 .45324 L .48756 .44569 L p F P
0 g
s
1 g
.48756 .44569 m .46575 .46125 L .47772 .46861 L p F P
0 g
s
1 g
.45739 .3967 m .43621 .41318 L .43993 .42677 L p F P
0 g
s
1 g
.43621 .41318 m .45739 .3967 L .45644 .38301 L p F P
0 g
s
.52349 .39125 m
.51675 .39623 L
s
1 g
.46575 .46125 m .48756 .44569 L .47672 .43569 L p F P
0 g
s
1 g
.47672 .43569 m .4551 .45146 L .46575 .46125 L p F P
0 g
s
1 g
.54845 .45378 m .5719 .43807 L .5609 .44249 L p F P
0 g
s
1 g
.5609 .44249 m .53755 .45819 L .54845 .45378 L p F P
0 g
s
1 g
.46123 .41053 m .43993 .42677 L .44634 .43976 L p F P
0 g
s
1 g
.43993 .42677 m .46123 .41053 L .45739 .3967 L p F P
0 g
s
1 g
.47045 .34954 m .49237 .33175 L .50181 .32491 L p F P
0 g
s
1 g
.49237 .33175 m .47045 .34954 L .46318 .35883 L p F P
0 g
s
1 g
.4551 .45146 m .47672 .43569 L .46779 .42376 L p F P
0 g
s
1 g
.46779 .42376 m .44634 .43976 L .4551 .45146 L p F P
0 g
s
1 g
.44634 .43976 m .46779 .42376 L .46123 .41053 L p F P
0 g
s
1 g
.56099 .30356 m .53773 .3219 L .52507 .31991 L p F P
0 g
s
0 .538 1 r
.54602 .2488 m
.55341 .26271 L
s
1 g
.53755 .45819 m .5609 .44249 L .5486 .44388 L p F P
0 g
s
1 g
.5486 .44388 m .52538 .45962 L .53755 .45819 L p F P
0 g
s
1 g
.54818 .30145 m .52507 .31991 L .5129 .32092 L p F P
0 g
s
1 g
.52507 .31991 m .54818 .30145 L .56099 .30356 L p F P
0 g
s
.53031 .38621 m
.52349 .39125 L
s
1 g
.48507 .34114 m .46318 .35883 L .45842 .37017 L p F P
0 g
s
1 g
.46318 .35883 m .48507 .34114 L .49237 .33175 L p F P
0 g
s
1 g
.58799 .42131 m .61245 .40481 L .60552 .41448 L p F P
0 g
s
1 g
.60552 .41448 m .58107 .43088 L .58799 .42131 L p F P
0 g
s
1 g
.52538 .45962 m .5486 .44388 L .5356 .44211 L p F P
0 g
s
1 g
.5356 .44211 m .51255 .45796 L .52538 .45962 L p F P
0 g
s
1 g
.53588 .30238 m .5129 .32092 L .50181 .32491 L p F P
0 g
s
0 1 1 r
.489 .31605 m
.50761 .32108 L
s
1 g
.5129 .32092 m .53588 .30238 L .54818 .30145 L p F P
0 g
s
1 g
.48031 .35262 m .45842 .37017 L .45644 .38301 L p F P
0 g
s
1 g
.45842 .37017 m .48031 .35262 L .48507 .34114 L p F P
0 g
s
.53721 .38112 m
.53031 .38621 L
s
1 g
.51255 .45796 m .5356 .44211 L .52259 .43724 L p F P
0 g
s
1 g
.52259 .43724 m .49971 .45324 L .51255 .45796 L p F P
0 g
s
1 g
.47838 .36565 m .45644 .38301 L .45739 .3967 L p F P
0 g
s
1 g
.45644 .38301 m .47838 .36565 L .48031 .35262 L p F P
0 g
s
1 g
.58107 .43088 m .60552 .41448 L .5963 .42173 L p F P
0 g
s
1 g
.5963 .42173 m .5719 .43807 L .58107 .43088 L p F P
0 g
s
1 g
.52469 .30637 m .50181 .32491 L .49237 .33175 L p F P
0 g
s
1 g
.50181 .32491 m .52469 .30637 L .53588 .30238 L p F P
0 g
s
1 g
.49971 .45324 m .52259 .43724 L .51024 .4295 L p F P
0 g
s
1 g
.51024 .4295 m .48756 .44569 L .49971 .45324 L p F P
0 g
s
.54419 .37596 m
.53721 .38112 L
s
1 g
.47942 .37956 m .45739 .3967 L .46123 .41053 L p F P
0 g
s
1 g
.45739 .3967 m .47942 .37956 L .47838 .36565 L p F P
0 g
s
1 g
.48756 .44569 m .51024 .4295 L .49922 .41928 L p F P
0 g
s
1 g
.49922 .41928 m .47672 .43569 L .48756 .44569 L p F P
0 g
s
1 g
.5719 .43807 m .5963 .42173 L .5852 .42615 L p F P
0 g
s
1 g
.5852 .42615 m .5609 .44249 L .5719 .43807 L p F P
0 g
s
1 g
.48339 .39363 m .46123 .41053 L .46779 .42376 L p F P
0 g
s
1 g
.46123 .41053 m .48339 .39363 L .47942 .37956 L p F P
0 g
s
1 .231 0 r
.5273 .30491 m
.52952 .30465 L
s
0 0 1 r
.03 w
.47191 .31142 Mdot
.5 Mabswid
1 g
.49237 .33175 m .51518 .31324 L .52469 .30637 L p F P
0 g
s
1 g
.51518 .31324 m .49237 .33175 L .48507 .34114 L p F P
0 g
s
1 .231 0 r
.47191 .31142 m
.49833 .30832 L
s
.49833 .30832 m
.5273 .30491 L
s
1 g
.47672 .43569 m .49922 .41928 L .49011 .40711 L p F P
0 g
s
1 g
.49011 .40711 m .46779 .42376 L .47672 .43569 L p F P
0 g
s
1 g
.46779 .42376 m .49011 .40711 L .48339 .39363 L p F P
0 g
s
1 g
.5852 .28447 m .56099 .30356 L .54818 .30145 L p F P
0 g
s
.55126 .37075 m
.54419 .37596 L
s
1 g
.5609 .44249 m .5852 .42615 L .57276 .42749 L p F P
0 g
s
1 0 .231 r
.57298 .44486 m
.57404 .44052 L
s
.57404 .44052 m
.57718 .42766 L
s
1 g
.57276 .42749 m .5486 .44388 L .5609 .44249 L p F P
0 g
s
1 g
.57224 .28223 m .54818 .30145 L .53588 .30238 L p F P
0 g
s
1 g
.54818 .30145 m .57224 .28223 L .5852 .28447 L p F P
0 g
s
1 g
.50784 .32272 m .48507 .34114 L .48031 .35262 L p F P
0 g
s
1 g
.48507 .34114 m .50784 .32272 L .51518 .31324 L p F P
0 g
s
1 0 .923 r
.47191 .31142 m
.48891 .33387 L
s
.49049 .33596 m
.49072 .33626 L
s
.48891 .33387 m
.49049 .33596 L
s
1 g
.61245 .40481 m .63792 .38762 L .63098 .3974 L p F P
0 g
s
1 g
.63098 .3974 m .60552 .41448 L .61245 .40481 L p F P
0 g
s
.55841 .36547 m
.55126 .37075 L
s
1 g
.5486 .44388 m .57276 .42749 L .55961 .42561 L p F P
0 g
s
1 g
.55961 .42561 m .5356 .44211 L .5486 .44388 L p F P
0 g
s
1 g
.5598 .28309 m .53588 .30238 L .52469 .30637 L p F P
0 g
s
1 g
.53588 .30238 m .5598 .28309 L .57224 .28223 L p F P
0 g
s
1 g
.5031 .33435 m .48031 .35262 L .47838 .36565 L p F P
0 g
s
1 g
.48031 .35262 m .5031 .33435 L .50784 .32272 L p F P
0 g
s
1 g
.5356 .44211 m .55961 .42561 L .54641 .42059 L p F P
0 g
s
1 g
.54641 .42059 m .52259 .43724 L .5356 .44211 L p F P
0 g
s
1 g
.50123 .34757 m .47838 .36565 L .47942 .37956 L p F P
0 g
s
1 g
.47838 .36565 m .50123 .34757 L .5031 .33435 L p F P
0 g
s
1 g
.60552 .41448 m .63098 .3974 L .6217 .40471 L p F P
0 g
s
1 g
.6217 .40471 m .5963 .42173 L .60552 .41448 L p F P
0 g
s
1 g
.5485 .28705 m .52469 .30637 L .51518 .31324 L p F P
0 g
s
1 g
.52469 .30637 m .5485 .28705 L .5598 .28309 L p F P
0 g
s
.56565 .36012 m
.55841 .36547 L
s
1 g
.52259 .43724 m .54641 .42059 L .53387 .41265 L p F P
0 g
s
1 g
.53387 .41265 m .51024 .4295 L .52259 .43724 L p F P
0 g
s
1 g
.50236 .36171 m .47942 .37956 L .48339 .39363 L p F P
0 g
s
1 g
.47942 .37956 m .50236 .36171 L .50123 .34757 L p F P
0 g
s
1 g
.51024 .4295 m .53387 .41265 L .52264 .40219 L p F P
0 g
s
1 g
.52264 .40219 m .49922 .41928 L .51024 .4295 L p F P
0 g
s
1 g
.5963 .42173 m .6217 .40471 L .61051 .40914 L p F P
0 g
s
1 g
.61051 .40914 m .5852 .42615 L .5963 .42173 L p F P
0 g
s
1 g
.50647 .37603 m .48339 .39363 L .49011 .40711 L p F P
0 g
s
1 g
.48339 .39363 m .50647 .37603 L .50236 .36171 L p F P
0 g
s
1 g
.51518 .31324 m .53892 .29397 L .5485 .28705 L p F P
0 g
s
1 g
.53892 .29397 m .51518 .31324 L .50784 .32272 L p F P
0 g
s
1 .231 0 r
.53495 .30401 m
.67665 .28734 L
s
1 g
.49922 .41928 m .52264 .40219 L .51335 .38976 L p F P
0 g
s
1 g
.51335 .38976 m .49011 .40711 L .49922 .41928 L p F P
0 g
s
1 g
.49011 .40711 m .51335 .38976 L .50647 .37603 L p F P
0 g
s
1 g
.61041 .26459 m .5852 .28447 L .57224 .28223 L p F P
0 g
s
.57298 .35471 m
.56565 .36012 L
s
1 g
.5852 .42615 m .61051 .40914 L .59794 .41041 L p F P
0 g
s
1 g
.59794 .41041 m .57276 .42749 L .5852 .42615 L p F P
0 g
s
1 g
.59729 .26222 m .57224 .28223 L .5598 .28309 L p F P
0 g
s
1 g
.57224 .28223 m .59729 .26222 L .61041 .26459 L p F P
0 g
s
1 g
.53157 .30354 m .50784 .32272 L .5031 .33435 L p F P
0 g
s
1 g
.50784 .32272 m .53157 .30354 L .53892 .29397 L p F P
0 g
s
.58039 .34924 m
.57298 .35471 L
s
1 g
.63792 .38762 m .66444 .36972 L .6575 .37961 L p F P
0 g
s
1 g
.6575 .37961 m .63098 .3974 L .63792 .38762 L p F P
0 g
s
1 g
.57276 .42749 m .59794 .41041 L .58462 .40842 L p F P
0 g
s
1 0 .692 r
.59338 .41386 m
.59347 .41372 L
s
1 0 .231 r
.58012 .41565 m
.59733 .34536 L
s
1 g
.58462 .40842 m .55961 .42561 L .57276 .42749 L p F P
0 g
s
1 0 .231 r
.57801 .42427 m
.57804 .42419 L
s
1 g
.58472 .263 m .5598 .28309 L .5485 .28705 L p F P
0 g
s
1 g
.5598 .28309 m .58472 .263 L .59729 .26222 L p F P
0 g
s
0 .538 1 r
.56324 .28121 m
.59733 .34536 L
s
1 g
.52684 .31532 m .5031 .33435 L .50123 .34757 L p F P
0 g
s
1 g
.5031 .33435 m .52684 .31532 L .53157 .30354 L p F P
0 g
s
.5879 .34369 m
.58039 .34924 L
s
1 g
.55961 .42561 m .58462 .40842 L .57123 .40323 L p F P
0 g
s
1 0 .692 r
.57298 .44486 m
.5912 .41717 L
s
.5912 .41717 m
.59338 .41386 L
s
1 0 .231 r
.57718 .42766 m
.57748 .42645 L
s
.57748 .42645 m
.57801 .42427 L
s
1 g
.57123 .40323 m .54641 .42059 L .55961 .42561 L p F P
0 g
s
1 0 .923 r
.55803 .42512 m
.57298 .44486 L
s
.55707 .42386 m
.55803 .42512 L
s
1 g
.52503 .32874 m .50123 .34757 L .50236 .36171 L p F P
0 g
s
1 g
.50123 .34757 m .52503 .32874 L .52684 .31532 L p F P
0 g
s
1 g
.63098 .3974 m .6575 .37961 L .64818 .38697 L p F P
0 g
s
1 g
.64818 .38697 m .6217 .40471 L .63098 .3974 L p F P
0 g
s
1 g
.57332 .26693 m .5485 .28705 L .53892 .29397 L p F P
0 g
s
1 g
.5485 .28705 m .57332 .26693 L .58472 .263 L p F P
0 g
s
1 g
.54641 .42059 m .57123 .40323 L .55849 .39508 L p F P
0 g
s
1 g
.55849 .39508 m .53387 .41265 L .54641 .42059 L p F P
0 g
s
1 0 .923 r
.55251 .41784 m
.55281 .41824 L
s
.55281 .41824 m
.55707 .42386 L
s
.50599 .35643 m
.54342 .40584 L
s
1 g
.52627 .34311 m .50236 .36171 L .50647 .37603 L p F P
0 g
s
1 g
.50236 .36171 m .52627 .34311 L .52503 .32874 L p F P
0 g
s
.5955 .33808 m
.5879 .34369 L
s
1 g
.53387 .41265 m .55849 .39508 L .54706 .38438 L p F P
0 g
s
1 g
.54706 .38438 m .52264 .40219 L .53387 .41265 L p F P
0 g
s
1 g
.6217 .40471 m .64818 .38697 L .63689 .3914 L p F P
0 g
s
1 g
.63689 .3914 m .61051 .40914 L .6217 .40471 L p F P
0 g
s
1 g
.53051 .35768 m .50647 .37603 L .51335 .38976 L p F P
0 g
s
1 g
.50647 .37603 m .53051 .35768 L .52627 .34311 L p F P
0 g
s
1 g
.53892 .29397 m .56368 .27388 L .57332 .26693 L p F P
0 g
s
1 g
.56368 .27388 m .53892 .29397 L .53157 .30354 L p F P
0 g
s
0 .538 1 r
.55341 .26271 m
.55866 .27259 L
s
.55866 .27259 m
.56065 .27634 L
s
1 g
.52264 .40219 m .54706 .38438 L .53757 .37169 L p F P
0 g
s
1 g
.53757 .37169 m .51335 .38976 L .52264 .40219 L p F P
0 g
s
1 g
.51335 .38976 m .53757 .37169 L .53051 .35768 L p F P
0 g
s
1 g
.63668 .24387 m .61041 .26459 L .59729 .26222 L p F P
0 g
s
1 g
.61051 .40914 m .63689 .3914 L .62419 .39261 L p F P
0 g
s
1 g
.62419 .39261 m .59794 .41041 L .61051 .40914 L p F P
0 g
s
1 0 .692 r
.59585 .4101 m
.67665 .28734 L
s
1 g
.6234 .24136 m .59729 .26222 L .58472 .263 L p F P
0 g
s
1 g
.59729 .26222 m .6234 .24136 L .63668 .24387 L p F P
0 g
s
.6032 .3324 m
.5955 .33808 L
s
1 g
.5563 .28355 m .53157 .30354 L .52684 .31532 L p F P
0 g
s
1 g
.53157 .30354 m .5563 .28355 L .56368 .27388 L p F P
0 g
s
1 g
.66444 .36972 m .6921 .35106 L .68516 .36106 L p F P
0 g
s
1 g
.68516 .36106 m .6575 .37961 L .66444 .36972 L p F P
0 g
s
1 g
.59794 .41041 m .62419 .39261 L .6107 .3905 L p F P
0 g
s
1 g
.6107 .3905 m .58462 .40842 L .59794 .41041 L p F P
0 g
s
1 g
.6107 .24204 m .58472 .263 L .57332 .26693 L p F P
0 g
s
1 g
.58472 .263 m .6107 .24204 L .6234 .24136 L p F P
0 g
s
.385 1 0 r
.58807 .26121 m
.67665 .28734 L
s
1 g
.55159 .29548 m .52684 .31532 L .52503 .32874 L p F P
0 g
s
1 g
.52684 .31532 m .55159 .29548 L .5563 .28355 L p F P
0 g
s
1 0 .462 r
.56828 .4107 m
.57298 .44486 L
s
.56787 .40774 m
.56828 .4107 L
s
.56779 .40718 m
.56787 .40774 L
s
.5508 .28361 m
.55124 .2868 L
s
.55124 .2868 m
.5513 .28726 L
s
.54602 .2488 m
.5508 .28361 L
s
0 0 1 r
.03 w
.57298 .44486 Mdot
0 g
.5 Mabswid
.61099 .32664 m
.6032 .3324 L
s
1 g
.58462 .40842 m .6107 .3905 L .59712 .38513 L p F P
0 g
s
1 g
.59712 .38513 m .57123 .40323 L .58462 .40842 L p F P
0 g
s
1 g
.54985 .3091 m .52503 .32874 L .52627 .34311 L p F P
0 g
s
1 g
.52503 .32874 m .54985 .3091 L .55159 .29548 L p F P
0 g
s
1 g
.6575 .37961 m .68516 .36106 L .6758 .36847 L p F P
0 g
s
1 g
.6758 .36847 m .64818 .38697 L .6575 .37961 L p F P
0 g
s
1 g
.5992 .24595 m .57332 .26693 L .56368 .27388 L p F P
0 g
s
.385 1 0 r
.58305 .25973 m
.5838 .25995 L
s
.58243 .25955 m
.58305 .25973 L
s
1 g
.57332 .26693 m .5992 .24595 L .6107 .24204 L p F P
0 g
s
1 g
.57123 .40323 m .59712 .38513 L .58417 .37676 L p F P
0 g
s
1 g
.58417 .37676 m .55849 .39508 L .57123 .40323 L p F P
0 g
s
.61888 .32082 m
.61099 .32664 L
s
1 g
.5512 .32371 m .52627 .34311 L .53051 .35768 L p F P
0 g
s
1 g
.52627 .34311 m .5512 .32371 L .54985 .3091 L p F P
0 g
s
.615 1 0 r
.47191 .31142 m
.54602 .2488 L
s
1 g
.55849 .39508 m .58417 .37676 L .57253 .36581 L p F P
0 g
s
1 g
.57253 .36581 m .54706 .38438 L .55849 .39508 L p F P
0 g
s
1 g
.64818 .38697 m .6758 .36847 L .66442 .37289 L p F P
0 g
s
1 g
.66442 .37289 m .63689 .3914 L .64818 .38697 L p F P
0 g
s
1 g
.5556 .33855 m .53051 .35768 L .53757 .37169 L p F P
0 g
s
1 g
.53051 .35768 m .5556 .33855 L .5512 .32371 L p F P
0 g
s
1 0 .462 r
.55222 .2939 m
.56305 .37271 L
s
1 g
.56368 .27388 m .58949 .25293 L .5992 .24595 L p F P
0 g
s
1 g
.58949 .25293 m .56368 .27388 L .5563 .28355 L p F P
0 g
s
.385 1 0 r
.54602 .2488 m
.57671 .25786 L
s
.57671 .25786 m
.58163 .25931 L
s
1 g
.54706 .38438 m .57253 .36581 L .56283 .35284 L p F P
0 g
s
1 g
.56283 .35284 m .53757 .37169 L .54706 .38438 L p F P
0 g
s
1 g
.53757 .37169 m .56283 .35284 L .5556 .33855 L p F P
0 g
s
1 g
.66409 .22226 m .63668 .24387 L .6234 .24136 L p F P
0 g
s
0 0 1 r
.03 w
.54602 .2488 Mdot
0 g
.5 Mabswid
.62688 .31491 m
.61888 .32082 L
s
1 g
.63689 .3914 m .66442 .37289 L .65158 .37403 L p F P
0 g
s
1 g
.65158 .37403 m .62419 .39261 L .63689 .3914 L p F P
0 g
s
1 g
.65065 .21959 m .6234 .24136 L .6107 .24204 L p F P
0 g
s
1 g
.6234 .24136 m .65065 .21959 L .66409 .22226 L p F P
0 g
s
1 g
.5821 .26269 m .5563 .28355 L .55159 .29548 L p F P
0 g
s
1 g
.5563 .28355 m .5821 .26269 L .58949 .25293 L p F P
0 g
s
.63497 .30894 m
.62688 .31491 L
s
1 g
.6921 .35106 m .72096 .33159 L .71403 .34169 L p F P
0 g
s
1 g
.71403 .34169 m .68516 .36106 L .6921 .35106 L p F P
0 g
s
1 g
.62419 .39261 m .65158 .37403 L .63792 .37179 L p F P
0 g
s
1 g
.63792 .37179 m .6107 .3905 L .62419 .39261 L p F P
0 g
s
1 g
.63781 .22018 m .6107 .24204 L .5992 .24595 L p F P
0 g
s
1 g
.6107 .24204 m .63781 .22018 L .65065 .21959 L p F P
0 g
s
1 g
.57743 .27477 m .55159 .29548 L .54985 .3091 L p F P
0 g
s
1 g
.55159 .29548 m .57743 .27477 L .5821 .26269 L p F P
0 g
s
1 g
.6107 .3905 m .63792 .37179 L .62415 .36624 L p F P
0 g
s
1 g
.62415 .36624 m .59712 .38513 L .6107 .3905 L p F P
0 g
s
1 g
.57576 .2886 m .54985 .3091 L .5512 .32371 L p F P
0 g
s
1 g
.54985 .3091 m .57576 .2886 L .57743 .27477 L p F P
0 g
s
1 g
.68516 .36106 m .71403 .34169 L .70463 .34916 L p F P
0 g
s
1 g
.70463 .34916 m .6758 .36847 L .68516 .36106 L p F P
0 g
s
.64317 .30288 m
.63497 .30894 L
s
1 g
.62621 .22404 m .5992 .24595 L .58949 .25293 L p F P
0 g
s
1 g
.5992 .24595 m .62621 .22404 L .63781 .22018 L p F P
0 g
s
1 g
.59712 .38513 m .62415 .36624 L .61097 .35763 L p F P
0 g
s
1 g
.61097 .35763 m .58417 .37676 L .59712 .38513 L p F P
0 g
s
1 g
.57723 .30346 m .5512 .32371 L .5556 .33855 L p F P
0 g
s
1 g
.5512 .32371 m .57723 .30346 L .57576 .2886 L p F P
0 g
s
1 g
.58417 .37676 m .61097 .35763 L .59912 .34641 L p F P
0 g
s
1 g
.59912 .34641 m .57253 .36581 L .58417 .37676 L p F P
0 g
s
1 g
.6758 .36847 m .70463 .34916 L .69317 .35356 L p F P
0 g
s
1 g
.69317 .35356 m .66442 .37289 L .6758 .36847 L p F P
0 g
s
1 g
.58179 .31858 m .5556 .33855 L .56283 .35284 L p F P
0 g
s
1 g
.5556 .33855 m .58179 .31858 L .57723 .30346 L p F P
0 g
s
1 g
.58949 .25293 m .61645 .23105 L .62621 .22404 L p F P
0 g
s
1 g
.61645 .23105 m .58949 .25293 L .5821 .26269 L p F P
0 g
s
1 g
.57253 .36581 m .59912 .34641 L .58921 .33315 L p F P
0 g
s
1 g
.58921 .33315 m .56283 .35284 L .57253 .36581 L p F P
0 g
s
1 g
.56283 .35284 m .58921 .33315 L .58179 .31858 L p F P
0 g
s
1 g
.69271 .19969 m .66409 .22226 L .65065 .21959 L p F P
0 g
s
.65148 .29675 m
.64317 .30288 L
s
1 g
.66442 .37289 m .69317 .35356 L .6802 .35463 L p F P
0 g
s
1 g
.6802 .35463 m .65158 .37403 L .66442 .37289 L p F P
0 g
s
1 g
.6791 .19686 m .65065 .21959 L .63781 .22018 L p F P
0 g
s
1 g
.65065 .21959 m .6791 .19686 L .69271 .19969 L p F P
0 g
s
1 g
.60904 .2409 m .5821 .26269 L .57743 .27477 L p F P
0 g
s
1 g
.5821 .26269 m .60904 .2409 L .61645 .23105 L p F P
0 g
s
.6599 .29053 m
.65148 .29675 L
s
1 g
.72096 .33159 m .7511 .31124 L .7442 .32146 L p F P
0 g
s
1 g
.7442 .32146 m .71403 .34169 L .72096 .33159 L p F P
0 g
s
1 g
.65158 .37403 m .6802 .35463 L .66636 .35225 L p F P
0 g
s
1 g
.66636 .35225 m .63792 .37179 L .65158 .37403 L p F P
0 g
s
1 g
.66613 .19734 m .63781 .22018 L .62621 .22404 L p F P
0 g
s
1 g
.63781 .22018 m .66613 .19734 L .6791 .19686 L p F P
0 g
s
1 g
.60441 .25314 m .57743 .27477 L .57576 .2886 L p F P
0 g
s
1 g
.57743 .27477 m .60441 .25314 L .60904 .2409 L p F P
0 g
s
.66842 .28424 m
.6599 .29053 L
s
1 g
.63792 .37179 m .66636 .35225 L .65238 .3465 L p F P
0 g
s
1 g
.65238 .3465 m .62415 .36624 L .63792 .37179 L p F P
0 g
s
1 g
.60283 .26718 m .57576 .2886 L .57723 .30346 L p F P
0 g
s
1 g
.57576 .2886 m .60283 .26718 L .60441 .25314 L p F P
0 g
s
1 g
.71403 .34169 m .7442 .32146 L .73476 .32897 L p F P
0 g
s
1 g
.73476 .32897 m .70463 .34916 L .71403 .34169 L p F P
0 g
s
1 g
.65443 .20116 m .62621 .22404 L .61645 .23105 L p F P
0 g
s
1 g
.62621 .22404 m .65443 .20116 L .66613 .19734 L p F P
0 g
s
1 g
.62415 .36624 m .65238 .3465 L .63899 .33764 L p F P
0 g
s
1 g
.63899 .33764 m .61097 .35763 L .62415 .36624 L p F P
0 g
s
1 g
.60443 .28229 m .57723 .30346 L .58179 .31858 L p F P
0 g
s
1 g
.57723 .30346 m .60443 .28229 L .60283 .26718 L p F P
0 g
s
.67706 .27786 m
.66842 .28424 L
s
1 g
.61097 .35763 m .63899 .33764 L .62691 .32614 L p F P
0 g
s
1 g
.62691 .32614 m .59912 .34641 L .61097 .35763 L p F P
0 g
s
1 g
.70463 .34916 m .73476 .32897 L .72321 .33336 L p F P
0 g
s
1 g
.72321 .33336 m .69317 .35356 L .70463 .34916 L p F P
0 g
s
1 g
.60915 .2977 m .58179 .31858 L .58921 .33315 L p F P
0 g
s
1 g
.58179 .31858 m .60915 .2977 L .60443 .28229 L p F P
0 g
s
1 g
.61645 .23105 m .64462 .20819 L .65443 .20116 L p F P
0 g
s
1 g
.64462 .20819 m .61645 .23105 L .60904 .2409 L p F P
0 g
s
1 g
.59912 .34641 m .62691 .32614 L .61678 .31258 L p F P
0 g
s
1 g
.61678 .31258 m .58921 .33315 L .59912 .34641 L p F P
0 g
s
1 g
.58921 .33315 m .61678 .31258 L .60915 .2977 L p F P
0 g
s
1 g
.72261 .17611 m .69271 .19969 L .6791 .19686 L p F P
0 g
s
1 g
.69317 .35356 m .72321 .33336 L .71011 .33434 L p F P
0 g
s
1 g
.71011 .33434 m .6802 .35463 L .69317 .35356 L p F P
0 g
s
.68582 .27139 m
.67706 .27786 L
s
1 g
.70884 .1731 m .6791 .19686 L .66613 .19734 L p F P
0 g
s
1 g
.6791 .19686 m .70884 .1731 L .72261 .17611 L p F P
0 g
s
1 g
.63721 .21813 m .60904 .2409 L .60441 .25314 L p F P
0 g
s
1 g
.60904 .2409 m .63721 .21813 L .64462 .20819 L p F P
0 g
s
1 g
.7511 .31124 m .78262 .28998 L .77574 .3003 L p F P
0 g
s
1 g
.77574 .3003 m .7442 .32146 L .7511 .31124 L p F P
0 g
s
1 g
.6802 .35463 m .71011 .33434 L .6961 .33181 L p F P
0 g
s
1 g
.6961 .33181 m .66636 .35225 L .6802 .35463 L p F P
0 g
s
1 g
.69573 .17346 m .66613 .19734 L .65443 .20116 L p F P
0 g
s
1 g
.66613 .19734 m .69573 .17346 L .70884 .1731 L p F P
0 g
s
1 g
.63262 .23053 m .60441 .25314 L .60283 .26718 L p F P
0 g
s
1 g
.60441 .25314 m .63262 .23053 L .63721 .21813 L p F P
0 g
s
.69469 .26484 m
.68582 .27139 L
s
1 g
.66636 .35225 m .6961 .33181 L .68192 .32585 L p F P
0 g
s
1 g
.68192 .32585 m .65238 .3465 L .66636 .35225 L p F P
0 g
s
1 g
.63113 .24478 m .60283 .26718 L .60443 .28229 L p F P
0 g
s
1 g
.60283 .26718 m .63113 .24478 L .63262 .23053 L p F P
0 g
s
1 g
.7442 .32146 m .77574 .3003 L .76627 .30786 L p F P
0 g
s
1 g
.76627 .30786 m .73476 .32897 L .7442 .32146 L p F P
0 g
s
1 g
.68395 .17723 m .65443 .20116 L .64462 .20819 L p F P
0 g
s
1 g
.65443 .20116 m .68395 .17723 L .69573 .17346 L p F P
0 g
s
.70368 .2582 m
.69469 .26484 L
s
1 g
.65238 .3465 m .68192 .32585 L .6683 .31674 L p F P
0 g
s
1 g
.6683 .31674 m .63899 .33764 L .65238 .3465 L p F P
0 g
s
1 g
.63287 .26016 m .60443 .28229 L .60915 .2977 L p F P
0 g
s
1 g
.60443 .28229 m .63287 .26016 L .63113 .24478 L p F P
0 g
s
1 g
.63899 .33764 m .6683 .31674 L .65597 .30493 L p F P
0 g
s
1 g
.65597 .30493 m .62691 .32614 L .63899 .33764 L p F P
0 g
s
1 g
.73476 .32897 m .76627 .30786 L .75465 .31222 L p F P
0 g
s
1 g
.75465 .31222 m .72321 .33336 L .73476 .32897 L p F P
0 g
s
1 g
.63778 .27587 m .60915 .2977 L .61678 .31258 L p F P
0 g
s
1 g
.60915 .2977 m .63778 .27587 L .63287 .26016 L p F P
0 g
s
1 g
.64462 .20819 m .67409 .18427 L .68395 .17723 L p F P
0 g
s
1 g
.67409 .18427 m .64462 .20819 L .63721 .21813 L p F P
0 g
s
1 g
.62691 .32614 m .65597 .30493 L .64562 .29106 L p F P
0 g
s
1 g
.64562 .29106 m .61678 .31258 L .62691 .32614 L p F P
0 g
s
1 g
.61678 .31258 m .64562 .29106 L .63778 .27587 L p F P
0 g
s
1 g
.7539 .15144 m .72261 .17611 L .70884 .1731 L p F P
0 g
s
.7128 .25147 m
.70368 .2582 L
s
1 g
.72321 .33336 m .75465 .31222 L .74142 .31311 L p F P
0 g
s
1 g
.74142 .31311 m .71011 .33434 L .72321 .33336 L p F P
0 g
s
1 g
.73996 .14824 m .70884 .1731 L .69573 .17346 L p F P
0 g
s
1 g
.70884 .1731 m .73996 .14824 L .7539 .15144 L p F P
0 g
s
1 g
.66668 .1943 m .63721 .21813 L .63262 .23053 L p F P
0 g
s
1 g
.63721 .21813 m .66668 .1943 L .67409 .18427 L p F P
0 g
s
.72204 .24465 m
.7128 .25147 L
s
1 g
.78262 .28998 m .8156 .26772 L .80876 .27815 L p F P
0 g
s
1 g
.80876 .27815 m .77574 .3003 L .78262 .28998 L p F P
0 g
s
1 g
.71011 .33434 m .74142 .31311 L .72724 .31041 L p F P
0 g
s
1 g
.72724 .31041 m .6961 .33181 L .71011 .33434 L p F P
0 g
s
1 g
.72672 .14847 m .69573 .17346 L .68395 .17723 L p F P
0 g
s
1 g
.69573 .17346 m .72672 .14847 L .73996 .14824 L p F P
0 g
s
1 g
.66215 .20686 m .63262 .23053 L .63113 .24478 L p F P
0 g
s
1 g
.63262 .23053 m .66215 .20686 L .66668 .1943 L p F P
0 g
s
1 g
.6961 .33181 m .72724 .31041 L .71284 .30423 L p F P
0 g
s
1 g
.71284 .30423 m .68192 .32585 L .6961 .33181 L p F P
0 g
s
1 g
.66077 .22133 m .63113 .24478 L .63287 .26016 L p F P
0 g
s
1 g
.63113 .24478 m .66077 .22133 L .66215 .20686 L p F P
0 g
s
1 g
.77574 .3003 m .80876 .27815 L .79928 .28575 L p F P
0 g
s
1 g
.79928 .28575 m .76627 .30786 L .77574 .3003 L p F P
0 g
s
.73141 .23773 m
.72204 .24465 L
s
1 g
.71485 .15217 m .68395 .17723 L .67409 .18427 L p F P
0 g
s
1 g
.68395 .17723 m .71485 .15217 L .72672 .14847 L p F P
0 g
s
1 g
.68192 .32585 m .71284 .30423 L .69898 .29484 L p F P
0 g
s
1 g
.69898 .29484 m .6683 .31674 L .68192 .32585 L p F P
0 g
s
1 g
.66266 .23698 m .63287 .26016 L .63778 .27587 L p F P
0 g
s
1 g
.63287 .26016 m .66266 .23698 L .66077 .22133 L p F P
0 g
s
1 g
.6683 .31674 m .69898 .29484 L .68642 .28273 L p F P
0 g
s
1 g
.68642 .28273 m .65597 .30493 L .6683 .31674 L p F P
0 g
s
1 g
.76627 .30786 m .79928 .28575 L .78758 .29008 L p F P
0 g
s
1 g
.78758 .29008 m .75465 .31222 L .76627 .30786 L p F P
0 g
s
1 g
.66776 .253 m .63778 .27587 L .64562 .29106 L p F P
0 g
s
1 g
.63778 .27587 m .66776 .253 L .66266 .23698 L p F P
0 g
s
1 g
.67409 .18427 m .70495 .15923 L .71485 .15217 L p F P
0 g
s
1 g
.70495 .15923 m .67409 .18427 L .66668 .1943 L p F P
0 g
s
1 g
.65597 .30493 m .68642 .28273 L .67582 .26853 L p F P
0 g
s
1 g
.67582 .26853 m .64562 .29106 L .65597 .30493 L p F P
0 g
s
1 g
.64562 .29106 m .67582 .26853 L .66776 .253 L p F P
0 g
s
1 g
.78666 .1256 m .7539 .15144 L .73996 .14824 L p F P
0 g
s
.74091 .23072 m
.73141 .23773 L
s
1 g
.75465 .31222 m .78758 .29008 L .77422 .29086 L p F P
0 g
s
1 g
.77422 .29086 m .74142 .31311 L .75465 .31222 L p F P
0 g
s
1 g
.77255 .1222 m .73996 .14824 L .72672 .14847 L p F P
0 g
s
1 g
.73996 .14824 m .77255 .1222 L .78666 .1256 L p F P
0 g
s
1 g
.69755 .16934 m .66668 .1943 L .66215 .20686 L p F P
0 g
s
1 g
.66668 .1943 m .69755 .16934 L .70495 .15923 L p F P
0 g
s
.75054 .22361 m
.74091 .23072 L
s
1 g
.8156 .26772 m .85016 .2444 L .84337 .25494 L p F P
0 g
s
1 g
.84337 .25494 m .80876 .27815 L .8156 .26772 L p F P
0 g
s
1 g
.74142 .31311 m .77422 .29086 L .75986 .28799 L p F P
0 g
s
1 g
.75986 .28799 m .72724 .31041 L .74142 .31311 L p F P
0 g
s
1 g
.75919 .12228 m .72672 .14847 L .71485 .15217 L p F P
0 g
s
1 g
.72672 .14847 m .75919 .12228 L .77255 .1222 L p F P
0 g
s
1 g
.69308 .18206 m .66215 .20686 L .66077 .22133 L p F P
0 g
s
1 g
.66215 .20686 m .69308 .18206 L .69755 .16934 L p F P
0 g
s
.76031 .21639 m
.75054 .22361 L
s
1 g
.72724 .31041 m .75986 .28799 L .74525 .28157 L p F P
0 g
s
1 g
.74525 .28157 m .71284 .30423 L .72724 .31041 L p F P
0 g
s
1 g
.69182 .19676 m .66077 .22133 L .66266 .23698 L p F P
0 g
s
1 g
.66077 .22133 m .69182 .19676 L .69308 .18206 L p F P
0 g
s
1 g
.80876 .27815 m .84337 .25494 L .83387 .26258 L p F P
0 g
s
1 g
.83387 .26258 m .79928 .28575 L .80876 .27815 L p F P
0 g
s
1 g
.74723 .12591 m .71485 .15217 L .70495 .15923 L p F P
0 g
s
1 g
.71485 .15217 m .74723 .12591 L .75919 .12228 L p F P
0 g
s
1 g
.71284 .30423 m .74525 .28157 L .73115 .27189 L p F P
0 g
s
1 g
.73115 .27189 m .69898 .29484 L .71284 .30423 L p F P
0 g
s
1 g
.69388 .21269 m .66266 .23698 L .66776 .253 L p F P
0 g
s
1 g
.66266 .23698 m .69388 .21269 L .69182 .19676 L p F P
0 g
s
.77021 .20908 m
.76031 .21639 L
s
1 g
.69898 .29484 m .73115 .27189 L .71833 .25945 L p F P
0 g
s
1 g
.71833 .25945 m .68642 .28273 L .69898 .29484 L p F P
0 g
s
1 g
.79928 .28575 m .83387 .26258 L .82211 .26686 L p F P
0 g
s
1 g
.82211 .26686 m .78758 .29008 L .79928 .28575 L p F P
0 g
s
1 g
.69918 .22903 m .66776 .253 L .67582 .26853 L p F P
0 g
s
1 g
.66776 .253 m .69918 .22903 L .69388 .21269 L p F P
0 g
s
1 g
.70495 .15923 m .7373 .13297 L .74723 .12591 L p F P
0 g
s
1 g
.7373 .13297 m .70495 .15923 L .69755 .16934 L p F P
0 g
s
1 g
.68642 .28273 m .71833 .25945 L .70748 .2449 L p F P
0 g
s
1 g
.70748 .2449 m .67582 .26853 L .68642 .28273 L p F P
0 g
s
1 g
.67582 .26853 m .70748 .2449 L .69918 .22903 L p F P
0 g
s
1 g
.82101 .09852 m .78666 .1256 L .77255 .1222 L p F P
0 g
s
1 g
.78758 .29008 m .82211 .26686 L .80862 .26753 L p F P
0 g
s
1 g
.80862 .26753 m .77422 .29086 L .78758 .29008 L p F P
0 g
s
.78026 .20166 m
.77021 .20908 L
s
1 g
.80673 .09489 m .77255 .1222 L .75919 .12228 L p F P
0 g
s
1 g
.77255 .1222 m .80673 .09489 L .82101 .09852 L p F P
0 g
s
1 g
.72992 .14317 m .69755 .16934 L .69308 .18206 L p F P
0 g
s
1 g
.69755 .16934 m .72992 .14317 L .7373 .13297 L p F P
0 g
s
1 g
.85016 .2444 m .8864 .21995 L .87967 .23059 L p F P
0 g
s
1 g
.87967 .23059 m .84337 .25494 L .85016 .2444 L p F P
0 g
s
1 g
.77422 .29086 m .80862 .26753 L .79409 .26447 L p F P
0 g
s
1 g
.79409 .26447 m .75986 .28799 L .77422 .29086 L p F P
0 g
s
1 g
.79324 .09482 m .75919 .12228 L .74723 .12591 L p F P
0 g
s
1 g
.75919 .12228 m .79324 .09482 L .80673 .09489 L p F P
0 g
s
1 g
.72553 .15605 m .69308 .18206 L .69182 .19676 L p F P
0 g
s
1 g
.69308 .18206 m .72553 .15605 L .72992 .14317 L p F P
0 g
s
.79045 .19413 m
.78026 .20166 L
s
1 g
.75986 .28799 m .79409 .26447 L .77926 .25779 L p F P
0 g
s
1 g
.77926 .25779 m .74525 .28157 L .75986 .28799 L p F P
0 g
s
1 g
.7244 .17098 m .69182 .19676 L .69388 .21269 L p F P
0 g
s
1 g
.69182 .19676 m .7244 .17098 L .72553 .15605 L p F P
0 g
s
1 g
.84337 .25494 m .87967 .23059 L .87018 .23825 L p F P
0 g
s
1 g
.87018 .23825 m .83387 .26258 L .84337 .25494 L p F P
0 g
s
1 g
.78121 .09836 m .74723 .12591 L .7373 .13297 L p F P
0 g
s
1 g
.74723 .12591 m .78121 .09836 L .79324 .09482 L p F P
0 g
s
.80079 .1865 m
.79045 .19413 L
s
1 g
.74525 .28157 m .77926 .25779 L .76491 .2478 L p F P
0 g
s
1 g
.76491 .2478 m .73115 .27189 L .74525 .28157 L p F P
0 g
s
1 g
.72663 .1872 m .69388 .21269 L .69918 .22903 L p F P
0 g
s
1 g
.69388 .21269 m .72663 .1872 L .7244 .17098 L p F P
0 g
s
1 g
.73115 .27189 m .76491 .2478 L .75182 .23502 L p F P
0 g
s
1 g
.75182 .23502 m .71833 .25945 L .73115 .27189 L p F P
0 g
s
1 g
.83387 .26258 m .87018 .23825 L .85835 .24249 L p F P
0 g
s
1 g
.85835 .24249 m .82211 .26686 L .83387 .26258 L p F P
0 g
s
1 g
.73216 .20388 m .69918 .22903 L .70748 .2449 L p F P
0 g
s
1 g
.69918 .22903 m .73216 .20388 L .72663 .1872 L p F P
0 g
s
1 g
.7373 .13297 m .77125 .10541 L .78121 .09836 L p F P
0 g
s
1 g
.77125 .10541 m .7373 .13297 L .72992 .14317 L p F P
0 g
s
1 g
.71833 .25945 m .75182 .23502 L .74071 .22011 L p F P
0 g
s
1 g
.74071 .22011 m .70748 .2449 L .71833 .25945 L p F P
0 g
s
1 g
.70748 .2449 m .74071 .22011 L .73216 .20388 L p F P
0 g
s
1 g
.85705 .07009 m .82101 .09852 L .80673 .09489 L p F P
0 g
s
.81129 .17875 m
.80079 .1865 L
s
1 g
.82211 .26686 m .85835 .24249 L .84475 .24303 L p F P
0 g
s
1 g
.84475 .24303 m .80862 .26753 L .82211 .26686 L p F P
0 g
s
1 g
.84261 .06623 m .80673 .09489 L .79324 .09482 L p F P
0 g
s
1 g
.80673 .09489 m .84261 .06623 L .85705 .07009 L p F P
0 g
s
1 g
.76391 .11569 m .72992 .14317 L .72553 .15605 L p F P
0 g
s
1 g
.72992 .14317 m .76391 .11569 L .77125 .10541 L p F P
0 g
s
.82193 .17089 m
.81129 .17875 L
s
1 g
.8864 .21995 m .92446 .19426 L .9178 .20501 L p F P
0 g
s
1 g
.9178 .20501 m .87967 .23059 L .8864 .21995 L p F P
0 g
s
1 g
.80862 .26753 m .84475 .24303 L .83004 .23976 L p F P
0 g
s
1 g
.83004 .23976 m .79409 .26447 L .80862 .26753 L p F P
0 g
s
1 g
.829 .06598 m .79324 .09482 L .78121 .09836 L p F P
0 g
s
1 g
.79324 .09482 m .829 .06598 L .84261 .06623 L p F P
0 g
s
1 g
.7596 .12873 m .72553 .15605 L .7244 .17098 L p F P
0 g
s
1 g
.72553 .15605 m .7596 .12873 L .76391 .11569 L p F P
0 g
s
1 g
.79409 .26447 m .83004 .23976 L .81498 .23281 L p F P
0 g
s
1 g
.81498 .23281 m .77926 .25779 L .79409 .26447 L p F P
0 g
s
1 g
.75862 .1439 m .7244 .17098 L .72663 .1872 L p F P
0 g
s
1 g
.7244 .17098 m .75862 .1439 L .7596 .12873 L p F P
0 g
s
1 g
.87967 .23059 m .9178 .20501 L .90833 .2127 L p F P
0 g
s
1 g
.90833 .2127 m .87018 .23825 L .87967 .23059 L p F P
0 g
s
.83274 .16291 m
.82193 .17089 L
s
1 g
.8169 .06942 m .78121 .09836 L .77125 .10541 L p F P
0 g
s
1 g
.78121 .09836 m .8169 .06942 L .829 .06598 L p F P
0 g
s
1 g
.77926 .25779 m .81498 .23281 L .80038 .22249 L p F P
0 g
s
1 g
.80038 .22249 m .76491 .2478 L .77926 .25779 L p F P
0 g
s
1 g
.76105 .16042 m .72663 .1872 L .73216 .20388 L p F P
0 g
s
1 g
.72663 .1872 m .76105 .16042 L .75862 .1439 L p F P
0 g
s
1 g
.76491 .2478 m .80038 .22249 L .78702 .20934 L p F P
0 g
s
1 g
.78702 .20934 m .75182 .23502 L .76491 .2478 L p F P
0 g
s
1 g
.87018 .23825 m .90833 .2127 L .89645 .21688 L p F P
0 g
s
1 g
.89645 .21688 m .85835 .24249 L .87018 .23825 L p F P
0 g
s
1 g
.76681 .17745 m .73216 .20388 L .74071 .22011 L p F P
0 g
s
1 g
.73216 .20388 m .76681 .17745 L .76105 .16042 L p F P
0 g
s
1 g
.77125 .10541 m .80693 .07646 L .8169 .06942 L p F P
0 g
s
1 g
.80693 .07646 m .77125 .10541 L .76391 .11569 L p F P
0 g
s
1 g
.75182 .23502 m .78702 .20934 L .77562 .19405 L p F P
0 g
s
1 g
.77562 .19405 m .74071 .22011 L .75182 .23502 L p F P
0 g
s
1 g
.74071 .22011 m .77562 .19405 L .76681 .17745 L p F P
0 g
s
.84371 .15481 m
.83274 .16291 L
s
1 g
.85835 .24249 m .89645 .21688 L .88273 .21727 L p F P
0 g
s
1 g
.88273 .21727 m .84475 .24303 L .85835 .24249 L p F P
0 g
s
1 g
.79963 .08681 m .76391 .11569 L .7596 .12873 L p F P
0 g
s
1 g
.76391 .11569 m .79963 .08681 L .80693 .07646 L p F P
0 g
s
.85484 .1466 m
.84371 .15481 L
s
1 g
.84475 .24303 m .88273 .21727 L .86785 .21378 L p F P
0 g
s
1 g
.86785 .21378 m .83004 .23976 L .84475 .24303 L p F P
0 g
s
1 g
.79543 .10001 m .7596 .12873 L .75862 .1439 L p F P
0 g
s
1 g
.7596 .12873 m .79543 .10001 L .79963 .08681 L p F P
0 g
s
.86614 .13825 m
.85484 .1466 L
s
1 g
.83004 .23976 m .86785 .21378 L .85257 .20653 L p F P
0 g
s
1 g
.85257 .20653 m .81498 .23281 L .83004 .23976 L p F P
0 g
s
1 g
.79461 .11542 m .75862 .1439 L .76105 .16042 L p F P
0 g
s
1 g
.75862 .1439 m .79461 .11542 L .79543 .10001 L p F P
0 g
s
1 g
.81498 .23281 m .85257 .20653 L .8377 .19587 L p F P
0 g
s
1 g
.8377 .19587 m .80038 .22249 L .81498 .23281 L p F P
0 g
s
1 g
.79725 .13226 m .76105 .16042 L .76681 .17745 L p F P
0 g
s
1 g
.76105 .16042 m .79725 .13226 L .79461 .11542 L p F P
0 g
s
.87761 .12978 m
.86614 .13825 L
s
1 g
.80038 .22249 m .8377 .19587 L .82405 .18233 L p F P
0 g
s
1 g
.82405 .18233 m .78702 .20934 L .80038 .22249 L p F P
0 g
s
1 g
.80327 .14964 m .76681 .17745 L .77562 .19405 L p F P
0 g
s
1 g
.76681 .17745 m .80327 .14964 L .79725 .13226 L p F P
0 g
s
1 g
.78702 .20934 m .82405 .18233 L .81236 .16664 L p F P
0 g
s
1 g
.81236 .16664 m .77562 .19405 L .78702 .20934 L p F P
0 g
s
1 g
.77562 .19405 m .81236 .16664 L .80327 .14964 L p F P
0 g
s
.88926 .12118 m
.87761 .12978 L
s
.90109 .11244 m
.88926 .12118 L
s
.91311 .10357 m
.90109 .11244 L
s
.92532 .09456 m
.91311 .10357 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[48]:=",
  ImageSize->{482.688, 311.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007R0001=b000`400?l00000o`00003ooooooooS
ooooo`00oooooooSooooo`00oooooooSooooo`00oooooooSooooo`00oooooooSooooo`00oooooooS
ooooo`00oooooooSooooo`00oooooooSooooo`00oooooooSooooo`00oooooooSooooo`00oooooooS
ooooo`00oooooooSooooo`00oooooooSooooo`00oooooooSooooo`00oooooooSooooo`00oooooooS
ooooo`00`oooool00ol0003oooooooooo`3ooooooagooooo0033ooooo`03o`000?oooooooooo0?oo
oooo7Oooool00<?ooooo00?o0000ooooooooool0oooooolMooooo`00`_ooool00ol0003ooooooooo
o`3ooooooakooooo0032ooooo`03o`000?oooooooooo0?oooooo7_ooool00<;ooooo00?o0000oooo
ooooool0oooooolNooooo`00`_ooool00ol0003oooooooooo`3ooooooakooooo0031ooooo`03o`00
0?oooooooooo0?oooooo7oooool00<7ooooo00?o0000ooooooooool0oooooolOooooo`00`Oooool0
0ol0003oooooooooo`3ooooooaoooooo0030ooooo`03o`000?oooooooooo0?oooooo8?ooool00<3o
oooo00?o0000ooooooooool0oooooolPooooo`00_oooool00ol0003oooooooooo`3oooooob7ooooo
002oooooo`03o`000?oooooooooo0?oooooo8Oooool00;oooooo00?o0000ooooooooool0oooooolQ
ooooo`00__ooool00ol0003oooooooooo`3oooooob;ooooo002nooooo`03o`000?oooooooooo0?oo
oooo8_ooool00;kooooo00?o0000ooooooooool0oooooolRooooo`00/Oooool6o`0000Oooooo00?o
0000ooooooooool0oooooolRooooo`00]oooool5o`000003ooooool0003ooooo0?oooooo9?ooool0
0;3ooooo0_l000000ooooooo0000o`000007ooooo`;o0000oooooolUooooo`00/?ooool2o`000005
ooooool0003o0000ooooool000000_ooool01Ol0003oooooooooool0003ooooo00?o0000oooooolR
ooooo`00/?ooool3o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool000000oooool0
1?l0003oooooo`000?l0003oooooob3ooooo002_ooooo`;o000000Koooooo`000?oooooo0000oooo
ool00002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooo0000ooooo`02o`000?oo
oooo7_ooool00:oooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000o`000?oooooo7?ooool0
0:oooooo0ol000001?oooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go
0000ooooool0003oooooo`000002ooooo`?o0000oooooolKooooo`00[oooool3o`000004ooooool0
003oooooo`0000;ooooo00?o0000ooooool000000_ooool01ol0003oooooooooool0003oooooo`00
0?ooool00_l000000ooooooo0000ooooo`3ooooooa[ooooo002^ooooo`;o000000?oooooo`000?l0
00000_ooool00ol0003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool0
0ol0003oooooo`000002o`000?oooooo7?ooool00:kooooo0ol000001?oooooo0000ooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o0000
oooooolLooooo`00[_ooool3o`000006ooooool0003oooooo`000?oooooo00000_ooool01?l0003o
ooooooooool00002ooooo`06o`000?oooooo0000ooooool0003ooooo0_l0003ooooooacooooo002]
ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooo`000?ooool3o`000?oooooo7Oooool00:gooooo1Ol000001Ooooooo0000
oooooooooooo000000;ooooo00?o0000ooooool000000_ooool01Ol0003oooooooooool0003ooooo
00?o0000oooooolMooooo`00/Oooool5o`0000?ooooo00?o0000ooooool000000_ooool00ol0003o
ooooo`000002ooooo`?o0000oooooolMooooo`00[?ooool3o`0000Kooooo0_l000001Ooooooo0000
oooooooooooo000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo
0?oooooo6oooool00:cooooo0ol000001?oooooo0000ooooool00004ooooo`?o00001_ooool00ol0
003oooooo`000002o`000?oooooo7_ooool00:_ooooo0_l000002?oooooo0000ooooool0003ooooo
o`000?oooooo00000oooool00ol0003oooooo`000004o`0000?ooooo0ol0003ooooooakooooo002[
ooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooo`000?l00002ooooo`;o0000oooooolNooooo`00Zoooool3o`00
0007ooooool0003oooooooooool0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00Ko
0000oooooooooooo0000ooooool0003oooooob7ooooo002Zooooo`;o000000Soooooo`000?oooooo
0000ooooool0003oooooo`0000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`?o0000oooooolOooooo`00Z_ooool2o`000008ooooool0003oooooo`000?oooooo0000oooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool2
o`000?oooooo7oooool00:[ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000000_ooool0
0ol0003oooooo`000002ooooo`05o`000?ooooooooooo`000?ooool00ol0003oooooob3ooooo002Y
ooooo`;o000000Koooooo`000?oooooo0000ooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00000_ooool00ol0003oooooooooo`02o`000003ooooool0003o00000?oooooo8?ooool00:Wo
oooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00000oooool00ol0003oooooo`00
0002ooooo`06o`000?oooooo0000ooooool0003ooooo0_l0003oooooob3ooooo002Xooooo`;o0000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01_l0003oooooooooool0003o
ooooo`0000;ooooo00?o0000ooooool000000ol0003oooooob3ooooo002Xooooo`Co000000Oooooo
o`000?ooooooooooo`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`02o`000003ooooool0003o00000?oooooo8Oooool00:_ooooo1Ol000000ooooooo0000oooo
o`02ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2o`000?oo
oooo8Oooool00:Oooooo0_l00006ooooo`Co000000Ooooooo`000?ooooooooooo`000?oooooo0000
00;ooooo00Co0000ooooool0003ooooo0_l0003oooooob7ooooo002Wooooo`;o000000Coooooo`00
0?oooooo00001_ooool3o`0000?ooooo00?o0000ooooooooool00_l000000ooooooo0000o`00003o
ooooob;ooooo002Wooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo
00Co0000ooooool0003o00001?ooool2o`000003ooooool0003ooooo0?oooooo8_ooool00:Kooooo
0_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
oooo0000ooooo`02o`0000Gooooo0_l0003oooooob;ooooo002Vooooo`;o000000Koooooo`000?oo
oooo0000ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003ooooo
o`000003o`0000;ooooo00?o0000ooooooooool0oooooolPooooo`00Y_ooool2o`000006ooooool0
003oooooo`000?oooooo00000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000ooo
ool2o`000003ooooool0003ooooo0?oooooo8oooool00:Kooooo0ol000001ooooooo0000oooooooo
oooo0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo0_l00002oooo
o`;o0000oooooolSooooo`00YOooool2o`000006ooooool0003oooooo`000?oooooo00000_ooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00_l000001?oooooo0000
ooooool0003oooooob?ooooo002Uooooo`;o000000Koooooo`000?oooooo0000ooooool00002oooo
o`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`04o`000?oooooo0000ooooo`;o
0000oooooolTooooo`00YOooool3o`000007ooooool0003oooooooooool0003oooooo`000002oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000003o`000?oooooo9?oo
ool00:Cooooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?l00000oooooolUoooo
o`00Y?ooool3o`000005ooooool0003oooooooooool000000_ooool00ol0003oooooo`000002oooo
o`09o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo00;o0000oooooolUooooo`00YOoo
ool6o`0000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooo000000?o0000oooooolUooooo`00Xoooool00ol0003oooooooooo`04ooooo`;o000000Gooooo
o`000?ooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_l0
003oooooobKooooo002Sooooo`?o000000?oooooo`000?ooool00oooool4o`0000Gooooo00Ko0000
ooooool0003oooooo`000?ooool2o`000?oooooo9_ooool00:?ooooo0ol000001?oooooo0000oooo
ool00005ooooo`Go00000oooool01_l0003oooooo`000?l0003oooooo`000?oooooo9_ooool00:;o
oooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooo`000?l00003ooooo`?o0000oooooolWooooo`00X_ooool3o`0000;ooooo
00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooo`000?oo
ool00_l00003ooooo`03o`000?oooooooooo0?oooooo9Oooool00:;ooooo0ol000001?oooooo0000
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01?l0
003oooooo`000?l0003oooooobWooooo002Rooooo`?o000000Coooooo`000?oooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool000000_ooool3o`000?oooooo
:?ooool00:7ooooo00So0000ooooool0003o0000ooooool0003oooooo`0000;ooooo00?o0000oooo
ool000000_ooool01ol0003oooooooooool0003oooooo`000?ooool00_l000000ooooooo0000oooo
o`3oooooobOooooo002Qooooo`?o000000Ooooooo`000?ooooooooooo`000?oooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?ooool3o`000?oooooo:Oooool00:7o
oooo0ol000001?oooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00So0000
ooooool0003oooooo`000?oooooo0000ooooo`;o0000oooooolYooooo`00X?ooool4o`000004oooo
ool0003oooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oooooo
0000ooooo`;o000000?oooooo`000?ooool0oooooolXooooo`00X?ooool3o`0000;ooooo00Go0000
ooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o
oooo0ol0003oooooob[ooooo002Pooooo`Go000000Goooooo`000?ooooooooooo`000002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool00_l000000ooooooo0000o`00003oooooob[o
oooo002Oooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`03o`000?oooooo000000;ooooo
00Ko0000ooooool0003oooooo`000?ooool2o`000?oooooo:_ooool009oooooo0ol00006ooooo`;o
000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?ooool0oooooolYooooo`00Woooool3o`000004ooooool0003oooooo`0000Cooooo0ol00004
ooooo`05o`000?oooooo0000o`000?ooool00_l0003oooooob_ooooo002Nooooo`Co000000Kooooo
o`000?oooooo0000ooooool00003ooooo`04o`000?oooooo0000o`0000Gooooo00Co0000ooooool0
003o0000ooooool[ooooo`00W_ooool3o`000007ooooool0003oooooooooool0003oooooo`000002
ooooo`05o`000?ooooooooooo`000?ooool01?l00004ooooo`03o`000?oooooooooo0?oooooo:Ooo
ool009kooooo0ol000001ooooooo0000oooooooooooo0000ooooool000000_ooool00ol0003ooooo
o`000003ooooo`03o`000?oooooo000000?o0000ooooool]ooooo`00W_ooool3o`000006ooooool0
003oooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo0000
ooooool0003ooooo0_l0003oooooobcooooo002Mooooo`Go00000_ooool00ol0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00So0000ooooool0003o0000ooooool0003oooooo`00
0?oooooo;?ooool009gooooo0ol000001ooooooo0000oooooooooooo0000ooooool000000_ooool0
0ol0003oooooo`000002ooooo`06o`000?oooooo0000ooooool0003ooooo0_l0003oooooobgooooo
002Mooooo`?o000000Coooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`07o`00
0?ooooooooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo0?oooooo;?ooool009co
oooo1Ol00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0
003oooooo`000?l0003ooooo00?o0000ooooool]ooooo`00W?ooool3o`000007ooooool0003ooooo
ooooool0003oooooo`000002ooooo`0;o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo
o`000?ooool00_l0003oooooobkooooo002Looooo`Co00000oooool01Ol0003oooooo`000?oooooo
000000;ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool0
ooooool]ooooo`00Voooool01?l0003oooooooooooooool2o`000004ooooool0003oooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?ooool4o`000?oooooo;_ooool0
09_ooooo0ol00003ooooo`Ko00000oooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo
0ol0003oooooobkooooo002Jooooo`Go00001oooool2o`0000Cooooo00Co0000ooooool0003ooooo
0_l000000ooooooo0000ooooo`3oooooobkooooo002Jooooo`;o000000?oooooo`000?l000000_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o00001Oooool4o`000?oooooo;ooo
ool009[ooooo0ol000002Ooooooo0000oooooooooooo0000ooooool0003oooooo`000003ooooo`03
o`000?oooooo000000?o00000oooool2o`000?oooooo;oooool009Wooooo1Ol00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool01ol0003oooooooooool0003oooooo`000?ooool00_l0
003ooooooc;ooooo002Iooooo`;o000000?oooooo`000?l000000_ooool01_l0003oooooooooool0
003oooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`Co0000ooooool`ooooo`00
VOooool2o`000003ooooool0003o000000;ooooo00Go0000ooooool0003oooooo`000003ooooo`06
o`000?oooooo0000ooooool0003ooooo0_l000000ooooooo0000o`00003ooooooc3ooooo002Hoooo
o`Co000000Coooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`07o`000?oooooo
ooooo`000?oooooo0000ooooo`04o`000?oooooo<Oooool009Sooooo0_l000000ooooooo0000o`00
0002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000000?o0000oooooolaooooo`00Uoooool01?l0003oooooo`000?ooool2o`0000;o
oooo00?o0000ooooool000000_ooool02Ol0003oooooooooool0003oooooo`000?oooooo0000oooo
o`02o`000003ooooool0003ooooo0?oooooo<Oooool009Oooooo0_l000001_oooooo0000ooooool0
003oooooo`0000;ooooo00?o0000ooooool000000oooool01_l0003oooooo`000?oooooo0000oooo
o`Co0000goooool6o`0004cooooo002Hooooo`Co00000_ooool01_l0003oooooooooool0003ooooo
o`0000;ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00Co0000gOooool3o`0000;ooooo
00Co0000oooooooooooo0000Boooool009Kooooo00?o0000ooooooooool00_ooool3o`0000?ooooo
00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0003Mooooo`?o
000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1:ooooo`00U_ooool2o`000003oooo
ool0003ooooo00;ooooo0_l000001?oooooo0000ooooool00003ooooo`06o`000?oooooo0000oooo
ool0003ooooo0_l000000ooooooo0000ooooo`3Looooo`04o`000?ooooooooooo`0000;ooooo0_l0
001=ooooo`00Uoooool01?l0003oooooo`000?l00004ooooo`Go00001?ooool01?l0003oooooo`00
0?ooool4o`000=[ooooo00Co0000ooooool0003ooooo0_l00002ooooo`03o`000?oooooooooo04go
oooo002Eooooo`Co000000Coooooo`000?oooooo00001Oooool00ol0003oooooo`000002o`0000?o
oooo00?o0000ooooool000000_l0003Jooooo`;o000000Coooooo`000?l0003o00000_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo002Eooooo`;o000000Koooooo`000?oo
oooo0000ooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003o00001Ooo
ool00ol0003oooooooooo`3Gooooo`;o000000?oooooo`000?l000000_ooool2o`00013ooooo0_l0
000oooooo`00U_ooool01?l0003oooooo`000?l00002ooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool01Ol0003oooooooooool0003ooooo00Co0000f_ooool2o`000003ooooool0003o0000
00;ooooo0_l0000@ooooo`03o`000?oooooooooo03oooooo002Eooooo`?o000000Coooooo`000?oo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooool000000_l0003Gooooo`?o000000Koooooo`000?oooooo0000ooooool0000Aooooo`03o`00
0?oooooooooo043ooooo002Dooooo`Co000000Coooooo`000?oooooo00000_ooool00ol0003ooooo
o`000002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo
0=Gooooo0_l000000ooooooo0000o`000002ooooo`;o00004?ooool2o`0004?ooooo002Dooooo`;o
000000Koooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00Oo0000
oooooooooooo0000ooooool0003ooooo00?o0000e_ooool4o`0000;ooooo0ol0000@ooooo`03o`00
0?oooooooooo04?ooooo002Dooooo`?o000000Ooooooo`000?ooooooooooo`000?oooooo000000;o
oooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo000000;o0000e?ooool5
o`0000;ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`14ooooo`00Toooool0
2?l0003oooooo`000?l0003oooooo`000?oooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000;ooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`3Booooo`;o00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00_ooooo0_l00017ooooo`00Tooo
ool3o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`07o`000?oo
ooooooooo`000?oooooo0000ooooo`03o`000=Cooooo00?o0000ooooooooool01?l00003ooooo`;o
00003?ooool00ol0003oooooooooo`17ooooo`00U?ooool4o`0000;ooooo00?o0000ooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000ooooo`?o0000dOooool01?l0
003oooooo`000?ooool2o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0B?ooool009;ooooo00?o0000ooooooooool00_ooool3o`00
00;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooo`000?ooool0
0ol0003@ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`;o0000Boooool009;ooooo0ol00004ooooo`?o00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?oo
ool0c_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000Cooooo00?o0000oooo
ool000001_ooool00ol0003oooooooooo`1;ooooo`00T_ooool3o`000003ooooool0003ooooo00?o
oooo1Ol00004ooooo`04o`000?oooooo0000ooooo`?o0000coooool2o`0000;ooooo00?o0000oooo
ool000001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0C?ooool0097ooooo00So0000ooooool0003o0000ooooool0003oooooo`0000Gooooo
00Co0000ooooool0003o00001?ooool00ol0003oooooo`000002o`000<oooooo00?o0000ooooool0
00000ol00003ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
0000Coooool0097ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000000_ooool01Ol0003o
ooooooooool0003ooooo00?o00001Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooool00000DOooool0097ooooo0ol000001ooooooo0000oooooooooooo0000ooooool000000_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooo000000?o0000coooool3o`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o000000?oooooo`000?ooool0DOoo
ool0097ooooo0ol000001?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000002o`000<cooooo0ol00002ooooo`;o0000
00Coooooo`000?l0003o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Coooool0093ooooo00[o0000ooooool0003o0000ooooool0003ooooo
o`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000ooooo`;o
000000?oooooo`000?ooool0b_ooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00?o0000
ooooooooool00oooool3o`0000?ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000oooo
o`1?ooooo`00T?ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00Go0000oooooooooooo0000ooooo`03o`000<[ooooo0_l000000ooooooo0000
ooooo`02o`0000?ooooo0_l00003ooooo`;o00000oooool3o`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1=ooooo`00T?ooool3o`000009ooooool0003oooooooooool0003o
ooooo`000?oooooo000000;ooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?ooool0
0_l00039ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`;o00000_ooool3o`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0??ooool008oooooo00So0000ooooool0003o0000ooooool0003ooooo
o`0000;ooooo00?o0000ooooool000000_ooool01ol0003oooooooooool0003oooooo`000?ooool0
0ol00038ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003ooooo00?ooooo
00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo00;o00001Oooool2o`000003oooo
ool0003ooooo00_ooooo0_l0000oooooo`00Soooool3o`0000;ooooo00Go0000ooooool0003ooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002o`00
0<Oooooo0_l00002ooooo`05o`000?oooooo0000o`000?ooool00_l00004ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo0_l00008ooooo`?o0000@?ooool0093ooooo1?l00002ooooo`05o`000?oooooo0000
ooooool000000_ooool02Ol0003oooooooooool0003oooooo`000?oooooo0000ooooo`02o`000<Oo
oooo00?o0000ooooool000000ol00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0
003oooooo`000?l00004ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03o`0000?ooooo1?l00011ooooo`00S_ooool00ol0003oooooooooo`02oooo
o`?o00000_ooool00ol0003oooooo`000002ooooo`09o`000?ooooooooooo`000?oooooo0000oooo
ool0003ooooo00;o0000a?ooool01_l0003oooooo`000?oooooo0000ooooo`;o00000oooool2o`00
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00000oooool01?l0
003oooooo`000?l00003ooooo`;o00000_ooool2o`0000;ooooo1_l00012ooooo`00S_ooool3o`00
00Cooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ool000000_l00034ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00005ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool5o`0004Cooooo002>oooo
o`?o000000?oooooo`000?ooool00oooool4o`0000Cooooo00Ko0000ooooool0003oooooo`000?oo
ool2o`000<?ooooo0_l000000ooooooo0000ooooo`02ooooo`04o`000?oooooo0000o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooool000001Oooool2o`000005oooo
ool0003o0000ooooool000000oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo
04Cooooo002=ooooo`08o`000?oooooo0000o`000?oooooo0000ooooool00004ooooo`03o`000?oo
oooo000000;o00000oooool01?l0003oooooo`000?ooool2o`000<?ooooo00Go0000ooooool0003o
0000ooooo`02o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo0_l000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l00000A_ooool008gooooo0ol000002Ooooooo0000
oooooooooooo0000ooooool0003oooooo`000003ooooo`04o`000?oooooo0000o`000;cooooo1?l0
0?l7ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l0
0002ooooo`03o`000?oooooo000000Gooooo00Co0000ooooool0003ooooo0_l00005ooooo`;o0000
0_ooool2o`0000;ooooo1Ol00018ooooo`00SOooool3o`000004ooooool0003oooooo`0000;ooooo
00?o0000ooooool000000_ooool01Ol0003oooooooooool0003ooooo00Ko0000]_ooool4o`00o`Ko
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02o`0000;ooooo0_l00005oooo
o`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo0_l00002oooo
o`;o00000_ooool3o`000003ooooool0003o000004Wooooo002=ooooo`?o000000Coooooo`000?oo
oooo00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00Co0000oooo
ool0003ooooo0_l0002fooooo`Co003o00?oH_l0ooooooooool00_ooool2o`000003ooooool0003o
oooo00;ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00000
1Ooooooo0000oooooooooooo000000Cooooo00Go0000ooooool0003o0000ooooo`02o`0000?ooooo
00Co0000oooooooooooooooo1Ol0001;ooooo`00S?ooool00ol0003oooooo`000002o`0000;ooooo
00Go0000ooooool0003oooooo`000003ooooo`08o`000?oooooo0000ooooool0003oooooo`000?oo
ool2o`000;Oooooo1?l00?l01oooooooH_l0of;o0?mRo`3oooooo`000?ooool00_l000001?oooooo
0000o`000?ooool2o`0000Cooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`;o00001?ooool2o`0000;ooooo0_l00002ooooo`Go0000COooool008cooooo0ol00000
1?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00Wo0000oooooooooooo0000
ooooool0003oooooo`000?ooool00_l0002fooooo`05oico0?ooooooo`1cooooool0ROl01?ooool3
o`000003ooooool0003o000000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`?o00001Ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00ol000001?oooooo0000
o`000?ooool3o`0004kooooo002<ooooo`?o000000Coooooo`000?oooooo00000_ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000ol0002dooooo`;o
W?l00oooool00ooo07?oooooo`29o`03ooooo`05o`000?ooooooooooooooool000000oooool2o`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o000000Coooooo`00
0?oooooo00001?ooool2o`0000;ooooo0_l00002ooooo`Go0000D?ooool008_ooooo00?o0000oooo
ool000000_l00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool02?l0003oooooo`00
0?oooooo0000ooooool0003ooooo0_l0002dooooo`03oico0?oooooooooo00?ooooo00Koo`1coooo
ool0ROoo0000ooooool00003ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Cooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000002ooooo`;o000000?oooooo`000?l00000D_ooool008_ooooo0ol0
0004o`00o`;ooooo00?o0000ooooool000000oooool02?l0003oooooo`000?oooooo0000ooooool0
003ooooo0_l0002cooooo`03oico0?oooooooooo00Cooooo00Coo`1cooooool0003ooooo0_l00000
1?oooooo0000o`000?ooool2o`0000Cooooo00Co0000oooooooooooooooo0_l00002ooooo`04o`00
0?oooooo0000o`0000?ooooo0_l000001Ooooooo0000o`000?oooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool2o`0005?ooooo002<ooooo`;o00001?l00?l2ooooo`03o`000?oooooo0000
00;ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00Co0000/_ooool00onLo`3ooooooooo
o`05ooooo`05ool0Lol0003o0000o`000?ooool00_l00003ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooool0003oooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l00000EOooool008[o
oooo00Co0000oooooooooooooooo1?l00?l2ooooo`03o`000?oooooo000000;ooooo00Go0000oooo
ool0003oooooo`000002ooooo`Co0000/Oooool00onLo`3oooooooooo`05ooooo`03o`000?oo07?o
000000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?ooool00_l00004ooooo`;o00000_ooool8o`0005Kooooo002:
ooooo`?o000000?oW?l0o`00ool00?l00_l00?l4of;o00?ooooo00So0000ooooool0003oooooo`00
0?oooooo0000ooooo`;o0000/?ooool2oico00Oooooo0ol00003ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000?ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02o`000004ooooool0003o0000ooooo`;o0000F?ooool008_o
oooo0_nLo`000ol0003oooooool0L`02o`29o`Co000000?oH_l0ooooooooool00_ooool01?l0003o
ooooo`000?ooool4o`000:cooooo0ol00?l00onLo`3oooooooooo`05ooooo`03o`000?oooooo0000
00;o000000Coooooo`000?l0003ooooo0_l00004ooooo`05o`000?ooooooooooooooool000000ooo
ool3o`0000Cooooo00Go0000ooooool0003o0000ooooo`02o`0000;ooooo00Go0000oooooooooooo
0000ooooo`03o`0005Wooooo0029ooooo`03o`000?nLo`3ooooo00;o000000?oooooool0Loooool0
1?ooool00ol0003oooooo`000002o`0000Gooooo1?l0002/ooooo`;o003o00?oW?l0o`00oooo>000
1Ooo>0001Ol0003oooooo`000?l0003ooooo00;o00000oooool01?l0003oooooooooooooool2o`00
0004ooooool0003o0000o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00000
1?oooooo0000o`000?ooool5o`0005_ooooo0029ooooo`0<oico0?l0003o0000ooooool0003ooooo
o`000?oo07?oooooo`000?oooooo00000oooool00ol0003oooooo`000003o`000004oooooomRo`3o
H_l0of;o00;ooooo1?l00?nWooooo`04o`00oonLo`3oocP0oolh00Gooooo0_l000001Ooooooo0000
oooooooooooo000000;ooooo0_l000001?oooooo0000o`000?l00003ooooo`03o`000?oooooooooo
00?ooooo00Ko0000ooooool0003o0000ooooool00004ooooo`;o00000_ooool8o`0005cooooo0028
ooooo`03oico0?oooooo000000;o00000_ooool01_l0003oo`1cooooool0003oooooo`0000;ooooo
00Oo0000oooooooooooo0000ooooool0003ooooo00Co00000_mRo`04o`00ojOooooo0_l00?l01?oo
0>ko003oo`3oool0ool2ooooo`;o000000?oooooo`000?ooool01Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool0
1_l0003ooooooooooooooooo0000ooooo`;o000000?oooooo`000?l00000G_ooool008Oooooo00Co
W?l0o`000?l0003ooooo0_l000002?oooooo0000oooooooo07?oooooo`000?oooooo00000_ooool0
1Ol0003oooooo`000?oooooo000000;ooooo0_l00004oolh00;oH_l00_l00?nZooooo`06ool0k_oo
ooooooooo`3oool0003ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o
00000_ooool00ol0003oooooo`000004ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`;o
000000?oooooo`000?ooool00ol0001Oooooo`00Q_ooool01OnLo`3oooooo`000?l0003ooooo00;o
000000Ooooooo`000?ooooooo`1co`000?oooooo000000;ooooo00Oo0000oooooooooooo0000oooo
ool0003ooooo00Co00000_ooool00ol0a_oo003oool0]002o`00oj[ooooo00?oo`3^ooooool00000
0ol000000ooooooo0000ooooo`02ooooo`;o00000_ooool2o`0000;ooooo0_l00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00Go0000ooooool0003o
0000ooooo`03o`00063ooooo0021ooooo`Co003o00ooW?l0oooooooooooo0000ooooool0003ooooo
o`000?oooooo0000oooooooo07?o0000ooooool000000_ooool01ol0003oooooooooool0003ooooo
o`000?ooool01?l000001?oooooo0<Kooooooooo0;B^ooooo`03ool0k_oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02ooooo`;o000000?o
ooooo`000?ooool00_l00003ooooo`;o00000_ooool8o`0006;ooooo0021ooooo`Co003o0_oo>002
o`000003ooooool0003o000000;ooooo00Ko0000oooooooo07?o0000ooooool00002ooooo`05o`00
0?oooooo0000ooooool000000_ooool3o`000004ooooool0a_ooooooool0]:kooooo00Ko0000ool0
k_l0003o0000ooooool00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
oooo0000ooooo`;o00001?ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?ooool0
0ol0001Sooooo`00POooool01?l00?ooo`3^oolh0?oo>002ooooo`03o`000?oooooooooo00;o0000
00[oooooo`000?ooooooooooo`000?oo07?oooooo`000?oooooo00000_ooool01?l0003oooooo`00
0?ooool3o`0000;o0<Ko0_ooool00ooo0;Coooooooooo`2[ooooo`?o000000?oooooo`000?l00000
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_l00004ooooo`05o`000?oooooo0000o`000?ooool00_l0001Uoooo
o`00POooool2o`00o`04ool0k_l00?oo0?ooo`3oo`?o000000Coooooo`000?oooooo00000_ooool0
0ol0003oo`1co`000002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`04o`0000;ooooo
00?oo`2dooooooooool0Z_ooool4o`0000;ooooo00?o0000ooooooooool00ol000000ooooooo0000
o`000002ooooo`;o00001?ooool00ol0003oooooo`000002ooooo`;o00000oooool01?l0003ooooo
o`000?ooool2o`000003ooooool0003ooooo00?o0000I_ooool008Cooooo00?oo`3^ooooool00000
0_ooool2o`0000;ooooo00Ko0000oooooooooooo0000ool0Lol00002ooooo`07o`000?oooooooooo
o`000?oooooo0000ooooo`03o`0000;ooooo00?oo`2dooooooooool0Z_ooool2o`000003ooooool0
003ooooo00Go00000_ooool2o`0000Cooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`00
0?oooooo000000?ooooo0_l00003ooooo`Oo0000J?ooool008Gooooo00?oo`3^o`000?ooool00_oo
ool3o`0000;ooooo00Ko0000oooooooo07?o0000ooooool00002ooooo`03o`000?oooooo000000;o
oooo0ol00002ooooo`03ool0]?oooooooooo0:Wooooo1_l00002ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l000001?oooooo0000ooooool00005ooooo`;o00000_ooool0
1?l0003oooooooooooooool2o`0000;ooooo0ol0001Zooooo`00Q_ooool00ol0003oooooo`000003
ooooo`Go000000Coo`1coooooooooooo00000_ooool01?l0003oooooo`000?ooool4o`000003oooo
oooo0;Cooooo0:[ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo
0_l000001?oooooo0000ooooool00004ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`?o
000000?oooooo`000?l000000_ooool4o`0006_ooooo0025ooooo`;o000000?oooooo`000?l00000
1oooool00ooo07?o0000ooooo`03ooooo`04o`000?oooooo0000ooooo`?o000000?oooooool0]?oo
ool0ZOooool2o`000003ooooool0003ooooo00?o000000Coooooo`000?oooooooooo0_l00004oooo
o`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool00_l00004ooooo`03o`000?oooooo
oooo00;o00000_ooool4o`0006cooooo0025ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`05o`000?ooooooooooo`000?oo07<00_l00006ooooo`?o000000?oooooool0]?ooool0
Z?ooool6o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?oo
oooo00001?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`04o`00
06kooooo0025ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo
0000oooooooo07?o0000ooooo`05o`0000Cooooo00?oo`2dooooooooool0Yoooool3o`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`;o000000Coooooo`000?l0003o00001?ooool01?l0
003oooooooooooooool2o`000005ooooool0003o0000ooooool000000_ooool2o`0000;ooooo1?l0
001_ooooo`00QOooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000;ooooo00?o
0000oooooooo07<00oooool01?l0003oooooo`000?ooool3o`000003ool0]?oooooooooo0:Kooooo
00Go0000ooooool0003o0000ooooo`03o`000004ooooool0003o0000ooooo`;o00000oooool00ol0
003oooooooooo`03ooooo`05o`000?oooooo0000ooooool000001Oooool2o`000004ooooool0003o
ooooooooo`Go0000L?ooool008Cooooo0ol000001?oooooo0000ool0k_l00002ooooo`06o`000?oo
ooooooooo`000?ooooooo`1c0_ooool00ol0003oooooo`000002ooooo`?o000000?oo`2doooooooo
ool0YOooool00ol0003oooooo`000003o`0000;ooooo0_l00003ooooo`07o`000?oooooooooooooo
ool0003oooooo`000002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o00000_ooool7
o`0007;ooooo0024ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00Ooo`1coooooooooooo0000ooooool0003ooooo00?o000000?oo`2doooooooo
ool0YOooool2o`000004ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00ol00002oooo
o`06o`000?ooooooooooo`000?oooooo00001?ooool01?l0003oooooo`000?ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002o`0007Cooooo0024ooooo`09o`000?oooooo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Co0000ooooool0003oo`1c0_ooool01?l0003oooooo`000?oo
ool3o`000003ool0]?oooooooooo0:Cooooo0_l000000ooooooo0000o`000002o`000004ooooool0
003o0000ooooo`;o00000oooool2o`0000Cooooo00Co0000oooooooooooooooo0_l00003ooooo`;o
000000Coooooo`000?l0003ooooo1Ol0001eooooo`00Poooool3o`000004ooooool0003oooooo`00
00;ooooo00_o0000oooooooooooo0000ooooool0003oo`1cooooool0003oooooo`000002ooooo`;o
000000?oo`2dooooooooool0Y?ooool5o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l000001?oooooo0000ooooool00003ooooo`04o`000?oo07?o
ooooooooo`Oo0000Moooool008?ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00co0000oooooooooooo0000ooooool0003oo`1cooooool0003oooooo`000?ooool2o`000003ool0
]?oooooooooo0:?ooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo00?o
00000_ooool2o`000004ooooool0003oooooo`0000Cooooo0_l000001Ooooooo0000o`000?oooooo
o`1c00;o000000?oo`0io`000?oo0;@00_l0001iooooo`00Poooool2o`0000;ooooo00Go0000oooo
ool0003oooooo`000002ooooo`0:o`000?ooooooooooo`000?oo07?oooooo`000?oooooo0000oooo
o`;o000000?oo`2dooooooooool0X_ooool01Ol0003oooooooooool0003ooooo00;o00000_ooool0
1?l0003oooooo`000?l00003ooooo`;o00001?ooool01?l0003oooooooooooooool2o`0000;ooooo
0_l000001ooo0>koooooool0Loooooooo`0io`000?oo0;@00_l0001jooooo`00P_ooool00ol0003o
ooooo`000002o`000005ooooool0003oooooooooool000000_ooool00ol0003oooooo`000002oooo
o`08ool0Lol0003oooooo`000?oooooo0000ool0]?l0002Tooooo`Go00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`000004ooooool0003oooooo`00
00;ooooo0_l00002ooooo`;oo`3^00Co0000ool0Looo03Woo`2d0_l0001kooooo`00P_ooool01?l0
003oooooooooooooool5o`0000?ooooo00?o0000ooooool000000_ooool01ooo07?oooooo`000?oo
oooo0000ool0]?l00000Xoooool3o`0000;ooooo00?o0000ooooooooool00_l000001?oooooo0000
o`000?l00002ooooo`;o000000Coooooo`000?oooooo00001?ooool2o`000003ooooool0003ooooo
00;ooooo0ol000001?oo0>koo`1cool0>Ooo0;Amooooo`00P_ooool2o`0000Kooooo0_l000001Ooo
oooo0000oooooooooooo000000;ooooo00Ooo`1cooooool0003oooooo`000?oo0;Co00000:7ooooo
2_l000000ooooooo0000o`000003ooooo`;o00001?ooool01?l0003oooooooooooooool2o`0000;o
oooo0_l000001_oooooo0000o`000?oooooo0000ooooo`Co003oOOooool0087ooooo0ol000001?oo
oooo0000ooooool00004ooooo`?o000000Woooooool0k_ooooooooooool0Looooooo0000oooooooo
0;@00_l0002Pooooo`?o000000?oooooo`000?l000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000_ooool2o`0000;ooooo1_l00004
o`00oggooooo0021ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000?ooooo
00Oo0000ooooool0003o0000ool0k_ooooooo`1c00;oo`0i00?oooooool0]?ooool0XOooool2o`00
00;ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;o00000_ooool00ol0
003oooooo`000003ooooo`?o000000Coooooo`000?oooooooooo0_l000000ooooooo0000o`000002
o`000003ooooool00?oo003o00;o003oOOooool0087ooooo0_l00002ooooo`05o`000?oooooo0000
ooooool000000_ooool02ol0003oooooooooool0003oooooo`000?oo0>koo`1cool0>Ol0003oo`2d
00;o0000X?ooool7o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0ol000000ooo
oooo0000o`000003ooooo`;o000000Koooooo`000?ooooooooooo`000?ooool2o`0000;ooooo1?l0
0?mmooooo`00P?ooool3o`000004ooooool0003oooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`Co003o0ol0002Nooooo`05o`000?oooooo0000ooooool000000_ooool01?l0
003oooooooooooooool2o`0000;ooooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool7o`0008Cooooo0020ooooo`?o000000Koooooo`000?oooooo0000
ooooool00003ooooo`03o`000?oooooo000000;ooooo00?o0000o`00ool00?l00_l00?l2o`0009ko
oooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`03o`0000;ooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o000000Coooooo`000?oooooo00000_ooool2o`000003ooooool0
003o000000;o0000Q_ooool0083ooooo0_l00002ooooo`05o`000?oooooo0000ooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?l00?oo003o00;o003o0_l0002Nooooo`Co0000
00?oooooo`000?l000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o0000
00Coooooo`000?oooooo00001?ooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?l0
0000Qoooool007oooooo0ol000001ooooooo0000oooooooooooo0000ooooool000000_ooool00ol0
003oooooo`000002ooooo`03o`000?oooooo003o00?o003o0_l0002Mooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o000000?oooooo`000?l000001?ooool0
1?l0003oooooooooooooool2o`000003ooooool0003o000000Ko0000R?ooool007oooooo0ol00000
1?oooooo0000ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003o
ooooo`000?ooool3o`0009kooooo1_l000000ooooooo0000o`000002ooooo`;o00000oooool01?l0
003oooooooooooooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`Co0000R_oo
ool007oooooo0_l00002ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003oooooo`00
0002ooooo`04o`000?oooooo0000ooooo`?o0000W_ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000?ooooo1Ol00002
ooooo`Co0000Roooool007kooooo1Ol00002ooooo`03o`000?oooooo000000;ooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`;o000000?oooooo`000?l00000W_ooool01?l0003oooooo`00
0?ooool3o`000008ooooool0003o0000o`000?oooooo0000ooooool00003ooooo`;o000000Cooooo
o`000?l0003ooooo0_l00002ooooo`Co0000SOooool007kooooo00Co0000oooooooooooooooo0ol0
0002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`02o`000003
ooooool0003o000009kooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool3o`00
0003ooooool0003o000000;ooooo0_l000001?oooooo0000ooooooooool4o`0008oooooo001noooo
o`;o00001?ooool3o`0000?ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooo
000000;o0000Woooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooool000000_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool7o`00093ooooo001mooooo`?o000000?ooooo
o`000?ooool00oooool2o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`;o0000
00?oooooo`000?l00000Woooool2o`0000?ooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o
000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000000;o0000T_ooool007go
oooo0ol000001?oooooo0000ooooool00004ooooo`?o00001_ooool2o`000003ooooool0003o0000
09oooooo00Co0000oooooooooooooooo0_l00002ooooo`05o`000?oooooo0000ooooool000000ooo
ool5o`000003ooooool0003o000000;o0000Toooool007gooooo0_l00002ooooo`05o`000?oooooo
0000ooooool000000oooool00ol0003oooooo`000003o`000:Oooooo0ol00002ooooo`;o00000ooo
ool2o`000004ooooool0003o0000ooooo`;o00000_ooool4o`0009Cooooo001mooooo`;o000000Oo
ooooo`000?ooooooooooo`000?oooooo000000;ooooo00Oo0000oooooooooooo0000ooooool0003o
oooo00Ko0000XOooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool2
o`000004ooooool0003oooooooooo`Co0000U_ooool007cooooo0ol000001?oooooo0000ooooool0
0002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00003ooooo`;o000000?oooooo`00
0?l00000X_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?l000000_ooool6
o`0009Sooooo001looooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`;o000000?oooooo`000?l00000Y?ooool2o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000004o`0009[ooooo001looooo`;o
00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`;o000000?oooooo`000?l00000Y_ooool01Ol0003ooooooooooooooooo000000;ooooo
1_l0002Kooooo`00Noooool3o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2o`000:Oooooo00Co0000
ooooool0003ooooo0_l000001?oooooo0000o`000?l0002Mooooo`00Noooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o
oooo0_l000000ooooooo0000o`00002Yooooo`Co000000?oooooo`000?l00000Woooool007_ooooo
0_l00002ooooo`05o`000?oooooo0000ooooool000000_ooool01_l0003oooooooooool0003ooooo
o`0000;ooooo0_l000000ooooooo0000o`00002]ooooo`03o`000?oooooooooo09oooooo001joooo
o`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00Ko0000ooooool0003oooooo`000?ooool2o`000?ooooooD?ooool007[ooooo00Co0000
oooooooooooooooo0ol00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_oo
ool01Ol0003oooooo`000?oooooo00000?ooooooDOooool007Wooooo0ol00004ooooo`?o00000_oo
ool02ol0003oooooooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o0000oooooomA
ooooo`00NOooool3o`000003ooooool0003ooooo00?ooooo0ol00005ooooo`06o`000?oooooo0000
ooooool0003ooooo0_l0003ooooooe7ooooo001iooooo`07o`000?oooooo0000ooooool0003ooooo
o`000004ooooo`Go00001Oooool00ol0003oooooo`00003ooooooe;ooooo001hooooo`?o00000_oo
ool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000oooooooooooo0000ooooo`04o`0000?o
oooo00?o0000ooooooooool0oooooom@ooooo`00N?ooool3o`000009ooooool0003oooooooooool0
003oooooo`000?oooooo000000;ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00Co0000
oooooomBooooo`00Moooool4o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool00000
0_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooool00000oooooomCooooo`00
Moooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`0;o`000?ooooooooooo`00
0?oooooo0000ooooool0003oooooo`000?ooool00_l0003ooooooe?ooooo001fooooo`06o`000?oo
oooo0000o`000?oooooo00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Wo0000oooo
oooooooo0000ooooool0003oooooo`000?ooool00_l0003ooooooe?ooooo001fooooo`Co000000Co
ooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool0
00000_ooool00ol0003oooooo`00003ooooooeCooooo001gooooo`;o00000_ooool01Ol0003ooooo
o`000?oooooo000000;ooooo00_o0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`02o`000?ooooooE?ooool007Gooooo00?o0000ooooool000000ol00002ooooo`05o`000?oo
oooo0000ooooool000000oooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l0003o
oooooeCooooo001eooooo`;o00000oooool3o`0000;ooooo00?o0000ooooool000000_ooool00ol0
003oooooo`000002ooooo`05o`000?oooooo0000ooooool00000oooooomEooooo`00M_ooool2o`00
00Cooooo0ol00002ooooo`0;o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?oo
ool00_l0003ooooooeGooooo001dooooo`Co000000?oooooo`000?ooool00oooool3o`0000?ooooo
00So0000ooooool0003oooooo`000?oooooo0000ooooo`;o0000oooooomEooooo`00M?ooool4o`00
0004ooooool0003oooooo`0000Cooooo0_l00006ooooo`05o`000?oooooo0000ooooool00000oooo
oomFooooo`00MOooool2o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oo
oooo000000Co00001Oooool00ol0003oooooooooo`3ooooooeCooooo001dooooo`?o000000Wooooo
o`000?ooooooooooo`000?oooooo0000ooooool000000oooool01?l0003oooooo`000?ooool6o`00
0?ooooooE_ooool007?ooooo1?l000001?oooooo0000ooooool00002ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooool000000_ooool01Ol0003oooooo`000?oooooo00000?ooooooEoooool0
07?ooooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool02ol0003ooooo
ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o0000oooooomGooooo`00Loooool3
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00So0000ooooool0003o
ooooo`000?oooooo0000ooooo`;o0000oooooomGooooo`00L_ooool01_l0003oooooo`000?l0003o
ooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooool000000_l0003ooooooeSooooo001booooo`;o000000Koooooo`000?oooooo0000
ooooool00002ooooo`03o`000?oooooo000000;ooooo00So0000ooooool0003oooooo`000?oooooo
0000ooooo`;o0000oooooomHooooo`00Loooool2o`0000;ooooo00Go0000ooooool0003oooooo`00
0002ooooo`0;o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l0003o
oooooeSooooo001aooooo`03o`000?oooooooooo00?o00000_ooool01Ol0003oooooo`000?oooooo
000000;ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00Co0000oooooomHooooo`00LOoo
ool2o`0000?ooooo0ol00002ooooo`03o`000?oooooo000000;ooooo00So0000ooooool0003ooooo
o`000?oooooo0000ooooo`;o0000oooooomIooooo`00LOooool3o`0000Cooooo0ol00002ooooo`09
o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo00Co0000oooooomIooooo`00L?ooool0
1_l0003oooooo`000?l0003oooooo`0000Cooooo0ol00005ooooo`04o`000?oooooo0000ooooo`Co
0000oooooomIooooo`00L?ooool2o`000006ooooool0003oooooo`000?oooooo00001?ooool5o`00
0?ooooooH_ooool0073ooooo0ol00002ooooo`05o`000?oooooo0000ooooool000000_ooool01Ol0
003oooooooooool0003ooooo00So0000oooooomJooooo`00Koooool02?l0003oooooo`000?l0003o
ooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`07o`000?ooooooooooo`000?oo
oooo0000ooooo`04o`000?ooooooF_ooool006oooooo0_l000001_oooooo0000ooooool0003ooooo
o`0000;ooooo00?o0000ooooool000000_ooool01_l0003oooooo`000?oooooo0000ooooo`Co0000
oooooomKooooo`00Koooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`00
0?oooooo000000;ooooo00Co0000ooooool0003ooooo1?l0003ooooooe_ooooo001^ooooo`08o`00
0?oooooo0000o`000?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00Oo0000
oooooooooooo0000ooooool0003ooooo00Co0000oooooomKooooo`00K_ooool2o`000006ooooool0
003oooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`06o`000?oooooo0000oooo
ool0003ooooo1?l0003ooooooecooooo001_ooooo`;o00000_ooool2o`0000;ooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`04o`000?oooooo0000ooooo`Co0000oooooomLooooo`00KOoo
ool00ol0003oooooooooo`03o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`07
o`000?ooooooooooo`000?oooooo0000ooooo`04o`000?ooooooG?ooool006gooooo0_l00003oooo
o`;o00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ool000000_l0003ooooooegooooo001]ooooo`?o00000oooool2o`000007ooooool0003ooooooooo
ool0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`Co0000oooooomMooooo`00K?ooool0
1_l0003oooooo`000?l0003oooooo`0000?ooooo1?l00002ooooo`07o`000?ooooooooooo`000?oo
oooo0000ooooo`04o`000?ooooooGOooool006cooooo0_l000000ooooooo0000ooooo`02o`0000Go
oooo0_l00006ooooo`04o`000?oooooo0000o`000?ooooooGoooool006cooooo0ol00002ooooo`;o
00000_ooool01Ol0003oooooooooool0003ooooo00Go00001?ooool2o`000?ooooooG_ooool006co
oooo0ol000001?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00Go0000oooo
oooooooo0000ooooo`06o`000?ooooooG_ooool006_ooooo00Go0000ooooool0003o0000ooooo`02
o`0000?ooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooo`000?ooool0
0ol0003ooooooeoooooo001[ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool4o`000?ooooooGoooool006_o
oooo0ol00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`07o`000?ooooooooooo`00
0?oooooo0000ooooo`04o`000?ooooooGoooool006[ooooo00So0000ooooool0003o0000ooooool0
003oooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooo`00
0?ooool00ol0003oooooof3ooooo001Zooooo`;o000000?oooooo`000?ooool00_l00003ooooo`05
o`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool4o`000?ooooooH?ooool0
06_ooooo0_l00002ooooo`;o00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co
0000ooooool0003ooooo1?l0003oooooof3ooooo001/ooooo`?o000000Woooooo`000?oooooooooo
o`000?oooooo0000ooooool000000oooool01?l0003oooooo`000?ooool3o`000?ooooooHOooool0
06Wooooo0_l00003ooooo`;o00000oooool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000
ooooool0003ooooo1?l0003oooooof7ooooo001Yooooo`?o00000oooool2o`000007ooooool0003o
ooooooooool0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`Co0000oooooomQooooo`00
J_ooool2o`000003ooooool0003ooooo00;ooooo1?l00005ooooo`04o`000?oooooo0000ooooo`?o
0000oooooomRooooo`00J?ooool2o`000003ooooool0003ooooo00;o00001Oooool4o`0000Sooooo
00?o0000ooooooooool0oooooomPooooo`00J?ooool3o`000004ooooool0003oooooo`0000;ooooo
00Oo0000oooooooooooo0000ooooool0003ooooo00Wo0000oooooomRooooo`00J?ooool3o`000004
ooooool0003oooooo`0000;ooooo00Go0000ooooool0003oooooo`000003ooooo`04o`000?oooooo
0000ooooo`?o0000oooooomSooooo`00Ioooool2o`000003ooooool0003ooooo00;o00000oooool0
1Ol0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo1?l0003oooooof?ooooo
001Wooooo`?o000000Coooooo`000?oooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00;ooooo00Co0000ooooool0003ooooo1?l0003oooooof?ooooo001Wooooo`?o000000Coooooo`00
0?oooooo00000_ooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000ooooool0003ooooo
0ol0003oooooofCooooo001Vooooo`;o000000Goooooo`000?l0003oooooo`000003ooooo`05o`00
0?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool4o`000?ooooooI?ooool006Ko
oooo0ol000001?oooooo0000ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01?l0003oooooo`000?ooool4o`000?ooooooI?ooool006Kooooo00Co0000ooooool0003o0000
0_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Oo0000oooooooooooo0000ooooool0
003ooooo00?o0000oooooomUooooo`00IOooool2o`0000;ooooo0ol00003ooooo`05o`000?oooooo
0000ooooool000000_ooool01?l0003oooooo`000?ooool4o`000?ooooooIOooool006Gooooo0ol0
0003ooooo`;o000000Ooooooo`000?ooooooooooo`000?oooooo000000;ooooo00Co0000ooooool0
003ooooo1?l0003oooooofGooooo001Uooooo`Co00001?ooool4o`0000;ooooo00Oo0000oooooooo
oooo0000ooooool0003ooooo00?o0000oooooomVooooo`00I?ooool2o`000005ooooool0003o0000
ooooool000001Oooool2o`0000[ooooo00?o0000ooooooooool0oooooomTooooo`00I?ooool3o`00
0004ooooool0003oooooo`0000;ooooo00Go0000oooooooooooo0000ooooo`0;o`000?ooooooI_oo
ool006Cooooo1?l00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01ol0003ooooo
ooooool0003oooooo`000?ooool00ol0003oooooofOooooo001Sooooo`;o000000Goooooo`000?l0
003oooooo`000003ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?oo
ool4o`000?ooooooIoooool006?ooooo0ol000001?oooooo0000ooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool4o`000?ooooooIoooool006?o
oooo1?l00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01ol0003oooooooooool0
003oooooo`000?ooool00ol0003oooooofSooooo001Sooooo`06o`000?oooooo0000o`000?oooooo
00000oooool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo1?l0003o
ooooofSooooo001Sooooo`;o000000Coooooo`000?oooooo00000_ooool01_l0003oooooooooool0
003oooooo`0000;ooooo00Co0000ooooool0003ooooo1?l0003oooooofSooooo001Tooooo`;o0000
0_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Oo0000oooooooooooo0000ooooool0
003ooooo00?o0000oooooomYooooo`00IOooool3o`0000?ooooo00Go0000ooooool0003oooooo`00
0002ooooo`05o`000?ooooooooooo`000?ooool00ol0003oooooofWooooo001Wooooo`;o000000Oo
ooooo`000?ooooooooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo1?l0003ooooo
ofWooooo001Yooooo`Co00000_ooool01ol0003oooooooooool0003oooooo`000?ooool00ol0003o
ooooof[ooooo001/ooooo`;o00001_ooool01Ol0003oooooo`000?oooooo00000?ooooooJ_ooool0
06cooooo00?o0000ooooool000001?l00003ooooo`;o0000oooooom[ooooo`00K?ooool00ol0003o
ooooooooo`04ooooo`?o0000oooooom]ooooo`00K?ooool00ol0003oooooooooo`3oooooogCooooo
001[ooooo`03o`000?oooooooooo0?ooooooMOooool006_ooooo00?o0000ooooooooool0oooooome
ooooo`00J_ooool00ol0003oooooooooo`3oooooogKooooo001Zooooo`03o`000?oooooooooo0?oo
ooooM_ooool006Wooooo00?o0000ooooooooool0oooooomgooooo`00JOooool00ol0003ooooooooo
o`3oooooogOooooo001Yooooo`03o`000?oooooooooo0?ooooooMoooool006Sooooo00?o0000oooo
ooooool0oooooomhooooo`00J?ooool00ol0003oooooooooo`3oooooogSooooo001Xooooo`03o`00
0?oooooooooo0?ooooooN?ooool006Oooooo00?o0000ooooooooool0oooooomiooooo`00Ioooool0
0ol0003oooooooooo`3oooooogWooooo003oooooon?ooooo003oooooon?ooooo003oooooon?ooooo
003oooooon?ooooo003oooooon?ooooo003oooooon?ooooo003oooooon?ooooo003oooooon?ooooo
003oooooon?ooooo003oooooon?ooooo003oooooon?ooooo003oooooon?ooooo003oooooon?ooooo
003oooooon?ooooo0000\
\>"],
  ImageRangeCache->{{{148.562, 630.25}, {510.75, 200.5}} -> {-1.02782, \
1.00563, 0.00520746, 0.00520746}, {{197.375, 380.25}, {503.312, 207.875}} -> \
{-0.471238, 0.632235, 0.00327477, 0.00327477}, {{398.5, 581.438}, {503.312, \
207.875}} -> {-1.90093, 0.65907, 0.00477019, 0.00477019}}]
}, Open  ]],

Cell[TextData[{
  "Conjecture: All five point configurations that give rise to six cylinders \
in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " are small perturbations of one of these two configurations. This idea, \
admittedly difficult to quantify, is based on visual experimental evidence. \
It is interesting that one of these examples has a four\[Hyphen]fold symmetry \
rather than exclusively two\[Hyphen]or\[Hyphen]three\[Hyphen]fold \
symmetries."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(More) configurations that give no real cylinders", "Subsection",
  CellDingbat->None,
  FontSize->10],

Cell["\<\
As noted earlier, we get no real cylinders whenever one point is in \
the convex hull of the other four. It is also clear from experiments that \
there are other configurations that give no real cylinders. To describe one \
family of such, we return to the double tetrahedron glued along a common \
face. If we alter either or both of the upper and lower vertices we can jump \
from having six cylinders through the five points to having none. In the code \
below we explicitly show this phenomenon by allowing the upper vertex to vary \
(actually there is no way to impose a positivity constraint so it could be \
negative. In this case we get no cylinders because either it or the other \
negative vertex will be in the tetrahedron hull of the remaining four \
vertices).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(dpointslong\  = \ {{1, 0, 0}, \ {\(-1\)/2, Sqrt[3]/2, 
          0}, {\(-1\)/2, \(-Sqrt[3]\)/2, 0}, \ {0, 0, z}, \ {0, 
          0, \(-1\)}}; \), "\n", 
    \(perps = 
      Table[perp[dpointslong[\([\)\(k\)\(]\)], vec, offset], {k, 
          5}]; \), "\n", 
    \(exprs = Map[Numerator[Together[# . # - rsqr]] &, perps]\)}], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \({a\^2 + 2\ a\ b + b\^2 + c\^2 + b\^2\ c\^2 + 2\ c\ d - 2\ a\ b\ c\ d + 
        d\^2 + a\^2\ d\^2 - rsqr - a\^2\ rsqr - c\^2\ rsqr, 
      3 + 2\ \@3\ a + a\^2 - 4\ \@3\ b - 4\ a\ b + 4\ b\^2 + 4\ c\^2 - 
        4\ \@3\ b\ c\^2 + 4\ b\^2\ c\^2 - 4\ c\ d + 4\ \@3\ a\ c\ d - 
        8\ a\ b\ c\ d + 4\ d\^2 + 4\ a\^2\ d\^2 - 4\ rsqr - 4\ a\^2\ rsqr - 
        4\ c\^2\ rsqr, 
      3 - 2\ \@3\ a + a\^2 + 4\ \@3\ b - 4\ a\ b + 4\ b\^2 + 4\ c\^2 + 
        4\ \@3\ b\ c\^2 + 4\ b\^2\ c\^2 - 4\ c\ d - 4\ \@3\ a\ c\ d - 
        8\ a\ b\ c\ d + 4\ d\^2 + 4\ a\^2\ d\^2 - 4\ rsqr - 4\ a\^2\ rsqr - 
        4\ c\^2\ rsqr, 
      b\^2 + b\^2\ c\^2 - 2\ a\ b\ c\ d + d\^2 + a\^2\ d\^2 - rsqr - 
        a\^2\ rsqr - c\^2\ rsqr + 2\ a\ b\ c\ z - 2\ d\ z - 2\ a\^2\ d\ z + 
        z\^2 + a\^2\ z\^2, 
      1 + a\^2 + b\^2 - 2\ a\ b\ c + b\^2\ c\^2 + 2\ d + 2\ a\^2\ d - 
        2\ a\ b\ c\ d + d\^2 + a\^2\ d\^2 - rsqr - a\^2\ rsqr - 
        c\^2\ rsqr}\)], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gb\  = \ 
      GroebnerBasis[exprs, {rsqr, d, b, a, c}, 
        CoefficientDomain \[Rule] RationalFunctions]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \({2 + 3\ c\^2 - 4\ z + c\^3\ \((\(-2\) + 2\ z)\), \(-1\) - 2\ c\^2 + 
        2\ z + a\^2\ \((\(-1\) + 2\ z)\), \(-a\) + a\ c\ \((1 - z)\) + 
        b\ \((1 + 2\ z)\), 
      4 - c + c\^2\ \((2 - 2\ z)\) - 4\ z + d\ \((4 + 8\ z)\), \(-5\) - 
        20\ z\^2 + rsqr\ \((4 + 16\ z + 16\ z\^2)\)}\)], "Output",
  CellLabel->"Out[120]="]
}, Open  ]],

Cell[TextData[{
  "We already know from the symmetry argument that we obtain at least one \
real solution if and only if we obtain six real solutions. So it suffices to \
indicate situations where we cannot have six. For this we focus on the \
univariate polynomial. Dividing by the leading coefficient we have a \
polynomial that, for ",
  Cell[BoxData[
      \(z\)],
    FontSlant->"Italic"],
  " sufficiently large, approximates ",
  Cell[BoxData[
      \(c\^3 - 2\)]],
  ". Clearly these do not have three real roots. Hence the system cannot give \
rise to six real solutions, and by the symmetry argument there are in fact \
none."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Enumerative geometry of cylinders through five points", "Section"],

Cell[CellGroupData[{

Cell["Basic theory", "Subsection",
  CellDingbat->None],

Cell["\<\
The above investigations indicate ways in which one might approach \
the problem computationally. Now we state and prove several results suggested \
by the computations of the previous sections.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Proposition 1",
    FontSlant->"Italic"],
  ": Generic configurations of five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " lie of the surface of finitely many cylinders. Moreover an upper bound on \
the number of these cylinders is nine."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontSlant->"Italic"],
  ": This is largely a computational proof which we first describe. We set up \
some linear algebra similar to that already seen, but now we reduce to two \
equations in two variables and several configuration parameters. The linear \
algebra is as follows. Without loss of generality we have one point at the \
origin, another at ",
  Cell[BoxData[
      \({1, 0, 0}\)]],
  ", and a third in the ",
  Cell[BoxData[
      StyleBox["x\[Hyphen]y",
        FontSlant->"Italic"]]],
  " coordinate plane. We project these onto the set of planes through the \
origin, parametrized (generically) by a normal vector ",
  Cell[BoxData[
      \({a, b, 1}\)]],
  ". We then obtain equations that must be satisfied by the parameters ",
  Cell[BoxData[
      \({a, b}\)]],
  " in order for the remaining two points to project onto the same circle in \
that plane as the first three; this is exactly the condition that all five \
lie on some cylinder. Factoring shows that they are irreducible and hence are \
relatively prime. So generically they have finite intersection, with upper \
bound given by the Bezout theorem. In fact, as each polynomial has degree \
three in the variables ",
  Cell[BoxData[
      \({a, b}\)]],
  ", we see that there are at most nine solutions for the cylinder axis \
direction parameters, hence at most nine solutions for the set of cylinder \
parameters."
}], "Text"],

Cell[BoxData[{
    \(Clear[a, b]; \), "\n", 
    \(normal = {a, b, 1}; \), "\n", 
    \(spanners = GramSchmidt[NullSpace[{normal}]]; \), "\n", 
    \(points = {{0, 0, 0}, {1, 0, 0}, {x\_2, y\_2, 0}, {x\_3, y\_3, 
          z\_3}, {x\_4, y\_4, z\_4}}; \), "\n", 
    \(projpoint[p_, 
        span_] := \[Sum]\+\(j = 1\)\%\(Length[span]\)p . 
            span\[LeftDoubleBracket]
              j\[RightDoubleBracket]\ span\[LeftDoubleBracket]
            j\[RightDoubleBracket]; \), "\n", 
    \(projpoints = 
      Table[Together[
          projpoint[points\[LeftDoubleBracket]j\[RightDoubleBracket], 
            spanners]], {j, Length[points]}]; \)}], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(circle[{p1_, p2_, p3_}, normal_] := 
      Module[{rsqr, c1, c2, c3, c, cp1, cp2, cp3, 
          gb}, \[IndentingNewLine]c = {c1, c2, c3}; \[IndentingNewLine]cp1 = 
          c - p1; cp2 = c - p2; 
        cp3 = c - p3; \[IndentingNewLine]polys = 
          Append[Thread[{cp1 . cp1, cp2 . cp2, cp3 . cp3} - rsqr], 
            c . normal]; \[IndentingNewLine]gb = 
          GroebnerBasis[polys, {c1, c2, c3, rsqr}, 
            CoefficientDomain \[Rule] 
              RationalFunctions]; \[IndentingNewLine]{{c1, c2, c3}, rsqr} /. 
          Solve[gb \[Equal] 0, {c1, c2, c3, rsqr}]]\)], "Input",
  CellLabel->"(math50) In[15]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \({cen, radsqr} = 
      First[circle[Take[projpoints, 3], normal]]; \), "\[IndentingNewLine]", 
    \(vec1 = projpoints[\([\)\(4\)\(]\)] - cen; \), "\n", 
    \(vec2 = projpoints[\([\)\(5\)\(]\)] - cen; \), "\n", 
    \(polys = 
      Numerator[
        Together[{vec1 . vec1 - radsqr, vec2 . vec2 - radsqr}]]\)}], "Input",
  CellLabel->"In[176]:="],

Cell[BoxData[
    \({\(-x\_3\)\ y\_2 - b\^2\ x\_3\ y\_2 + x\_3\%2\ y\_2 + 
        b\^2\ x\_3\%2\ y\_2 + x\_2\ y\_3 + b\^2\ x\_2\ y\_3 - x\_2\%2\ y\_3 - 
        b\^2\ x\_2\%2\ y\_3 + 2\ a\ b\ x\_2\ y\_2\ y\_3 - 
        2\ a\ b\ x\_3\ y\_2\ y\_3 - y\_2\%2\ y\_3 - a\^2\ y\_2\%2\ y\_3 + 
        y\_2\ y\_3\%2 + a\^2\ y\_2\ y\_3\%2 - b\ x\_2\ z\_3 - 
        b\^3\ x\_2\ z\_3 + b\ x\_2\%2\ z\_3 + b\^3\ x\_2\%2\ z\_3 + 
        a\ y\_2\ z\_3 + a\ b\^2\ y\_2\ z\_3 - 2\ a\ b\^2\ x\_2\ y\_2\ z\_3 - 
        2\ a\ x\_3\ y\_2\ z\_3 + b\ y\_2\%2\ z\_3 + a\^2\ b\ y\_2\%2\ z\_3 - 
        2\ b\ y\_2\ y\_3\ z\_3 + a\^2\ y\_2\ z\_3\%2 + 
        b\^2\ y\_2\ z\_3\%2, \(-x\_4\)\ y\_2 - b\^2\ x\_4\ y\_2 + 
        x\_4\%2\ y\_2 + b\^2\ x\_4\%2\ y\_2 + x\_2\ y\_4 + b\^2\ x\_2\ y\_4 - 
        x\_2\%2\ y\_4 - b\^2\ x\_2\%2\ y\_4 + 2\ a\ b\ x\_2\ y\_2\ y\_4 - 
        2\ a\ b\ x\_4\ y\_2\ y\_4 - y\_2\%2\ y\_4 - a\^2\ y\_2\%2\ y\_4 + 
        y\_2\ y\_4\%2 + a\^2\ y\_2\ y\_4\%2 - b\ x\_2\ z\_4 - 
        b\^3\ x\_2\ z\_4 + b\ x\_2\%2\ z\_4 + b\^3\ x\_2\%2\ z\_4 + 
        a\ y\_2\ z\_4 + a\ b\^2\ y\_2\ z\_4 - 2\ a\ b\^2\ x\_2\ y\_2\ z\_4 - 
        2\ a\ x\_4\ y\_2\ z\_4 + b\ y\_2\%2\ z\_4 + a\^2\ b\ y\_2\%2\ z\_4 - 
        2\ b\ y\_2\ y\_4\ z\_4 + a\^2\ y\_2\ z\_4\%2 + 
        b\^2\ y\_2\ z\_4\%2}\)], "Output",
  CellLabel->"Out[179]="]
}, Open  ]],

Cell[TextData[{
  "One verifies the claims made above from this computation. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": We will presently give two proofs that the correct number is six. One \
method will use the computation shown above."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": In [13] it is noted that this projected circles approach is related to \
the Delaunay triangulation of projections of the five points on all possible \
planes. Specifically, directions of projection where the triangulation \
changes are important, as these occur exactly when four points become \
collinear. This gives a direct tie between the enumerative and computational \
geometry aspects to the problems under scrutiny."
}], "Text"],

Cell[TextData[{
  StyleBox["Proposition 2",
    FontSlant->"Italic"],
  ": Real valued solutions always have positive values for the square of the \
radius.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": The significance of this proposition is that all real valued solutions \
do indeed give cylinders in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontSlant->"Italic"],
  ": Suppose we form a lexicographic Gr\[ODoubleDot]bner basis with the \
radius\[Hyphen]square variable ordered as smallest. Then generically (shape \
lemma) we have a basis containing a univariate polynomial in that variable. \
For each of the other variables there will correspond a linear polynomial in \
the basis, and it will have real valued coefficients. Suppose a solution to \
that univariate polynomial is real valued. Then the remaining cylinder \
parameters, on back substitution, will also be real valued as they are given \
by linear polynomials over the reals. Now recall that our original equations \
were of the form ",
  Cell[BoxData[
      \(sum\[Hyphen]of\[Hyphen]squares = radius\[Hyphen]squared\)]],
  " where the left hand side is a polynomial function of the input data and \
cylinder parameters. Hence all the original equations will have positive left \
hand sides, so the radius squared must also be positive. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 1",
    FontSlant->"Italic"],
  ": Five generic points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " determine six distinct sets of cylinder parameters, of which an even \
number are real valued."
}], "Text"],

Cell["\<\
The proofs of this theorem are deferred to the following \
subsection.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": One way to prove this would be to do a brute force computation of a Gr\
\[ODoubleDot]bner basis for a system with generic configuration parameters. \
But this is not possible with software and methods available to the author. \
Some evidence furthermore suggests that the problem is computationally quite \
difficult. Indeed, using the linear algebra ",
  "setup",
  " first shown, it was quite strenuous to compute a Gr\[ODoubleDot]bner \
basis when we made a generic parameter of just one coordinate of one point."
}], "Text"],

Cell[TextData[{
  StyleBox["Proposition 3",
    FontSlant->"Italic"],
  ": Configurations that give rise to an empty solution set or to a solution \
set of positive dimension lie on a variety."
}], "Text"],

Cell[TextData[{
  StyleBox["Outline of proof:",
    FontSlant->"Italic"],
  " One obtains, in principle, a description of the generic solutions by \
forming a lexicographic Gr\[ODoubleDot]bner basis for the system with \
indeterminate data. The process of doing this gives rise to the generic basis \
because at steps along the way one is allowed to divide by polynomials in the \
indeterminates. All inputs that fail to give the generic basis thus must \
satisfy conditions among the coordinates that cause these polynomials, upon \
specialization, to vanish. As there are finitely many steps in forming the \
basis, there are finitely many such conditions. As thesevanishing conditions \
are defined by polynomials, their union is a variety. We may further refine \
it. Some configurations might fail to give the generic basis but still yield \
a nonzero finite solution set. If we exclude the conditions that give this \
situation, we are still left with a variety for which we get either zero or \
infinitely many (complex valued) solutions. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Definition",
    FontSlant->"Italic"],
  ": Generically we have six solutions for the cylinder parameters, given \
five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " (or ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalC]\^3\)]],
  ", for that matter). Above we saw that the subset of nongeneric \
configurations that give either zero or infinitely many solutions comprises a \
variety. We refer to this as the \"bad variety\", denoted ",
  Cell[BoxData[
      SubscriptBox["V", 
        StyleBox["bad",
          FontSlant->"Plain"]]],
    FontSlant->"Italic"],
  ". Several results below are stated in terms of configurations that miss \
this variety."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 2",
    FontSlant->"Italic"],
  ": There is a nonempty open set in our configuration space (which is, in \
effect, ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^15\)]],
  ") for which we obtain no cylinders in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontSlant->"Italic"],
  ": Suppose we have a configuration that gives no real cylinders. Again \
consider a Gr\[ODoubleDot]bner basis with a univariate polynomial in the \
radius\[Hyphen]squared. Then all of its roots are complex valued. Small \
perturbations of this configuration will still give complex valued roots \
because the real and imaginary parts vary continuously in the configuration \
parameters. We already know there exist configurations that give no real \
cylinders, which establishes that the set is nonempty. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary",
    FontSlant->"Italic"],
  ": The maximum number of cylinders, already shown to be bounded by nine, is \
in fact no larger than eight."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontSlant->"Italic"],
  ": This is a consequence of the following facts. (i) Restricting to real \
inputs does not move us out of the generic case because this restriction is \
not algebraic. (ii) Given real data, complex solutions appear in pairs. (iii) \
The case where one coordinate lies in the hull of the other four contains an \
open subset in the real part of the parameter space. Hence there is an open \
set in parameter space for which there are only complex solutions. So in \
general there must be an even number of solutions. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": This also shows that the the number cannot be seven. So we know it is \
either six or eight."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 3",
    FontSlant->"Italic"],
  ": There is a closed set with nonempty interior in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^15 - V\_bad\)]],
  " for which we obtain six cylinders real cylinders provided we count \
solutions to the cylinder parameter equations by multiplicity."
}], "Text"],

Cell[TextData[{
  StyleBox["Outline of proof",
    FontSlant->"Italic"],
  ": We may count the number of real roots using the Rule of Signs [28] on \
the univariate polynomial in the lexicographic Gr\[ODoubleDot]bner basis. \
This gives a closed condition for the boundary of the set of configurations \
that yield six sets of real valued cylinder parameters. To show it has \
nonempty interior it suffices to demonstrate one such configuration that has \
no multiple solutions. But this was the case for both six\[Hyphen]real\
\[Hyphen]cylinder examples shown earlier. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": Similar argument shows that the sets in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^15 - V\_bad\)]],
  " that give rise to two or four cylinders real cylinders also have nonempty \
interiors."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 4",
    FontSlant->"Italic"],
  ": Suppose we have four non\[Hyphen]coplanar points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ". They are the vertices of some tetrahedron. Then there is an open set ",
  Cell[BoxData[
      \(S\)]],
  " containing the open tetrahedron and a dense subset of its boundary in the \
configuration space, such that if the fifth is chosen in ",
  Cell[BoxData[
      \(S\)]],
  " there will be no real cylinders containing all five points."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": If the fifth point is inside the convex hull of the other four then we \
already know this result. Now take the tetrahedron formed by the four points. \
Through each vertex the planes containing the three coincident faces form a \
cone with triangular base. If the fifth point lies within that cone then it \
obscures that vertex, i.e. the vertex lies inside the new tetrahedron formed \
by the fifth point and the remaining three. Hence this case is also covered \
by the \"one point in the hull of the others\" situation. Note that in this \
case the fifth point need not be near in distance to the other four."
}], "Text"],

Cell[TextData[{
  StyleBox["Algebraic proof",
    FontSlant->"Italic"],
  ": Suppose the fifth point lies on a face of the tetrahedron formed by the \
other four. Then the convexity argument still tells us that no cylinder in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " can contain all five points. As we assumed the tetrahedron coordinates \
are generic, we are in one of two situations: either having the fifth \
coordinate lie on a face formed by three others puts the configuration in ",
  Cell[BoxData[
      \(V\_bad\)]],
  " or it does not. We show that generically it does not, or in other words, \
the algebraic condition that four points are coplanar is not a condition for \
the bad variety. That this is so follows from the trivial observation \
(verified computationally) that there are configurations with four coplanar \
points that give rise to lexicographic Gr\[ODoubleDot]bner basis with the \
generic \"shape\"; were this a condition to lie in the bad variety then every \
configuration with four coplanar points would be in it."
}], "Text"],

Cell[TextData[{
  "The preceding argument shows that generically the fifth point is not on ",
  Cell[BoxData[
      \(V\_bad\)]],
  ", so the set of such fifth points is dense in the set of all boundary \
points of the tetrahedron. By genericity we may assume that we have a \
univariate polynomial of degree six for one of the cylinder parameters. As \
there are no real cylinders containing this configuration, this polynomial \
has exclusively nonreal roots. These roots vary continuously with the \
configuration, hence the imaginary parts remain nonzero under small \
perturbations of the five points. Thus there is an open set around this point \
on the boundary for which we still obtain no real roots. As we require real \
roots in order to obtain cylinders in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  "this suffices to finish the proof. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Outline of a geometric proof",
    FontSlant->"Italic"],
  ": (This line of proof was suggested by Dick Bishop [4].) In order for all \
five points to lie on a cylinder there must be a plane tangent to the unit \
sphere, and a circle in that plane, such that they all project onto that \
circle. Suppose the fifth point is inside or on the boundary of the \
tetrahedron formed by the other four. Then it is clear that the projection of \
the five points onto any such plane will have the projection of this last \
point contained in the quadrilateral formed by the projection of the other \
four. Hence any quadratic in the plane that contains all five projected \
points must be a hyperbola (because all other quadratic curves are convex). \
Moreover the parameters of the hyperbola equation are continuous in the \
locations of the five points. As the set of projection planes is compact, a \
small perturbation of the fifth point beyond the hull of the other four will \
not alter the situation that the five points project onto hyperbolas in all \
such planes, hence they cannot lie on any cylinder in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ". Hence from every boundary point on the tetrahedral hull of the four \
points, we may perturb outward some minimal distance (depending on that \
boundary point) and still have no real cylinders. As the tetrahedron boundary \
is compact we deduce that there is a minimum positive distance we can move \
outside and still not get real cylinders. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary to proof:",
    FontSlant->"Italic"],
  " There is an open set ",
  Cell[BoxData[
      \(S\)]],
  " containing the closed tetrahedron, such that if the fifth is chosen in ",
  Cell[BoxData[
      \(S\)]],
  " there will be no cylinders in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " containing all five points. In other words, the \"bad\" variety in \
configuration space is not an issue."
}], "Text"],

Cell[TextData[{
  StyleBox["Open question:",
    FontSlant->"Italic"],
  " Might one use similar ideas to get a geometrical description of what \
configurations will give rise to the various numbers of real valued \
cylinders? Perhaps there is some way to use more refined information about \
the convex hull to determine when such projections, say in directions that \
intersect the six faces (if origin is placed appropriately e.g. at the \
centroid), cannot possibly give circles?"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Proof and further remarks for theorem 1", "Subsection"],

Cell[TextData[{
  StyleBox["Proof",
    FontSlant->"Italic"],
  ": We know from the proposition that the generic solution set is finite. \
Moreover as the ideal formed by the cylinder equations is generically radical \
and in general position with respect to all variables one may apply the Shape \
Lemma. Hence we may assert that the generic lexicographic Gr\[ODoubleDot]bner \
basis has a univariate polynomial in one variable, say ",
  Cell[BoxData[
      \(a\)]],
  ", of the form"
}], "Text"],

Cell[BoxData[
    \(p[a] = \(p\_n\ a\^n + p\_\(n - 1\)\ a\^\(n - 1\) +  ... \) + p\_1\ a + 
        p\_0\)], "DisplayFormula"],

Cell[TextData[{
  "where each ",
  Cell[BoxData[
      \(p\_j\)]],
  " is a polynomial in the configuration data, that is the coordinates of the \
five points. We know from the preceding theory that either ",
  Cell[BoxData[
      \(TraditionalForm\`n = 6\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`n = 8\)]],
  " and wish to show that it must be the former. Note that each of the more \
than four thousand examples run in the simulation gave exactly six solutions. \
So we must now show that we did not choose in excess of four thousand \
unfortunate examples. It will turn out we need only work with one such \"good\
\" choice."
}], "Text"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(C\_0\)]],
  " denote a configuration of five points that gives rise to exactly six \
solutions to the cylinder equations. We will show it is generic in the sense \
that this is the number of solutions in an open set around ",
  Cell[BoxData[
      \(C\_0\)]],
  " in the configuration space. Suppose this is not the case. Then in an open \
dense set around ",
  Cell[BoxData[
      \(C\_0 - V\_bad\)]],
  " there are configurations that give ",
  Cell[BoxData[
      \(n = 8\)]],
  " solutions. We take a sequence of these configurations that approaches ",
  Cell[BoxData[
      \(C\_0\)]],
  ". As solutions vary continuously with the configuration in the generic \
case (which comprises a dense open connected subset of ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalC]\^15\)]],
  ") we see that some solutions for the variable ",
  Cell[BoxData[
      \(a\)]],
  " must go to infinity as the configurations approach ",
  Cell[BoxData[
      \(C\_0\)]],
  ". This is so because the leading coefficient of ",
  Cell[BoxData[
      \(p[a]\)]],
  " is going to zero; if not then we would have ",
  Cell[BoxData[
      \(n\)]],
  " solutions for ",
  Cell[BoxData[
      \(C\_0\)]],
  " in contradiction to our hypotheses."
}], "Text"],

Cell[TextData[{
  "A similar argument shows that solutions for the other radial direction \
parameter, ",
  Cell[BoxData[
      \(b\)]],
  ", also go to infinity. Hence the axial direction for these excess \
solutions must lie in the ",
  Cell[BoxData[
      StyleBox["x\[Hyphen]y",
        FontSlant->"Italic"]]],
  " coordinate plane, assuming our axial direction was set up to be ",
  Cell[BoxData[
      \({a, b, 1}\)]],
  ". Now we recompute the solution set for ",
  Cell[BoxData[
      \(C\_0\)]],
  " with the axial direction taken to be ",
  Cell[BoxData[
      \({a, 1, b}\)]],
  ", and again repeat with direction vector of ",
  Cell[BoxData[
      \({1, a, b}\)]],
  ". If we still have only six solutions in all cases then the same reasoning \
as above demonstrates that the axial directions of the sequence of \
configurations approaching ",
  Cell[BoxData[
      \(C\_0\)]],
  " must also lie in the ",
  Cell[BoxData[
      \(x\[Hyphen]z\)],
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(y\[Hyphen]z\)],
    FontSlant->"Italic"],
  " coordinate planes. As no nonzero vector lies in all three coordinate \
planes we obtain a contradiction."
}], "Text"],

Cell["\<\
To finish the proof it suffices to demonstrate a configuration that \
gives six solutions using all three forms of axial direction vector. For \
example, take\
\>", "Text"],

Cell[BoxData[
    \(dpoints = {{1, 2, \(-4\)}, {\(-1\), 1, 3}, {\(-1\), \(-1\), 1}, {1, 0, 
          1}, {6, 1, \(-1\)}}; \)], "Input"],

Cell[TextData[{
  "Now simply use the procedure ",
  Cell[BoxData[
      StyleBox["solveCylinders",
        FontWeight->"Bold"]]],
  " above to compute the number of solutions obtained using all three \
possibilities indicated above for direction vector; verify that six solutions \
are obtained in each case."
}], "Text"],

Cell[TextData[{
  "An alternative argument is as follows. Take a given configuration with six \
solutions, using the ",
  "setup",
  " that forces axial directions going to infinity to do so in the ",
  Cell[BoxData[
      FormBox[
        StyleBox["x\[Hyphen]y",
          FontFamily->"Times",
          FontSlant->"Italic"], TraditionalForm]]],
  " coordinate plane. Rotate it so that no axis moves into that plane, and \
the axis of rotation does not lie in that plane.  Then a symmetry argument \
shows that the axial directions going to infinity can no longer lie in that \
plane, but a computational argument shows that they must, a contradiction. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": A similar argument can be used to show that, if we have ",
  Cell[BoxData[
      RowBox[{"n", ">", 
        StyleBox["0",
          FontSlant->"Italic"]}]]],
  " solutions at some point counting multiplicity, then ",
  Cell[BoxData[
      \(n\)]],
  " must be six (that is, it cannot be less). Note, however, that using the \
computational setup from previous sections one may construct examples with \
only four solutions. This is an artifact of how we choose coordinates. For \
example, by insisting that the axis direction vector have a ",
  Cell[BoxData[
      \(z\)]],
  " coordinate value of ",
  Cell[BoxData[
      StyleBox["1",
        FontSlant->"Italic"]]],
  " (which generically is allowable) we may lose valid cylinders in examples \
that are not generic for that choice. As remarked at the outset, we could \
instead have worked in projective space, rather than in an affine open set \
thereof and similarly made the displacement vector generic, but at some \
computational expense. In particular we would need to use a pair of extra \
equations (e.g. normalize the direction vector to unity length and make the \
displacement perpendicular to the direction), and we would also have to work \
with doubled solutions because a given direction and its negative are \
equivalent in this setting."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark concerning computational approaches to theorem 1",
    FontSlant->"Italic"],
  ": One might wish to use the method of mixed volume to compute the number \
of solutions [30]. One finds the convex hull of the Newton polytopes of the \
exponent vectors for each polynomial and then computes a mixed volume. This \
is easy to do using the computation from the proof of proposition 1. Each of \
the two polynomials has the same set of power products in ",
  Cell[BoxData[
      \({a, b}\)]],
  " and specifically the hull of the exponent vectors is given by the vertex \
set:"
}], "Text"],

Cell[BoxData[
    \({{0, 0}, {2, 0}, {2, 1}, {1, 2}, {0, 3}}\)], "DisplayFormula"],

Cell[TextData[{
  "The volume of this region is ",
  Cell[BoxData[
      \(4\)],
    FontSlant->"Italic"],
  ". The Minkowski sum of the two polytopes is just the same hull scaled to \
twice its size, and the mixed volume is equal to the total volume minus the \
sum of the volumes of each separate hull, or ",
  Cell[BoxData[
      \(16 - 2\ *4 = 8\)],
    FontSlant->"Italic"],
  ". So the generic number of solutions for equations with these sets of \
exponent vectors is ",
  Cell[BoxData[
      \(8\)],
    FontSlant->"Italic"],
  " rather than ",
  Cell[BoxData[
      \(6\)],
    FontSlant->"Italic"],
  ". Indeed, one can verify this immediately by solving a pair of random \
equations that use the same power products. We thus conclude that the entire \
family of cylinder problems is nongeneric with respect to the theory \
presented in [30]. A hint as to why this is so may be gleaned from the \
computational proof of theorem 1 presented next. This sort of nongeneric \
example is also noted in [20]. The related problem discussed in [15] and [26] \
similarly fails to be generic for the polyhedral homotopy solving method."
}], "Text"],

Cell[TextData[{
  StyleBox["Second proof of theorem 1",
    FontSlant->"Italic"],
  ": We will look at the solutions at infinity for the polynomials shown in \
the proof of proposition 1. First we will homogenize and then set the \
homogenizing variable to zero to get the initials (that is, the degree \
forms)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(hompolys = 
      Expand[a\ polys /. \[InvisibleSpace]{a \[Rule] a\ t, 
              b \[Rule] b\ t}] /. \[InvisibleSpace]t\^n_.  \[RuleDelayed] 
          w\^\(4 - n\)\/a; \), "\n", 
    \(initials = hompolys /. \[InvisibleSpace]w \[Rule] 0\)}], "Input",
  CellLabel->"In[410]:="],

Cell[BoxData[
    \({\(-b\^3\)\ x\_2\ z\_3 + b\^3\ x\_2\%2\ z\_3 + a\ b\^2\ y\_2\ z\_3 - 
        2\ a\ b\^2\ x\_2\ y\_2\ z\_3 + 
        a\^2\ b\ y\_2\%2\ z\_3, \(-b\^3\)\ x\_2\ z\_4 + b\^3\ x\_2\%2\ z\_4 + 
        a\ b\^2\ y\_2\ z\_4 - 2\ a\ b\^2\ x\_2\ y\_2\ z\_4 + 
        a\^2\ b\ y\_2\%2\ z\_4}\)], "Output",
  CellLabel->"Out[411]="]
}, Open  ]],

Cell[TextData[{
  "We now solve for ",
  Cell[BoxData[
      \({a, b}\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solns\  = \ Solve[initials \[Equal] 0, \ {a, b}]\)], "Input",
  CellLabel->"In[412]:="],

Cell[BoxData[
    \(Solve::"svars" \(\(:\)\(\ \)\) 
      "Equations may not give solutions for all \"solve\" variables."\)], \
"Message",
  CellLabel->"From In[412]:="],

Cell[BoxData[
    \({{a \[Rule] \(-\(\(b\ \((1 - 
                      x\_2)\)\)\/y\_2\)\)}, {a \[Rule] \(b\ x\_2\)\/y\_2}, {b \
\[Rule] 0}}\)], "Output",
  CellLabel->"Out[412]="]
}, Open  ]],

Cell[TextData[{
  "We thus obtain three solutions at infinity for the homogenized system \
(these are simply the directions of the three lines between any pair of the \
first three points). The number of solutions from the Bezout theorem, nine, \
counts these three, and hence there are six solutions in affine space. To \
understand why this is not generic for the mixed volume computation, note \
that the initials are identical up to a constant multiple; any random \
perturbation (say, add ",
  Cell[BoxData[
      \(b\^3\)]],
  " to the first polynomial) will give only one solution at infinity, and \
therefore yield ",
  Cell[BoxData[
      \(TraditionalForm\`8\)]],
  " finite solutions. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Purely computational proofs of theorem 1",
    FontSlant->"Italic"],
  ": We can form a Gr\[ODoubleDot]bner basis with respect to a degree based \
term ordering for the polynomials we created in proposition 1. Looking at the \
head terms we find that there are 6 monomials in ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " that lie are not reducible with respect to this basis and hence 6 \
solutions to the system  [9] [10]."
}], "Text"],

Cell[TextData[{
  "Alternatively we can compute the resultant of the pair of polynomials with \
respect to one of the two variables. We obtain a (very large) polynomial of \
degree 6 in the other. This means there are at most 6 solutions. As we \
already know there can be that many, this suffices to show that there are \
generically 6 solutions. ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Square]\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": It may be useful to look at theorem 1 in the context of what are known \
as comprehensive Gr\[ODoubleDot]bner bases [3] [32]. This construction in \
effect allows one to circumvent the problem that Gr\[ODoubleDot]bner bases \
are not continuous in their input data (and indeed it seems designed in part \
for the purpose of addressing that defect). Such a basis contains encoded all \
Gr\[ODoubleDot]bner bases for a given ideal under all specializations of the \
parameters. It does so in essence by doing multiple polynomial reductions, in \
the sense of Gr\[ODoubleDot]bner basis literature, on a given polynomial in \
the basis. This has the desirable effect of allowing for the possibility that \
any (nonnumeric) leading coefficients may be zero. The upshot is that the \
coefficients of the comprehensive Gr\[ODoubleDot]bner basis vary continuously \
in the parameters of the configuration. The typical use of such a basis is in \
concrete examples when one wishes to make case distinctions based on \
parameter values. When a lexicographic term ordering is utilized we can say a \
bit about the structure of such bases in the (generic) case of finite \
solution sets, using insight gained from our examples."
}], "Text"],

Cell[TextData[{
  "For instance, suppose we have six distinct solutions in a situation where \
the Shape Lemma does not apply (we have seen this in the two examples where \
we obtained six real valued cylinders; in one case all radii were equal and \
in the other there were two distinct radii, but of course the cylinders were \
all distinct in both examples). Then the degree of the univariate polynomial \
in this variable (say, ",
  Cell[BoxData[
      \(r\)]],
  "), in a lexicographic Gr\[ODoubleDot]bner basis, must be less than six \
(otherwise we would have solutions with multiplicity). We also know from the \
Shape Lemma that the comprehensive Gr\[ODoubleDot]bner basis with respect to \
the same lexicographic term ordering must contain linear polynomials in each \
of the higher variables, with lead coefficients that generically do not \
vanish. But by [21] one or more such linear polynomials must vanish for the \
type of example under consideration (otherwise we would have fewer than six \
solutions). Hence there must be, in the comprehensive basis, polynomials of \
higher degree in those variables. Again invoking results from [21] we know \
that for the corresponding linear polynomials, when their coefficients do not \
vanish, they are satisfied at values for which their higher degree \
counterparts must also be satisfied. So such a linear polynomial (say, in the \
variable ",
  Cell[BoxData[
      \(b\)]],
  ") must have the form"
}], "Text"],

Cell[BoxData[
    \(p[parameters]\ \((b - q[r])\)\)], "DisplayFormula"],

Cell[TextData[{
  "where the second factor divides any corresponding polynomial(s) of higher \
degree in ",
  Cell[BoxData[
      \(b\)]],
  ". In other words, when the first factor, which involves only parameters, \
is nonzero, then where the second is satisfied all those in higher degree \
must also be satisfied; moreover they cannot all vanish when the first factor \
vanishes, so they must be divisible by the second factor."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nongeneric configurations", "Subsection"],

Cell["\<\
Thus far we have discussed exclusively the generic situation. It is \
of interest to make a few observations about the nongeneric case. This in \
turn sheds light on cylinder solutions for point configurations that are \
generic but \"near\" to such nongeneric ones.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Proposition 4",
    FontSlant->"Italic"],
  ": Sets of five coplanar points are not generic insofar as they do not give \
six solutions to the cylinder equations. In general they give four such \
solutions."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontSlant->"Italic"],
  ": This follows from the computation performed in the proof of proposition \
1. We take the pair of polynomials generated, substitute zero for the two \
nontrivial ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " parameters, and compute a Gr\[ODoubleDot]bner basis in terms of the \
cylinder normal parameters ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  ". This is in the form specified by the shape lemma, and has a univariate \
polynomial of degree four with a second polynomial linear in the remaining \
variable. Hence for coplanar configurations there are generically four \
solutions rather than six. Of course there are further degeneracies that can \
arise. For example, if four of the points are collinear then there will be \
infinitely many cylinders containing all five. To finish the proof we must \
show that there are no cylinders parallel to the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " coordinate plane (as we tacitly set the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " coordinate of the normal vector to ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ").  But this is clear from the fact that such a cylinder would intersect \
the coordinate plane in a pair of lines, and generically the five coplanar \
points do not lie on any pair of lines.",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary",
    FontSlant->"Italic"],
  ": As configurations of five points move toward a (generic) coplanar \
configuration, two of the six (possibly complex) cylinder solutions go to \
infinity."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": This shows that in any comprehensive Gr\[ODoubleDot]bner basis for the \
system, using a lexicographic ordering, the univariate polynomial of generic \
degree six has leading and second coefficients vanish when the points are \
coplanar. The third coefficient will in general not vanish in this situation. \
Note also that the solutions set at infinity, consisting of three direction \
values, was computed in a way that implicitly depended on the five points not \
being coplanar. Hence the corollary does not conflict with our prior count of \
solutions at infinity."
}], "Text"],

Cell["\<\
We give a converse to proposition 4. We state it as a conjecture \
because the proof is not rigorous in all details.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Conjecture",
    FontSlant->"Italic"],
  ": Any nongeneric configuration of five distinct points must be coplanar."
}], "Text"],

Cell[TextData[{
  StyleBox["Idea of proof",
    FontSlant->"Italic"],
  ": First assume no three points are collinear. We need to show that there \
cannot be a dimensional component of solutions. For this to happen, the \
algebraic curves that are solution sets to the two polynomial equations for \
two direction variables must share a component. That is, on a component of \
directions in which four points project onto a circle, the fifth must project \
onto that same circle. But for the first three points fixed and no three \
collinear, that direction curve component uniquely defines the fourth point. \
Hence the fifth must coincide with one of the other four. The case of three \
points collinear forces the direction vector to define that line, and one \
must look at the other cylinder parameters to deduce a contradiction. The \
fifth point cannot lie on the line containing the threesome (otherwise the \
five are coplanar). As the set of cylinders containing the first four now \
uniquely defines the line containing the fourth and parallel to the cylinder \
axis (that is, parallel to the line containing the collinear threesome), the \
fifth must lie on that line. But this too makes the five points coplanar. ",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": The above argument leads one to believe that the cases that give \
infinitely many solutions involve either four collinear points or three \
collinear with the line between the remaining two parallel to the collinear \
triad. Further evidence to support this may be deduced from dimensional \
considerations. First note that, once three noncollinear points are fixed in \
a plane, there are finitely many ways to combine the remaining two points \
such that one of the above conditions holds. For any such combination, there \
are two degrees of freedom in how the points are placed. Now observe that \
cubic equations of the form imposed by our choices above has eight degrees of \
freedom (general cubics have ten coefficients but ours lose one degree three \
term, and the cubics are only defined up to nonzero scalar multiplication, \
giving eight degrees of freedom). Hence pairs of cubics of that form have \
sixteen parameters. The set of pairs we can actually attain has eight degrees \
of freedom (from the eight coordinates not a priori known). In order that a \
pair share a component, they must factor (they cannot be identical unless a \
pair of points coincides, in contradiction of hypotheses). The set of pairs \
that share a common factor has dimension ten. Thus we expect the dimension of \
the set of attainable cubic pairs that share a component to be given by the \
intersection dimension, which is two."
}], "Text"],

Cell["We now describe what happens in the generic coplanar case.", "Text"],

Cell[TextData[{
  StyleBox["Theorem 5",
    FontSlant->"Italic"],
  ": Given five coplanar points",
  " in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " there are four (complex) cylinders containing them. Of those, either zero \
or two will be real cylinders."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": It is interesting to note that the full set of four solutions cannot all \
be real valued."
}], "Text"],

Cell[TextData[{
  StyleBox["Proof",
    FontSlant->"Italic"],
  ": That there are four complex cylinders was noted in the proof to \
proposition 4. As is well known, the five points uniquely determine a \
quadratic curve in the plane in which they lie. The intersection of a \
cylinder with a plane is likewise a quadratic in that plane, and hence any \
cylinder containing five coplanar points contains the entire quadratic curve \
they determine.  If that curve is a hyperbola then no (real) cylinder can \
contain it. If instead it is an ellipse then there are two cylinders that \
contain it. These cylinders have radial axes that each go through the center \
of the ellipse and lie in the plane perpendicular to the ellipse minor axis. \
Their angle of intersection is determined by the eccentricity of the ellipse. \
",
  Cell[BoxData[
      \(\[Square]\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["Corollary",
    FontSlant->"Italic"],
  ": Five point configurations sufficiently close to coplanar are contained \
by at most two real cylinders."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark",
    FontSlant->"Italic"],
  ": The example we constructed from a pair of elongated tetrahedra that \
gives no real cylinders is a case where a configuration approaches \
coplanarity."
}], "Text"],

Cell[TextData[{
  "We can use the computational construction of proposition 1 to shed light \
on the problem of counting the number of cylinders of a given fixed radius \
through four points (which, as noted in [26], is equivalent to the problem of \
counting the number of lines simultaneously tangent to four given spheres of \
equal radius). As the radius is fixed (say, to ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  "), we are no longer free to rescale so we would use ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_1, 0, 0}\)]],
  " for our second point. We would modify ",
  StyleBox["circle ", "Input"],
  "to use only two points along with the given radius. One change now is that \
for projections of two points onto any given plane, there are two circles of \
the given radius containing them. This ansatz would lead us to expect twice \
as many solutions for this problem as we obtained for counting cylinders \
through five points. That there are in fact twelve (not necessarily real \
valued) cylinders of given radius through four generically placed points is a \
theorem in [26]. In the special case that the points are coplanar, that there \
are eight such cylinders is a result of [27]. In contrast to theorem 5 above, \
all of them can be real valued."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A partial converse to theorem 4", "Subsection"],

Cell["\<\
We wish to show that all configurations that give no real cylinders \
arise in the setting of theorem 4. Specifically we state the following \
conjecture.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Conjecture:",
    FontSlant->"Italic"],
  " Suppose we have a configuration of five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " for which no real cylinders exist, and moreover assume that no point lies \
in the hull of the others. Then one of the points can be moved anywhere \
inside the convex hull of the full set and still we will get no real \
cylinders. In particular we could move this point along a line segment from \
outside to inside the hull of the other four, and at no point on that path \
would we get real cylinders. Thus we could regard the given configuration as \
a perturbation of one that has one point inside the hull of the other four, \
effectively providing a converse to theorem 4."
}], "Text"],

Cell["\<\
We make observations of sufficient conditions for a proof, then \
state as a theorem a special case wherein we can fullfill the conditions. \
First we observe that the two curves in direction parameter space, as given \
by solutions to the two polynomials we constructed in proposition 1, are \
cubics that have one or more closed topological components in two dimensional \
real projective space, and because they are cubic they each have at least one \
real component that go to infinity. (It is well known that they are connected \
as complex curves; by \"components\" we mean the obvious thing with respect \
to intersections with real space.)\
\>", "Text"],

Cell["\<\
We regard each point on such a curve as a solution to the direction \
parameter equations given by the four points in configuration space lying on \
a cylinder with axis in that direction. In other words, each point on the \
solution curve in parameter space defines a cylinder through the four points \
in configuration space that were used to form that equation. Suppose that at \
solution on one such component, the fifth point lies inside the cylinder thus \
obtained (we are being loose with terminology but trust the meaning of \
\"inside a cylinder\" is clear). Then it must lie inside all cylinders \
defined by points on that affine component of the solution curve. The proof \
of this remark has a small complication. We next claim that the fifth point, \
in order to \"escape\" outside the cylinder containing the other four, must \
cross the cylinder (in contradiction to our hypothesis that there are no real \
cylinders containing all five points). A priori there is another way it might \
escape: the cylinder containing four can degenerate to a plane and \
subsequently reverse its \"open\" side, if the four points project onto a \
line for some solution direction. To see this does not happen for generic \
configurations, note that any such direction must lie in all four planes \
containing three of the four points. Thus the fifth point stays inside the \
cylinders defined by all directions on that component of the solution curve \
for directions of cylinders containing the other four points.\
\>", "Text"],

Cell["\<\
Next we observe that, were this true not just on one topological \
component of the direction solution curve, but on all of them, then that \
fifth point works in the conjecture. We see this as follows. When the fifth \
point lies inside all cylinders defined by a solution curve component, then \
it projects along the cylinder axis to a point inside the circle that \
intersects the projections of the other four. The same must hold for any \
other point in the interior of the convex hull of the five points. This is \
because such a point, written as a convex combination of the five, must \
either be in the interior of the tetrahedron defined by the first four (and \
thus project to the interior of the circle they define), or else have a \
nontrivial component of that fifth point and again project to that circle \
interior.\
\>", "Text"],

Cell[TextData[{
  "We now proceed to construct a solution on one direction curve, that is, a \
cylinder containing four of the points, such that the fifth is inside it. We \
can arrange our four so that three are in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " coordinate plane, and the remaining two have a segment joining them that \
intersects the triangle defined by the first three (such an arrangement can \
always be found for a configuration of five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  "). We place the fourth point on the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " axis beneath the origin. Projecting from the fourth point onto a plane in \
the direction of the segment between the fourth and fifth points gives a \
unique a circle containing the first three. The cylinder along that direction \
and  containing that circle thus encloses the fourth and fifth points. Now we \
simply move one of the direction coordinates, forming new projections and \
cylinders containing the first three points, until one of the remaining \
points (say, the fourth) hits that cylinder. What we have done is to arrive \
on the first of the two solution curves for the equation for directions for \
cylinders containing the first four four points, as set up in proposition \
one. We now have a cylinder containing four points and enclosing the fifth. \
From the discussion above we know that this holds for all cylinders defined \
by this affine component of the curve of directions."
}], "Text"],

Cell["\<\
At this point we have a sufficient condition for the conjecture to \
hold. We simply require that each of the solution curves have only one affine \
component.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem 6",
    FontSlant->"Italic"],
  ": Given five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " for which there are no real solutions to the cylinder equations, suppose \
there are three such that\n(i) The segment joining the remaining two lies in \
the triangle defined by those three.\n(ii) The two curves of solution \
directions for cylinders containing those three and either the fourth or \
fifth respectively, each have only one component in real projective space.\n\
Then either the fourth or fifth point can be moved anywhere inside the hull \
of the five and there will be no real cylinder containing this new point and \
the other four."
}], "Text"],

Cell[TextData[{
  "As remarked above, we can always order the points in such a way that the \
first condition holds. But then in general the second condition will not \
hold. We believe the conjecture to be true all the same, though we do not \
have a proof as yet. We also mention that extensive graphical evidence \
suggests that most often these curves have one component in two dimensional \
real projective space. This is found by taking random examples with three \
points in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\[Hyphen]y\)]],
  " coordinate plane and the fourth and fifth above and below respectively, \
throwing away those that have real solutions, throwing away from the rest \
those for which the segment between fourth and fifth points does not go \
through the triangle bounded by the first three, and plotting the zero level \
sets for the two cylinder equations in remaining cases. In any case it would \
seem that this method applies to \"most\" of the configurations that give no \
real cylinder solutions."
}], "Text"],

Cell["\<\
Indeed, we can weaken the second hypothesis of theorem 6 so that \
the curves may have multiple components, provided the components for one are \
not separated by any component of the other. Graphical evidence supports the \
belief that this weaker requirement is always satisfied. Clearly a proof to \
this effect would suffice to prove the conjecture.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Summary", "Section"],

Cell[TextData[{
  "We have discussed computational methods for finding cylinders through a \
given set of five points in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ". Along the way we have covered several related problems and computational \
approaches thereto. We have investigated the various real valued scenarios \
using first simulation and then theoretical approaches. In particular we have \
combined geometric reasoning with Gr\[ODoubleDot]bner bases and several \
related tools from computational algebra, in order to study a rich family of \
problems from enumerative and computational geometry."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. Acknowledgements", "Section"],

Cell["\<\
The author is pleased to acknowledge helpful conversations with \
Dick Bishop, John D'Angelo, Dan Grayson, and Dave Rusin (the last conducted \
via email). He thanks David Cox and Thorsten Theobald for bringing to his \
attention the earlier work of Bottema and Veldkamp. He thanks the Math \
Department of the University of Illinois for extending their hospitality \
during the academic year 1998\[Hyphen]9 when he was a visitor there, during \
which time part of this work was done. In particular he thanks Jack Wetzel \
for inviting him to speak on this topic at the weekly geometry seminar (and \
for buying him lunch anyway after having sat through said talk).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. References", "Section"],

Cell[TextData[{
  "1. W. Adams and P. Loustaunau. ",
  StyleBox["An Introduction to Gr\[ODoubleDot]bner Bases",
    FontSlant->"Italic"],
  ". Graduate Studies in Mathematics ",
  StyleBox["3",
    FontWeight->"Bold"],
  ". American ",
  StyleBox["Mathematical",
    FontVariations->{"CompatibilityType"->0}],
  " Society, 1994"
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "2. E. Becker, M. G. Marinari, T. Mora, and C. Traverso. The shape of the \
Shape Lemma. In ISSAC '94, ",
  StyleBox["Proceedings of the International Symposium on Symbolic and \
Algebraic Computation",
    FontSlant->"Italic"],
  ". 129\[Hyphen]133. ACM Press, 1994."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "3. T. Becker, W. Weispfenning, and H. Kredel. ",
  StyleBox["Gr\[ODoubleDot]bner Bases",
    FontSlant->"Italic"],
  ": ",
  StyleBox["A Computational Approach to Computer Algebra",
    FontSlant->"Italic"],
  ".  Graduate Texts in Mathematics ",
  StyleBox["141",
    FontWeight->"Bold"],
  ". Springer\[Hyphen]Verlag, 1993."
}], "Reference",
  PageBreakAbove->Automatic],

Cell["4. R. Bishop. Private communication, 1999.", "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "5. O. Bottema and G. Veldkamp. On the lines in space with equal distances \
to ",
  StyleBox["n",
    FontSlant->"Italic"],
  " given points. ",
  StyleBox["Geometriae Dedicata",
    FontSlant->"Italic"],
  " ",
  StyleBox["6",
    FontWeight->"Bold"],
  ":121\[Hyphen]129. D. Reidel Publishing Company, 1977."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "6. B. Buchberger. Gr\[ODoubleDot]bner bases: An algorithmic method in \
polynomial ideal theory. In ",
  StyleBox["Multidimensional Systems Theory",
    FontSlant->"Italic"],
  ", chap 6. N. K. Bose, ed. D. Reidel Publishing Company, 1985."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "7. B. Buchberger. Applications of Gr\[ODoubleDot]bner bases in \
non\[Hyphen]linear computational geometry. In ",
  StyleBox["Proceedings of the International Symposium on Trends in Computer \
Algebra '87",
    FontSlant->"Italic"],
  ", R. Janssen, ed. Lecture Notes in Computer Science ",
  StyleBox["296",
    FontWeight->"Bold"],
  ":52\[Hyphen]80. Springer\[Hyphen]Verlag, 1988."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "9. R. Corless. Editor's corner: Gr\[ODoubleDot]bner bases and matrix \
eigenproblems. ",
  StyleBox["ACM Sigsam Bulletin: Communications in Computer Algebra",
    FontSlant->"Italic"],
  " ",
  StyleBox["30",
    FontWeight->"Bold"],
  "(4):26\[Hyphen]32, 1996."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "10. D. Cox. Introduction to Gr\[ODoubleDot]bner bases. In ",
  StyleBox["Proceedings of Symposia in Applied Mathematics",
    FontSlant->"Italic"],
  " ",
  StyleBox["53,",
    FontWeight->"Bold"],
  " D. Cox and B. Sturmfels, eds. 1\[Hyphen]24. ACM Press, 1998."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "11. D. Cox, J. Little, and D. O'Shea. ",
  StyleBox["Ideals, Varieties, and Algorithms: An Introduction to \
Computational Algebraic Geometry and Computer Algebra",
    FontSlant->"Italic"],
  ". Undergraduate Texts in Mathematics. Springer\[Hyphen]Verlag, 1992."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "12. H. T. Croft,  K. Falconer, and R. T. Guy. ",
  StyleBox["Unsolved Problems in Geometry",
    FontSlant->"Italic"],
  ". 54\[Hyphen]55. Springer\[Hyphen]Verlag, 1991."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "13. O. Devillers, B. Mourrain, F. Preparata, and P. Trebuchet. On circular \
cylinders by four or five points in space. ",
  StyleBox["Discrete and Computational Geometry ",
    FontSlant->"Italic"],
  StyleBox["28",
    FontWeight->"Bold"],
  ":83\[Hyphen]104, 2003."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "14. O. Devillers and F. Preparata. Evaluating the cylindricity of a \
nominally cylindrical point set. In SODA 2000, ",
  StyleBox["Symposium on Discrete Algorithms",
    FontSlant->"Italic"],
  StyleBox[", pages",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontSlant->"Italic"],
  "518\[Hyphen]527, 2000."
}], "Reference",
  PageBreakAbove->Automatic],

Cell["\<\
15. C. Durand. Symbolic and Numerical Techniques for Constraint \
Solving. Ph.D thesis. Purdue University, Department of Computer Science, \
1998.\
\>", "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "16. P. Gianni. Properties of Gr\[ODoubleDot]bner bases under \
specialization. In Eurocal '87, ",
  StyleBox["European Converence on Computer Algebra",
    FontSlant->"Italic"],
  ". J. Davenport, ed. Springer Lecture Notes in Computer Science ",
  StyleBox["378",
    FontWeight->"Bold"],
  ", ",
  StyleBox["pages",
    FontVariations->{"CompatibilityType"->0}],
  " 293\[Hyphen]297. Springer\[Hyphen]Verlag, 1987."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "17. P. Gianni and T. Mora. Algebraic Solutions of systems of polynomial \
equations using Gr\[ODoubleDot]bner bases. In AAECC 5, ",
  StyleBox["Applied Algebra, Algebraic Algorithms, and Error",
    FontSlant->"Italic"],
  "\[Hyphen]",
  StyleBox["Correcting Codes",
    FontSlant->"Italic"],
  ". L. Hugeut, A. Poli, eds. Springer Lecture Notes in Computer Science ",
  StyleBox["356,",
    FontWeight->"Bold"],
  " pages 247\[Hyphen]257. Springer\[Hyphen]Verlag, 1988."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "18. C. Hoffmann. ",
  StyleBox["Geometric and Solid Modelling: An Introduction",
    FontSlant->"Italic"],
  ".  Morgan Kaufmann, 1989"
}], "Reference",
  PageBreakAbove->Automatic],

Cell["\<\
19. C. Hoffmann and B. Yuan. There are 12 common tangents to four \
spheres, 2000. Website URL: 
http://www.cs.purdue.edu/homes/cmh/distribution/SphereTangents.htm\
\>", \
"Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "20. B. Huber and B. Sturmfels. Bernstein's theorem in affine space. ",
  StyleBox["Discrete and Computational Geometry ",
    FontSlant->"Italic"],
  StyleBox["17",
    FontWeight->"Bold"],
  ":137\[Hyphen]141, 1997."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "21. M. Kalkbrenner. Solving systems of algebraic equations by using Gr\
\[ODoubleDot]bner bases. In Eurocal '87, ",
  StyleBox["European Conference on Computer Algebra",
    FontSlant->"Italic"],
  ". J. Davenport, ed. Springer Lecture Notes in Computer Science ",
  StyleBox["378",
    FontWeight->"Bold"],
  ", 282\[Hyphen]292. Springer\[Hyphen]Verlag, 1987."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "22. M. Kalkbrenner. Implicitization of rational parametric curves and \
surfaces. In AAECC8, ",
  StyleBox["Applied Algebra, Algebraic Algorithms, and Error",
    FontSlant->"Italic"],
  "\[Hyphen]",
  StyleBox["Correcting Codes",
    FontSlant->"Italic"],
  ". S. Sakata, ed. Springer Lecture Notes in Computer Science ",
  StyleBox["508",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[",",
    FontVariations->{"CompatibilityType"->0}],
  " pages 249\[Hyphen]259. Springer\[Hyphen]Verlag, 1990."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "23. I. Kotsireas. Homotopies and polynomial system solving I: Basic \
principles. A",
  StyleBox["CM Sigsam Bulletin: Communications in Computer Algebra",
    FontSlant->"Italic"],
  " ",
  StyleBox["35",
    FontWeight->"Bold"],
  "(1):19\[Hyphen]32, 2001."
}], "Reference",
  PageBreakAbove->Automatic],

Cell["\<\
24. D. Lichtblau. Usenet news post to sci.math.symbolic, 1998. \
Google URL:
http://groups.google.com/groups?q=Lichtblau+cylinder+group:sci.math.symbolic&\
hl=en&lr=&ie=UTF-8&group=sci.math.symbolic&safe=off&selm=36407D25.7E3FCDAD%\
40wolfram.com&rnum=1\
\>", "Reference",
  PageBreakAbove->Automatic],

Cell["\<\
25. D. Lichtblau. Solving finite algebraic systems using numeric Gr\
\[ODoubleDot]bner bases and eigenvalues. In SCI2000, Proceedings of the World \
Conference on Systemics, Cybernetics, and Informatics, Volume 10. (Concepts \
and Applications of Systemics, Cybernetics, and Informatics). M. Torres, J. \
Molero, Y. Kurihara, and A. David, eds., pages 555\[Hyphen]560. International \
Institute of Informatics and Systemics, 2000.\
\>", "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "26.I. G. Macdonald, J. Pach, and T. Theobald. Common tangents to four unit \
balls in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^3\)],
    FormatType->StandardForm],
  ". ",
  StyleBox["Discrete and Computational Geometry",
    FontSlant->"Italic"],
  " ",
  StyleBox["26",
    FontWeight->"Bold"],
  ":1\[Hyphen]17, 2001."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "27. G. Megyesi. Lines tangent to four unit spheres with coplanar centres. \
",
  StyleBox["Discrete and Computational Geometry ",
    FontSlant->"Italic"],
  StyleBox["26",
    FontWeight->"Bold"],
  ":493\[Hyphen]497, 2001."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "28. B. Mishra. ",
  StyleBox["Algorithmic Algebra",
    FontSlant->"Italic"],
  ". Springer\[Hyphen]Verlag, 1993."
}], "Reference",
  PageBreakAbove->Automatic],

Cell["\<\
29. D. Rusin. Private communication, 1998. Website URL:
http://www.math\[Hyphen]atlas.org/98/5pt.cyl\
\>", "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "30. B. Sturmfels. Polynomial equations and convex polytopes. ",
  StyleBox["American Mathematical Monthly",
    FontSlant->"Italic"],
  " ",
  StyleBox["105",
    FontWeight->"Bold"],
  ":907\[Hyphen]922, 1998."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "31. J. Vershelde, P. Verlinden, and R. Cools. Homotopies exploiting Newton \
polytopes for solving sparse polynomial systems. ",
  StyleBox["SIAM J. Numer. Anal.",
    FontSlant->"Italic"],
  " ",
  StyleBox["31",
    FontWeight->"Bold"],
  "(3):915\[Hyphen]930, 1994."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "32. V. Weispfenning. Comprehensive Gr\[ODoubleDot]bner bases. ",
  StyleBox["Journal of Symbolic Computation",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  " ",
  StyleBox["14",
    FontWeight->"Bold"],
  ":1\[Hyphen]29, 1992."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "33. S. Wolfram. ",
  StyleBox["The Mathematica Book",
    FontSlant->"Italic"],
  " (5th edition). Wolfram Media, 2003."
}], "Reference",
  PageBreakAbove->Automatic],

Cell[TextData[{
  "34. A. Zinani. The expected volume of a tetrahedron whose vertices are \
chosen at random in the interior of a cube. ",
  StyleBox["Monatshefte Math.",
    FontSlant->"Italic"],
  " ",
  StyleBox["139:",
    FontWeight->"Bold"],
  "341-348, 2003."
}], "Reference",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 763}},
ScreenStyleEnvironment->"Working",
WindowSize->{761, 555},
WindowMargins->{{Automatic, 5}, {Automatic, 29}},
PrintingCopies->1,
PrintingPageRange->{1, 1},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited}, {
    Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited}},
PrintingOptions->{"PrintingMargins"->{{93.5625, 79.1875}, {93.5625, \
93.5625}},
"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageFooter"->False,
"FacingPages"->False,
"FirstPageFace"->Left,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "usr2", \
"danl", "Notebooks"}, "cylinder_paper.nb.ps", CharacterEncoding -> \
"MacintoshRoman"],
"Magnification"->1},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageHeaderLines->{False, False},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{10, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Left,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{10, 30}, {4, 6}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[RawData["\<\
Cell[StyleData[\"SectionFirst\", \"Printout\"],
  FontSize->14]\
\>"],
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{18, 30}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Left,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->None,
    CellMargins->{{18, 30}, {3, 5}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->9]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 4}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 1},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 2}},
    LineSpacing->{2, 1},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {0, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {4, 4}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {0, 4}},
    ShowCellLabel->False,
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{18, Inherited}, {2, 14}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{18, Inherited}, {2, 14}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{18, Inherited}, {2, 18}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    TextAlignment->Left,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{18, Inherited}, {2, 18}},
    TextAlignment->Left,
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 20}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 20}},
    LineSpacing->{1.8, 0},
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {1, 1}},
    LineSpacing->{1.8, 0},
    FontSize->9]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 4}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Danny's new stuff", "Section"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->False,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Open  ]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 52, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[1831, 56, 148, 5, 47, "Title"],
Cell[1982, 63, 156, 3, 52, "Author"],
Cell[2141, 68, 107, 5, 76, "Address"],
Cell[2251, 75, 1230, 24, 148, "Abstract"],

Cell[CellGroupData[{
Cell[3506, 103, 44, 0, 25, "Section"],
Cell[3553, 105, 1692, 35, 137, "Text"],
Cell[5248, 142, 1133, 20, 136, "Text"],
Cell[6384, 164, 1226, 22, 125, "Text"],
Cell[7613, 188, 827, 12, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8477, 205, 61, 0, 70, "Section"],

Cell[CellGroupData[{
Cell[8563, 209, 109, 2, 70, "Subsection"],
Cell[8675, 213, 662, 10, 70, "Text"],
Cell[9340, 225, 1762, 63, 70, "Text"],
Cell[11105, 290, 2566, 64, 70, "Text"],
Cell[13674, 356, 701, 28, 70, "Text"],
Cell[14378, 386, 1385, 45, 70, "Text"],
Cell[15766, 433, 736, 25, 70, "Text"],
Cell[16505, 460, 339, 9, 70, "DisplayFormula"],
Cell[16847, 471, 191, 4, 70, "DisplayFormula"],
Cell[17041, 477, 111, 3, 70, "Text"],
Cell[17155, 482, 314, 7, 19, "Input",
  CellOpen->False],

Cell[CellGroupData[{
Cell[17494, 493, 307, 6, 70, "Input"],
Cell[17804, 501, 158, 4, 70, "Output"]
}, Open  ]],
Cell[17977, 508, 483, 9, 70, "Input"],
Cell[18463, 519, 931, 30, 70, "Text"],
Cell[19397, 551, 141, 3, 70, "Input"],
Cell[19541, 556, 134, 4, 70, "Input"],
Cell[19678, 562, 189, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[19892, 572, 77, 2, 70, "Input"],
Cell[19972, 576, 156, 3, 70, "Output"]
}, Open  ]],
Cell[20143, 582, 409, 12, 70, "Text"],
Cell[20555, 596, 340, 6, 70, "Input"],
Cell[20898, 604, 154, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[21077, 611, 217, 5, 70, "Input"],
Cell[21297, 618, 216, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21550, 627, 208, 5, 70, "Input"],
Cell[21761, 634, 229, 4, 70, "Output"]
}, Open  ]],
Cell[22005, 641, 228, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[22258, 649, 306, 6, 70, "Input"],
Cell[22567, 657, 142, 3, 70, "Message"],
Cell[22712, 662, 251, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23000, 671, 227, 5, 70, "Input"],
Cell[23230, 678, 238, 4, 70, "Output"]
}, Open  ]],
Cell[23483, 685, 196, 4, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23716, 694, 141, 5, 70, "Subsection"],
Cell[23860, 701, 800, 16, 70, "Text"],
Cell[24663, 719, 375, 9, 70, "Input"],
Cell[25041, 730, 487, 13, 70, "Text"],

Cell[CellGroupData[{
Cell[25553, 747, 113, 2, 70, "Input"],
Cell[25669, 751, 2649, 46, 70, "Output"]
}, Open  ]],
Cell[28333, 800, 314, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[28672, 810, 182, 5, 70, "Input"],
Cell[28857, 817, 80, 2, 70, "Output"]
}, Open  ]],
Cell[28952, 822, 94, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[29071, 829, 79, 2, 70, "Input"],
Cell[29153, 833, 64, 2, 70, "Output"]
}, Open  ]],
Cell[29232, 838, 424, 7, 70, "Text"],
Cell[29659, 847, 1810, 42, 70, "Text"],
Cell[31472, 891, 1063, 15, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32572, 911, 87, 2, 70, "Subsection"],
Cell[32662, 915, 739, 16, 70, "Text"],

Cell[CellGroupData[{
Cell[33426, 935, 131, 2, 70, "Input"],
Cell[33560, 939, 69, 1, 70, "Output"],
Cell[33632, 942, 207, 3, 70, "Output"]
}, Open  ]],
Cell[33854, 948, 870, 23, 70, "Text"],

Cell[CellGroupData[{
Cell[34749, 975, 202, 4, 70, "Input"],
Cell[34954, 981, 218, 3, 70, "Output"]
}, Open  ]],
Cell[35187, 987, 180, 4, 70, "Text"],
Cell[35370, 993, 1797, 25, 70, "Text"],
Cell[37170, 1020, 217, 4, 70, "Text"],
Cell[37390, 1026, 169, 4, 70, "Text"],
Cell[37562, 1032, 584, 13, 70, "Text"],
Cell[38149, 1047, 577, 10, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38775, 1063, 70, 0, 70, "Section"],

Cell[CellGroupData[{
Cell[38870, 1067, 137, 5, 70, "Subsection"],
Cell[39010, 1074, 2945, 80, 70, "Text"],
Cell[41958, 1156, 353, 8, 70, "Input"],

Cell[CellGroupData[{
Cell[42336, 1168, 390, 8, 70, "Input"],
Cell[42729, 1178, 481, 9, 70, "Output"]
}, Open  ]],
Cell[43225, 1190, 214, 8, 70, "Text"],
Cell[43442, 1200, 95, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[43562, 1207, 253, 5, 70, "Input"],
Cell[43818, 1214, 162, 3, 70, "Output"],
Cell[43983, 1219, 75, 2, 70, "Output"]
}, Open  ]],
Cell[44073, 1224, 287, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[44385, 1233, 194, 4, 70, "Input"],
Cell[44582, 1239, 61, 2, 70, "Output"]
}, Open  ]],
Cell[44658, 1244, 310, 5, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45005, 1254, 109, 2, 70, "Subsection"],
Cell[45117, 1258, 1145, 18, 70, "Text"],

Cell[CellGroupData[{
Cell[46287, 1280, 379, 8, 70, "Input"],
Cell[46669, 1290, 144, 3, 70, "Output"]
}, Open  ]],
Cell[46828, 1296, 734, 16, 70, "Text"],

Cell[CellGroupData[{
Cell[47587, 1316, 598, 14, 70, "Input"],
Cell[48188, 1332, 144, 3, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[48381, 1341, 95, 2, 70, "Subsection"],
Cell[48479, 1345, 1240, 23, 70, "Text"],
Cell[49722, 1370, 812, 15, 70, "Input"],
Cell[50537, 1387, 69, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[50631, 1391, 388, 9, 70, "Input"],
Cell[51022, 1402, 2741, 46, 70, "Output"]
}, Open  ]],
Cell[53778, 1451, 290, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[54093, 1460, 212, 5, 70, "Input"],
Cell[54308, 1467, 198, 4, 70, "Output"]
}, Open  ]],
Cell[54521, 1474, 116, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[54662, 1481, 174, 4, 70, "Input"],
Cell[54839, 1487, 236, 4, 70, "Output"]
}, Open  ]],
Cell[55090, 1494, 63, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[55178, 1498, 437, 10, 70, "Input"],
Cell[55618, 1510, 270, 5, 70, "Output"]
}, Open  ]],
Cell[55903, 1518, 200, 4, 70, "Text"],
Cell[56106, 1524, 924, 14, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57067, 1543, 131, 5, 70, "Subsection"],
Cell[57201, 1550, 682, 13, 70, "Text"],
Cell[57886, 1565, 864, 16, 70, "Input"],
Cell[58753, 1583, 999, 20, 70, "Input"],
Cell[59755, 1605, 358, 8, 70, "Text"],
Cell[60116, 1615, 208, 4, 70, "Input"],
Cell[60327, 1621, 70, 1, 70, "Input"],
Cell[60400, 1624, 504, 10, 70, "Input"],

Cell[CellGroupData[{
Cell[60929, 1638, 104, 2, 70, "Input"],
Cell[61036, 1642, 111, 2, 70, "Output"]
}, Open  ]],
Cell[61162, 1647, 274, 9, 70, "Text"],
Cell[61439, 1658, 273, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[61737, 1669, 88, 2, 70, "Input"],
Cell[61828, 1673, 983, 17, 70, "Output"]
}, Open  ]],
Cell[62826, 1693, 55, 0, 70, "Text"],

Cell[CellGroupData[{
Cell[62906, 1697, 230, 6, 70, "Input"],
Cell[63139, 1705, 197095, 7782, 70, 105618, 6648, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[260249, 9490, 1140, 16, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[261438, 9512, 70, 0, 70, "Section"],

Cell[CellGroupData[{
Cell[261533, 9516, 85, 2, 70, "Subsection"],
Cell[261621, 9520, 702, 11, 70, "Text"],
Cell[262326, 9533, 246, 5, 70, "Input"],
Cell[262575, 9540, 195, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[262795, 9549, 478, 10, 70, "Input"],
Cell[263276, 9561, 83, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263396, 9568, 363, 8, 70, "Input"],
Cell[263762, 9578, 54, 1, 70, "Output"]
}, Open  ]],
Cell[263831, 9582, 539, 10, 70, "Text"],
Cell[264373, 9594, 256, 5, 70, "Text"],
Cell[264632, 9601, 1120, 21, 70, "Input"],
Cell[265755, 9624, 219, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[265999, 9634, 153, 4, 70, "Input"],
Cell[266155, 9640, 95, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[266287, 9647, 243, 5, 70, "Input"],
Cell[266533, 9654, 64, 2, 70, "Output"],
Cell[266600, 9658, 77, 2, 70, "Output"]
}, Open  ]],
Cell[266692, 9663, 380, 6, 70, "Text"],
Cell[267075, 9671, 1357, 29, 70, "Text"],
Cell[268435, 9702, 459, 13, 70, "Text"],
Cell[268897, 9717, 143, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[269065, 9724, 485, 8, 70, "Input"],
Cell[269553, 9734, 81, 2, 70, "Output"]
}, Open  ]],
Cell[269649, 9739, 445, 11, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[270131, 9755, 102, 2, 70, "Subsection"],
Cell[270236, 9759, 2117, 53, 70, "Text"],

Cell[CellGroupData[{
Cell[272378, 9816, 314, 6, 70, "Input"],
Cell[272695, 9824, 199, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272931, 9833, 191, 5, 70, "Input"],
Cell[273125, 9840, 152362, 7315, 70, 103112, 6702, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[425502, 17158, 484, 10, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[426023, 17173, 108, 2, 70, "Subsection"],
Cell[426134, 17177, 797, 12, 70, "Text"],

Cell[CellGroupData[{
Cell[426956, 17193, 383, 8, 70, "Input"],
Cell[427342, 17203, 1011, 17, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[428390, 17225, 169, 4, 70, "Input"],
Cell[428562, 17231, 354, 6, 70, "Output"]
}, Open  ]],
Cell[428931, 17240, 648, 15, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[429628, 17261, 75, 0, 70, "Section"],

Cell[CellGroupData[{
Cell[429728, 17265, 55, 1, 70, "Subsection"],
Cell[429786, 17268, 218, 4, 70, "Text"],
Cell[430007, 17274, 306, 8, 70, "Text"],
Cell[430316, 17284, 1448, 32, 70, "Text"],
Cell[431767, 17318, 687, 15, 70, "Input"],
Cell[432457, 17335, 654, 12, 70, "Input"],

Cell[CellGroupData[{
Cell[433136, 17351, 369, 8, 70, "Input"],
Cell[433508, 17361, 1340, 20, 70, "Output"]
}, Open  ]],
Cell[434863, 17384, 129, 4, 70, "Text"],
Cell[434995, 17390, 197, 5, 70, "Text"],
Cell[435195, 17397, 505, 9, 70, "Text"],
Cell[435703, 17408, 171, 5, 70, "Text"],
Cell[435877, 17415, 245, 8, 70, "Text"],
Cell[436125, 17425, 1052, 19, 70, "Text"],
Cell[437180, 17446, 264, 8, 70, "Text"],
Cell[437447, 17456, 94, 3, 70, "Text"],
Cell[437544, 17461, 596, 11, 70, "Text"],
Cell[438143, 17474, 205, 5, 70, "Text"],
Cell[438351, 17481, 1098, 18, 70, "Text"],
Cell[439452, 17501, 720, 20, 70, "Text"],
Cell[440175, 17523, 328, 11, 70, "Text"],
Cell[440506, 17536, 621, 12, 70, "Text"],
Cell[441130, 17550, 188, 5, 70, "Text"],
Cell[441321, 17557, 632, 12, 70, "Text"],
Cell[441956, 17571, 173, 5, 70, "Text"],
Cell[442132, 17578, 336, 8, 70, "Text"],
Cell[442471, 17588, 622, 12, 70, "Text"],
Cell[443096, 17602, 280, 8, 70, "Text"],
Cell[443379, 17612, 537, 14, 70, "Text"],
Cell[443919, 17628, 693, 11, 70, "Text"],
Cell[444615, 17641, 1079, 19, 70, "Text"],
Cell[445697, 17662, 918, 18, 70, "Text"],
Cell[446618, 17682, 1593, 26, 70, "Text"],
Cell[448214, 17710, 459, 14, 70, "Text"],
Cell[448676, 17726, 496, 9, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[449209, 17740, 61, 0, 70, "Subsection"],
Cell[449273, 17742, 497, 11, 70, "Text"],
Cell[449773, 17755, 126, 2, 70, "DisplayFormula"],
Cell[449902, 17759, 655, 16, 70, "Text"],
Cell[450560, 17777, 1284, 39, 70, "Text"],
Cell[451847, 17818, 1182, 37, 70, "Text"],
Cell[453032, 17857, 182, 4, 70, "Text"],
Cell[453217, 17863, 136, 2, 70, "Input"],
Cell[453356, 17867, 322, 8, 70, "Text"],
Cell[453681, 17877, 706, 16, 70, "Text"],
Cell[454390, 17895, 1388, 30, 70, "Text"],
Cell[455781, 17927, 618, 12, 70, "Text"],
Cell[456402, 17941, 82, 1, 70, "DisplayFormula"],
Cell[456487, 17944, 1148, 27, 70, "Text"],
Cell[457638, 17973, 325, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[457988, 17984, 303, 6, 70, "Input"],
Cell[458294, 17992, 342, 6, 70, "Output"]
}, Open  ]],
Cell[458651, 18001, 92, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[458768, 18010, 107, 2, 70, "Input"],
Cell[458878, 18014, 169, 4, 70, "Message"],
Cell[459050, 18020, 181, 4, 70, "Output"]
}, Open  ]],
Cell[459246, 18027, 748, 17, 70, "Text"],
Cell[459997, 18046, 479, 10, 70, "Text"],
Cell[460479, 18058, 414, 8, 70, "Text"],
Cell[460896, 18068, 1296, 19, 70, "Text"],
Cell[462195, 18089, 1472, 25, 70, "Text"],
Cell[463670, 18116, 71, 1, 70, "DisplayFormula"],
Cell[463744, 18119, 443, 9, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[464224, 18133, 47, 0, 70, "Subsection"],
Cell[464274, 18135, 290, 5, 70, "Text"],
Cell[464567, 18142, 247, 6, 70, "Text"],
Cell[464817, 18150, 1432, 32, 70, "Text"],
Cell[466252, 18184, 237, 6, 70, "Text"],
Cell[466492, 18192, 649, 11, 70, "Text"],
Cell[467144, 18205, 140, 3, 70, "Text"],
Cell[467287, 18210, 155, 4, 70, "Text"],
Cell[467445, 18216, 1278, 20, 70, "Text"],
Cell[468726, 18238, 1505, 22, 70, "Text"],
Cell[470234, 18262, 74, 0, 70, "Text"],
Cell[470311, 18264, 289, 9, 70, "Text"],
Cell[470603, 18275, 171, 5, 70, "Text"],
Cell[470777, 18282, 875, 16, 70, "Text"],
Cell[471655, 18300, 187, 5, 70, "Text"],
Cell[471845, 18307, 232, 6, 70, "Text"],
Cell[472080, 18315, 1293, 22, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[473410, 18342, 53, 0, 70, "Subsection"],
Cell[473466, 18344, 178, 4, 70, "Text"],
Cell[473647, 18350, 777, 14, 70, "Text"],
Cell[474427, 18366, 671, 10, 70, "Text"],
Cell[475101, 18378, 1540, 21, 70, "Text"],
Cell[476644, 18401, 857, 13, 70, "Text"],
Cell[477504, 18416, 1553, 26, 70, "Text"],
Cell[479060, 18444, 183, 4, 70, "Text"],
Cell[479246, 18450, 719, 14, 70, "Text"],
Cell[479968, 18466, 1049, 17, 70, "Text"],
Cell[481020, 18485, 377, 6, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[481446, 18497, 29, 0, 70, "Section"],
Cell[481478, 18499, 636, 11, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[482151, 18515, 38, 0, 70, "Section"],
Cell[482192, 18517, 689, 10, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[482918, 18532, 32, 0, 70, "Section"],
Cell[482953, 18534, 374, 12, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[483330, 18548, 332, 8, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[483665, 18558, 391, 12, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[484059, 18572, 92, 1, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[484154, 18575, 375, 13, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[484532, 18590, 305, 7, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[484840, 18599, 449, 11, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[485292, 18612, 327, 10, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[485622, 18624, 328, 9, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[485953, 18635, 328, 7, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[486284, 18644, 235, 6, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[486522, 18652, 333, 9, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[486858, 18663, 395, 11, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[487256, 18676, 204, 5, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[487463, 18683, 482, 13, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[487948, 18698, 536, 13, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[488487, 18713, 200, 6, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[488690, 18721, 223, 6, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[488916, 18729, 282, 8, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[489201, 18739, 426, 10, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[489630, 18751, 598, 16, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[490231, 18769, 323, 10, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[490557, 18781, 311, 7, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[490871, 18790, 488, 8, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[491362, 18800, 414, 14, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[491779, 18816, 290, 9, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[492072, 18827, 179, 6, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[492254, 18835, 158, 4, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[492415, 18841, 276, 9, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[492694, 18852, 334, 10, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[493031, 18864, 321, 10, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[493355, 18876, 185, 6, 70, "Reference",
  PageBreakAbove->Automatic],
Cell[493543, 18884, 312, 10, 70, "Reference",
  PageBreakAbove->Automatic]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

